--
--  Copyright (C) 2014-2022, AdaCore
--  SPDX-License-Identifier: Apache-2.0
--

with Ada.Containers;                  use Ada.Containers;
with Ada.Containers.Hashed_Maps;
with Ada.Containers.Vectors;
with Ada.Directories;
with Ada.Exceptions;
with Ada.Finalization;
with Ada.Strings.Unbounded; use Ada.Strings.Unbounded;
with Ada.Strings.Wide_Wide_Unbounded; use Ada.Strings.Wide_Wide_Unbounded;
pragma Warnings (Off, "internal");
with Ada.Strings.Wide_Wide_Unbounded.Aux;
use Ada.Strings.Wide_Wide_Unbounded.Aux;
pragma Warnings (On, "internal");
with Ada.Text_IO;                     use Ada.Text_IO;
with Ada.Unchecked_Conversion;
with Ada.Unchecked_Deallocation;
with System;
with GNAT.Task_Lock;
with GNAT.Traceback.Symbolic;
with GNATCOLL.Traces;
with Langkit_Support.Adalog.Debug;
with Langkit_Support.Hashes; use Langkit_Support.Hashes;
with Langkit_Support.Images; use Langkit_Support.Images;
with Langkit_Support.Relative_Get;
with Libadalang.Private_Converters;
use Libadalang.Private_Converters;
with Libadalang.Introspection_Implementation;
pragma Warnings (Off, "referenced");
          with Ada.Containers.Hashed_Sets;
          with Libadalang.Env_Hooks;
            use Libadalang.Env_Hooks;
          with Libadalang.Implementation.Extensions;
            use Libadalang.Implementation.Extensions;
          with Libadalang.Internal_Default_Provider;
          with Libadalang.Sources;
pragma Warnings (On, "referenced");
package body Libadalang.Implementation is
   use Precomputed_Symbols;
   pragma Warnings (Off, "has no effect");
   use Solver;
   pragma Warnings (On, "has no effect");
   package Context_Vectors is new Ada.Containers.Vectors
     (Index_Type   => Positive,
      Element_Type => Internal_Context);
   type Contexts_Destructor is limited
      new Ada.Finalization.Limited_Controlled with null record;
   overriding procedure Finalize (CD : in out Contexts_Destructor);
   --  Helper to destroy all contexts when terminating the process
   package Context_Pool is
      procedure Acquire (Context : out Internal_Context)
         with Post => Context /= null;
      --  If a context is free for reuse, increment its serial number and
      --  return it. Otherwise, allocate a new one. In any case, this does not
      --  initialize it, except for the Serial_Number field.
      procedure Release (Context : in out Internal_Context)
         with Pre  => Context /= null,
              Post => Context = null;
      --  Tag Context as free for reuse and set it to null
      procedure Free;
      --  Free all contexts in this pool. Intended to be called only when the
      --  process is terminating, to avoid reported memory leaks.
   private
      Available : Context_Vectors.Vector;
      --  List of allocated contexts that can be re-used right now
      CD : Contexts_Destructor with Unreferenced;
      --  Singleton whose only purpose is to free all contexts in Available
      --  when finalized.
   end Context_Pool;
   procedure Register_Destroyable_Helper
     (Unit    : Internal_Unit;
      Object  : System.Address;
      Destroy : Destroy_Procedure);
   --  Common underlying implementation for Register_Destroyable_Gen
   pragma Warnings (Off, "referenced");
   function Construct_Entity_Array
     (V : AST_Envs.Entity_Vectors.Vector) return Internal_Entity_Array_Access;
   pragma Warnings (On, "referenced");
   procedure Destroy (Env : in out Lexical_Env_Access);
   function Snaps_At_Start (Self : Bare_Ada_Node) return Boolean;
   function Snaps_At_End (Self : Bare_Ada_Node) return Boolean;
   --  Those maps are used to give unique ids to lexical envs while pretty
   --  printing them.
   package Address_To_Id_Maps is new Ada.Containers.Hashed_Maps
     (Lexical_Env, Integer, Hash, "=");
   type Dump_Lexical_Env_State is record
      Env_Ids : Address_To_Id_Maps.Map;
      --  Mapping: Lexical_Env -> Integer, used to remember which unique Ids we
      --  assigned to the lexical environments we found.
      Next_Id : Positive := 1;
      --  Id to assign to the next unknown lexical environment
      Root_Env : Lexical_Env;
      --  Lexical environment we consider a root (this is the Root_Scope from
      --  the current analysis context), or null if unknown.
   end record;
   --  Holder for the state of lexical environment dumpers
   function Get_Env_Id
     (E : Lexical_Env; State : in out Dump_Lexical_Env_State) return String;
   --  If E is known, return its unique Id from State. Otherwise, assign it a
   --  new unique Id and return it.
   ------------------------
   -- Precomputed_Symbol --
   ------------------------
   pragma Warnings (Off, "referenced");
   function Precomputed_Symbol
     (Index : Precomputed_Symbol_Index) return Text_Type is
   pragma Warnings (On, "referenced");
   begin
         declare
            Raw_Text : constant Text_Type := (case Index is
               when Precomputed_Sym => """&""",
               when Precomputed_Sym_1 => """&""""+""",
               when Precomputed_Sym_10 => """=""",
               when Precomputed_Sym_11 => """>""",
               when Precomputed_Sym_12 => """>=""",
               when Precomputed_Sym_2 => """*""",
               when Precomputed_Sym_20 => "<<>>",
               when Precomputed_Sym_3 => """**""",
               when Precomputed_Sym_4 => """+""",
               when Precomputed_Sym_5 => """-""",
               when Precomputed_Sym_6 => """/""",
               when Precomputed_Sym_7 => """/=""",
               when Precomputed_Sym_8 => """<""",
               when Precomputed_Sym_9 => """<=""",
               when Precomputed_Sym_Abort => "abort",
               when Precomputed_Sym_Abort_Signal => "Abort_Signal",
               when Precomputed_Sym_Abort_Signal_259 => "abort_signal_",
               when Precomputed_Sym_Abs => """abs""",
               when Precomputed_Sym_Abs_260 => "abs",
               when Precomputed_Sym_Abstract => "abstract",
               when Precomputed_Sym_Abstract_State => "Abstract_State",
               when Precomputed_Sym_Accept => "accept",
               when Precomputed_Sym_Access => "Access",
               when Precomputed_Sym_Access_263 => "access",
               when Precomputed_Sym_Ada => "Ada",
               when Precomputed_Sym_Ada_264 => "ada",
               when Precomputed_Sym_Address => "Address",
               when Precomputed_Sym_Address_Size => "Address_Size",
               when Precomputed_Sym_Adjacent => "Adjacent",
               when Precomputed_Sym_Adjacent_265 => "adjacent",
               when Precomputed_Sym_Aft => "Aft",
               when Precomputed_Sym_Aliased => "aliased",
               when Precomputed_Sym_Alignment => "Alignment",
               when Precomputed_Sym_All => "all",
               when Precomputed_Sym_And => """and""",
               when Precomputed_Sym_And_268 => "and",
               when Precomputed_Sym_Array => "array",
               when Precomputed_Sym_Asm_Input => "Asm_Input",
               when Precomputed_Sym_Asm_Input_270 => "asm_input",
               when Precomputed_Sym_Asm_Input_Operand => "Asm_Input_Operand",
               when Precomputed_Sym_Asm_Output => "Asm_Output",
               when Precomputed_Sym_Asm_Output_271 => "asm_output",
               when Precomputed_Sym_Asm_Output_Operand => "Asm_Output_Operand",
               when Precomputed_Sym_Assert => "Assert",
               when Precomputed_Sym_Assert_And_Cut => "Assert_And_Cut",
               when Precomputed_Sym_Assume => "Assume",
               when Precomputed_Sym_Asynchronous => "Asynchronous",
               when Precomputed_Sym_At => "at",
               when Precomputed_Sym_Atomic => "Atomic",
               when Precomputed_Sym_Atomic_Components => "Atomic_Components",
               when Precomputed_Sym_Attach_Handler => "Attach_Handler",
               when Precomputed_Sym_Aux_Dec => "Aux_DEC",
               when Precomputed_Sym_Base => "Base",
               when Precomputed_Sym_Begin => "begin",
               when Precomputed_Sym_Bit_Order => "Bit_Order",
               when Precomputed_Sym_Body => "body",
               when Precomputed_Sym_Boolean => "Boolean",
               when Precomputed_Sym_Buffer => "Buffer",
               when Precomputed_Sym_Callable => "Callable",
               when Precomputed_Sym_Caller => "Caller",
               when Precomputed_Sym_Case => "case",
               when Precomputed_Sym_Ceiling => "Ceiling",
               when Precomputed_Sym_Ceiling_276 => "ceiling",
               when Precomputed_Sym_Character => "Character",
               when Precomputed_Sym_Class => "Class",
               when Precomputed_Sym_Compile_Time_Error => "Compile_Time_Error",
               when Precomputed_Sym_Compile_Time_Warning => "Compile_Time_Warning",
               when Precomputed_Sym_Component_Size => "Component_Size",
               when Precomputed_Sym_Compose => "Compose",
               when Precomputed_Sym_Compose_277 => "compose",
               when Precomputed_Sym_Constant => "constant",
               when Precomputed_Sym_Constant_Indexing => "Constant_Indexing",
               when Precomputed_Sym_Constrained => "Constrained",
               when Precomputed_Sym_Contract_Cases => "Contract_Cases",
               when Precomputed_Sym_Convention => "Convention",
               when Precomputed_Sym_Copy_Sign => "Copy_Sign",
               when Precomputed_Sym_Copy_Sign_279 => "copy_sign",
               when Precomputed_Sym_Count => "Count",
               when Precomputed_Sym_Cursor => "Cursor",
               when Precomputed_Sym_Debug => "Debug",
               when Precomputed_Sym_Declare => "declare",
               when Precomputed_Sym_Default_Bit_Order => "Default_Bit_Order",
               when Precomputed_Sym_Default_Initial_Condition => "Default_Initial_Condition",
               when Precomputed_Sym_Definite => "Definite",
               when Precomputed_Sym_Delay => "delay",
               when Precomputed_Sym_Delta => "Delta",
               when Precomputed_Sym_Delta_282 => "delta",
               when Precomputed_Sym_Depends => "Depends",
               when Precomputed_Sym_Descriptor_Size => "Descriptor_Size",
               when Precomputed_Sym_Digits => "Digits",
               when Precomputed_Sym_Digits_283 => "digits",
               when Precomputed_Sym_Discard_Names => "Discard_Names",
               when Precomputed_Sym_Do => "do",
               when Precomputed_Sym_Dummy => "__dummy",
               when Precomputed_Sym_Duration => "Duration",
               when Precomputed_Sym_Dynamic_Predicate => "Dynamic_Predicate",
               when Precomputed_Sym_Elaborate_Body => "Elaborate_Body",
               when Precomputed_Sym_Element => "Element",
               when Precomputed_Sym_Else => "else",
               when Precomputed_Sym_Elsif => "elsif",
               when Precomputed_Sym_End => "end",
               when Precomputed_Sym_Ensures => "Ensures",
               when Precomputed_Sym_Entry => "entry",
               when Precomputed_Sym_Enum_Rep => "Enum_Rep",
               when Precomputed_Sym_Enum_Rep_289 => "enum_rep",
               when Precomputed_Sym_Enum_Val => "Enum_Val",
               when Precomputed_Sym_Enum_Val_290 => "enum_val",
               when Precomputed_Sym_Epsilon => "Epsilon",
               when Precomputed_Sym_Exception => "exception",
               when Precomputed_Sym_Exception_Id => "Exception_Id",
               when Precomputed_Sym_Exception_Occurrence => "Exception_Occurrence",
               when Precomputed_Sym_Exceptions => "Exceptions",
               when Precomputed_Sym_Exit => "exit",
               when Precomputed_Sym_Exponent => "Exponent",
               when Precomputed_Sym_Exponent_293 => "exponent",
               when Precomputed_Sym_Export => "Export",
               when Precomputed_Sym_External_Tag => "External_Tag",
               when Precomputed_Sym_Finalization_Size => "Finalization_Size",
               when Precomputed_Sym_First => "First",
               when Precomputed_Sym_First_Bit => "First_Bit",
               when Precomputed_Sym_Fixed_Value => "Fixed_Value",
               when Precomputed_Sym_Fixed_Value_294 => "fixed_value",
               when Precomputed_Sym_Floor => "Floor",
               when Precomputed_Sym_Floor_295 => "floor",
               when Precomputed_Sym_For => "for",
               when Precomputed_Sym_Fore => "Fore",
               when Precomputed_Sym_Fraction => "Fraction",
               when Precomputed_Sym_Fraction_297 => "fraction",
               when Precomputed_Sym_Function => "function",
               when Precomputed_Sym_Generic => "generic",
               when Precomputed_Sym_Ghost => "Ghost",
               when Precomputed_Sym_Global => "Global",
               when Precomputed_Sym_Goto => "goto",
               when Precomputed_Sym_Has_Access_Values => "Has_Access_Values",
               when Precomputed_Sym_Has_Discriminants => "Has_Discriminants",
               when Precomputed_Sym_Has_Tagged_Values => "Has_Tagged_Values",
               when Precomputed_Sym_Identity => "Identity",
               when Precomputed_Sym_If => "if",
               when Precomputed_Sym_Image => "Image",
               when Precomputed_Sym_Image_302 => "image",
               when Precomputed_Sym_Img => "Img",
               when Precomputed_Sym_Implicit_Dereference => "Implicit_Dereference",
               when Precomputed_Sym_Import => "Import",
               when Precomputed_Sym_Import_Function => "Import_Function",
               when Precomputed_Sym_Import_Procedure => "Import_Procedure",
               when Precomputed_Sym_In => "in",
               when Precomputed_Sym_Independent => "Independent",
               when Precomputed_Sym_Independent_Components => "Independent_Components",
               when Precomputed_Sym_Index => "Index",
               when Precomputed_Sym_Initialized => "Initialized",
               when Precomputed_Sym_Inline => "Inline",
               when Precomputed_Sym_Input => "Input",
               when Precomputed_Sym_Input_304 => "input",
               when Precomputed_Sym_Integer => "Integer",
               when Precomputed_Sym_Integer_Literal => "Integer_Literal",
               when Precomputed_Sym_Integer_Value => "Integer_Value",
               when Precomputed_Sym_Integer_Value_305 => "integer_value",
               when Precomputed_Sym_Interface => "Interface",
               when Precomputed_Sym_Interface_306 => "interface",
               when Precomputed_Sym_Interrupt_Handler => "Interrupt_Handler",
               when Precomputed_Sym_Invalid_Value => "Invalid_Value",
               when Precomputed_Sym_Invariant => "Invariant",
               when Precomputed_Sym_Invariant_Class => "Invariant'Class",
               when Precomputed_Sym_Is => "is",
               when Precomputed_Sym_Iterable => "Iterable",
               when Precomputed_Sym_Iterator_Element => "Iterator_Element",
               when Precomputed_Sym_Iterator_Interfaces => "Iterator_Interfaces",
               when Precomputed_Sym_Large => "Large",
               when Precomputed_Sym_Last => "Last",
               when Precomputed_Sym_Last_Bit => "Last_Bit",
               when Precomputed_Sym_Left => "left",
               when Precomputed_Sym_Length => "Length",
               when Precomputed_Sym_Limited => "limited",
               when Precomputed_Sym_Loop => "loop",
               when Precomputed_Sym_Loop_Entry => "Loop_Entry",
               when Precomputed_Sym_Loop_Invariant => "Loop_Invariant",
               when Precomputed_Sym_Machine => "Machine",
               when Precomputed_Sym_Machine_311 => "machine",
               when Precomputed_Sym_Machine_Code => "Machine_Code",
               when Precomputed_Sym_Machine_Emax => "Machine_Emax",
               when Precomputed_Sym_Machine_Emin => "Machine_Emin",
               when Precomputed_Sym_Machine_Mantissa => "Machine_Mantissa",
               when Precomputed_Sym_Machine_Overflows => "Machine_Overflows",
               when Precomputed_Sym_Machine_Radix => "Machine_Radix",
               when Precomputed_Sym_Machine_Rounding => "Machine_Rounding",
               when Precomputed_Sym_Machine_Rounding_312 => "machine_rounding",
               when Precomputed_Sym_Machine_Rounds => "Machine_Rounds",
               when Precomputed_Sym_Mantissa => "Mantissa",
               when Precomputed_Sym_Max => "Max",
               when Precomputed_Sym_Max_313 => "max",
               when Precomputed_Sym_Max_Integer_Size => "Max_Integer_Size",
               when Precomputed_Sym_Max_Size_In_Storage_Elements => "Max_Size_In_Storage_Elements",
               when Precomputed_Sym_Maximum_Alignment => "Maximum_Alignment",
               when Precomputed_Sym_Min => "Min",
               when Precomputed_Sym_Min_314 => "min",
               when Precomputed_Sym_Mod => """mod""",
               when Precomputed_Sym_Mod_142 => "Mod",
               when Precomputed_Sym_Mod_315 => "mod",
               when Precomputed_Sym_Model_Epsilon => "Model_Epsilon",
               when Precomputed_Sym_Model_Mantissa => "Model_Mantissa",
               when Precomputed_Sym_Model_Small => "Model_Small",
               when Precomputed_Sym_Modulus => "Modulus",
               when Precomputed_Sym_New => "new",
               when Precomputed_Sym_Nextpart => "__nextpart",
               when Precomputed_Sym_No_Elaboration_Code => "No_Elaboration_Code",
               when Precomputed_Sym_No_Return => "No_Return",
               when Precomputed_Sym_Not => """not""",
               when Precomputed_Sym_Not_317 => "not",
               when Precomputed_Sym_Null => "null",
               when Precomputed_Sym_Object_Size => "Object_Size",
               when Precomputed_Sym_Of => "of",
               when Precomputed_Sym_Old => "Old",
               when Precomputed_Sym_Or => """or""",
               when Precomputed_Sym_Or_320 => "or",
               when Precomputed_Sym_Others => "others",
               when Precomputed_Sym_Out => "out",
               when Precomputed_Sym_Output => "Output",
               when Precomputed_Sym_Output_323 => "output",
               when Precomputed_Sym_Overriding => "overriding",
               when Precomputed_Sym_Pack => "Pack",
               when Precomputed_Sym_Package => "package",
               when Precomputed_Sym_Pos => "Pos",
               when Precomputed_Sym_Pos_326 => "pos",
               when Precomputed_Sym_Position => "Position",
               when Precomputed_Sym_Post => "Post",
               when Precomputed_Sym_Post_Class => "Post'Class",
               when Precomputed_Sym_Postcondition => "Postcondition",
               when Precomputed_Sym_Postcondition_Class => "Postcondition'Class",
               when Precomputed_Sym_Pragma => "pragma",
               when Precomputed_Sym_Pre => "Pre",
               when Precomputed_Sym_Pre_Class => "Pre'Class",
               when Precomputed_Sym_Precondition => "Precondition",
               when Precomputed_Sym_Precondition_Class => "Precondition'Class",
               when Precomputed_Sym_Pred => "Pred",
               when Precomputed_Sym_Pred_328 => "pred",
               when Precomputed_Sym_Predicate => "Predicate",
               when Precomputed_Sym_Predicate_Failure => "Predicate_Failure",
               when Precomputed_Sym_Preelaborate => "Preelaborate",
               when Precomputed_Sym_Private => "private",
               when Precomputed_Sym_Privatepart => "__privatepart",
               when Precomputed_Sym_Procedure => "procedure",
               when Precomputed_Sym_Protected => "protected",
               when Precomputed_Sym_Pure => "Pure",
               when Precomputed_Sym_Put_Image => "Put_Image",
               when Precomputed_Sym_Put_Image_332 => "put_image",
               when Precomputed_Sym_Raise => "raise",
               when Precomputed_Sym_Range => "Range",
               when Precomputed_Sym_Range_334 => "range",
               when Precomputed_Sym_Range_Length => "Range_Length",
               when Precomputed_Sym_Read => "Read",
               when Precomputed_Sym_Read_335 => "read",
               when Precomputed_Sym_Real_Literal => "Real_Literal",
               when Precomputed_Sym_Record => "record",
               when Precomputed_Sym_Reduce => "Reduce",
               when Precomputed_Sym_Refined_Depends => "Refined_Depends",
               when Precomputed_Sym_Refined_Global => "Refined_Global",
               when Precomputed_Sym_Refined_Post => "Refined_Post",
               when Precomputed_Sym_Refined_State => "Refined_State",
               when Precomputed_Sym_Rem => """rem""",
               when Precomputed_Sym_Rem_337 => "rem",
               when Precomputed_Sym_Remainder => "Remainder",
               when Precomputed_Sym_Remainder_338 => "remainder",
               when Precomputed_Sym_Remote_Call_Interface => "Remote_Call_Interface",
               when Precomputed_Sym_Remote_Types => "Remote_Types",
               when Precomputed_Sym_Renames => "renames",
               when Precomputed_Sym_Requeue => "requeue",
               when Precomputed_Sym_Requires => "Requires",
               when Precomputed_Sym_Restrictions => "Restrictions",
               when Precomputed_Sym_Result => "Result",
               when Precomputed_Sym_Return => "return",
               when Precomputed_Sym_Reverse => "reverse",
               when Precomputed_Sym_Right => "right",
               when Precomputed_Sym_Root_Buffer_Type => "Root_Buffer_Type",
               when Precomputed_Sym_Root_Integer => "root_integer",
               when Precomputed_Sym_Root_Real => "root_real",
               when Precomputed_Sym_Root_Storage_Pool => "Root_Storage_Pool",
               when Precomputed_Sym_Root_Stream_Type => "Root_Stream_Type",
               when Precomputed_Sym_Root_Types => "root_types_",
               when Precomputed_Sym_Rounding => "Rounding",
               when Precomputed_Sym_Rounding_347 => "rounding",
               when Precomputed_Sym_S => "S",
               when Precomputed_Sym_Safe_Large => "Safe_Large",
               when Precomputed_Sym_Safe_Small => "Safe_Small",
               when Precomputed_Sym_Scalar_Storage_Order => "Scalar_Storage_Order",
               when Precomputed_Sym_Scaling => "Scaling",
               when Precomputed_Sym_Scaling_348 => "scaling",
               when Precomputed_Sym_Select => "select",
               when Precomputed_Sym_Separate => "separate",
               when Precomputed_Sym_Shared_Passive => "Shared_Passive",
               when Precomputed_Sym_Size => "Size",
               when Precomputed_Sym_Small => "Small",
               when Precomputed_Sym_Small_Denominator => "Small_Denominator",
               when Precomputed_Sym_Small_Numerator => "Small_Numerator",
               when Precomputed_Sym_Some => "some",
               when Precomputed_Sym_Stable_Properties => "Stable_Properties",
               when Precomputed_Sym_Standard => "Standard",
               when Precomputed_Sym_Standard_352 => "standard",
               when Precomputed_Sym_Static_Predicate => "Static_Predicate",
               when Precomputed_Sym_Storage_Elements => "Storage_Elements",
               when Precomputed_Sym_Storage_Pool => "Storage_Pool",
               when Precomputed_Sym_Storage_Pools => "Storage_Pools",
               when Precomputed_Sym_Storage_Size => "Storage_Size",
               when Precomputed_Sym_Storage_Unit => "Storage_Unit",
               when Precomputed_Sym_Streams => "Streams",
               when Precomputed_Sym_String => "String",
               when Precomputed_Sym_String_Literal => "String_Literal",
               when Precomputed_Sym_Strings => "Strings",
               when Precomputed_Sym_Style_Checks => "Style_Checks",
               when Precomputed_Sym_Subtype => "subtype",
               when Precomputed_Sym_Succ => "Succ",
               when Precomputed_Sym_Succ_354 => "succ",
               when Precomputed_Sym_Synchronized => "synchronized",
               when Precomputed_Sym_System => "System",
               when Precomputed_Sym_System_Allocator_Alignment => "System_Allocator_Alignment",
               when Precomputed_Sym_Tag => "Tag",
               when Precomputed_Sym_Tagged => "tagged",
               when Precomputed_Sym_Tags => "Tags",
               when Precomputed_Sym_Target_Name => "Target_Name",
               when Precomputed_Sym_Task => "task",
               when Precomputed_Sym_Task_Id => "Task_Id",
               when Precomputed_Sym_Task_Identification => "Task_Identification",
               when Precomputed_Sym_Terminate => "terminate",
               when Precomputed_Sym_Terminated => "Terminated",
               when Precomputed_Sym_Test_Case => "Test_Case",
               when Precomputed_Sym_Text_Buffers => "Text_Buffers",
               when Precomputed_Sym_Text_Io => "text_io",
               when Precomputed_Sym_Then => "then",
               when Precomputed_Sym_To_Address => "To_Address",
               when Precomputed_Sym_Truncation => "Truncation",
               when Precomputed_Sym_Truncation_361 => "truncation",
               when Precomputed_Sym_Type => "type",
               when Precomputed_Sym_Type_Class => "Type_Class",
               when Precomputed_Sym_Type_Invariant => "Type_Invariant",
               when Precomputed_Sym_Type_Invariant_Class => "Type_Invariant'Class",
               when Precomputed_Sym_Unchecked_Access => "Unchecked_Access",
               when Precomputed_Sym_Unchecked_Union => "Unchecked_Union",
               when Precomputed_Sym_Universal_Int_Type => "Universal_Int_Type_",
               when Precomputed_Sym_Universal_Real_Type => "Universal_Real_Type_",
               when Precomputed_Sym_Unreferenced => "Unreferenced",
               when Precomputed_Sym_Unrestricted_Access => "Unrestricted_Access",
               when Precomputed_Sym_Until => "until",
               when Precomputed_Sym_Update => "Update",
               when Precomputed_Sym_Use => "use",
               when Precomputed_Sym_Vads_Size => "VADS_Size",
               when Precomputed_Sym_Val => "Val",
               when Precomputed_Sym_Val_365 => "val",
               when Precomputed_Sym_Valid => "Valid",
               when Precomputed_Sym_Valid_Scalars => "Valid_Scalars",
               when Precomputed_Sym_Value => "Value",
               when Precomputed_Sym_Value_366 => "value",
               when Precomputed_Sym_Value_Size => "Value_Size",
               when Precomputed_Sym_Variable_Indexing => "Variable_Indexing",
               when Precomputed_Sym_Volatile => "Volatile",
               when Precomputed_Sym_Volatile_Components => "Volatile_Components",
               when Precomputed_Sym_Warnings => "Warnings",
               when Precomputed_Sym_When => "when",
               when Precomputed_Sym_While => "while",
               when Precomputed_Sym_Wide_Character => "Wide_Character",
               when Precomputed_Sym_Wide_Image => "Wide_Image",
               when Precomputed_Sym_Wide_Image_369 => "wide_image",
               when Precomputed_Sym_Wide_String => "Wide_String",
               when Precomputed_Sym_Wide_Text_Io => "wide_text_io",
               when Precomputed_Sym_Wide_Value => "Wide_Value",
               when Precomputed_Sym_Wide_Value_371 => "wide_value",
               when Precomputed_Sym_Wide_Wide_Character => "Wide_Wide_Character",
               when Precomputed_Sym_Wide_Wide_Image => "Wide_Wide_Image",
               when Precomputed_Sym_Wide_Wide_Image_372 => "wide_wide_image",
               when Precomputed_Sym_Wide_Wide_String => "Wide_Wide_String",
               when Precomputed_Sym_Wide_Wide_Text_Io => "wide_wide_text_io",
               when Precomputed_Sym_Wide_Wide_Value => "Wide_Wide_Value",
               when Precomputed_Sym_Wide_Wide_Value_374 => "wide_wide_value",
               when Precomputed_Sym_Width => "Width",
               when Precomputed_Sym_With => "with",
               when Precomputed_Sym_Word_Size => "Word_Size",
               when Precomputed_Sym_Write => "Write",
               when Precomputed_Sym_Write_376 => "write",
               when Precomputed_Sym_Xor => """xor""",
               when Precomputed_Sym_Xor_377 => "xor"
            );
            Symbol : constant Symbolization_Result :=
                  Libadalang.Sources.Canonicalize (Raw_Text)
            ;
         begin
            if Symbol.Success then
               return Symbol.Symbol;
            else
               raise Program_Error with
                 "Cannot canonicalize symbol literal: " & Image (Raw_Text);
            end if;
         end;
   end Precomputed_Symbol;
   ----------------------------
   -- Construct_Entity_Array --
   ----------------------------
   function Construct_Entity_Array
     (V : AST_Envs.Entity_Vectors.Vector) return Internal_Entity_Array_Access
   is
      Ret : Internal_Entity_Array_Access :=
        Create_Internal_Entity_Array (V.Length);
   begin
      for J in V.First_Index .. V.Last_Index loop
         Ret.Items (J) := V.Get (J);
      end loop;
      declare
         Tmp : AST_Envs.Entity_Vectors.Vector := V;
      begin
         Tmp.Destroy;
      end;
      return Ret;
   end Construct_Entity_Array;
   ----------------
   -- Enter_Call --
   ----------------
   procedure Enter_Call
     (Context : Internal_Context; Call_Depth : access Natural)
   is
      Max             : Natural renames Context.Max_Call_Depth;
      Current         : Natural renames Context.Current_Call_Depth;
      High_Water_Mark : Natural renames Context.Call_Depth_High_Water_Mark;
   begin
      Current := Current + 1;
      High_Water_Mark := Natural'Max (High_Water_Mark, Current);
      Call_Depth.all := Current;
      if Current > Max then
         raise Property_Error with "stack overflow";
      end if;
   end Enter_Call;
   ---------------
   -- Exit_Call --
   ---------------
   procedure Exit_Call (Context : Internal_Context; Call_Depth : Natural) is
      Current : Natural renames Context.Current_Call_Depth;
   begin
      if Call_Depth /= Current then
         raise Unexpected_Call_Depth with
            "Langkit code generation bug for call depth handling detected";
      end if;
      Current := Current - 1;
   end Exit_Call;
   -----------
   -- Image --
   -----------
   function Image (Self : Symbol_Type) return String_Type is
   begin
      return Create_String (Image (Self));
   end Image;
   ------------------
   -- Context_Pool --
   ------------------
   package body Context_Pool is
      -------------
      -- Acquire --
      -------------
      procedure Acquire (Context : out Internal_Context) is
      begin
         GNAT.Task_Lock.Lock;
         if Available.Is_Empty then
            Context := new Analysis_Context_Type;
            Context.Serial_Number := 1;
         else
            Context := Available.Last_Element;
            Available.Delete_Last;
         end if;
         GNAT.Task_Lock.Unlock;
      exception
         when others =>
            GNAT.Task_Lock.Unlock;
            raise;
      end Acquire;
      -------------
      -- Release --
      -------------
      procedure Release (Context : in out Internal_Context) is
      begin
         GNAT.Task_Lock.Lock;
         Available.Append (Context);
         Context.Serial_Number := Context.Serial_Number + 1;
         Context := null;
         GNAT.Task_Lock.Unlock;
      exception
         when others =>
            GNAT.Task_Lock.Unlock;
            raise;
      end Release;
      ----------
      -- Free --
      ----------
      procedure Free is
      begin
         GNAT.Task_Lock.Lock;
         for C of Available loop
            Free (C);
         end loop;
         GNAT.Task_Lock.Unlock;
      exception
         when others =>
            GNAT.Task_Lock.Unlock;
            raise;
      end Free;
   end Context_Pool;
   --------------
   -- Finalize --
   --------------
   overriding procedure Finalize (CD : in out Contexts_Destructor) is
      pragma Unreferenced (CD);
   begin
      Context_Pool.Free;
   end Finalize;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (File_Reader : in out Internal_File_Reader_Access) is
      procedure Destroy is new Ada.Unchecked_Deallocation
        (Internal_File_Reader'Class, Internal_File_Reader_Access);
   begin
      if File_Reader /= null and then File_Reader.all.Dec_Ref then
         Destroy (File_Reader);
      end if;
   end Dec_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (Self : in out Internal_Event_Handler_Access) is
      procedure Destroy is new Ada.Unchecked_Deallocation
        (Internal_Event_Handler'Class, Internal_Event_Handler_Access);
   begin
      if Self /= null and then Self.all.Dec_Ref then
         Destroy (Self);
      end if;
   end Dec_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (Provider : in out Internal_Unit_Provider_Access) is
      procedure Destroy is new Ada.Unchecked_Deallocation
        (Internal_Unit_Provider'Class, Internal_Unit_Provider_Access);
   begin
      if Provider /= null and then Provider.all.Dec_Ref then
         Destroy (Provider);
      end if;
   end Dec_Ref;
   ----------------
   -- Get_Env_Id --
   ----------------
   function Get_Env_Id
     (E : Lexical_Env; State : in out Dump_Lexical_Env_State) return String
   is
      C        : Address_To_Id_Maps.Cursor;
      Inserted : Boolean;
   begin
      if E = Null_Lexical_Env then
         return "$null";
      elsif E = State.Root_Env then
         --  Insert root env with a special Id so that we only print it once
         State.Env_Ids.Insert (E, -1, C, Inserted);
         return "$root";
      end if;
      State.Env_Ids.Insert (E, State.Next_Id, C, Inserted);
      if Inserted then
         State.Next_Id := State.Next_Id + 1;
      end if;
      return '@' & Stripped_Image (Address_To_Id_Maps.Element (C));
   end Get_Env_Id;
   pragma Warnings (Off, "referenced");
   function To_Lookup_Kind_Type (K : Lookup_Kind) return Lookup_Kind_Type
   is
     (Lookup_Kind_Type'Val (Lookup_Kind'Pos (K)));
   pragma Warnings (On, "referenced");
   --------------------
   -- Create_Context --
   --------------------
   function Create_Context
     (Charset        : String;
      File_Reader    : Internal_File_Reader_Access;
      Unit_Provider  : Internal_Unit_Provider_Access;
      Event_Handler  : Internal_Event_Handler_Access;
      With_Trivia    : Boolean;
      Tab_Stop       : Positive;
      Max_Call_Depth : Natural := 1000)
      return Internal_Context
   is
      Actual_Charset : constant String :=
        (if Charset = "" then Default_Charset else Charset);
      Symbols        : constant Precomputed_Symbol_Table
        := Create_Symbol_Table;
      Context        : Internal_Context;
   begin
      Context_Pool.Acquire (Context);
      Context.Ref_Count := 1;
      Context.Symbols := Symbol_Table (Symbols);
      Context.Charset := To_Unbounded_String (Actual_Charset);
      Context.Tab_Stop := Tab_Stop;
      Context.With_Trivia := With_Trivia;
      Context.Root_Scope := Create_Static_Lexical_Env
        (Parent => Null_Lexical_Env,
         Node   => null);
      --  Create a new ownership share for Event_Handler so that it lives at
      --  least as long as this analysis context.
      Context.Event_Handler := Event_Handler;
      if Context.Event_Handler /= null then
         Context.Event_Handler.Inc_Ref;
      end if;
      --  Create a new ownership share for File_Reader so that it lives at
      --  least as long as this analysis context.
      Context.File_Reader := File_Reader;
      if Context.File_Reader /= null then
         Context.File_Reader.Inc_Ref;
      end if;
      --  Create a new ownership share for Unit_Provider so that it lives at
      --  least as long as this analysis context.
      Context.Unit_Provider := Unit_Provider;
      if Context.Unit_Provider /= null then
         Context.Unit_Provider.Inc_Ref;
      end if;
         if Context.Unit_Provider = null then
            Context.Unit_Provider := Libadalang.Internal_Default_Provider.Create;
         end if;
      Initialize (Context.Parser);
      Context.Discard_Errors_In_Populate_Lexical_Env := True;
      Context.Logic_Resolution_Timeout :=
        Langkit_Support.Adalog.Default_Timeout_Ticks_Number;
      Context.In_Populate_Lexical_Env := False;
      Context.Cache_Version := 0;
      Context.Reparse_Cache_Version := 0;
      Context.Rewriting_Handle := No_Rewriting_Handle_Pointer;
      Context.Templates_Unit := No_Analysis_Unit;
      Context.Max_Call_Depth := Max_Call_Depth;
      Context.Available_Rebindings := Env_Rebindings_Vectors.Empty_Vector;
Fetch_Standard (Context);
      return Context;
   end Create_Context;
   -----------------
   -- Create_Unit --
   -----------------
   function Create_Unit
     (Context             : Internal_Context;
      Normalized_Filename : Virtual_File;
      Charset             : String;
      Rule                : Grammar_Rule) return Internal_Unit
   is
      use Units_Maps;
      Unit : Internal_Unit;
   begin
      Unit := Create_Special_Unit
        (Context, Normalized_Filename, Charset, Rule);
      Context.Units.Insert (Normalized_Filename, Unit);
      return Unit;
   end Create_Unit;
   --------------
   -- Get_Unit --
   --------------
   function Get_Unit
     (Context           : Internal_Context;
      Filename, Charset : String;
      Reparse           : Boolean;
      Input             : Internal_Lexer_Input;
      Rule              : Grammar_Rule;
      Is_Internal       : Boolean := False) return Internal_Unit
   is
      use Units_Maps;
      Normalized_Filename : constant GNATCOLL.VFS.Virtual_File :=
         Normalized_Unit_Filename (Context, Filename);
      Cur     : constant Cursor :=
         Context.Units.Find (Normalized_Filename);
      Created : constant Boolean := Cur = No_Element;
      Unit    : Internal_Unit;
      Actual_Charset : Unbounded_String;
      Refined_Input  : Internal_Lexer_Input := Input;
   begin
      --  Determine which encoding to use. Use the Charset parameter (if
      --  provided), otherwise use the context-wide default.
      Actual_Charset := (if Charset'Length /= 0
                         then To_Unbounded_String (Charset)
                         else Context.Charset);
      if Refined_Input.Kind = File then
         Refined_Input.Filename := Normalized_Filename;
      end if;
      if Refined_Input.Kind in File | Bytes_Buffer then
         Refined_Input.Charset := Actual_Charset;
         --  Unless the caller requested a specific charset for this unit,
         --  allow the lexer to automatically discover the source file encoding
         --  before defaulting to the context-specific one. We do this trying
         --  to match a byte order mark.
         Refined_Input.Read_BOM := Charset'Length = 0;
      end if;
      --  Create the Internal_Unit if needed
      Unit :=
        (if Created
         then Create_Unit (Context, Normalized_Filename,
                           To_String (Actual_Charset), Rule)
         else Element (Cur));
      --  If an internal unit is requested, set the corresponding flag.
      --  Otherwise, make sure that the unit we return isn't internal.
      if Is_Internal then
         Unit.Is_Internal := True;
      end if;
      --  (Re)parse it if needed
      if Created or else Reparse then
         --  It is illegal to reparse an internal unit for public API users.
         --  Since public APIs do not allow to pass True to Is_Internal, we can
         --  check here that only the implementation can ask to reparse an
         --  internal unit.
         if Unit.Is_Internal and then not Is_Internal then
            raise Precondition_Failure with "cannot reparse an internal unit";
         end if;
         declare
            Reparsed : Reparsed_Unit;
         begin
            Do_Parsing (Unit, Refined_Input, Reparsed);
            Update_After_Reparse (Unit, Reparsed);
         end;
         --  Now that we have removed reparsed the unit, update its current
         --  charset.
         Unit.Charset := Actual_Charset;
      end if;
      if Context.Event_Handler /= null then
         Context.Event_Handler.Unit_Parsed_Callback (Context, Unit, Reparse);
      end if;
      return Unit;
   end Get_Unit;
   --------------
   -- Has_Unit --
   --------------
   function Has_Unit
     (Context : Internal_Context; Unit_Filename : String) return Boolean is
   begin
      return Context.Units.Contains
        (Normalized_Unit_Filename (Context, Unit_Filename));
   end Has_Unit;
   -------------------
   -- Get_From_File --
   -------------------
   function Get_From_File
     (Context  : Internal_Context;
      Filename : String;
      Charset  : String;
      Reparse  : Boolean;
      Rule     : Grammar_Rule) return Internal_Unit
   is
      Input : constant Internal_Lexer_Input :=
        (Kind     => File,
         Charset  => <>,
         Read_BOM => False,
         Filename => <>);
   begin
      if Reparse and then Has_Rewriting_Handle (Context) then
         raise Precondition_Failure with
            "cannot reparse during tree rewriting";
      end if;
      return Get_Unit (Context, Filename, Charset, Reparse, Input, Rule);
   end Get_From_File;
   ---------------------
   -- Get_From_Buffer --
   ---------------------
   function Get_From_Buffer
     (Context  : Internal_Context;
      Filename : String;
      Charset  : String;
      Buffer   : String;
      Rule     : Grammar_Rule) return Internal_Unit
   is
      Input : constant Internal_Lexer_Input :=
        (Kind        => Bytes_Buffer,
         Charset     => <>,
         Read_BOM    => False,
         Bytes       => Buffer'Address,
         Bytes_Count => Buffer'Length);
   begin
      if Has_Rewriting_Handle (Context) then
         raise Precondition_Failure with
            "cannot parse from buffer during tree rewriting";
      elsif Context.File_Reader /= null then
         raise Precondition_Failure with
            "cannot parse from buffer with a file reader";
      end if;
      return Get_Unit (Context, Filename, Charset, True, Input, Rule);
   end Get_From_Buffer;
   --------------------
   -- Get_With_Error --
   --------------------
   function Get_With_Error
     (Context  : Internal_Context;
      Filename : String;
      Error    : Text_Type;
      Charset  : String;
      Rule     : Grammar_Rule) return Internal_Unit
   is
      use Units_Maps;
      Normalized_Filename : constant Virtual_File :=
         Normalized_Unit_Filename (Context, Filename);
      Cur                 : constant Cursor :=
         Context.Units.Find (Normalized_Filename);
   begin
      if Cur = No_Element then
         declare
            Unit : constant Internal_Unit := Create_Unit
              (Context, Normalized_Filename, Charset, Rule);
         begin
            Append (Unit.Diagnostics, No_Source_Location_Range, Error);
            return Unit;
         end;
      else
         return Element (Cur);
      end if;
   end Get_With_Error;
   -----------------------
   -- Get_From_Provider --
   -----------------------
   function Get_From_Provider
     (Context : Internal_Context;
      Name    : Text_Type;
      Kind    : Analysis_Unit_Kind;
      Charset : String;
      Reparse : Boolean) return Internal_Unit is
   begin
      if Reparse and then Has_Rewriting_Handle (Context) then
         raise Precondition_Failure with
            "cannot reparse during tree rewriting";
      end if;
      begin
         return Context.Unit_Provider.Get_Unit
           (Context, Name, Kind, Charset, Reparse);
      exception
         when Precondition_Failure | Property_Error =>
            raise Invalid_Unit_Name_Error with
               "Invalid unit name: " & Image (Name, With_Quotes => True)
               & " (" & Analysis_Unit_Kind'Image (Kind) & ")";
      end;
   end Get_From_Provider;
   -------------------
   -- Unit_Provider --
   -------------------
   function Unit_Provider
     (Context : Internal_Context) return Internal_Unit_Provider_Access
   is (Context.Unit_Provider);
   ----------
   -- Hash --
   ----------
   function Hash (Context : Internal_Context) return Hash_Type is
      function H is new Hash_Access (Analysis_Context_Type, Internal_Context);
   begin
      return H (Context);
   end Hash;
   ---------------------
   -- Has_With_Trivia --
   ---------------------
   function Has_With_Trivia (Context : Internal_Context) return Boolean is
   begin
      return Context.With_Trivia;
   end Has_With_Trivia;
   --------------------------------------------
   -- Discard_Errors_In_Populate_Lexical_Env --
   --------------------------------------------
   procedure Discard_Errors_In_Populate_Lexical_Env
     (Context : Internal_Context; Discard : Boolean) is
   begin
      Context.Discard_Errors_In_Populate_Lexical_Env := Discard;
   end Discard_Errors_In_Populate_Lexical_Env;
   ----------------------------------
   -- Set_Logic_Resolution_Timeout --
   ----------------------------------
   procedure Set_Logic_Resolution_Timeout
     (Context : Internal_Context; Timeout : Natural) is
   begin
      Context.Logic_Resolution_Timeout := Timeout;
   end Set_Logic_Resolution_Timeout;
   --------------------------
   -- Has_Rewriting_Handle --
   --------------------------
   function Has_Rewriting_Handle (Context : Internal_Context) return Boolean is
   begin
      return Context.Rewriting_Handle /= No_Rewriting_Handle_Pointer;
   end Has_Rewriting_Handle;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (Context : Internal_Context) is
   begin
      if Context /= null then
         Context.Ref_Count := Context.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (Context : in out Internal_Context) is
   begin
      if Context /= null then
         Context.Ref_Count := Context.Ref_Count - 1;
         if Context.Ref_Count = 0 then
            Destroy (Context);
         end if;
      end if;
   end Dec_Ref;
   -------------
   -- Destroy --
   -------------
   procedure Destroy (Context : in out Internal_Context) is
   begin
      --  Destroy all named environment data structures
      for Desc of Context.Named_Envs loop
         for V of Desc.Foreign_Nodes loop
            V.Destroy;
         end loop;
         Destroy (Desc);
      end loop;
      Context.Named_Envs.Clear;
      --  If we are asked to free this context, it means that no one else have
      --  references to its analysis units, so it's safe to destroy these.
      for Unit of Context.Units loop
         Destroy (Unit);
      end loop;
      Context.Units := Units_Maps.Empty_Map;
      Context.Filenames := Virtual_File_Maps.Empty_Map;
      declare
         procedure Destroy is new Ada.Unchecked_Deallocation
           (Env_Rebindings_Type, Env_Rebindings);
         AR : Env_Rebindings_Vectors.Vector renames
            Context.Available_Rebindings;
         R  : Env_Rebindings;
      begin
         for I in AR.First_Index .. AR.Last_Index loop
            R := AR.Get (I);
            Destroy (R);
         end loop;
         AR.Destroy;
      end;
      Destroy (Context.Templates_Unit);
      AST_Envs.Destroy (Context.Root_Scope);
      Destroy (Context.Symbols);
      Destroy (Context.Parser);
      Dec_Ref (Context.File_Reader);
      Dec_Ref (Context.Unit_Provider);
      Dec_Ref (Context.Event_Handler);
      Context_Pool.Release (Context);
   end Destroy;
   -------------
   -- Context --
   -------------
   function Context (Unit : Internal_Unit) return Internal_Context is
   begin
      return Unit.Context;
   end Context;
   ----------
   -- Hash --
   ----------
   function Hash (Unit : Internal_Unit) return Hash_Type is
      function H is new Hash_Access (Analysis_Unit_Type, Internal_Unit);
   begin
      return H (Unit);
   end Hash;
   -------------
   -- Reparse --
   -------------
   procedure Reparse (Unit : Internal_Unit; Charset : String) is
      Dummy : constant Internal_Unit := Get_From_File
        (Unit.Context, +Unit.Filename.Full_Name, Charset,
         Reparse => True,
         Rule    => Unit.Rule);
   begin
      null;
   end Reparse;
   -------------
   -- Reparse --
   -------------
   procedure Reparse (Unit : Internal_Unit; Charset : String; Buffer : String)
   is
      Dummy : constant Internal_Unit := Get_From_Buffer
        (Unit.Context, +Unit.Filename.Full_Name, Charset, Buffer, Unit.Rule);
   begin
      null;
   end Reparse;
   --------------------------
   -- Populate_Lexical_Env --
   --------------------------
   procedure Populate_Lexical_Env (Unit : Internal_Unit) is
      Context : constant Internal_Context := Unit.Context;
      Has_Errors : Boolean := False;
      --  Whether at least one Property_Error occurred during this PLE pass
      Saved_In_Populate_Lexical_Env : constant Boolean :=
         Unit.Context.In_Populate_Lexical_Env;
      procedure Reset_Envs_Caches (Unit : Internal_Unit) is
         procedure Internal (Node : Bare_Ada_Node) is
         begin
            if Node = null then
               return;
            end if;
            Reset_Caches (Node.Self_Env);
            for I in 1 .. Children_Count (Node) loop
               Internal (Child (Node, I));
            end loop;
         end Internal;
      begin
         Internal (Unit.Ast_Root);
      end Reset_Envs_Caches;
   begin
      --  TODO??? Handle env invalidation when reparsing a unit and when a
      --  previous call raised a Property_Error.
      if Unit.Is_Env_Populated then
         return;
      end if;
      Unit.Is_Env_Populated := True;
      if Unit.Ast_Root = null then
         return;
      end if;
      GNATCOLL.Traces.Trace (Main_Trace, "Populating lexical envs for unit: "
                                         & Basename (Unit));
      if GNATCOLL.Traces.Active (Main_Trace) then
         GNATCOLL.Traces.Increase_Indent (Main_Trace);
      end if;
      Context.In_Populate_Lexical_Env := True;
      Has_Errors := Populate_Lexical_Env (Unit.Ast_Root);
      Context.In_Populate_Lexical_Env := Saved_In_Populate_Lexical_Env;
      if GNATCOLL.Traces.Active (Main_Trace) then
         GNATCOLL.Traces.Decrease_Indent (Main_Trace);
         GNATCOLL.Traces.Trace
           (Main_Trace,
            "Finished populating lexical envs for unit: " & Basename (Unit));
      end if;
      Reset_Envs_Caches (Unit);
      if Has_Errors and then not Context.Discard_Errors_In_Populate_Lexical_Env
      then
         raise Property_Error with
            "errors occurred in Populate_Lexical_Env";
      end if;
   end Populate_Lexical_Env;
   ------------------
   -- Get_Filename --
   ------------------
   function Get_Filename (Unit : Internal_Unit) return String is
     (+Unit.Filename.Full_Name);
   -----------------
   -- Get_Charset --
   -----------------
   function Get_Charset (Unit : Internal_Unit) return String is
   begin
      return To_String (Unit.Charset);
   end Get_Charset;
   ---------------------
   -- Has_Diagnostics --
   ---------------------
   function Has_Diagnostics (Unit : Internal_Unit) return Boolean is
   begin
      return not Unit.Diagnostics.Is_Empty;
   end Has_Diagnostics;
   -----------------
   -- Diagnostics --
   -----------------
   function Diagnostics (Unit : Internal_Unit) return Diagnostics_Array is
      Result : Diagnostics_Array (1 .. Natural (Unit.Diagnostics.Length));
      I      : Natural := 1;
   begin
      for D of Unit.Diagnostics loop
         Result (I) := D;
         I := I + 1;
      end loop;
      return Result;
   end Diagnostics;
   ---------------------------
   -- Format_GNU_Diagnostic --
   ---------------------------
   function Format_GNU_Diagnostic
     (Unit : Internal_Unit; D : Diagnostic) return String
   is
      Filename : constant String := Basename (Unit);
      Sloc     : constant Source_Location := Start_Sloc (D.Sloc_Range);
      Msg      : constant String :=
         Image
           (Ada.Strings.Wide_Wide_Unbounded.To_Wide_Wide_String (D.Message));
   begin
      return (Filename
              & (if Sloc = No_Source_Location then "" else ":" & Image (Sloc))
              & ": " & Msg);
   end Format_GNU_Diagnostic;
   ----------
   -- Root --
   ----------
   function Root (Unit : Internal_Unit) return Bare_Ada_Node is
     (Unit.Ast_Root);
   -----------------
   -- First_Token --
   -----------------
   function First_Token (Unit : Internal_Unit) return Token_Reference is
     (Wrap_Token_Reference (Unit.Context,
                            Unit.TDH'Access,
                            First_Token_Or_Trivia (Unit.TDH)));
   ----------------
   -- Last_Token --
   ----------------
   function Last_Token (Unit : Internal_Unit) return Token_Reference is
     (Wrap_Token_Reference (Unit.Context,
                            Unit.TDH'Access,
                            Last_Token_Or_Trivia (Unit.TDH)));
   -----------------
   -- Token_Count --
   -----------------
   function Token_Count (Unit : Internal_Unit) return Natural is
     (Unit.TDH.Tokens.Length);
   ------------------
   -- Trivia_Count --
   ------------------
   function Trivia_Count (Unit : Internal_Unit) return Natural is
     (Unit.TDH.Trivias.Length);
   ----------
   -- Text --
   ----------
   function Text (Unit : Internal_Unit) return Text_Type is
   begin
      return Text (First_Token (Unit), Last_Token (Unit));
   end Text;
   ------------------
   -- Lookup_Token --
   ------------------
   function Lookup_Token
     (Unit : Internal_Unit; Sloc : Source_Location) return Token_Reference
   is
      Result : constant Token_Or_Trivia_Index := Lookup_Token (Unit.TDH, Sloc);
   begin
      return Wrap_Token_Reference (Unit.Context, Unit.TDH'Access, Result);
   end Lookup_Token;
   ----------------------
   -- Dump_Lexical_Env --
   ----------------------
   procedure Dump_Lexical_Env (Unit : Internal_Unit) is
      Node     : constant Bare_Ada_Node := Unit.Ast_Root;
      Root_Env : constant Lexical_Env := Unit.Context.Root_Scope;
      State    : Dump_Lexical_Env_State := (Root_Env => Root_Env, others => <>);
      function Get_Parent (Env : Lexical_Env) return Lexical_Env
      is (Unwrap (Env).Parent);
      --------------------------
      -- Explore_Parent_Chain --
      --------------------------
      procedure Explore_Parent_Chain (Env : Lexical_Env) is
         P : Lexical_Env;
      begin
         if Env /= Null_Lexical_Env then
            P := Get_Parent (Env);
            Dump_One_Lexical_Env
              (Env, Get_Env_Id (Env, State), Get_Env_Id (P, State));
            Explore_Parent_Chain (P);
         end if;
      end Explore_Parent_Chain;
      --------------
      -- Internal --
      --------------
      procedure Internal (Current : Bare_Ada_Node) is
         Explore_Parent : Boolean := False;
         Env, Parent    : Lexical_Env;
      begin
         if Current = null then
            return;
         end if;
         --  We only dump environments that we haven't dumped before. This way
         --  we'll only dump environments at the site of their creation, and
         --  not in any subsequent link. We use the Env_Ids map to check which
         --  envs we have already seen or not.
         if not State.Env_Ids.Contains (Current.Self_Env) then
            Env := Current.Self_Env;
            Parent := Get_Parent (Env);
            Explore_Parent := not State.Env_Ids.Contains (Parent);
            Dump_One_Lexical_Env
              (Env, Get_Env_Id (Env, State), Get_Env_Id (Parent, State));
            if Explore_Parent then
               Explore_Parent_Chain (Parent);
            end if;
         end if;
         for Child of Internal_Bare_Ada_Node_Array'(Children (Current))
         loop
            Internal (Child);
         end loop;
      end Internal;
      --  This procedure implements the main recursive logic of dumping the
      --  environments.
   begin
      Internal (Bare_Ada_Node (Node));
   end Dump_Lexical_Env;
   --------------
   -- Get_Line --
   --------------
   function Get_Line
     (Unit : Internal_Unit; Line_Number : Positive) return Text_Type
   is
   begin
      return Get_Line (Unit.TDH, Line_Number);
   end Get_Line;
   -----------
   -- Print --
   -----------
   procedure Print (Unit : Internal_Unit; Show_Slocs : Boolean) is
   begin
      if Unit.Ast_Root = null then
         Put_Line ("<empty analysis unit>");
      else
         Print (Unit.Ast_Root, Show_Slocs);
      end if;
   end Print;
   ---------------
   -- PP_Trivia --
   ---------------
   procedure PP_Trivia (Unit : Internal_Unit) is
      procedure Process (Trivia : Token_Index) is
         Data : constant Stored_Token_Data :=
            Unit.TDH.Trivias.Get (Natural (Trivia)).T;
      begin
         Put_Line (Image (Text (Unit.TDH, Data)));
      end Process;
      Last_Token : constant Token_Index :=
         Token_Index (Token_Vectors.Last_Index (Unit.TDH.Tokens) - 1);
      --  Index for the last token in Unit excluding the Termination token
      --  (hence the -1).
   begin
      for Tok of Get_Leading_Trivias (Unit.TDH) loop
         Process (Tok);
      end loop;
      PP_Trivia (Unit.Ast_Root);
      for Tok of Get_Trivias (Unit.TDH, Last_Token) loop
         Process (Tok);
      end loop;
   end PP_Trivia;
   -------------
   -- Destroy --
   -------------
   procedure Destroy (Unit : in out Internal_Unit) is
   begin
      if Unit = No_Analysis_Unit then
         return;
      end if;
      Unit.Exiled_Entries.Destroy;
      Unit.Foreign_Nodes.Destroy;
      Unit.Exiled_Entries_In_NED.Destroy;
      Unit.Exiled_Envs.Destroy;
      Unit.Named_Envs.Destroy;
      Analysis_Unit_Sets.Destroy (Unit.Referenced_Units);
         Destroy (Unit.Memoization_Map);
      Destroy_Rebindings (Unit.Rebindings'Access);
      Unit.Rebindings.Destroy;
      if Unit.Ast_Root /= null then
         Destroy (Unit.Ast_Root);
      end if;
      Free (Unit.TDH);
      Free (Unit.Ast_Mem_Pool);
      Destroy_Unit_Destroyables (Unit);
      Destroyable_Vectors.Destroy (Unit.Destroyables);
      Free (Unit);
   end Destroy;
   -------------------
   -- Is_Token_Node --
   -------------------
   function Is_Token_Node (Node : Bare_Ada_Node) return Boolean is
   begin
      return Is_Token_Node (Node.Kind);
   end Is_Token_Node;
   ------------------
   -- Is_Synthetic --
   ------------------
   function Is_Synthetic (Node : Bare_Ada_Node) return Boolean is
   begin
      return Node.Kind in Synthetic_Nodes;
   end Is_Synthetic;
   ------------------------------
   -- Raise_Property_Exception --
   ------------------------------
   procedure Raise_Property_Exception
     (Node    : Bare_Ada_Node;
      Exc     : Ada.Exceptions.Exception_Id;
      Message : String)
   is
      Sloc_Prefix : constant String :=
        (if Node = null
         then ""
         else Ada.Directories.Simple_Name (Get_Filename (Unit (Node)))
              & ":" & Image (Sloc_Range (Node)) & ": ");
   begin
      Ada.Exceptions.Raise_Exception (Exc, Sloc_Prefix & Message);
   end Raise_Property_Exception;
   ------------------------------
   -- Register_Destroyable_Gen --
   ------------------------------
   procedure Register_Destroyable_Gen
     (Unit : Internal_Unit; Object : T_Access)
   is
      function Convert is new Ada.Unchecked_Conversion
        (System.Address, Destroy_Procedure);
      procedure Destroy_Procedure (Object : in out T_Access) renames Destroy;
   begin
      Register_Destroyable_Helper
        (Unit,
         Object.all'Address,
         Convert (Destroy_Procedure'Address));
   end Register_Destroyable_Gen;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Ada_Node_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Ada_Node
   is
      function Absolute_Get
        (T : Bare_Ada_Node_Array_Access; Index : Integer)
         return Bare_Ada_Node
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Ada_Node,
         Sequence_Type => Bare_Ada_Node_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Ada_Node;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Ada_Node_Array_Access) return Bare_Ada_Node_Array_Access is
      Ret : Bare_Ada_Node_Array_Access := Create_Bare_Ada_Node_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Ada_Node_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Ada_Node_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Ada_Node_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Ada_Node_Array (Items_Count : Natural) return Bare_Ada_Node_Array_Access
   is (if Items_Count = 0
       then No_Bare_Ada_Node_Array_Type
       else new Bare_Ada_Node_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Ada_Node_Array
     (Items : Internal_Bare_Ada_Node_Array) return Bare_Ada_Node_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Ada_Node_Array_Type;
      end if;
      return new Bare_Ada_Node_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Ada_Node_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Ada_Node_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Bare_Anonymous_Expr_Decl_Vectors is new Langkit_Support.Vectors (Bare_Anonymous_Expr_Decl);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Anonymous_Expr_Decl_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Anonymous_Expr_Decl
   is
      function Absolute_Get
        (T : Bare_Anonymous_Expr_Decl_Array_Access; Index : Integer)
         return Bare_Anonymous_Expr_Decl
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Anonymous_Expr_Decl,
         Sequence_Type => Bare_Anonymous_Expr_Decl_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Anonymous_Expr_Decl;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Anonymous_Expr_Decl_Array_Access) return Bare_Anonymous_Expr_Decl_Array_Access is
      Ret : Bare_Anonymous_Expr_Decl_Array_Access := Create_Bare_Anonymous_Expr_Decl_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Anonymous_Expr_Decl_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Anonymous_Expr_Decl_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Anonymous_Expr_Decl_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Anonymous_Expr_Decl_Array (Items_Count : Natural) return Bare_Anonymous_Expr_Decl_Array_Access
   is (if Items_Count = 0
       then No_Bare_Anonymous_Expr_Decl_Array_Type
       else new Bare_Anonymous_Expr_Decl_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Anonymous_Expr_Decl_Array
     (Items : Internal_Bare_Anonymous_Expr_Decl_Array) return Bare_Anonymous_Expr_Decl_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Anonymous_Expr_Decl_Array_Type;
      end if;
      return new Bare_Anonymous_Expr_Decl_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Anonymous_Expr_Decl_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Anonymous_Expr_Decl_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Bare_Compilation_Unit_Vectors is new Langkit_Support.Vectors (Bare_Compilation_Unit);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Compilation_Unit_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Compilation_Unit
   is
      function Absolute_Get
        (T : Bare_Compilation_Unit_Array_Access; Index : Integer)
         return Bare_Compilation_Unit
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Compilation_Unit,
         Sequence_Type => Bare_Compilation_Unit_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Compilation_Unit;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Compilation_Unit_Array_Access) return Bare_Compilation_Unit_Array_Access is
      Ret : Bare_Compilation_Unit_Array_Access := Create_Bare_Compilation_Unit_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Compilation_Unit_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Compilation_Unit_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Compilation_Unit_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Compilation_Unit_Array (Items_Count : Natural) return Bare_Compilation_Unit_Array_Access
   is (if Items_Count = 0
       then No_Bare_Compilation_Unit_Array_Type
       else new Bare_Compilation_Unit_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Compilation_Unit_Array
     (Items : Internal_Bare_Compilation_Unit_Array) return Bare_Compilation_Unit_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Compilation_Unit_Array_Type;
      end if;
      return new Bare_Compilation_Unit_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Compilation_Unit_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Compilation_Unit_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Bare_Expr_Vectors is new Langkit_Support.Vectors (Bare_Expr);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Expr_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Expr
   is
      function Absolute_Get
        (T : Bare_Expr_Array_Access; Index : Integer)
         return Bare_Expr
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Expr,
         Sequence_Type => Bare_Expr_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Expr;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Expr_Array_Access) return Bare_Expr_Array_Access is
      Ret : Bare_Expr_Array_Access := Create_Bare_Expr_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Expr_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Expr_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Expr_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Expr_Array (Items_Count : Natural) return Bare_Expr_Array_Access
   is (if Items_Count = 0
       then No_Bare_Expr_Array_Type
       else new Bare_Expr_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Expr_Array
     (Items : Internal_Bare_Expr_Array) return Bare_Expr_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Expr_Array_Type;
      end if;
      return new Bare_Expr_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Expr_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Expr_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Bare_Name_Vectors is new Langkit_Support.Vectors (Bare_Name);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Name_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Name
   is
      function Absolute_Get
        (T : Bare_Name_Array_Access; Index : Integer)
         return Bare_Name
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Name,
         Sequence_Type => Bare_Name_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Name;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Name_Array_Access) return Bare_Name_Array_Access is
      Ret : Bare_Name_Array_Access := Create_Bare_Name_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Name_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Name_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Name_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Name_Array (Items_Count : Natural) return Bare_Name_Array_Access
   is (if Items_Count = 0
       then No_Bare_Name_Array_Type
       else new Bare_Name_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Name_Array
     (Items : Internal_Bare_Name_Array) return Bare_Name_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Name_Array_Type;
      end if;
      return new Bare_Name_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Name_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Name_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Bare_Pragma_Node_Vectors is new Langkit_Support.Vectors (Bare_Pragma_Node);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Pragma_Node_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Pragma_Node
   is
      function Absolute_Get
        (T : Bare_Pragma_Node_Array_Access; Index : Integer)
         return Bare_Pragma_Node
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Pragma_Node,
         Sequence_Type => Bare_Pragma_Node_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Pragma_Node;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Pragma_Node_Array_Access) return Bare_Pragma_Node_Array_Access is
      Ret : Bare_Pragma_Node_Array_Access := Create_Bare_Pragma_Node_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Pragma_Node_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Pragma_Node_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Pragma_Node_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Pragma_Node_Array (Items_Count : Natural) return Bare_Pragma_Node_Array_Access
   is (if Items_Count = 0
       then No_Bare_Pragma_Node_Array_Type
       else new Bare_Pragma_Node_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Pragma_Node_Array
     (Items : Internal_Bare_Pragma_Node_Array) return Bare_Pragma_Node_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Pragma_Node_Array_Type;
      end if;
      return new Bare_Pragma_Node_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Pragma_Node_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Pragma_Node_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Single_Tok_Node_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Single_Tok_Node
   is
      function Absolute_Get
        (T : Bare_Single_Tok_Node_Array_Access; Index : Integer)
         return Bare_Single_Tok_Node
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Single_Tok_Node,
         Sequence_Type => Bare_Single_Tok_Node_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Single_Tok_Node;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Single_Tok_Node_Array_Access) return Bare_Single_Tok_Node_Array_Access is
      Ret : Bare_Single_Tok_Node_Array_Access := Create_Bare_Single_Tok_Node_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Single_Tok_Node_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Single_Tok_Node_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Single_Tok_Node_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Single_Tok_Node_Array (Items_Count : Natural) return Bare_Single_Tok_Node_Array_Access
   is (if Items_Count = 0
       then No_Bare_Single_Tok_Node_Array_Type
       else new Bare_Single_Tok_Node_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Single_Tok_Node_Array
     (Items : Internal_Bare_Single_Tok_Node_Array) return Bare_Single_Tok_Node_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Single_Tok_Node_Array_Type;
      end if;
      return new Bare_Single_Tok_Node_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Single_Tok_Node_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Single_Tok_Node_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Bare_Use_Clause_Vectors is new Langkit_Support.Vectors (Bare_Use_Clause);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Bare_Use_Clause_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Use_Clause
   is
      function Absolute_Get
        (T : Bare_Use_Clause_Array_Access; Index : Integer)
         return Bare_Use_Clause
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Use_Clause,
         Sequence_Type => Bare_Use_Clause_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Use_Clause;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Bare_Ada_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Bare_Use_Clause_Array_Access) return Bare_Use_Clause_Array_Access is
      Ret : Bare_Use_Clause_Array_Access := Create_Bare_Use_Clause_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Use_Clause_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Bare_Use_Clause_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Use_Clause_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Bare_Use_Clause_Array (Items_Count : Natural) return Bare_Use_Clause_Array_Access
   is (if Items_Count = 0
       then No_Bare_Use_Clause_Array_Type
       else new Bare_Use_Clause_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Bare_Use_Clause_Array
     (Items : Internal_Bare_Use_Clause_Array) return Bare_Use_Clause_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Bare_Use_Clause_Array_Type;
      end if;
      return new Bare_Use_Clause_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Bare_Use_Clause_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Use_Clause_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Aspect_Vectors is new Langkit_Support.Vectors (Internal_Aspect);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Aspect_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Aspect
   is
      function Absolute_Get
        (T : Internal_Aspect_Array_Access; Index : Integer)
         return Internal_Aspect
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Aspect,
         Sequence_Type => Internal_Aspect_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Aspect;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Aspect;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Aspect_Array_Access) return Internal_Aspect_Array_Access is
      Ret : Internal_Aspect_Array_Access := Create_Internal_Aspect_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Aspect_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Aspect_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Aspect_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Aspect_Array (Items_Count : Natural) return Internal_Aspect_Array_Access
   is (if Items_Count = 0
       then No_Internal_Aspect_Array_Type
       else new Internal_Aspect_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Aspect_Array
     (Items : Internal_Internal_Aspect_Array) return Internal_Aspect_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Aspect_Array_Type;
      end if;
      return new Internal_Aspect_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Aspect_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Aspect_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Completion_Item_Vectors is new Langkit_Support.Vectors (Internal_Completion_Item);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Completion_Item_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Completion_Item
   is
      function Absolute_Get
        (T : Internal_Completion_Item_Array_Access; Index : Integer)
         return Internal_Completion_Item
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Completion_Item,
         Sequence_Type => Internal_Completion_Item_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Completion_Item;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Completion_Item;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Completion_Item_Array_Access) return Internal_Completion_Item_Array_Access is
      Ret : Internal_Completion_Item_Array_Access := Create_Internal_Completion_Item_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Completion_Item_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Completion_Item_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Completion_Item_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Completion_Item_Array (Items_Count : Natural) return Internal_Completion_Item_Array_Access
   is (if Items_Count = 0
       then No_Internal_Completion_Item_Array_Type
       else new Internal_Completion_Item_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Completion_Item_Array
     (Items : Internal_Internal_Completion_Item_Array) return Internal_Completion_Item_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Completion_Item_Array_Type;
      end if;
      return new Internal_Completion_Item_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Completion_Item_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- To_Iterator --
      -----------------
      function To_Iterator
        (Self    : Internal_Completion_Item_Array_Access;
         Context : Internal_Context) return Internal_Completion_Item_Iterator_Access
      is
      begin
         Inc_Ref (Self);
         return new Internal_Internal_Completion_Item_Iterator'
           (Ref_Count  => 1,
            Safety_Net => Create_Safety_Net (Context),
            Elements   => Self,
            Index      => 1);
      end To_Iterator;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Completion_Item_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Discriminant_Values_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Discriminant_Values
   is
      function Absolute_Get
        (T : Internal_Discriminant_Values_Array_Access; Index : Integer)
         return Internal_Discriminant_Values
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Discriminant_Values,
         Sequence_Type => Internal_Discriminant_Values_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Discriminant_Values;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Discriminant_Values;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Discriminant_Values_Array_Access) return Internal_Discriminant_Values_Array_Access is
      Ret : Internal_Discriminant_Values_Array_Access := Create_Internal_Discriminant_Values_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Discriminant_Values_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Discriminant_Values_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Discriminant_Values_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Discriminant_Values_Array (Items_Count : Natural) return Internal_Discriminant_Values_Array_Access
   is (if Items_Count = 0
       then No_Internal_Discriminant_Values_Array_Type
       else new Internal_Discriminant_Values_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Discriminant_Values_Array
     (Items : Internal_Internal_Discriminant_Values_Array) return Internal_Discriminant_Values_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Discriminant_Values_Array_Type;
      end if;
      return new Internal_Discriminant_Values_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Discriminant_Values_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Discriminant_Values_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Doc_Annotation_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Doc_Annotation
   is
      function Absolute_Get
        (T : Internal_Doc_Annotation_Array_Access; Index : Integer)
         return Internal_Doc_Annotation
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Doc_Annotation,
         Sequence_Type => Internal_Doc_Annotation_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Doc_Annotation;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return No_Doc_Annotation;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Doc_Annotation_Array_Access) return Internal_Doc_Annotation_Array_Access is
      Ret : Internal_Doc_Annotation_Array_Access := Create_Internal_Doc_Annotation_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Doc_Annotation_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Doc_Annotation_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Doc_Annotation_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Doc_Annotation_Array (Items_Count : Natural) return Internal_Doc_Annotation_Array_Access
   is (if Items_Count = 0
       then No_Internal_Doc_Annotation_Array_Type
       else new Internal_Doc_Annotation_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Doc_Annotation_Array
     (Items : Internal_Internal_Doc_Annotation_Array) return Internal_Doc_Annotation_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Doc_Annotation_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new Internal_Doc_Annotation_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Doc_Annotation_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               not Equivalent (L.Items (I), R.Items (I))
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Doc_Annotation_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Accept_Stmt_Vectors is new Langkit_Support.Vectors (Internal_Entity_Accept_Stmt);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Accept_Stmt_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Accept_Stmt
   is
      function Absolute_Get
        (T : Internal_Entity_Accept_Stmt_Array_Access; Index : Integer)
         return Internal_Entity_Accept_Stmt
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Accept_Stmt,
         Sequence_Type => Internal_Entity_Accept_Stmt_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Accept_Stmt;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Accept_Stmt;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Accept_Stmt_Array_Access) return Internal_Entity_Accept_Stmt_Array_Access is
      Ret : Internal_Entity_Accept_Stmt_Array_Access := Create_Internal_Entity_Accept_Stmt_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Accept_Stmt_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Accept_Stmt_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Accept_Stmt_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Accept_Stmt_Array (Items_Count : Natural) return Internal_Entity_Accept_Stmt_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Accept_Stmt_Array_Type
       else new Internal_Entity_Accept_Stmt_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Accept_Stmt_Array
     (Items : Internal_Internal_Entity_Accept_Stmt_Array) return Internal_Entity_Accept_Stmt_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Accept_Stmt_Array_Type;
      end if;
      return new Internal_Entity_Accept_Stmt_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Accept_Stmt_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Accept_Stmt_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Vectors is new Langkit_Support.Vectors (Internal_Entity);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity
   is
      function Absolute_Get
        (T : Internal_Entity_Array_Access; Index : Integer)
         return Internal_Entity
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity,
         Sequence_Type => Internal_Entity_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Array_Access) return Internal_Entity_Array_Access is
      Ret : Internal_Entity_Array_Access := Create_Internal_Entity_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Array (Items_Count : Natural) return Internal_Entity_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Array_Type
       else new Internal_Entity_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Array
     (Items : AST_Envs.Entity_Array) return Internal_Entity_Array_Access
   is (if Items'Length = 0
       then No_Internal_Entity_Array_Type
       else new Internal_Entity_Array_Record'
         (N         => Items'Length,
          Items     => Implementation.Internal_Internal_Entity_Array (Items),
          Ref_Count => 1));
   function Create_Internal_Entity_Array
     (Items : Internal_Internal_Entity_Array) return Internal_Entity_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Array_Type;
      end if;
      return new Internal_Entity_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Base_Assoc_Vectors is new Langkit_Support.Vectors (Internal_Entity_Base_Assoc);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Base_Assoc_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Base_Assoc
   is
      function Absolute_Get
        (T : Internal_Entity_Base_Assoc_Array_Access; Index : Integer)
         return Internal_Entity_Base_Assoc
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Base_Assoc,
         Sequence_Type => Internal_Entity_Base_Assoc_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Base_Assoc;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Base_Assoc;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Base_Assoc_Array_Access) return Internal_Entity_Base_Assoc_Array_Access is
      Ret : Internal_Entity_Base_Assoc_Array_Access := Create_Internal_Entity_Base_Assoc_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Base_Assoc_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Base_Assoc_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Base_Assoc_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Base_Assoc_Array (Items_Count : Natural) return Internal_Entity_Base_Assoc_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Base_Assoc_Array_Type
       else new Internal_Entity_Base_Assoc_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Base_Assoc_Array
     (Items : Internal_Internal_Entity_Base_Assoc_Array) return Internal_Entity_Base_Assoc_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Base_Assoc_Array_Type;
      end if;
      return new Internal_Entity_Base_Assoc_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Base_Assoc_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Base_Assoc_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Base_Formal_Param_Decl_Vectors is new Langkit_Support.Vectors (Internal_Entity_Base_Formal_Param_Decl);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Base_Formal_Param_Decl
   is
      function Absolute_Get
        (T : Internal_Entity_Base_Formal_Param_Decl_Array_Access; Index : Integer)
         return Internal_Entity_Base_Formal_Param_Decl
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Base_Formal_Param_Decl,
         Sequence_Type => Internal_Entity_Base_Formal_Param_Decl_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Base_Formal_Param_Decl;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Base_Formal_Param_Decl;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Base_Formal_Param_Decl_Array_Access) return Internal_Entity_Base_Formal_Param_Decl_Array_Access is
      Ret : Internal_Entity_Base_Formal_Param_Decl_Array_Access := Create_Internal_Entity_Base_Formal_Param_Decl_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Base_Formal_Param_Decl_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Base_Formal_Param_Decl_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Base_Formal_Param_Decl_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Base_Formal_Param_Decl_Array (Items_Count : Natural) return Internal_Entity_Base_Formal_Param_Decl_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Base_Formal_Param_Decl_Array_Type
       else new Internal_Entity_Base_Formal_Param_Decl_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Base_Formal_Param_Decl_Array
     (Items : Internal_Internal_Entity_Base_Formal_Param_Decl_Array) return Internal_Entity_Base_Formal_Param_Decl_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
      end if;
      return new Internal_Entity_Base_Formal_Param_Decl_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Base_Formal_Param_Decl_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Base_Formal_Param_Decl_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Base_Type_Decl_Vectors is new Langkit_Support.Vectors (Internal_Entity_Base_Type_Decl);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Base_Type_Decl_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Base_Type_Decl
   is
      function Absolute_Get
        (T : Internal_Entity_Base_Type_Decl_Array_Access; Index : Integer)
         return Internal_Entity_Base_Type_Decl
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Base_Type_Decl,
         Sequence_Type => Internal_Entity_Base_Type_Decl_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Base_Type_Decl;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Base_Type_Decl;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Base_Type_Decl_Array_Access) return Internal_Entity_Base_Type_Decl_Array_Access is
      Ret : Internal_Entity_Base_Type_Decl_Array_Access := Create_Internal_Entity_Base_Type_Decl_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Base_Type_Decl_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Base_Type_Decl_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Base_Type_Decl_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Base_Type_Decl_Array (Items_Count : Natural) return Internal_Entity_Base_Type_Decl_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Base_Type_Decl_Array_Type
       else new Internal_Entity_Base_Type_Decl_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Base_Type_Decl_Array
     (Items : Internal_Internal_Entity_Base_Type_Decl_Array) return Internal_Entity_Base_Type_Decl_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Base_Type_Decl_Array_Type;
      end if;
      return new Internal_Entity_Base_Type_Decl_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Base_Type_Decl_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Base_Type_Decl_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      function Make_Unique (A : Internal_Entity_Base_Type_Decl_Array_Access) return Internal_Entity_Base_Type_Decl_Array_Access is
         --  To keep the order of the result deterministic, this function works
         --  in two steps. First, determine for each item in A whether it
         --  duplicate a previous item. Only then, go through all items in A
         --  and add only non-duplicated ones to the result.
         Duplicates : array (A.Items'Range) of Boolean := (others => False);
         --  For each item in A, indicate whether the value is a duplicate of a
         --  previous one in the array.
         Unique_Elements : Natural;
         --  Number of unique elements in A
      begin
         --  Step 1: compute Duplicates
         declare
            package Sets is new Ada.Containers.Hashed_Sets
              (Element_Type        => Internal_Entity_Base_Type_Decl,
               "="                 => "=",
               Equivalent_Elements => "=",
               Hash                => Hash);
            Set : Sets.Set;
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Entity_Base_Type_Decl renames A.Items (I);
               begin
                  if Set.Contains (Item) then
                     Duplicates (I) := True;
                  else
                     Set.Insert (Item);
                  end if;
               end;
            end loop;
            Unique_Elements := Natural (Set.Length);
         end;
         --  Step 2: create the result
         declare
            Next   : Positive := 1;
            Result : constant Internal_Entity_Base_Type_Decl_Array_Access :=
               Create_Internal_Entity_Base_Type_Decl_Array (Unique_Elements);
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Entity_Base_Type_Decl renames A.Items (I);
               begin
                  if not Duplicates (I) then
                     Result.Items (Next) := Item;
                     Next := Next + 1;
                  end if;
               end;
            end loop;
            pragma Assert (Next = Result.N + 1);
            return Result;
         end;
      end Make_Unique;
      ----------
      -- Hash --
      ----------
      function Hash (R : Internal_Entity_Base_Type_Decl_Array_Access) return Hash_Type is
         Result : Hash_Type := Initial_Hash;
      begin
         for I in R.Items'Range loop
            Result := Combine (Result, Hash (R.Items (I)));
         end loop;
         return Result;
      end Hash;
      package Internal_Entity_Basic_Assoc_Vectors is new Langkit_Support.Vectors (Internal_Entity_Basic_Assoc);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Basic_Assoc_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Basic_Assoc
   is
      function Absolute_Get
        (T : Internal_Entity_Basic_Assoc_Array_Access; Index : Integer)
         return Internal_Entity_Basic_Assoc
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Basic_Assoc,
         Sequence_Type => Internal_Entity_Basic_Assoc_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Basic_Assoc;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Basic_Assoc;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Basic_Assoc_Array_Access) return Internal_Entity_Basic_Assoc_Array_Access is
      Ret : Internal_Entity_Basic_Assoc_Array_Access := Create_Internal_Entity_Basic_Assoc_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Basic_Assoc_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Basic_Assoc_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Basic_Assoc_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Basic_Assoc_Array (Items_Count : Natural) return Internal_Entity_Basic_Assoc_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Basic_Assoc_Array_Type
       else new Internal_Entity_Basic_Assoc_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Basic_Assoc_Array
     (Items : Internal_Internal_Entity_Basic_Assoc_Array) return Internal_Entity_Basic_Assoc_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Basic_Assoc_Array_Type;
      end if;
      return new Internal_Entity_Basic_Assoc_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Basic_Assoc_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Basic_Assoc_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Basic_Decl_Vectors is new Langkit_Support.Vectors (Internal_Entity_Basic_Decl);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Basic_Decl_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Basic_Decl
   is
      function Absolute_Get
        (T : Internal_Entity_Basic_Decl_Array_Access; Index : Integer)
         return Internal_Entity_Basic_Decl
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Basic_Decl,
         Sequence_Type => Internal_Entity_Basic_Decl_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Basic_Decl;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Basic_Decl;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Basic_Decl_Array_Access) return Internal_Entity_Basic_Decl_Array_Access is
      Ret : Internal_Entity_Basic_Decl_Array_Access := Create_Internal_Entity_Basic_Decl_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Basic_Decl_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Basic_Decl_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Basic_Decl_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Basic_Decl_Array (Items_Count : Natural) return Internal_Entity_Basic_Decl_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Basic_Decl_Array_Type
       else new Internal_Entity_Basic_Decl_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Basic_Decl_Array
     (Items : Internal_Internal_Entity_Basic_Decl_Array) return Internal_Entity_Basic_Decl_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Basic_Decl_Array_Type;
      end if;
      return new Internal_Entity_Basic_Decl_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Basic_Decl_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Basic_Decl_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      function Make_Unique (A : Internal_Entity_Basic_Decl_Array_Access) return Internal_Entity_Basic_Decl_Array_Access is
         --  To keep the order of the result deterministic, this function works
         --  in two steps. First, determine for each item in A whether it
         --  duplicate a previous item. Only then, go through all items in A
         --  and add only non-duplicated ones to the result.
         Duplicates : array (A.Items'Range) of Boolean := (others => False);
         --  For each item in A, indicate whether the value is a duplicate of a
         --  previous one in the array.
         Unique_Elements : Natural;
         --  Number of unique elements in A
      begin
         --  Step 1: compute Duplicates
         declare
            package Sets is new Ada.Containers.Hashed_Sets
              (Element_Type        => Internal_Entity_Basic_Decl,
               "="                 => "=",
               Equivalent_Elements => "=",
               Hash                => Hash);
            Set : Sets.Set;
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Entity_Basic_Decl renames A.Items (I);
               begin
                  if Set.Contains (Item) then
                     Duplicates (I) := True;
                  else
                     Set.Insert (Item);
                  end if;
               end;
            end loop;
            Unique_Elements := Natural (Set.Length);
         end;
         --  Step 2: create the result
         declare
            Next   : Positive := 1;
            Result : constant Internal_Entity_Basic_Decl_Array_Access :=
               Create_Internal_Entity_Basic_Decl_Array (Unique_Elements);
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Entity_Basic_Decl renames A.Items (I);
               begin
                  if not Duplicates (I) then
                     Result.Items (Next) := Item;
                     Next := Next + 1;
                  end if;
               end;
            end loop;
            pragma Assert (Next = Result.N + 1);
            return Result;
         end;
      end Make_Unique;
      package Internal_Entity_Compilation_Unit_Vectors is new Langkit_Support.Vectors (Internal_Entity_Compilation_Unit);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Compilation_Unit_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Compilation_Unit
   is
      function Absolute_Get
        (T : Internal_Entity_Compilation_Unit_Array_Access; Index : Integer)
         return Internal_Entity_Compilation_Unit
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Compilation_Unit,
         Sequence_Type => Internal_Entity_Compilation_Unit_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Compilation_Unit;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Compilation_Unit;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Compilation_Unit_Array_Access) return Internal_Entity_Compilation_Unit_Array_Access is
      Ret : Internal_Entity_Compilation_Unit_Array_Access := Create_Internal_Entity_Compilation_Unit_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Compilation_Unit_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Compilation_Unit_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Compilation_Unit_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Compilation_Unit_Array (Items_Count : Natural) return Internal_Entity_Compilation_Unit_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Compilation_Unit_Array_Type
       else new Internal_Entity_Compilation_Unit_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Compilation_Unit_Array
     (Items : Internal_Internal_Entity_Compilation_Unit_Array) return Internal_Entity_Compilation_Unit_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Compilation_Unit_Array_Type;
      end if;
      return new Internal_Entity_Compilation_Unit_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Compilation_Unit_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Compilation_Unit_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      function Make_Unique (A : Internal_Entity_Compilation_Unit_Array_Access) return Internal_Entity_Compilation_Unit_Array_Access is
         --  To keep the order of the result deterministic, this function works
         --  in two steps. First, determine for each item in A whether it
         --  duplicate a previous item. Only then, go through all items in A
         --  and add only non-duplicated ones to the result.
         Duplicates : array (A.Items'Range) of Boolean := (others => False);
         --  For each item in A, indicate whether the value is a duplicate of a
         --  previous one in the array.
         Unique_Elements : Natural;
         --  Number of unique elements in A
      begin
         --  Step 1: compute Duplicates
         declare
            package Sets is new Ada.Containers.Hashed_Sets
              (Element_Type        => Internal_Entity_Compilation_Unit,
               "="                 => "=",
               Equivalent_Elements => "=",
               Hash                => Hash);
            Set : Sets.Set;
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Entity_Compilation_Unit renames A.Items (I);
               begin
                  if Set.Contains (Item) then
                     Duplicates (I) := True;
                  else
                     Set.Insert (Item);
                  end if;
               end;
            end loop;
            Unique_Elements := Natural (Set.Length);
         end;
         --  Step 2: create the result
         declare
            Next   : Positive := 1;
            Result : constant Internal_Entity_Compilation_Unit_Array_Access :=
               Create_Internal_Entity_Compilation_Unit_Array (Unique_Elements);
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Entity_Compilation_Unit renames A.Items (I);
               begin
                  if not Duplicates (I) then
                     Result.Items (Next) := Item;
                     Next := Next + 1;
                  end if;
               end;
            end loop;
            pragma Assert (Next = Result.N + 1);
            return Result;
         end;
      end Make_Unique;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Declarative_Part_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Declarative_Part
   is
      function Absolute_Get
        (T : Internal_Entity_Declarative_Part_Array_Access; Index : Integer)
         return Internal_Entity_Declarative_Part
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Declarative_Part,
         Sequence_Type => Internal_Entity_Declarative_Part_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Declarative_Part;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Declarative_Part;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Declarative_Part_Array_Access) return Internal_Entity_Declarative_Part_Array_Access is
      Ret : Internal_Entity_Declarative_Part_Array_Access := Create_Internal_Entity_Declarative_Part_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Declarative_Part_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Declarative_Part_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Declarative_Part_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Declarative_Part_Array (Items_Count : Natural) return Internal_Entity_Declarative_Part_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Declarative_Part_Array_Type
       else new Internal_Entity_Declarative_Part_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Declarative_Part_Array
     (Items : Internal_Internal_Entity_Declarative_Part_Array) return Internal_Entity_Declarative_Part_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Declarative_Part_Array_Type;
      end if;
      return new Internal_Entity_Declarative_Part_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Declarative_Part_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Declarative_Part_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Defining_Name_Vectors is new Langkit_Support.Vectors (Internal_Entity_Defining_Name);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Defining_Name_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Defining_Name
   is
      function Absolute_Get
        (T : Internal_Entity_Defining_Name_Array_Access; Index : Integer)
         return Internal_Entity_Defining_Name
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Defining_Name,
         Sequence_Type => Internal_Entity_Defining_Name_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Defining_Name;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Defining_Name;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Defining_Name_Array_Access) return Internal_Entity_Defining_Name_Array_Access is
      Ret : Internal_Entity_Defining_Name_Array_Access := Create_Internal_Entity_Defining_Name_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Defining_Name_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Defining_Name_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Defining_Name_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Defining_Name_Array (Items_Count : Natural) return Internal_Entity_Defining_Name_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Defining_Name_Array_Type
       else new Internal_Entity_Defining_Name_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Defining_Name_Array
     (Items : Internal_Internal_Entity_Defining_Name_Array) return Internal_Entity_Defining_Name_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Defining_Name_Array_Type;
      end if;
      return new Internal_Entity_Defining_Name_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Defining_Name_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Defining_Name_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Expr_Vectors is new Langkit_Support.Vectors (Internal_Entity_Expr);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Expr_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Expr
   is
      function Absolute_Get
        (T : Internal_Entity_Expr_Array_Access; Index : Integer)
         return Internal_Entity_Expr
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Expr,
         Sequence_Type => Internal_Entity_Expr_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Expr;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Expr;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Expr_Array_Access) return Internal_Entity_Expr_Array_Access is
      Ret : Internal_Entity_Expr_Array_Access := Create_Internal_Entity_Expr_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Expr_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Expr_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Expr_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Expr_Array (Items_Count : Natural) return Internal_Entity_Expr_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Expr_Array_Type
       else new Internal_Entity_Expr_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Expr_Array
     (Items : Internal_Internal_Entity_Expr_Array) return Internal_Entity_Expr_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Expr_Array_Type;
      end if;
      return new Internal_Entity_Expr_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Expr_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Expr_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Generic_Instantiation_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Generic_Instantiation
   is
      function Absolute_Get
        (T : Internal_Entity_Generic_Instantiation_Array_Access; Index : Integer)
         return Internal_Entity_Generic_Instantiation
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Generic_Instantiation,
         Sequence_Type => Internal_Entity_Generic_Instantiation_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Generic_Instantiation;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Generic_Instantiation;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Generic_Instantiation_Array_Access) return Internal_Entity_Generic_Instantiation_Array_Access is
      Ret : Internal_Entity_Generic_Instantiation_Array_Access := Create_Internal_Entity_Generic_Instantiation_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Generic_Instantiation_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Generic_Instantiation_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Generic_Instantiation_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Generic_Instantiation_Array (Items_Count : Natural) return Internal_Entity_Generic_Instantiation_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Generic_Instantiation_Array_Type
       else new Internal_Entity_Generic_Instantiation_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Generic_Instantiation_Array
     (Items : Internal_Internal_Entity_Generic_Instantiation_Array) return Internal_Entity_Generic_Instantiation_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Generic_Instantiation_Array_Type;
      end if;
      return new Internal_Entity_Generic_Instantiation_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Generic_Instantiation_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Generic_Instantiation_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Identifier_Vectors is new Langkit_Support.Vectors (Internal_Entity_Identifier);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Identifier_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Identifier
   is
      function Absolute_Get
        (T : Internal_Entity_Identifier_Array_Access; Index : Integer)
         return Internal_Entity_Identifier
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Identifier,
         Sequence_Type => Internal_Entity_Identifier_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Identifier;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Identifier;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Identifier_Array_Access) return Internal_Entity_Identifier_Array_Access is
      Ret : Internal_Entity_Identifier_Array_Access := Create_Internal_Entity_Identifier_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Identifier_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Identifier_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Identifier_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Identifier_Array (Items_Count : Natural) return Internal_Entity_Identifier_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Identifier_Array_Type
       else new Internal_Entity_Identifier_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Identifier_Array
     (Items : Internal_Internal_Entity_Identifier_Array) return Internal_Entity_Identifier_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Identifier_Array_Type;
      end if;
      return new Internal_Entity_Identifier_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Identifier_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Identifier_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Mode_Vectors is new Langkit_Support.Vectors (Internal_Entity_Mode);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Mode_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Mode
   is
      function Absolute_Get
        (T : Internal_Entity_Mode_Array_Access; Index : Integer)
         return Internal_Entity_Mode
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Mode,
         Sequence_Type => Internal_Entity_Mode_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Mode;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Mode;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Mode_Array_Access) return Internal_Entity_Mode_Array_Access is
      Ret : Internal_Entity_Mode_Array_Access := Create_Internal_Entity_Mode_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Mode_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Mode_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Mode_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Mode_Array (Items_Count : Natural) return Internal_Entity_Mode_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Mode_Array_Type
       else new Internal_Entity_Mode_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Mode_Array
     (Items : Internal_Internal_Entity_Mode_Array) return Internal_Entity_Mode_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Mode_Array_Type;
      end if;
      return new Internal_Entity_Mode_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Mode_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Mode_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Name_Vectors is new Langkit_Support.Vectors (Internal_Entity_Name);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Name_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Name
   is
      function Absolute_Get
        (T : Internal_Entity_Name_Array_Access; Index : Integer)
         return Internal_Entity_Name
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Name,
         Sequence_Type => Internal_Entity_Name_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Name;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Name;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Name_Array_Access) return Internal_Entity_Name_Array_Access is
      Ret : Internal_Entity_Name_Array_Access := Create_Internal_Entity_Name_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Name_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Name_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Name_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Name_Array (Items_Count : Natural) return Internal_Entity_Name_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Name_Array_Type
       else new Internal_Entity_Name_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Name_Array
     (Items : Internal_Internal_Entity_Name_Array) return Internal_Entity_Name_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Name_Array_Type;
      end if;
      return new Internal_Entity_Name_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Name_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Name_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Param_Spec_Vectors is new Langkit_Support.Vectors (Internal_Entity_Param_Spec);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Param_Spec_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Param_Spec
   is
      function Absolute_Get
        (T : Internal_Entity_Param_Spec_Array_Access; Index : Integer)
         return Internal_Entity_Param_Spec
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Param_Spec,
         Sequence_Type => Internal_Entity_Param_Spec_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Param_Spec;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Param_Spec;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Param_Spec_Array_Access) return Internal_Entity_Param_Spec_Array_Access is
      Ret : Internal_Entity_Param_Spec_Array_Access := Create_Internal_Entity_Param_Spec_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Param_Spec_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Param_Spec_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Param_Spec_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Param_Spec_Array (Items_Count : Natural) return Internal_Entity_Param_Spec_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Param_Spec_Array_Type
       else new Internal_Entity_Param_Spec_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Param_Spec_Array
     (Items : Internal_Internal_Entity_Param_Spec_Array) return Internal_Entity_Param_Spec_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Param_Spec_Array_Type;
      end if;
      return new Internal_Entity_Param_Spec_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Param_Spec_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Param_Spec_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Pragma_Node_Vectors is new Langkit_Support.Vectors (Internal_Entity_Pragma_Node);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Pragma_Node_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Pragma_Node
   is
      function Absolute_Get
        (T : Internal_Entity_Pragma_Node_Array_Access; Index : Integer)
         return Internal_Entity_Pragma_Node
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Pragma_Node,
         Sequence_Type => Internal_Entity_Pragma_Node_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Pragma_Node;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Pragma_Node;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Pragma_Node_Array_Access) return Internal_Entity_Pragma_Node_Array_Access is
      Ret : Internal_Entity_Pragma_Node_Array_Access := Create_Internal_Entity_Pragma_Node_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Pragma_Node_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Pragma_Node_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Pragma_Node_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Pragma_Node_Array (Items_Count : Natural) return Internal_Entity_Pragma_Node_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Pragma_Node_Array_Type
       else new Internal_Entity_Pragma_Node_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Pragma_Node_Array
     (Items : Internal_Internal_Entity_Pragma_Node_Array) return Internal_Entity_Pragma_Node_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Pragma_Node_Array_Type;
      end if;
      return new Internal_Entity_Pragma_Node_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Pragma_Node_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Pragma_Node_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Type_Decl_Vectors is new Langkit_Support.Vectors (Internal_Entity_Type_Decl);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Type_Decl_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Type_Decl
   is
      function Absolute_Get
        (T : Internal_Entity_Type_Decl_Array_Access; Index : Integer)
         return Internal_Entity_Type_Decl
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Type_Decl,
         Sequence_Type => Internal_Entity_Type_Decl_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Type_Decl;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Type_Decl;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Type_Decl_Array_Access) return Internal_Entity_Type_Decl_Array_Access is
      Ret : Internal_Entity_Type_Decl_Array_Access := Create_Internal_Entity_Type_Decl_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Type_Decl_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Type_Decl_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Type_Decl_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Type_Decl_Array (Items_Count : Natural) return Internal_Entity_Type_Decl_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Type_Decl_Array_Type
       else new Internal_Entity_Type_Decl_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Type_Decl_Array
     (Items : Internal_Internal_Entity_Type_Decl_Array) return Internal_Entity_Type_Decl_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Type_Decl_Array_Type;
      end if;
      return new Internal_Entity_Type_Decl_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Type_Decl_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Type_Decl_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Entity_Type_Expr_Vectors is new Langkit_Support.Vectors (Internal_Entity_Type_Expr);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Entity_Type_Expr_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Entity_Type_Expr
   is
      function Absolute_Get
        (T : Internal_Entity_Type_Expr_Array_Access; Index : Integer)
         return Internal_Entity_Type_Expr
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Entity_Type_Expr,
         Sequence_Type => Internal_Entity_Type_Expr_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Entity_Type_Expr;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Entity_Type_Expr;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Entity_Type_Expr_Array_Access) return Internal_Entity_Type_Expr_Array_Access is
      Ret : Internal_Entity_Type_Expr_Array_Access := Create_Internal_Entity_Type_Expr_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Type_Expr_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Entity_Type_Expr_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Type_Expr_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Entity_Type_Expr_Array (Items_Count : Natural) return Internal_Entity_Type_Expr_Array_Access
   is (if Items_Count = 0
       then No_Internal_Entity_Type_Expr_Array_Type
       else new Internal_Entity_Type_Expr_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Entity_Type_Expr_Array
     (Items : Internal_Internal_Entity_Type_Expr_Array) return Internal_Entity_Type_Expr_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Entity_Type_Expr_Array_Type;
      end if;
      return new Internal_Entity_Type_Expr_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Entity_Type_Expr_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Type_Expr_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Env_Assoc_Vectors is new Langkit_Support.Vectors (Internal_Env_Assoc);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Env_Assoc_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Env_Assoc
   is
      function Absolute_Get
        (T : Internal_Env_Assoc_Array_Access; Index : Integer)
         return Internal_Env_Assoc
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Env_Assoc,
         Sequence_Type => Internal_Env_Assoc_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Env_Assoc;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return No_Env_Assoc;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Env_Assoc_Array_Access) return Internal_Env_Assoc_Array_Access is
      Ret : Internal_Env_Assoc_Array_Access := Create_Internal_Env_Assoc_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Env_Assoc_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Env_Assoc_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Env_Assoc_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Env_Assoc_Array (Items_Count : Natural) return Internal_Env_Assoc_Array_Access
   is (if Items_Count = 0
       then No_Internal_Env_Assoc_Array_Type
       else new Internal_Env_Assoc_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Env_Assoc_Array
     (Items : Internal_Internal_Env_Assoc_Array) return Internal_Env_Assoc_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Env_Assoc_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new Internal_Env_Assoc_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Env_Assoc_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               not Equivalent (L.Items (I), R.Items (I))
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Env_Assoc_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Expected_Type_For_Expr_Vectors is new Langkit_Support.Vectors (Internal_Expected_Type_For_Expr);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Expected_Type_For_Expr_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Expected_Type_For_Expr
   is
      function Absolute_Get
        (T : Internal_Expected_Type_For_Expr_Array_Access; Index : Integer)
         return Internal_Expected_Type_For_Expr
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Expected_Type_For_Expr,
         Sequence_Type => Internal_Expected_Type_For_Expr_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Expected_Type_For_Expr;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Expected_Type_For_Expr;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Expected_Type_For_Expr_Array_Access) return Internal_Expected_Type_For_Expr_Array_Access is
      Ret : Internal_Expected_Type_For_Expr_Array_Access := Create_Internal_Expected_Type_For_Expr_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Expected_Type_For_Expr_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Expected_Type_For_Expr_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Expected_Type_For_Expr_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Expected_Type_For_Expr_Array (Items_Count : Natural) return Internal_Expected_Type_For_Expr_Array_Access
   is (if Items_Count = 0
       then No_Internal_Expected_Type_For_Expr_Array_Type
       else new Internal_Expected_Type_For_Expr_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Expected_Type_For_Expr_Array
     (Items : Internal_Internal_Expected_Type_For_Expr_Array) return Internal_Expected_Type_For_Expr_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Expected_Type_For_Expr_Array_Type;
      end if;
      return new Internal_Expected_Type_For_Expr_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Expected_Type_For_Expr_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Expected_Type_For_Expr_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Inner_Env_Assoc_Vectors is new Langkit_Support.Vectors (Internal_Inner_Env_Assoc);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Inner_Env_Assoc_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Inner_Env_Assoc
   is
      function Absolute_Get
        (T : Internal_Inner_Env_Assoc_Array_Access; Index : Integer)
         return Internal_Inner_Env_Assoc
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Inner_Env_Assoc,
         Sequence_Type => Internal_Inner_Env_Assoc_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Inner_Env_Assoc;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Inner_Env_Assoc;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Inner_Env_Assoc_Array_Access) return Internal_Inner_Env_Assoc_Array_Access is
      Ret : Internal_Inner_Env_Assoc_Array_Access := Create_Internal_Inner_Env_Assoc_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Inner_Env_Assoc_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Inner_Env_Assoc_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Inner_Env_Assoc_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Inner_Env_Assoc_Array (Items_Count : Natural) return Internal_Inner_Env_Assoc_Array_Access
   is (if Items_Count = 0
       then No_Internal_Inner_Env_Assoc_Array_Type
       else new Internal_Inner_Env_Assoc_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Inner_Env_Assoc_Array
     (Items : Internal_Internal_Inner_Env_Assoc_Array) return Internal_Inner_Env_Assoc_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Inner_Env_Assoc_Array_Type;
      end if;
      return new Internal_Inner_Env_Assoc_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Inner_Env_Assoc_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Inner_Env_Assoc_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Param_Actual_Vectors is new Langkit_Support.Vectors (Internal_Param_Actual);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Param_Actual_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Param_Actual
   is
      function Absolute_Get
        (T : Internal_Param_Actual_Array_Access; Index : Integer)
         return Internal_Param_Actual
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Param_Actual,
         Sequence_Type => Internal_Param_Actual_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Param_Actual;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Param_Actual;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Param_Actual_Array_Access) return Internal_Param_Actual_Array_Access is
      Ret : Internal_Param_Actual_Array_Access := Create_Internal_Param_Actual_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Param_Actual_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Param_Actual_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Param_Actual_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Param_Actual_Array (Items_Count : Natural) return Internal_Param_Actual_Array_Access
   is (if Items_Count = 0
       then No_Internal_Param_Actual_Array_Type
       else new Internal_Param_Actual_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Param_Actual_Array
     (Items : Internal_Internal_Param_Actual_Array) return Internal_Param_Actual_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Param_Actual_Array_Type;
      end if;
      return new Internal_Param_Actual_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Param_Actual_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Param_Actual_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Param_Match_Vectors is new Langkit_Support.Vectors (Internal_Param_Match);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Param_Match_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Param_Match
   is
      function Absolute_Get
        (T : Internal_Param_Match_Array_Access; Index : Integer)
         return Internal_Param_Match
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Param_Match,
         Sequence_Type => Internal_Param_Match_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Param_Match;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Param_Match;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Param_Match_Array_Access) return Internal_Param_Match_Array_Access is
      Ret : Internal_Param_Match_Array_Access := Create_Internal_Param_Match_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Param_Match_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Param_Match_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Param_Match_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Param_Match_Array (Items_Count : Natural) return Internal_Param_Match_Array_Access
   is (if Items_Count = 0
       then No_Internal_Param_Match_Array_Type
       else new Internal_Param_Match_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Param_Match_Array
     (Items : Internal_Internal_Param_Match_Array) return Internal_Param_Match_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Param_Match_Array_Type;
      end if;
      return new Internal_Param_Match_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Param_Match_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Param_Match_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Ref_Result_Vectors is new Langkit_Support.Vectors (Internal_Ref_Result);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Ref_Result_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Ref_Result
   is
      function Absolute_Get
        (T : Internal_Ref_Result_Array_Access; Index : Integer)
         return Internal_Ref_Result
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Ref_Result,
         Sequence_Type => Internal_Ref_Result_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Ref_Result;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Ref_Result;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Ref_Result_Array_Access) return Internal_Ref_Result_Array_Access is
      Ret : Internal_Ref_Result_Array_Access := Create_Internal_Ref_Result_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Ref_Result_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Ref_Result_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Ref_Result_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Ref_Result_Array (Items_Count : Natural) return Internal_Ref_Result_Array_Access
   is (if Items_Count = 0
       then No_Internal_Ref_Result_Array_Type
       else new Internal_Ref_Result_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Ref_Result_Array
     (Items : Internal_Internal_Ref_Result_Array) return Internal_Ref_Result_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Ref_Result_Array_Type;
      end if;
      return new Internal_Ref_Result_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Ref_Result_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Ref_Result_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Shape_Vectors is new Langkit_Support.Vectors (Internal_Shape);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Shape_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Shape
   is
      function Absolute_Get
        (T : Internal_Shape_Array_Access; Index : Integer)
         return Internal_Shape
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Shape,
         Sequence_Type => Internal_Shape_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Shape;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return No_Shape;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Shape_Array_Access) return Internal_Shape_Array_Access is
      Ret : Internal_Shape_Array_Access := Create_Internal_Shape_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Shape_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Shape_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Shape_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Shape_Array (Items_Count : Natural) return Internal_Shape_Array_Access
   is (if Items_Count = 0
       then No_Internal_Shape_Array_Type
       else new Internal_Shape_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Shape_Array
     (Items : Internal_Internal_Shape_Array) return Internal_Shape_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Shape_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new Internal_Shape_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Shape_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               not Equivalent (L.Items (I), R.Items (I))
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Shape_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Single_Actual_Vectors is new Langkit_Support.Vectors (Internal_Single_Actual);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Single_Actual_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Single_Actual
   is
      function Absolute_Get
        (T : Internal_Single_Actual_Array_Access; Index : Integer)
         return Internal_Single_Actual
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Single_Actual,
         Sequence_Type => Internal_Single_Actual_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Single_Actual;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return No_Single_Actual;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Single_Actual_Array_Access) return Internal_Single_Actual_Array_Access is
      Ret : Internal_Single_Actual_Array_Access := Create_Internal_Single_Actual_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Single_Actual_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Single_Actual_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Single_Actual_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Single_Actual_Array (Items_Count : Natural) return Internal_Single_Actual_Array_Access
   is (if Items_Count = 0
       then No_Internal_Single_Actual_Array_Type
       else new Internal_Single_Actual_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Single_Actual_Array
     (Items : Internal_Internal_Single_Actual_Array) return Internal_Single_Actual_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Single_Actual_Array_Type;
      end if;
      return new Internal_Single_Actual_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Single_Actual_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Single_Actual_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Substitution_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Substitution
   is
      function Absolute_Get
        (T : Internal_Substitution_Array_Access; Index : Integer)
         return Internal_Substitution
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Substitution,
         Sequence_Type => Internal_Substitution_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Substitution;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return No_Substitution;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Substitution_Array_Access) return Internal_Substitution_Array_Access is
      Ret : Internal_Substitution_Array_Access := Create_Internal_Substitution_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Substitution_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Substitution_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Substitution_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Substitution_Array (Items_Count : Natural) return Internal_Substitution_Array_Access
   is (if Items_Count = 0
       then No_Internal_Substitution_Array_Type
       else new Internal_Substitution_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Substitution_Array
     (Items : Internal_Internal_Substitution_Array) return Internal_Substitution_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Substitution_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new Internal_Substitution_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Substitution_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               not Equivalent (L.Items (I), R.Items (I))
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Substitution_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Internal_Unit_Vectors is new Langkit_Support.Vectors (Internal_Unit);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Internal_Unit_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Internal_Unit
   is
      function Absolute_Get
        (T : Internal_Unit_Array_Access; Index : Integer)
         return Internal_Unit
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Internal_Unit,
         Sequence_Type => Internal_Unit_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Internal_Unit;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return null;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Internal_Unit_Array_Access) return Internal_Unit_Array_Access is
      Ret : Internal_Unit_Array_Access := Create_Internal_Unit_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Unit_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Internal_Unit_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Unit_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Internal_Unit_Array (Items_Count : Natural) return Internal_Unit_Array_Access
   is (if Items_Count = 0
       then No_Internal_Unit_Array_Type
       else new Internal_Unit_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Internal_Unit_Array
     (Items : Internal_Internal_Unit_Array) return Internal_Unit_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Internal_Unit_Array_Type;
      end if;
      return new Internal_Unit_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Internal_Unit_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Unit_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      function Make_Unique (A : Internal_Unit_Array_Access) return Internal_Unit_Array_Access is
         --  To keep the order of the result deterministic, this function works
         --  in two steps. First, determine for each item in A whether it
         --  duplicate a previous item. Only then, go through all items in A
         --  and add only non-duplicated ones to the result.
         Duplicates : array (A.Items'Range) of Boolean := (others => False);
         --  For each item in A, indicate whether the value is a duplicate of a
         --  previous one in the array.
         Unique_Elements : Natural;
         --  Number of unique elements in A
      begin
         --  Step 1: compute Duplicates
         declare
            package Sets is new Ada.Containers.Hashed_Sets
              (Element_Type        => Internal_Unit,
               "="                 => "=",
               Equivalent_Elements => "=",
               Hash                => Hash);
            Set : Sets.Set;
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Unit renames A.Items (I);
               begin
                  if Set.Contains (Item) then
                     Duplicates (I) := True;
                  else
                     Set.Insert (Item);
                  end if;
               end;
            end loop;
            Unique_Elements := Natural (Set.Length);
         end;
         --  Step 2: create the result
         declare
            Next   : Positive := 1;
            Result : constant Internal_Unit_Array_Access :=
               Create_Internal_Unit_Array (Unique_Elements);
         begin
            for I in A.Items'Range loop
               declare
                  Item : Internal_Unit renames A.Items (I);
               begin
                  if not Duplicates (I) then
                     Result.Items (Next) := Item;
                     Next := Next + 1;
                  end if;
               end;
            end loop;
            pragma Assert (Next = Result.N + 1);
            return Result;
         end;
      end Make_Unique;
      package Lexical_Env_Vectors is new Langkit_Support.Vectors (Lexical_Env);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Lexical_Env_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Lexical_Env
   is
      function Absolute_Get
        (T : Lexical_Env_Array_Access; Index : Integer)
         return Lexical_Env
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Lexical_Env,
         Sequence_Type => Lexical_Env_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Lexical_Env;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return Empty_Env;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Lexical_Env_Array_Access) return Lexical_Env_Array_Access is
      Ret : Lexical_Env_Array_Access := Create_Lexical_Env_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Lexical_Env_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Lexical_Env_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Lexical_Env_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Lexical_Env_Array (Items_Count : Natural) return Lexical_Env_Array_Access
   is (if Items_Count = 0
       then No_Lexical_Env_Array_Type
       else new Lexical_Env_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Lexical_Env_Array
     (Items : Internal_Lexical_Env_Array) return Lexical_Env_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Lexical_Env_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new Lexical_Env_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Lexical_Env_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               not Equivalent (L.Items (I), R.Items (I))
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Lexical_Env_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Logic_Equation_Vectors is new Langkit_Support.Vectors (Logic_Equation);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Logic_Equation_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Logic_Equation
   is
      function Absolute_Get
        (T : Logic_Equation_Array_Access; Index : Integer)
         return Logic_Equation
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Logic_Equation,
         Sequence_Type => Logic_Equation_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Logic_Equation;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return Null_Logic_Equation;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Logic_Equation_Array_Access) return Logic_Equation_Array_Access is
      Ret : Logic_Equation_Array_Access := Create_Logic_Equation_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Logic_Equation_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Logic_Equation_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Logic_Equation_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Logic_Equation_Array (Items_Count : Natural) return Logic_Equation_Array_Access
   is (if Items_Count = 0
       then No_Logic_Equation_Array_Type
       else new Logic_Equation_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Logic_Equation_Array
     (Items : Internal_Logic_Equation_Array) return Logic_Equation_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Logic_Equation_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new Logic_Equation_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Logic_Equation_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Logic_Equation_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package String_Type_Vectors is new Langkit_Support.Vectors (String_Type);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : String_Type_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return String_Type
   is
      function Absolute_Get
        (T : String_Type_Array_Access; Index : Integer)
         return String_Type
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => String_Type,
         Sequence_Type => String_Type_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : String_Type;
   begin
      if Relative_Get (T, Index, Result) then
            Inc_Ref (Result);
         return Result;
      elsif Or_Null then
         return Empty_String;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : String_Type_Array_Access) return String_Type_Array_Access is
      Ret : String_Type_Array_Access := Create_String_Type_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
         for Item of Ret.Items loop
            Inc_Ref (Item);
         end loop;
      return Ret;
   end Concat;
      ------------------
      -- Join_Strings --
      ------------------
      function Join_Strings
        (Separator : String_Type;
         Strings   : String_Type_Array_Access) return String_Type
      is
         Separator_Length : constant Natural := Separator.Length;
         Length           : Natural := 0;
         First            : Boolean;
      begin
         --  First, compute the length of the result: the sum of all string
         --  lengths in Strings.
         First := True;
         for S of Strings.Items loop
            if First then
               First := False;
            else
               Length := Length + Separator_Length;
            end if;
            Length := Length + S.Length;
         end loop;
         --  Create the result string with the correct length. Do not use our
         --  constructor and initialize the content in-place, to avoid extra
         --  copies.
         return Result : constant String_Type :=
            new String_Record (Length)
         do
            Result.Ref_Count := 1;
            --  Now copy the content of all strings into the result
            declare
               Last : Natural := 0;
            begin
               First := True;
               for S of Strings.Items loop
                  if First then
                     First := False;
                  else
                     Result.Content (Last + 1 .. Last + Separator_Length) :=
                        Separator.Content;
                     Last := Last + Separator_Length;
                  end if;
                  Result.Content (Last + 1 .. Last + S.Length) := S.Content;
                  Last := Last + S.Length;
               end loop;
            end;
         end return;
      end Join_Strings;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : String_Type_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : String_Type_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out String_Type_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
            for Item of T.Items loop
               Dec_Ref (Item);
            end loop;
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_String_Type_Array (Items_Count : Natural) return String_Type_Array_Access
   is (if Items_Count = 0
       then No_String_Type_Array_Type
       else new String_Type_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_String_Type_Array
     (Items : Internal_String_Type_Array) return String_Type_Array_Access is
   begin
      if Items'Length = 0 then
         return No_String_Type_Array_Type;
      end if;
         for El of Items loop
            Inc_Ref (El);
         end loop;
      return new String_Type_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : String_Type_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               not Equivalent (L.Items (I), R.Items (I))
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : String_Type_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
      package Symbol_Type_Vectors is new Langkit_Support.Vectors (Symbol_Type);
   ---------
   -- Get --
   ---------
   function Get
     (Node    : Bare_Ada_Node;
      T       : Symbol_Type_Array_Access;
      Index   : Integer;
      Or_Null : Boolean := False) return Symbol_Type
   is
      function Absolute_Get
        (T : Symbol_Type_Array_Access; Index : Integer)
         return Symbol_Type
      is
        (T.Items (Index + 1)); --  T.Items is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Symbol_Type,
         Sequence_Type => Symbol_Type_Array_Access,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Symbol_Type;
   begin
      if Relative_Get (T, Index, Result) then
         return Result;
      elsif Or_Null then
         return null;
      else
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "out-of-bounds array access");
      end if;
   end Get;
   ------------
   -- Concat --
   ------------
   function Concat (L, R : Symbol_Type_Array_Access) return Symbol_Type_Array_Access is
      Ret : Symbol_Type_Array_Access := Create_Symbol_Type_Array (Length (L) + Length (R));
   begin
      Ret.Items := L.Items & R.Items;
      return Ret;
   end Concat;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Symbol_Type_Array_Access) is
   begin
      if T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   ------------
   -- Length --
   ------------
   function Length (T : Symbol_Type_Array_Access) return Natural is (T.N);
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Symbol_Type_Array_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
   function Create_Symbol_Type_Array (Items_Count : Natural) return Symbol_Type_Array_Access
   is (if Items_Count = 0
       then No_Symbol_Type_Array_Type
       else new Symbol_Type_Array_Record'(N => Items_Count, Ref_Count => 1, Items => <>));
   function Create_Symbol_Type_Array
     (Items : Internal_Symbol_Type_Array) return Symbol_Type_Array_Access is
   begin
      if Items'Length = 0 then
         return No_Symbol_Type_Array_Type;
      end if;
      return new Symbol_Type_Array_Record'
        (N => Items'Length, Ref_Count => 1, Items => Items);
   end;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (L, R : Symbol_Type_Array_Access) return Boolean is
   begin
      if L.N /= R.N then
         return False;
      end if;
      for I in L.Items'Range loop
         if
               L.Items (I) /= R.Items (I)
         then
            return False;
         end if;
      end loop;
      return True;
   end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Symbol_Type_Array_Access) return String is
         Result : Unbounded_String;
      begin
         Append (Result, "[");
         for I in A.Items'Range loop
            if I > A.Items'First then
               Append (Result, ", ");
            end if;
            Append (Result, Trace_Image (A.Items (I)));
         end loop;
         Append (Result, "]");
         return To_String (Result);
      end Trace_Image;
   ----------
   -- Next --
   ----------
   function Next
     (T       : Bare_Ada_Node_Iterator_Access;
      Element : out Bare_Ada_Node) return Boolean is
   begin
      if T = null then
         raise Property_Error with "null access dereference";
      end if;
      Check_Safety_Net (T.Safety_Net);
      if T.Index > T.Elements.Items'Last then
         return False;
      else
         Element := T.Elements.Items (T.Index);
         T.Index := T.Index + 1;
         return True;
      end if;
   end Next;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Bare_Ada_Node_Iterator_Access) is
   begin
      if T /= null and then T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Bare_Ada_Node_Iterator_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Dec_Ref (T.Elements);
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Bare_Ada_Node_Iterator_Access) return String is
      begin
         return "<Iterator of AdaNode, index="
                & A.Index'Image & ">";
      end Trace_Image;
   ----------
   -- Next --
   ----------
   function Next
     (T       : Internal_Completion_Item_Iterator_Access;
      Element : out Internal_Completion_Item) return Boolean is
   begin
      if T = null then
         raise Property_Error with "null access dereference";
      end if;
      Check_Safety_Net (T.Safety_Net);
      if T.Index > T.Elements.Items'Last then
         return False;
      else
         Element := T.Elements.Items (T.Index);
         T.Index := T.Index + 1;
         return True;
      end if;
   end Next;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Completion_Item_Iterator_Access) is
   begin
      if T /= null and then T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Completion_Item_Iterator_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Dec_Ref (T.Elements);
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Completion_Item_Iterator_Access) return String is
      begin
         return "<Iterator of CompletionItem, index="
                & A.Index'Image & ">";
      end Trace_Image;
   ----------
   -- Next --
   ----------
   function Next
     (T       : Internal_Entity_Iterator_Access;
      Element : out Internal_Entity) return Boolean is
   begin
      if T = null then
         raise Property_Error with "null access dereference";
      end if;
      Check_Safety_Net (T.Safety_Net);
      if T.Index > T.Elements.Items'Last then
         return False;
      else
         Element := T.Elements.Items (T.Index);
         T.Index := T.Index + 1;
         return True;
      end if;
   end Next;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Entity_Iterator_Access) is
   begin
      if T /= null and then T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Entity_Iterator_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Dec_Ref (T.Elements);
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Entity_Iterator_Access) return String is
      begin
         return "<Iterator of AdaNode.entity, index="
                & A.Index'Image & ">";
      end Trace_Image;
   ----------
   -- Next --
   ----------
   function Next
     (T       : Internal_Inner_Env_Assoc_Iterator_Access;
      Element : out Internal_Inner_Env_Assoc) return Boolean is
   begin
      if T = null then
         raise Property_Error with "null access dereference";
      end if;
      Check_Safety_Net (T.Safety_Net);
      if T.Index > T.Elements.Items'Last then
         return False;
      else
         Element := T.Elements.Items (T.Index);
         T.Index := T.Index + 1;
         return True;
      end if;
   end Next;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (T : Internal_Inner_Env_Assoc_Iterator_Access) is
   begin
      if T /= null and then T.Ref_Count >= 0 then
         T.Ref_Count := T.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (T : in out Internal_Inner_Env_Assoc_Iterator_Access) is
   begin
      if T = null or else T.Ref_Count < 0 then
         return;
      end if;
      if T.Ref_Count = 1 then
         Dec_Ref (T.Elements);
         Free (T);
      else
         T.Ref_Count := T.Ref_Count - 1;
         T := null;
      end if;
   end Dec_Ref;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (A : Internal_Inner_Env_Assoc_Iterator_Access) return String is
      begin
         return "<Iterator of InnerEnvAssoc, index="
                & A.Index'Image & ">";
      end Trace_Image;
   ---------
   -- "<" --
   ---------
   function "<" (Left, Right : Internal_Unit) return Boolean is
   begin
      return Left.Filename < Right.Filename;
   end "<";
function Hash (Key : Mmz_Key_Item) return Hash_Type;
function Equivalent (L, R : Mmz_Key_Item) return Boolean;
procedure Destroy (Key : in out Mmz_Key_Array_Access);
----------------
-- Equivalent --
----------------
function Equivalent (L, R : Mmz_Key_Item) return Boolean is
begin
   if L.Kind /= R.Kind then
      return False;
   end if;
   case L.Kind is
         when Mmz_Bare_Access_Def =>
               return L.As_Bare_Access_Def = R.As_Bare_Access_Def;
         when Mmz_Bare_Ada_Node =>
               return L.As_Bare_Ada_Node = R.As_Bare_Ada_Node;
         when Mmz_Bare_Anonymous_Expr_Decl =>
               return L.As_Bare_Anonymous_Expr_Decl = R.As_Bare_Anonymous_Expr_Decl;
         when Mmz_Bare_Array_Type_Def =>
               return L.As_Bare_Array_Type_Def = R.As_Bare_Array_Type_Def;
         when Mmz_Bare_Assoc_List =>
               return L.As_Bare_Assoc_List = R.As_Bare_Assoc_List;
         when Mmz_Bare_Base_Aggregate =>
               return L.As_Bare_Base_Aggregate = R.As_Bare_Base_Aggregate;
         when Mmz_Bare_Base_Id =>
               return L.As_Bare_Base_Id = R.As_Bare_Base_Id;
         when Mmz_Bare_Base_Subp_Spec =>
               return L.As_Bare_Base_Subp_Spec = R.As_Bare_Base_Subp_Spec;
         when Mmz_Bare_Base_Type_Decl =>
               return L.As_Bare_Base_Type_Decl = R.As_Bare_Base_Type_Decl;
         when Mmz_Bare_Basic_Decl =>
               return L.As_Bare_Basic_Decl = R.As_Bare_Basic_Decl;
         when Mmz_Bare_Body_Node =>
               return L.As_Bare_Body_Node = R.As_Bare_Body_Node;
         when Mmz_Bare_Classwide_Type_Decl =>
               return L.As_Bare_Classwide_Type_Decl = R.As_Bare_Classwide_Type_Decl;
         when Mmz_Bare_Compilation_Unit =>
               return L.As_Bare_Compilation_Unit = R.As_Bare_Compilation_Unit;
         when Mmz_Bare_Decimal_Fixed_Point_Def =>
               return L.As_Bare_Decimal_Fixed_Point_Def = R.As_Bare_Decimal_Fixed_Point_Def;
         when Mmz_Bare_Defining_Name =>
               return L.As_Bare_Defining_Name = R.As_Bare_Defining_Name;
         when Mmz_Bare_End_Name =>
               return L.As_Bare_End_Name = R.As_Bare_End_Name;
         when Mmz_Bare_Enum_Literal_Decl =>
               return L.As_Bare_Enum_Literal_Decl = R.As_Bare_Enum_Literal_Decl;
         when Mmz_Bare_Enum_Type_Def =>
               return L.As_Bare_Enum_Type_Def = R.As_Bare_Enum_Type_Def;
         when Mmz_Bare_For_Loop_Spec =>
               return L.As_Bare_For_Loop_Spec = R.As_Bare_For_Loop_Spec;
         when Mmz_Bare_For_Loop_Var_Decl =>
               return L.As_Bare_For_Loop_Var_Decl = R.As_Bare_For_Loop_Var_Decl;
         when Mmz_Bare_Formal_Discrete_Type_Def =>
               return L.As_Bare_Formal_Discrete_Type_Def = R.As_Bare_Formal_Discrete_Type_Def;
         when Mmz_Bare_Generic_Instantiation =>
               return L.As_Bare_Generic_Instantiation = R.As_Bare_Generic_Instantiation;
         when Mmz_Bare_Mod_Int_Type_Def =>
               return L.As_Bare_Mod_Int_Type_Def = R.As_Bare_Mod_Int_Type_Def;
         when Mmz_Bare_Name =>
               return L.As_Bare_Name = R.As_Bare_Name;
         when Mmz_Bare_Ordinary_Fixed_Point_Def =>
               return L.As_Bare_Ordinary_Fixed_Point_Def = R.As_Bare_Ordinary_Fixed_Point_Def;
         when Mmz_Bare_Private_Type_Def =>
               return L.As_Bare_Private_Type_Def = R.As_Bare_Private_Type_Def;
         when Mmz_Bare_Real_Type_Def =>
               return L.As_Bare_Real_Type_Def = R.As_Bare_Real_Type_Def;
         when Mmz_Bare_Record_Type_Def =>
               return L.As_Bare_Record_Type_Def = R.As_Bare_Record_Type_Def;
         when Mmz_Bare_Signed_Int_Type_Def =>
               return L.As_Bare_Signed_Int_Type_Def = R.As_Bare_Signed_Int_Type_Def;
         when Mmz_Bare_Type_Decl =>
               return L.As_Bare_Type_Decl = R.As_Bare_Type_Decl;
         when Mmz_Bare_Type_Expr =>
               return L.As_Bare_Type_Expr = R.As_Bare_Type_Expr;
         when Mmz_Boolean =>
               return L.As_Boolean = R.As_Boolean;
         when Mmz_Env_Rebindings =>
               return L.As_Env_Rebindings = R.As_Env_Rebindings;
         when Mmz_Integer =>
               return L.As_Integer = R.As_Integer;
         when Mmz_Internal_Entity_Base_Type_Decl_Array_Access =>
               return Equivalent (L.As_Internal_Entity_Base_Type_Decl_Array_Access, R.As_Internal_Entity_Base_Type_Decl_Array_Access);
         when Mmz_Internal_Entity_Info =>
               return L.As_Internal_Entity_Info = R.As_Internal_Entity_Info;
         when Mmz_Internal_Metadata =>
               return L.As_Internal_Metadata = R.As_Internal_Metadata;
         when Mmz_Lexical_Env =>
               return Equivalent (L.As_Lexical_Env, R.As_Lexical_Env);
         when Mmz_Symbol_Type =>
               return L.As_Symbol_Type = R.As_Symbol_Type;
   end case;
end Equivalent;
----------
-- Hash --
----------
function Hash (Key : Mmz_Key_Item) return Hash_Type is
begin
   case Key.Kind is
         when Mmz_Bare_Access_Def =>
            return Hash (Key.As_Bare_Access_Def);
         when Mmz_Bare_Ada_Node =>
            return Hash (Key.As_Bare_Ada_Node);
         when Mmz_Bare_Anonymous_Expr_Decl =>
            return Hash (Key.As_Bare_Anonymous_Expr_Decl);
         when Mmz_Bare_Array_Type_Def =>
            return Hash (Key.As_Bare_Array_Type_Def);
         when Mmz_Bare_Assoc_List =>
            return Hash (Key.As_Bare_Assoc_List);
         when Mmz_Bare_Base_Aggregate =>
            return Hash (Key.As_Bare_Base_Aggregate);
         when Mmz_Bare_Base_Id =>
            return Hash (Key.As_Bare_Base_Id);
         when Mmz_Bare_Base_Subp_Spec =>
            return Hash (Key.As_Bare_Base_Subp_Spec);
         when Mmz_Bare_Base_Type_Decl =>
            return Hash (Key.As_Bare_Base_Type_Decl);
         when Mmz_Bare_Basic_Decl =>
            return Hash (Key.As_Bare_Basic_Decl);
         when Mmz_Bare_Body_Node =>
            return Hash (Key.As_Bare_Body_Node);
         when Mmz_Bare_Classwide_Type_Decl =>
            return Hash (Key.As_Bare_Classwide_Type_Decl);
         when Mmz_Bare_Compilation_Unit =>
            return Hash (Key.As_Bare_Compilation_Unit);
         when Mmz_Bare_Decimal_Fixed_Point_Def =>
            return Hash (Key.As_Bare_Decimal_Fixed_Point_Def);
         when Mmz_Bare_Defining_Name =>
            return Hash (Key.As_Bare_Defining_Name);
         when Mmz_Bare_End_Name =>
            return Hash (Key.As_Bare_End_Name);
         when Mmz_Bare_Enum_Literal_Decl =>
            return Hash (Key.As_Bare_Enum_Literal_Decl);
         when Mmz_Bare_Enum_Type_Def =>
            return Hash (Key.As_Bare_Enum_Type_Def);
         when Mmz_Bare_For_Loop_Spec =>
            return Hash (Key.As_Bare_For_Loop_Spec);
         when Mmz_Bare_For_Loop_Var_Decl =>
            return Hash (Key.As_Bare_For_Loop_Var_Decl);
         when Mmz_Bare_Formal_Discrete_Type_Def =>
            return Hash (Key.As_Bare_Formal_Discrete_Type_Def);
         when Mmz_Bare_Generic_Instantiation =>
            return Hash (Key.As_Bare_Generic_Instantiation);
         when Mmz_Bare_Mod_Int_Type_Def =>
            return Hash (Key.As_Bare_Mod_Int_Type_Def);
         when Mmz_Bare_Name =>
            return Hash (Key.As_Bare_Name);
         when Mmz_Bare_Ordinary_Fixed_Point_Def =>
            return Hash (Key.As_Bare_Ordinary_Fixed_Point_Def);
         when Mmz_Bare_Private_Type_Def =>
            return Hash (Key.As_Bare_Private_Type_Def);
         when Mmz_Bare_Real_Type_Def =>
            return Hash (Key.As_Bare_Real_Type_Def);
         when Mmz_Bare_Record_Type_Def =>
            return Hash (Key.As_Bare_Record_Type_Def);
         when Mmz_Bare_Signed_Int_Type_Def =>
            return Hash (Key.As_Bare_Signed_Int_Type_Def);
         when Mmz_Bare_Type_Decl =>
            return Hash (Key.As_Bare_Type_Decl);
         when Mmz_Bare_Type_Expr =>
            return Hash (Key.As_Bare_Type_Expr);
         when Mmz_Boolean =>
            return Hash (Key.As_Boolean);
         when Mmz_Env_Rebindings =>
            return Hash (Key.As_Env_Rebindings);
         when Mmz_Integer =>
            return Hash (Key.As_Integer);
         when Mmz_Internal_Entity_Base_Type_Decl_Array_Access =>
            return Hash (Key.As_Internal_Entity_Base_Type_Decl_Array_Access);
         when Mmz_Internal_Entity_Info =>
            return Hash (Key.As_Internal_Entity_Info);
         when Mmz_Internal_Metadata =>
            return Hash (Key.As_Internal_Metadata);
         when Mmz_Lexical_Env =>
            return Hash (Key.As_Lexical_Env);
         when Mmz_Symbol_Type =>
            return Hash (Key.As_Symbol_Type);
   end case;
end Hash;
----------
-- Hash --
----------
function Hash (Key : Mmz_Key) return Hash_Type is
   Result : Hash_Type := Mmz_Property'Pos (Key.Property);
begin
   for K of Key.Items.all loop
      Result := Combine (Result, Hash (K));
   end loop;
   return Result;
end Hash;
----------------
-- Equivalent --
----------------
function Equivalent (L, R : Mmz_Key) return Boolean is
   L_Items : Mmz_Key_Array renames L.Items.all;
   R_Items : Mmz_Key_Array renames R.Items.all;
begin
   if L.Property /= R.Property or else L_Items'Length /= R_Items'Length then
      return False;
   end if;
   for I in L_Items'Range loop
      if not Equivalent (L_Items (I), R_Items (I)) then
         return False;
      end if;
   end loop;
   return True;
end Equivalent;
-------------
-- Destroy --
-------------
procedure Destroy (Map : in out Memoization_Maps.Map) is
   use Memoization_Maps;
   --  We need keys and values to be valid when clearing the memoization map,
   --  but on the other hand we need to free keys and values as well. To
   --  achieve both goals, we first copy key and values into arrays, then we
   --  clear the map, and then we free keys/values in the arrays. Allocate both
   --  arrays on the heap to avoid stack overflow, as they can be quite big.
   Length : constant Natural := Natural (Map.Length);
   type Key_Array is array (1 .. Length) of Mmz_Key_Array_Access;
   type Key_Array_Access is access Key_Array;
   procedure Free is new Ada.Unchecked_Deallocation
     (Key_Array, Key_Array_Access);
   type Value_Array is array (1 .. Length) of Mmz_Value;
   type Value_Array_Access is access Value_Array;
   procedure Free is new Ada.Unchecked_Deallocation
     (Value_Array, Value_Array_Access);
   Keys   : Key_Array_Access := new Key_Array;
   Values : Value_Array_Access := new Value_Array;
   I      : Positive := 1;
begin
   for Cur in Map.Iterate loop
      Keys (I) := Key (Cur).Items;
      Values (I) := Element (Cur);
      I := I + 1;
   end loop;
   Map.Clear;
   for K_Array of Keys.all loop
      Destroy (K_Array);
   end loop;
      for V of Values.all loop
         case V.Kind is
               when Mmz_Internal_Entity_Array_Access =>
                  Dec_Ref (V.As_Internal_Entity_Array_Access);
               when Mmz_Internal_Entity_Base_Formal_Param_Decl_Array_Access =>
                  Dec_Ref (V.As_Internal_Entity_Base_Formal_Param_Decl_Array_Access);
               when Mmz_Internal_Entity_Base_Type_Decl_Array_Access =>
                  Dec_Ref (V.As_Internal_Entity_Base_Type_Decl_Array_Access);
               when Mmz_Internal_Entity_Basic_Decl_Array_Access =>
                  Dec_Ref (V.As_Internal_Entity_Basic_Decl_Array_Access);
               when Mmz_Internal_Entity_Compilation_Unit_Array_Access =>
                  Dec_Ref (V.As_Internal_Entity_Compilation_Unit_Array_Access);
               when Mmz_Internal_Env_Assoc =>
                  Dec_Ref (V.As_Internal_Env_Assoc);
               when Mmz_Internal_Env_Assoc_Array_Access =>
                  Dec_Ref (V.As_Internal_Env_Assoc_Array_Access);
               when Mmz_Internal_Inner_Env_Assoc_Array_Access =>
                  Dec_Ref (V.As_Internal_Inner_Env_Assoc_Array_Access);
               when Mmz_Internal_Param_Match_Array_Access =>
                  Dec_Ref (V.As_Internal_Param_Match_Array_Access);
               when Mmz_Internal_Single_Actual_Array_Access =>
                  Dec_Ref (V.As_Internal_Single_Actual_Array_Access);
               when Mmz_Lexical_Env =>
                  Dec_Ref (V.As_Lexical_Env);
            when others => null;
         end case;
      end loop;
   Free (Keys);
   Free (Values);
end Destroy;
-------------
-- Destroy --
-------------
procedure Destroy (Key : in out Mmz_Key_Array_Access) is
   procedure Free is new Ada.Unchecked_Deallocation
     (Mmz_Key_Array, Mmz_Key_Array_Access);
begin
      for K of Key.all loop
         case K.Kind is
               when Mmz_Internal_Entity_Base_Type_Decl_Array_Access =>
                  Dec_Ref (K.As_Internal_Entity_Base_Type_Decl_Array_Access);
               when Mmz_Lexical_Env =>
                  Dec_Ref (K.As_Lexical_Env);
            when others => null;
         end case;
      end loop;
   Free (Key);
end Destroy;
-------------------------
-- Find_Memoized_Value --
-------------------------
function Find_Memoized_Value
  (Unit       : Internal_Unit;
   Handle     : out Memoization_Handle;
   Value      : out Mmz_Value;
   Create_Key : access function return Mmz_Key) return Boolean
is
   Inserted : Boolean;
begin
   --  Make sure that we don't lookup stale caches
   Reset_Caches (Unit);
   --  Initialize handle: create the key and create a cursor pointing to an
   --  existing entry.
   Handle.Key := Create_Key.all;
   Handle.Cache_Version := Unit.Cache_Version;
   Value := (Kind => Mmz_Evaluating);
   Unit.Memoization_Map.Insert (Handle.Key, Value, Handle.Cur, Inserted);
   --  No existing entry yet? The above just created one. Otherwise, destroy
   --  our key and reuse the existing entry's.
   if not Inserted then
      Destroy (Handle.Key.Items);
      Handle.Key := Memoization_Maps.Key (Handle.Cur);
      Value := Memoization_Maps.Element (Handle.Cur);
   end if;
   return not Inserted;
end Find_Memoized_Value;
------------------------
-- Add_Memoized_Value --
------------------------
procedure Add_Memoized_Value
  (Unit   : Internal_Unit;
   Handle : in out Memoization_Handle;
   Value  : Mmz_Value;
   Stored : out Boolean) is
begin
   --  If Handle was created using a memoization map that has been since then
   --  reset, do nothing: the result can be partly stale due to the event that
   --  triggered the memoization tables reset.
   Stored := Unit.Cache_Version <= Handle.Cache_Version;
   if Stored then
      Unit.Memoization_Map.Replace_Element (Handle.Cur, Value);
   end if;
end Add_Memoized_Value;
   -------------------
   -- Solve_Wrapper --
   -------------------
   function Solve_Wrapper
     (R            : Solver.Relation;
      Context_Node : Bare_Ada_Node) return Boolean is
   begin
      if Context_Node /= null and then Langkit_Support.Adalog.Debug.Debug then
         Assign_Names_To_Logic_Vars (Context_Node);
      end if;
      begin
         return Solver.Solve_First
           (R, Timeout => Context_Node.Unit.Context.Logic_Resolution_Timeout);
      exception
         when Langkit_Support.Adalog.Early_Binding_Error =>
            Raise_Property_Exception
              (Context_Node,
               Property_Error'Identity,
               "invalid equation for logic resolution");
         when Langkit_Support.Adalog.Timeout_Error =>
            Raise_Property_Exception
              (Context_Node,
               Property_Error'Identity,
               "logic resolution timed out");
      end;
   end Solve_Wrapper;
   -------------
   -- Destroy --
   -------------
   procedure Destroy (Env : in out Lexical_Env_Access) is
      Mutable_Env : Lexical_Env :=
        (Wrap (Env), 0, Env.Kind, No_Generic_Unit, 0);
   begin
      Destroy (Mutable_Env);
      Env := null;
   end Destroy;
   ----------------
   -- Initialize --
   ----------------
   procedure Initialize
     (Self              : Bare_Ada_Node;
      Kind              : Ada_Node_Kind_Type;
      Unit              : Internal_Unit;
      Token_Start_Index : Token_Index;
      Token_End_Index   : Token_Index;
      Parent            : Bare_Ada_Node := null;
      Self_Env          : Lexical_Env := AST_Envs.Empty_Env) is
   begin
      pragma Unreferenced (Kind);
      Self.Parent := Parent;
      Self.Unit := Unit;
      Self.Token_Start_Index := Token_Start_Index;
      Self.Token_End_Index := Token_End_Index;
      Self.Self_Env := Self_Env;
      Self.Last_Attempted_Child := -1;
   end Initialize;
   --------------------
   -- Use_Direct_Env --
   --------------------
   procedure Use_Direct_Env (State : in out PLE_Node_State; Env : Lexical_Env)
   is
   begin
      State.Current_Env := Env;
      State.Current_NED := null;
   end Use_Direct_Env;
   -------------------
   -- Use_Named_Env --
   -------------------
   procedure Use_Named_Env
     (State   : in out PLE_Node_State;
      Context : Internal_Context;
      Name    : Symbol_Type) is
   begin
      State.Current_NED := Get_Named_Env_Descriptor (Context, Name);
      State.Current_Env := State.Current_NED.Env_With_Precedence;
   end Use_Named_Env;
   ---------------------
   -- Set_Initial_Env --
   ---------------------
   procedure Set_Initial_Env
     (Self         : Bare_Ada_Node;
      State        : in out PLE_Node_State;
      Env          : Internal_Designated_Env;
      DSL_Location : String) is
   begin
      case Env.Kind is
         when None =>
            Use_Direct_Env (State, Empty_Env);
         when Current_Env =>
            null;
         when Named_Env =>
            Use_Named_Env (State, Self.Unit.Context, Env.Env_Name);
         when Direct_Env =>
            --  Sanitize this environment value: make sure it's a non-foreign
            --  and primary environment.
            if Env.Direct_Env.Kind /= Static_Primary then
               Raise_Property_Exception
                 (Self,
                  Property_Error'Identity,
                  "Cannot set an env that is not static-primary as the"
                  & " initial env");
            elsif Is_Foreign_Strict (Env.Direct_Env, Self) then
               Raise_Property_Exception
                 (Self,
                  Property_Error'Identity,
                  "unsound foreign environment in SetInitialEnv ("
                  & DSL_Location & ")");
            end if;
            Use_Direct_Env (State, Env.Direct_Env);
      end case;
   end Set_Initial_Env;
   ----------------
   -- Add_To_Env --
   ----------------
   procedure Add_To_Env
     (Self         : Bare_Ada_Node;
      State        : PLE_Node_State;
      Key          : Symbol_Type;
      Value        : Bare_Ada_Node;
      Md           : Internal_Metadata;
      Resolver     : Entity_Resolver;
      Dest_Env     : Internal_Designated_Env;
      DSL_Location : String)
   is
      Context    : constant Internal_Context := Self.Unit.Context;
      Root_Scope : Lexical_Env renames Context.Root_Scope;
      --  Shortcuts
      Actual_Dest_Env : Lexical_Env;
      Dest_NED        : Named_Env_Descriptor_Access;
      --  Description for the destination environment
   begin
      --  Skip the env addition if explicitly requested
      if Key = null
         or else Value = null
         or else (case Dest_Env.Kind is
                  when None        => True,
                  when Current_Env => False,
                  when Named_Env   => Dest_Env.Env_Name = null,
                  when Direct_Env  => Dest_Env.Direct_Env = Empty_Env)
      then
         return;
      end if;
      if Value.Unit /= Self.Unit then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "Cannot add_to_env an AST node that comes from another analysis"
            & " unit");
      end if;
         --  Make sure metadata does not contain any foreign node
         if (Md.Primitive /= null and then Md.Primitive.Unit /= Self.Unit) or else (Md.Primitive_Real_Type /= null and then Md.Primitive_Real_Type.Unit /= Self.Unit)
         then
            Raise_Property_Exception
              (Self,
               Property_Error'Identity,
               "Cannot add metadata that contains foreign nodes");
         end if;
      --  Then determine the destination environment
      case Dest_Env.Kind is
         when None =>
            raise Program_Error with "unreachable code";
         when Current_Env =>
            --  Just use the current environment
            Dest_NED := State.Current_NED;
            Actual_Dest_Env := State.Current_Env;
         when Named_Env =>
            --  There is an environment name: just lookup the corresponding
            --  NED/env.
            Dest_NED := Get_Named_Env_Descriptor (Context, Dest_Env.Env_Name);
            Actual_Dest_Env := Dest_NED.Env_With_Precedence;
         when Direct_Env =>
            --  There is an explicit destination environment
            Dest_NED := null;
            Actual_Dest_Env := Dest_Env.Direct_Env;
      end case;
      --  Sanitize it
      if Actual_Dest_Env.Kind /= Static_Primary then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "Cannot add elements to a lexical env that is not static-primary");
      elsif
         --  Since lexical envs need to sort the foreign nodes they contain,
         --  and that the total order on nodes is not defined for synthetic
         --  nodes, it is not possible to add a synthetic node to a foreign
         --  lexical environment.
         --
         --  This reasoning applies to environments that belong to foreign
         --  units, but also to the root environment.
         Is_Foreign (Actual_Dest_Env, Self) and then Is_Synthetic (Value)
      then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "Cannot add a synthetic node to a lexical env from another"
            & " analysis unit");
      elsif
         --  Reject direct references to foreign destination environments.
         --
         --  This is an attempt at identifying uses of the unsound relocation
         --  mechanism (as opposed to named environments), so this applies to
         --  all foreign environments (root scope included).
         DSL_Location'Length > 0
         and then Dest_Env.Kind = Direct_Env
         and then Is_Foreign_Strict (Actual_Dest_Env, Self)
      then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "unsound foreign environment in AddToEnv (" & DSL_Location & ")");
      end if;
      --  Now that everything is sanitized, we can proceed with the actual
      --  key/value pair addition. Note that this does nothing if
      --  Actual_Dest_Env ended up empty.
      Add (Actual_Dest_Env, Key, Value, Md, Resolver);
      --  If we're adding the element to an environment by env name, we must
      --  register this association in two places: in the target named env
      --  entry, and in Value's unit.
      if Dest_NED /= null then
         declare
            use NED_Assoc_Maps;
            FN    : Map renames Dest_NED.Foreign_Nodes;
            Dummy : Boolean;
            Cur   : Cursor;
         begin
            FN.Insert (Key      => Key,
                       New_Item => Internal_Map_Node_Vectors.Empty_Vector,
                       Position => Cur,
                       Inserted => Dummy);
            declare
               V : Internal_Map_Node_Vectors.Vector renames
                  FN.Reference (Cur);
            begin
               V.Append ((Value, Md, Resolver));
            end;
         end;
         Value.Unit.Exiled_Entries_In_NED.Append ((Dest_NED, Key, Value));
      --  Otherwise, if we're adding the element to an environment that belongs
      --  to a different unit, or to the root scope, then...
      elsif Is_Foreign_Not_Empty (Actual_Dest_Env, Self) then
         --  Add the Key/Value association to the list of entries contained in
         --  other units, so we can remove them when reparsing Value's unit.
         Value.Unit.Exiled_Entries.Append ((Actual_Dest_Env, Key, Value));
         if Actual_Dest_Env /= Root_Scope then
            --  Add Val to the list of foreign nodes that Actual_Dest_Env's
            --  unit contains, so that when that unit is reparsed, we can call
            --  Add_To_Env again on those nodes.
            Convert_Unit (Actual_Dest_Env.Owner).Foreign_Nodes.Append
              ((Value, Self.Unit));
         end if;
      end if;
   end Add_To_Env;
   -------------
   -- Ref_Env --
   -------------
   procedure Ref_Env
     (Self                : Bare_Ada_Node;
      Dest_Env            : Lexical_Env;
      Ref_Env_Nodes       : in out Bare_Ada_Node_Array_Access;
      Resolver            : Lexical_Env_Resolver;
      Kind                : Ref_Kind;
      Cats                : Ref_Categories;
      Shed_Rebindings     : Boolean) is
   begin
      for N of Ref_Env_Nodes.Items loop
         if N /= null then
            if N.Unit /= Self.Unit then
               Raise_Property_Exception
                 (Self,
                  Property_Error'Identity,
                  "attempt to add a referenced environment to a foreign unit");
            end if;
            Reference (Dest_Env, N, Resolver, Kind, Cats, Shed_Rebindings);
         end if;
      end loop;
      Dec_Ref (Ref_Env_Nodes);
   end Ref_Env;
   -------------
   -- Add_Env --
   -------------
   procedure Add_Env
     (Self              : Bare_Ada_Node;
      State             : in out PLE_Node_State;
      No_Parent         : Boolean;
      Transitive_Parent : Boolean;
      Names             : in out Symbol_Type_Array_Access)
   is
      Parent_From_Name : constant Boolean := State.Current_NED /= null;
      --  Does the parent environment comes from a named environment lookup?
      --  Determine the parent of this new environment:
      --
      --  (1) no parent if requested;
      --  (2) the current environment as the static parent if it comes from a
      --      named env lookup or if it is not foreign (or is the empty/root
      --      environment).
      Parent : constant Lexical_Env :=
        (if No_Parent
         then Null_Lexical_Env
         else State.Current_Env);
   begin
      --  Create the environment itself
      Self.Self_Env := Create_Static_Lexical_Env
        (Parent            => Parent,
         Node              => Self,
         Transitive_Parent => Transitive_Parent);
      --  If the parent of this new environment comes from a named environment
      --  lookup, register this new environment so that its parent is updated
      --  when the precence for this named environment changes.
      if Parent_From_Name then
         declare
            NED : constant Named_Env_Descriptor_Access := State.Current_NED;
         begin
            Self.Unit.Exiled_Envs.Append ((NED, Self.Self_Env));
            NED.Foreign_Envs.Insert (Self, Self.Self_Env);
         end;
      end if;
      --  From now on, the current environment is Self.Self_Env, with a direct
      --  access to it. It does not go through the env naming scheme, since
      --  only this node and its children (i.e. non-foreign nodes) will access
      --  it as a "current" environment during PLE.
      Use_Direct_Env (State, Self.Self_Env);
      --  Register the environment we just created on all the requested names
      if Names /= null then
         declare
            Context   : constant Internal_Context := Self.Unit.Context;
            Env       : constant Lexical_Env := Self.Self_Env;
            NENU      : NED_Maps.Map renames
               State.Unit_State.Named_Envs_Needing_Update;
         begin
            for N of Names.Items loop
               Register_Named_Env (Context, N, Env, NENU);
            end loop;
            Dec_Ref (Names);
         end;
      end if;
   end Add_Env;
   ---------------------
   -- Pre_Env_Actions --
   ---------------------
   procedure Pre_Env_Actions
     (Self            : Bare_Ada_Node;
      State           : in out PLE_Node_State;
      Add_To_Env_Only : Boolean := False) is
   begin
   case Self.Kind is
            when Ada_With_Clause =>
            With_Clause_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Use_Type_Clause =>
            Use_Type_Clause_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Use_Package_Clause =>
            Use_Package_Clause_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Access_To_Subp_Def =>
            Access_To_Subp_Def_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Named_Stmt =>
            Named_Stmt_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Extended_Return_Stmt =>
            Extended_Return_Stmt_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Begin_Block .. Ada_Decl_Block =>
            Block_Stmt_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_For_Loop_Stmt =>
            For_Loop_Stmt_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Accept_Stmt .. Ada_Accept_Stmt_With_Stmts =>
            Accept_Stmt_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Pragma_Node =>
            Pragma_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Decl_Expr =>
            Decl_Expr_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Private_Part =>
            Private_Part_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Single_Task_Decl =>
            Single_Task_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Single_Protected_Decl =>
            Single_Protected_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Package_Renaming_Decl =>
            Package_Renaming_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
            Object_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Number_Decl =>
            Number_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Label_Decl =>
            Label_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Subp_Renaming_Decl =>
            Generic_Subp_Renaming_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Package_Renaming_Decl =>
            Generic_Package_Renaming_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Subp_Instantiation =>
            Generic_Subp_Instantiation_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Package_Instantiation =>
            Generic_Package_Instantiation_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Subp_Decl =>
            Generic_Subp_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Package_Decl =>
            Generic_Package_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_For_Loop_Var_Decl =>
            For_Loop_Var_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Exception_Handler =>
            Exception_Handler_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Exception_Decl =>
            Exception_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Entry_Index_Spec =>
            Entry_Index_Spec_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Task_Body =>
            Task_Body_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Protected_Body =>
            Protected_Body_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Package_Body =>
            Package_Body_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Entry_Body =>
            Entry_Body_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Task_Body_Stub =>
            Task_Body_Stub_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Subp_Body_Stub =>
            Subp_Body_Stub_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Protected_Body_Stub =>
            Protected_Body_Stub_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Package_Body_Stub =>
            Package_Body_Stub_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
            Base_Subp_Body_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Subp_Internal =>
            Generic_Subp_Internal_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Enum_Literal_Decl .. Ada_Synthetic_Char_Enum_Lit =>
            Enum_Literal_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Entry_Decl =>
            Entry_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Abstract_Subp_Decl .. Ada_Subp_Decl | Ada_Synthetic_Subp_Decl =>
            Basic_Subp_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Anonymous_Type_Decl .. Ada_Synth_Anonymous_Type_Decl =>
            null;
            when Ada_Concrete_Type_Decl .. Ada_Formal_Type_Decl =>
            Type_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Single_Task_Type_Decl =>
            Single_Task_Type_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Task_Type_Decl =>
            Task_Type_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Protected_Type_Decl =>
            Protected_Type_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
            Incomplete_Type_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Classwide_Type_Decl =>
            null;
            when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
            Base_Type_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Package_Decl =>
            Package_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Generic_Package_Internal =>
            Generic_Package_Internal_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Param_Spec =>
            Param_Spec_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Discriminant_Spec =>
            Discriminant_Spec_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Component_Decl =>
            Component_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
            when Ada_Abstract_State_Decl =>
            Abstract_State_Decl_Pre_Env_Actions (Self, State, Add_To_Env_Only);
      when others =>  null; 
   end case;
   end Pre_Env_Actions;
   ----------------------
   -- Post_Env_Actions --
   ----------------------
   procedure Post_Env_Actions
     (Self : Bare_Ada_Node; State : in out PLE_Node_State) is
   begin
   case Self.Kind is
            when Ada_With_Clause =>
            null;
            when Ada_Use_Type_Clause =>
            Use_Type_Clause_Post_Env_Actions (Self, State);
            when Ada_Use_Package_Clause =>
            Use_Package_Clause_Post_Env_Actions (Self, State);
            when Ada_Access_To_Subp_Def =>
            null;
            when Ada_Named_Stmt =>
            null;
            when Ada_Extended_Return_Stmt =>
            null;
            when Ada_Begin_Block .. Ada_Decl_Block =>
            null;
            when Ada_For_Loop_Stmt =>
            null;
            when Ada_Accept_Stmt .. Ada_Accept_Stmt_With_Stmts =>
            null;
            when Ada_Pragma_Node =>
            null;
            when Ada_Decl_Expr =>
            null;
            when Ada_Private_Part =>
            null;
            when Ada_Single_Task_Decl =>
            null;
            when Ada_Single_Protected_Decl =>
            null;
            when Ada_Package_Renaming_Decl =>
            null;
            when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
            null;
            when Ada_Number_Decl =>
            null;
            when Ada_Label_Decl =>
            null;
            when Ada_Generic_Subp_Renaming_Decl =>
            null;
            when Ada_Generic_Package_Renaming_Decl =>
            null;
            when Ada_Generic_Subp_Instantiation =>
            null;
            when Ada_Generic_Package_Instantiation =>
            null;
            when Ada_Generic_Subp_Decl =>
            Generic_Subp_Decl_Post_Env_Actions (Self, State);
            when Ada_Generic_Package_Decl =>
            null;
            when Ada_For_Loop_Var_Decl =>
            null;
            when Ada_Exception_Handler =>
            null;
            when Ada_Exception_Decl =>
            null;
            when Ada_Entry_Index_Spec =>
            null;
            when Ada_Task_Body =>
            null;
            when Ada_Protected_Body =>
            null;
            when Ada_Package_Body =>
            null;
            when Ada_Entry_Body =>
            null;
            when Ada_Task_Body_Stub =>
            null;
            when Ada_Subp_Body_Stub =>
            null;
            when Ada_Protected_Body_Stub =>
            null;
            when Ada_Package_Body_Stub =>
            null;
            when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
            null;
            when Ada_Generic_Subp_Internal =>
            null;
            when Ada_Enum_Literal_Decl .. Ada_Synthetic_Char_Enum_Lit =>
            null;
            when Ada_Entry_Decl =>
            null;
            when Ada_Abstract_Subp_Decl .. Ada_Subp_Decl | Ada_Synthetic_Subp_Decl =>
            Basic_Subp_Decl_Post_Env_Actions (Self, State);
            when Ada_Anonymous_Type_Decl .. Ada_Synth_Anonymous_Type_Decl =>
            null;
            when Ada_Concrete_Type_Decl .. Ada_Formal_Type_Decl =>
            Type_Decl_Post_Env_Actions (Self, State);
            when Ada_Single_Task_Type_Decl =>
            null;
            when Ada_Task_Type_Decl =>
            null;
            when Ada_Protected_Type_Decl =>
            null;
            when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
            null;
            when Ada_Classwide_Type_Decl =>
            null;
            when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
            null;
            when Ada_Package_Decl =>
            null;
            when Ada_Generic_Package_Internal =>
            null;
            when Ada_Param_Spec =>
            null;
            when Ada_Discriminant_Spec =>
            null;
            when Ada_Component_Decl =>
            null;
            when Ada_Abstract_State_Decl =>
            null;
      when others =>  null; 
   end case;
   end Post_Env_Actions;
   ----------------
   -- Get_Symbol --
   ----------------
   function Get_Symbol
     (Node : Bare_Ada_Node) return Symbol_Type is
   begin
      if Node = null then
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "cannot get the symbol of a null node");
      end if;
      return Get_Symbol (Token (Node, Node.Token_Start_Index));
   end Get_Symbol;
   ----------
   -- Text --
   ----------
   function Text
     (Node : Bare_Ada_Node) return Text_Type
   is
   begin
      if Node = null then
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "cannot get the text of a null node");
      end if;
      declare
         Start_T : constant Token_Reference :=
            Token (Node, Node.Token_Start_Index);
         End_T   : constant Token_Reference :=
            Token (Node, Node.Token_End_Index);
      begin
         --  No text is associated to synthetic and ghost nodes
         if Is_Synthetic (Node) then
            return "";
         end if;
         if Is_Ghost (Node) then
            return "";
         end if;
         return Text (Start_T, End_T);
      end;
   end Text;
   ---------------------
   -- Is_Visible_From --
   ---------------------
   function Is_Visible_From
     (Self                     : Bare_Ada_Node;
      Referenced_Env, Base_Env : Lexical_Env) return Boolean
   is
      Referenced_Unit : constant Internal_Unit :=
         Convert_Unit (Referenced_Env.Owner);
      Base_Unit       : constant Internal_Unit :=
         Convert_Unit (Base_Env.Owner);
   begin
      if Referenced_Unit = null then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "referenced environment does not belong to any analysis unit");
      elsif Base_Unit = null then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "base environment does not belong to any analysis unit");
      end if;
      return Is_Referenced_From (Referenced_Unit, Base_Unit);
   end Is_Visible_From;
   ----------
   -- Unit --
   ----------
   function Unit (Node : Bare_Ada_Node) return Internal_Unit is
   begin
      return Node.Unit;
   end Unit;
   function Lookup_Internal
     (Node : Bare_Ada_Node;
      Sloc : Source_Location) return Bare_Ada_Node;
   procedure Lookup_Relative
     (Node       : Bare_Ada_Node;
      Sloc       : Source_Location;
      Position   : out Relative_Position;
      Node_Found : out Bare_Ada_Node);
   --  Implementation helpers for the looking up process
   -----------------
   -- Set_Parents --
   -----------------
   procedure Set_Parents
     (Node, Parent : Bare_Ada_Node)
   is
   begin
      if Node = null then
         return;
      end if;
      Node.Parent := Bare_Ada_Node (Parent);
      for I in 1 .. Children_Count (Node) loop
         Set_Parents (Child (Node, I), Node);
      end loop;
   end Set_Parents;
   -------------
   -- Destroy --
   -------------
   procedure Destroy (Node : Bare_Ada_Node) is
   begin
      if Node = null then
         return;
      end if;
      Free_User_Fields (Node);
      for I in 1 .. Children_Count (Node) loop
         Destroy (Child (Node, I));
      end loop;
   end Destroy;
   -----------
   -- Child --
   -----------
   function Child (Node  : Bare_Ada_Node;
                   Index : Positive) return Bare_Ada_Node
   is
      Result          : Bare_Ada_Node;
      Index_In_Bounds : Boolean;
   begin
      Get_Child (Node, Index, Index_In_Bounds, Result);
      return Result;
   end Child;
   --------------
   -- Traverse --
   --------------
   function Traverse
     (Node  : Bare_Ada_Node;
      Visit : access function (Node : Bare_Ada_Node)
              return Visit_Status)
     return Visit_Status
   is
      Status : Visit_Status := Into;
   begin
      if Node /= null then
         Status := Visit (Node);
         --  Skip processing the child nodes if the returned status is Over
         --  or Stop. In the former case the previous call to Visit has taken
         --  care of processing the needed childs, and in the latter case we
         --  must immediately stop processing the tree.
         if Status = Into then
            for I in 1 .. Children_Count (Node) loop
               declare
                  Cur_Child : constant Bare_Ada_Node :=
                     Child (Node, I);
               begin
                  if Cur_Child /= null then
                     Status := Traverse (Cur_Child, Visit);
                     exit when Status /= Into;
                  end if;
               end;
            end loop;
         end if;
      end if;
      if Status = Stop then
         return Stop;
      --  At this stage the Over status has no sense and we just continue
      --  processing the tree.
      else
         return Into;
      end if;
   end Traverse;
   --------------
   -- Traverse --
   --------------
   procedure Traverse
     (Node  : Bare_Ada_Node;
      Visit : access function (Node : Bare_Ada_Node)
                               return Visit_Status)
   is
      Result_Status : Visit_Status;
      pragma Unreferenced (Result_Status);
   begin
      Result_Status := Traverse (Node, Visit);
   end Traverse;
   ------------------------
   -- Traverse_With_Data --
   ------------------------
   function Traverse_With_Data
     (Node  : Bare_Ada_Node;
      Visit : access function (Node : Bare_Ada_Node;
                               Data : in out Data_Type)
                               return Visit_Status;
      Data  : in out Data_Type)
      return Visit_Status
   is
      function Helper (Node : Bare_Ada_Node) return Visit_Status;
      ------------
      -- Helper --
      ------------
      function Helper (Node : Bare_Ada_Node) return Visit_Status is
      begin
         return Visit (Node, Data);
      end Helper;
      Saved_Data : Data_Type;
      Result     : Visit_Status;
   begin
      if Reset_After_Traversal then
         Saved_Data := Data;
      end if;
      Result := Traverse (Node, Helper'Access);
      if Reset_After_Traversal then
         Data := Saved_Data;
      end if;
      return Result;
   end Traverse_With_Data;
   ----------------
   -- Sloc_Range --
   ----------------
   function Sloc_Range
     (Node : Bare_Ada_Node) return Source_Location_Range
   is
      type Token_Anchor is (T_Start, T_End);
      type Token_Pos is record
         Pos    : Token_Index;
         Anchor : Token_Anchor;
      end record;
      TDH                    : Token_Data_Handler renames Node.Unit.TDH;
      Token_Start, Token_End : Token_Pos;
      function Get (Index : Token_Index) return Stored_Token_Data is
        (Get_Token (TDH, Index));
      function Sloc (T : Token_Pos) return Source_Location is
        (if T.Anchor = T_Start
         then Sloc_Start (TDH, Get (T.Pos))
         else Sloc_End (TDH, Get (T.Pos)));
   begin
      if Is_Synthetic (Node) then
         return Sloc_Range (Node.Parent);
      end if;
      if Is_Ghost (Node) then
         Token_Start := (if Node.Token_Start_Index = 1
                         then (1, T_Start)
                         else (Node.Token_Start_Index - 1, T_End));
         Token_End := Token_Start;
      else
         Token_Start := (Node.Token_Start_Index, T_Start);
         Token_End := (Node.Token_End_Index, T_End);
      end if;
      if Snaps_At_Start (Node)
         and then not Is_Ghost (Node)
         and then Token_Start.Pos /= 1
      then
         Token_Start := (Token_Start.Pos - 1, T_End);
      end if;
      if Snaps_At_End (Node) and then Token_End.Pos /= Last_Token (TDH) then
         Token_End := (Token_End.Pos + 1, T_Start);
      end if;
      return Make_Range (Sloc (Token_Start), Sloc (Token_End));
   end Sloc_Range;
   ------------
   -- Lookup --
   ------------
   function Lookup
     (Node : Bare_Ada_Node;
      Sloc : Source_Location) return Bare_Ada_Node
   is
      Position : Relative_Position;
      Result   : Bare_Ada_Node;
   begin
      if Sloc = No_Source_Location then
         return null;
      end if;
      Lookup_Relative
        (Bare_Ada_Node (Node), Sloc, Position, Result);
      return Result;
   end Lookup;
   ---------------------
   -- Lookup_Internal --
   ---------------------
   function Lookup_Internal
     (Node : Bare_Ada_Node;
      Sloc : Source_Location) return Bare_Ada_Node
   is
      --  For this implementation helper (i.e. internal primitive), we can
      --  assume that all lookups fall into this node's sloc range.
      pragma Assert (Compare (Sloc_Range (Node), Sloc) = Inside);
      Children : constant Internal_Bare_Ada_Node_Array :=
         Implementation.Children (Node);
      Pos      : Relative_Position;
      Result   : Bare_Ada_Node;
   begin
      --  Look for a child node that contains Sloc (i.e. return the most
      --  precise result).
      for Child of Children loop
         --  Note that we assume here that child nodes are ordered so that the
         --  first one has a sloc range that is before the sloc range of the
         --  second child node, etc.
         if Child /= null then
            Lookup_Relative (Child, Sloc, Pos, Result);
            case Pos is
               when Before =>
                   --  If this is the first node, Sloc is before it, so we can
                   --  stop here.  Otherwise, Sloc is between the previous
                   --  child node and the next one...  so we can stop here,
                   --  too.
                   return Node;
               when Inside =>
                   return Result;
               when After =>
                   --  Sloc is after the current child node, so see with the
                   --  next one.
                   null;
            end case;
         end if;
      end loop;
      --  If we reach this point, we found no children that covers Sloc, but
      --  Node still covers it (see the assertion).
      return Node;
   end Lookup_Internal;
   -------------
   -- Compare --
   -------------
   function Compare
     (Node : Bare_Ada_Node;
      Sloc : Source_Location) return Relative_Position is
   begin
      return Compare (Sloc_Range (Node), Sloc);
   end Compare;
   ---------------------
   -- Lookup_Relative --
   ---------------------
   procedure Lookup_Relative
     (Node       : Bare_Ada_Node;
      Sloc       : Source_Location;
      Position   : out Relative_Position;
      Node_Found : out Bare_Ada_Node)
   is
      Result : constant Relative_Position :=
        Compare (Node, Sloc);
   begin
      Position := Result;
      Node_Found := (if Result = Inside
                     then Lookup_Internal (Node, Sloc)
                     else null);
   end Lookup_Relative;
   -------------
   -- Compare --
   -------------
   function Compare
     (Self, Left, Right : Bare_Ada_Node;
      Relation          : Comparison_Relation) return Boolean
   is
      LS, RS : Source_Location;
   begin
      if Left = null or else Right = null or else Left.Unit /= Right.Unit then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "invalid node comparison");
      end if;
      LS := Start_Sloc (Sloc_Range (Left));
      RS := Start_Sloc (Sloc_Range (Right));
      return (case Relation is
              when Langkit_Support.Types.Less_Than        => LS < RS,
              when Langkit_Support.Types.Less_Or_Equal    => LS <= RS,
              when Langkit_Support.Types.Greater_Than     => LS > RS,
              when Langkit_Support.Types.Greater_Or_Equal => LS >= RS);
   end Compare;
   --------------
   -- Children --
   --------------
   function Children
     (Node : Bare_Ada_Node) return Internal_Bare_Ada_Node_Array
   is
      First : constant Integer := Bare_Ada_Node_Vectors.Index_Type'First;
      Last  : constant Integer := First + Children_Count (Node) - 1;
   begin
      return A : Internal_Bare_Ada_Node_Array (First .. Last)
      do
         for I in First .. Last loop
            A (I) := Child (Node, I);
         end loop;
      end return;
   end Children;
   function Children
     (Node : Bare_Ada_Node) return Bare_Ada_Node_Array_Access
   is
      C : Internal_Bare_Ada_Node_Array := Children (Node);
   begin
      return Ret : Bare_Ada_Node_Array_Access :=
         Create_Bare_Ada_Node_Array (C'Length)
      do
         Ret.Items := C;
      end return;
   end Children;
   ---------
   -- Get --
   ---------
   function Get
     (Self    : Bare_Ada_Node;
      Node    : Bare_Ada_List;
      Index   : Integer;
      Or_Null : Boolean := False) return Bare_Ada_Node
   is
      function Length (Node : Bare_Ada_List) return Natural
      is (Node.Count);
      --  Wrapper around the Length primitive to get the compiler happy for the
      --  the package instantiation below.
      function Absolute_Get
        (L     : Bare_Ada_List;
         Index : Integer) return Bare_Ada_Node
      is (L.Nodes.all (Index + 1));
      --  L.Nodes is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Bare_Ada_Node,
         Sequence_Type => Bare_Ada_List,
         Length        => Length,
         Get           => Absolute_Get);
      Result : Bare_Ada_Node;
   begin
      if Node = null and then Or_Null then
         return null;
      elsif Relative_Get (Node, Index, Result) then
         return Result;
      elsif Or_Null then
         return null;
      else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "out-of-bounds AST list access");
      end if;
   end Get;
   ---------------
   -- PP_Trivia --
   ---------------
   procedure PP_Trivia
     (Node        : Bare_Ada_Node;
      Line_Prefix : String := "")
   is
      Children_Prefix : constant String := Line_Prefix & "|  ";
   begin
      if Node = null then
         Put_Line (Line_Prefix & "None");
         return;
      end if;
      Put_Line (Line_Prefix & Kind_Name (Node));
      for C of Children_And_Trivia (Node) loop
         case C.Kind is
            when Trivia =>
               Put_Line (Children_Prefix & Image (Text (C.Trivia)));
            when Child =>
               PP_Trivia (C.Node, Children_Prefix);
         end case;
      end loop;
   end PP_Trivia;
   --------------------------
   -- Populate_Lexical_Env --
   --------------------------
   function Populate_Lexical_Env (Node : Bare_Ada_Node) return Boolean is
      Context    : constant Internal_Context := Node.Unit.Context;
      Unit_State : aliased PLE_Unit_State := (Named_Envs_Needing_Update => <>);
      Root_State : constant PLE_Node_State :=
        (Unit_State  => Unit_State'Unchecked_Access,
         Current_Env => Context.Root_Scope,
         Current_NED => null);
      function Populate_Internal
        (Node         : Bare_Ada_Node;
         Parent_State : PLE_Node_State) return Boolean;
      --  Do the lexical env population on Node and recurse on its children
      procedure Register_Foreign_Env
        (Node : Bare_Ada_Node; State : PLE_Node_State);
      --  Given a node and its PLE state, register Node.Self_Env as being
      --  initialized through the named environment mechanism, if that's indeed
      --  the case. Do nothing otherwise.
      -----------------------
      -- Populate_Internal --
      -----------------------
      function Populate_Internal
        (Node         : Bare_Ada_Node;
         Parent_State : PLE_Node_State) return Boolean
      is
         Result : Boolean := False;
         State  : PLE_Node_State := Parent_State;
      begin
         if Node = null then
            return Result;
         end if;
         --  By default (i.e. unless env actions add a new env), the
         --  environment we store in Node is the current one.
         Node.Self_Env := State.Current_Env;
         --  Run pre/post actions, and run PLE on children in between. Make
         --  sure we register the potential foreign Node.Self_Env environment
         --  at the end, even when an exception interrupts PLE to keep the
         --  state consistent.
         begin
            Pre_Env_Actions (Node, State);
            if State.Current_Env /= Null_Lexical_Env then
               Node.Self_Env := State.Current_Env;
               Register_Foreign_Env (Node, State);
            end if;
            --  Call recursively on children
            for I in First_Child_Index (Node) .. Last_Child_Index (Node) loop
               Result := Populate_Internal
                 (Child (Node, I), State) or else Result;
            end loop;
            Post_Env_Actions (Node, State);
         exception
            when Exc : Precondition_Failure | Property_Error =>
               if PLE_Errors_Trace.Is_Active then
                   GNATCOLL.Traces.Trace
                     (PLE_Errors_Trace,
                      "Exception raised during PLE "
                      & Ada.Exceptions.Exception_Name (Exc) & " : "
                      & Ada.Exceptions.Exception_Message (Exc));
                   GNATCOLL.Traces.Trace
                     (PLE_Errors_Trace,
                      GNAT.Traceback.Symbolic.Symbolic_Traceback (Exc));
               end if;
               Register_Foreign_Env (Node, State);
               return True;
         end;
         return Result;
      end Populate_Internal;
      --------------------------
      -- Register_Foreign_Env --
      --------------------------
      procedure Register_Foreign_Env
        (Node : Bare_Ada_Node; State : PLE_Node_State) is
      begin
         if State.Current_NED /= null then
            State.Current_NED.Nodes_With_Foreign_Env.Insert (Node);
            Node.Unit.Nodes_With_Foreign_Env.Insert (Node, State.Current_NED);
         end if;
      end Register_Foreign_Env;
   begin
      --  This function is meant to be called during an existing PLE pass. If
      --  if is called outside of this context, run the PLE pass on Node's
      --  analysis unit. Likewise, if PLE has not run on the unit that owns
      --  this PLE unit yet, do a full run, which will in the end trigger the
      --  PLE on this PLE unit.
      --
      --  We do this so that as soon as PLE is required on a PLE unit: the
      --  whole unit end up with its lexical environments populated.
      if not Context.In_Populate_Lexical_Env then
         begin
            Populate_Lexical_Env (Node.Unit);
            return False;
         exception
            when Precondition_Failure | Property_Error =>
               return True;
         end;
      end if;
      --  This is intended to be called on the root node only
      if Node.Parent /= null then
         raise Program_Error;
      end if;
      return Result : constant Boolean :=
         Populate_Internal (Node, Root_State)
      do
         Update_Named_Envs (Context, Unit_State.Named_Envs_Needing_Update);
      end return;
   end Populate_Lexical_Env;
   ------------------------------
   -- AST_Envs_Node_Text_Image --
   ------------------------------
   function AST_Envs_Node_Text_Image
     (Node  : Bare_Ada_Node;
      Short : Boolean := True) return Text_Type is
   begin
      if Short then
         if Node = null then
            return "null";
         end if;
         return To_Text (Basename (Node.Unit))
           & ":" & To_Text (Image (Start_Sloc (Sloc_Range (Node))));
      else
         return Short_Text_Image (Node);
      end if;
   end AST_Envs_Node_Text_Image;
   -------------------
   -- Is_Rebindable --
   -------------------
   function Is_Rebindable (Node : Bare_Ada_Node) return Boolean is
   begin
         return Node.Kind in Ada_Generic_Package_Decl .. Ada_Generic_Subp_Decl;
   end Is_Rebindable;
   -----------------------
   -- Acquire_Rebinding --
   -----------------------
   function Acquire_Rebinding
     (Node             : Bare_Ada_Node;
      Parent           : Env_Rebindings;
      Old_Env, New_Env : Lexical_Env) return Env_Rebindings
   is
      Result    : Env_Rebindings;
      Available : Env_Rebindings_Vectors.Vector renames
         Node.Unit.Context.Available_Rebindings;
   begin
      --  Use an existing and available Env_Rebindings_Type record for Node's
      --  Context, otherwise allocate a new rebinding.
      Result := (if Available.Is_Empty
                 then new Env_Rebindings_Type'(Version => 0, others => <>)
                 else Available.Pop);
      Result.Parent := Parent;
      Result.Old_Env := Old_Env;
      Result.New_Env := New_Env;
      Result.Children := Env_Rebindings_Vectors.Empty_Vector;
      return Result;
   end Acquire_Rebinding;
   -----------------------
   -- Release_Rebinding --
   -----------------------
   procedure Release_Rebinding (Self : in out Env_Rebindings) is
      Available : Env_Rebindings_Vectors.Vector renames
         Unwrap (Self.Old_Env).Node.Unit.Context.Available_Rebindings;
   begin
      --  Bumping the version number, to invalidate existing references to
      --  Self.
      Self.Version := Self.Version + 1;
      Self.Children.Destroy;
      Available.Append (Self);
      Self := null;
   end Release_Rebinding;
   ------------------------
   -- Register_Rebinding --
   ------------------------
   procedure Register_Rebinding
     (Node : Bare_Ada_Node; Rebinding : Env_Rebindings) is
   begin
      Node.Unit.Rebindings.Append (Rebinding);
   end Register_Rebinding;
   --------------------
   -- Element_Parent --
   --------------------
   function Element_Parent
     (Node : Bare_Ada_Node) return Bare_Ada_Node
   is (Node.Parent);
   ---------------
   -- Node_Unit --
   ---------------
   function Node_Unit (Node : Bare_Ada_Node) return Generic_Unit_Ptr is
   begin
      return Convert_Unit (Node.Unit);
   end Node_Unit;
   ----------
   -- Hash --
   ----------
   function Hash (Node : Bare_Ada_Node) return Hash_Type
   is
      function H is new Hash_Access
        (Root_Node_Record, Bare_Ada_Node);
   begin
      return H (Node);
   end Hash;
      function Hash (B : Boolean) return Hash_Type is (Boolean'Pos (B));
      function Hash (I : Integer) return Hash_Type is (Hash_Type'Mod (I));
   ------------------------
   -- Named environments --
   ------------------------
   ---------
   -- Add --
   ---------
   procedure Add
     (Self : in out NED_Assoc_Maps.Map;
      Key  : Symbol_Type;
      Node : AST_Envs.Internal_Map_Node)
   is
      use NED_Assoc_Maps;
      Pos   : Cursor;
      Dummy : Boolean;
   begin
      --  Make sure there is a vector entry for Key
      Self.Insert (Key, Internal_Map_Node_Vectors.Empty_Vector, Pos, Dummy);
      --  Append Node to that vector
      declare
         V : Internal_Map_Node_Vectors.Vector renames Self.Reference (Pos);
      begin
         V.Append (Node);
      end;
   end Add;
   ------------
   -- Remove --
   ------------
   procedure Remove
     (Self : in out NED_Assoc_Maps.Map;
      Key  : Symbol_Type;
      Node : Bare_Ada_Node)
   is
      use NED_Assoc_Maps;
      V : Internal_Map_Node_Vectors.Vector renames Self.Reference (Key);
   begin
      --  Remove the (assumed unique) entry in V whose node is Node. The order
      --  of items in V is not significant, so we can use Pop for efficient
      --  removal. Do the traversal in reverse order for correctness.
      for I in reverse 1 .. V.Length loop
         if V.Get_Access (I).Node = Node then
            V.Pop (I);
            exit;
         end if;
      end loop;
   end Remove;
   ------------------------------
   -- Get_Named_Env_Descriptor --
   ------------------------------
   function Get_Named_Env_Descriptor
     (Context : Internal_Context;
      Name    : Symbol_Type) return Named_Env_Descriptor_Access
   is
      use NED_Maps;
      --  Look for an existing entry for Name
      Pos : constant Cursor := Context.Named_Envs.Find (Name);
   begin
      if Has_Element (Pos) then
         return Element (Pos);
      end if;
      --  There is no such entry: create one
      return Result : constant Named_Env_Descriptor_Access :=
         new Named_Env_Descriptor'
           (Name                   => Name,
            Envs                   => <>,
            Env_With_Precedence    => Empty_Env,
            Foreign_Nodes          => <>,
            Foreign_Envs           => <>,
            Nodes_With_Foreign_Env => <>)
      do
         Context.Named_Envs.Insert (Name, Result);
      end return;
   end Get_Named_Env_Descriptor;
   ------------------------
   -- Register_Named_Env --
   ------------------------
   procedure Register_Named_Env
     (Context                   : Internal_Context;
      Name                      : Symbol_Type;
      Env                       : Lexical_Env;
      Named_Envs_Needing_Update : in out NED_Maps.Map)
   is
      NED_Access : constant Named_Env_Descriptor_Access :=
         Get_Named_Env_Descriptor (Context, Name);
      NED        : Named_Env_Descriptor renames NED_Access.all;
      Node       : constant Bare_Ada_Node := Env_Node (Env);
   begin
      NED.Envs.Insert (Node, Env);
      Node.Unit.Named_Envs.Append ((Name, Env));
      --  If that insertion must change the env that has precedence, signal
      --  that NED requires an update.
      if NED.Envs.First_Element /= NED.Env_With_Precedence then
         Named_Envs_Needing_Update.Include (Name, NED_Access);
      end if;
   end Register_Named_Env;
   ----------------------
   -- Update_Named_Env --
   ----------------------
   procedure Update_Named_Envs
     (Context : Internal_Context; Named_Envs : NED_Maps.Map)
   is
      Require_Cache_Reset : Boolean := False;
   begin
      for Cur in Named_Envs.Iterate loop
         declare
            NE      : Named_Env_Descriptor renames NED_Maps.Element (Cur).all;
            New_Env : constant Lexical_Env :=
              (if NE.Envs.Is_Empty
               then Empty_Env
               else NE.Envs.First_Element);
         begin
            --  If there was an environment with precedence, remove its foreign
            --  nodes.
            if NE.Env_With_Precedence /= Empty_Env then
               for Cur in NE.Foreign_Nodes.Iterate loop
                  declare
                     Key   : constant Symbol_Type :=
                        NED_Assoc_Maps.Key (Cur);
                     Nodes : Internal_Map_Node_Vectors.Vector renames
                        NE.Foreign_Nodes.Reference (Cur);
                  begin
                     for N of Nodes loop
                        Remove (NE.Env_With_Precedence, Key, N.Node);
                     end loop;
                  end;
               end loop;
            end if;
            --  Now, set the new environment that has precedence
            NE.Env_With_Precedence := New_Env;
            --  Add the foreign nodes to the new environment with precedence,
            --  if any.
            for Cur in NE.Foreign_Nodes.Iterate loop
               declare
                  Key   : constant Symbol_Type :=
                     NED_Assoc_Maps.Key (Cur);
                  Nodes : Internal_Map_Node_Vectors.Vector renames
                     NE.Foreign_Nodes.Reference (Cur);
               begin
                  for N of Nodes loop
                     Add (New_Env, Key, N.Node, N.Md, N.Resolver);
                  end loop;
               end;
            end loop;
            --  Set the parent environment of all foreign environments
            for Cur in NE.Foreign_Envs.Iterate loop
               declare
                  Env : Lexical_Env_Record renames
                     Unwrap (Sorted_Env_Maps.Element (Cur)).all;
               begin
                  Env.Parent := New_Env;
                  --  We have updated the lexical env hierarchy (e.g. an env
                  --  which had no parent may have one now), so the cached
                  --  entries for queries that traveresed the old env hierarchy
                  --  need to be invalidated.
                  Require_Cache_Reset := True;
               end;
            end loop;
            --  Update nodes whose environment was the old env with precedence
            for N of NE.Nodes_With_Foreign_Env loop
               N.Self_Env := New_Env;
            end loop;
         end;
      end loop;
      if Require_Cache_Reset then
         Invalidate_Caches (Context, Invalidate_Envs => True);
      end if;
   end Update_Named_Envs;
   --------------------------
   -- Big integers wrapper --
   --------------------------
   ------------------------
   -- Create_Big_Integer --
   ------------------------
   function Create_Big_Integer
     (Image : String; Base : Integer := 10) return Big_Integer_Type
   is
      use GNATCOLL.GMP;
      use GNATCOLL.GMP.Integers;
   begin
      return new Big_Integer_Record'(Value     => Make (Image, Int (Base)),
                                     Ref_Count => 1);
   end Create_Big_Integer;
   ------------------------
   -- Create_Big_Integer --
   ------------------------
   function Create_Big_Integer
     (Big_Int : GNATCOLL.GMP.Integers.Big_Integer) return Big_Integer_Type
   is
      Result : constant Big_Integer_Type :=
         new Big_Integer_Record'(Value     => <>,
                                 Ref_Count => 1);
   begin
      Result.Value.Set (Big_Int);
      return Result;
   end Create_Big_Integer;
   ------------------------
   -- Create_Big_Integer --
   ------------------------
   function Create_Big_Integer (Int : Integer) return Big_Integer_Type is
      Result : constant Big_Integer_Type :=
         new Big_Integer_Record'(Value     => <>,
                                 Ref_Count => 1);
   begin
      Result.Value.Set (GNATCOLL.GMP.Long (Int));
      return Result;
   end Create_Big_Integer;
   -------------------------------
   -- Create_Public_Big_Integer --
   -------------------------------
   function Create_Public_Big_Integer
     (Big_Int : Big_Integer_Type) return GNATCOLL.GMP.Integers.Big_Integer is
   begin
      return Result : GNATCOLL.GMP.Integers.Big_Integer do
         Result.Set (Big_Int.Value);
      end return;
   end Create_Public_Big_Integer;
   -----------------
   -- Trace_Image --
   -----------------
   function Trace_Image (I : Big_Integer_Type) return String is
   begin
      return GNATCOLL.GMP.Integers.Image (I.Value);
   end Trace_Image;
   ----------------
   -- To_Integer --
   ----------------
   function To_Integer
     (Self    : Bare_Ada_Node;
      Big_Int : Big_Integer_Type) return Integer
   is
      Image : constant String := Big_Int.Value.Image;
   begin
      return Integer'Value (Image);
   exception
      when Constraint_Error =>
         Raise_Property_Exception
           (Self, Property_Error'Identity, "out of range big integer");
   end To_Integer;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (Big_Int : Big_Integer_Type) is
   begin
      if Big_Int.Ref_Count /= -1 then
         Big_Int.Ref_Count := Big_Int.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (Big_Int : in out Big_Integer_Type) is
      procedure Destroy is new Ada.Unchecked_Deallocation
        (Big_Integer_Record, Big_Integer_Type);
   begin
      if Big_Int = null or else Big_Int.Ref_Count = -1 then
         return;
      end if;
      Big_Int.Ref_Count := Big_Int.Ref_Count - 1;
      if Big_Int.Ref_Count = 0 then
         Destroy (Big_Int);
      end if;
   end Dec_Ref;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (Left, Right : Big_Integer_Type) return Boolean is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Left.Value = Right.Value;
   end Equivalent;
   ---------
   -- "<" --
   ---------
   function "<" (Left, Right : Big_Integer_Type) return Boolean is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Left.Value < Right.Value;
   end "<";
   ----------
   -- "<=" --
   ----------
   function "<=" (Left, Right : Big_Integer_Type) return Boolean is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Left.Value <= Right.Value;
   end "<=";
   ---------
   -- ">" --
   ---------
   function ">" (Left, Right : Big_Integer_Type) return Boolean is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Left.Value > Right.Value;
   end ">";
   ----------
   -- ">=" --
   ----------
   function ">=" (Left, Right : Big_Integer_Type) return Boolean is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Left.Value >= Right.Value;
   end ">=";
   ---------
   -- "+" --
   ---------
   function "+" (Left, Right : Big_Integer_Type) return Big_Integer_Type is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Create_Big_Integer (Left.Value + Right.Value);
   end "+";
   ---------
   -- "-" --
   ---------
   function "-" (Left, Right : Big_Integer_Type) return Big_Integer_Type is
      use type GNATCOLL.GMP.Integers.Big_Integer;
   begin
      return Create_Big_Integer (Left.Value - Right.Value);
   end "-";
   ------------------
   -- Unit_Version --
   ------------------
   function Unit_Version (Unit : Generic_Unit_Ptr) return Version_Number is
   begin
      return Convert_Unit (Unit).Unit_Version;
   end Unit_Version;
   -------------------------
   -- Get_Context_Version --
   -------------------------
   function Get_Context_Version
     (Node : Bare_Ada_Node) return Version_Number is
   begin
      return Node.Unit.Context.Cache_Version;
   end Get_Context_Version;
   --------------------------
   -- Properties_May_Raise --
   --------------------------
   function Properties_May_Raise
     (Exc : Ada.Exceptions.Exception_Occurrence) return Boolean is
   begin
      return Ada.Exceptions.Exception_Identity (Exc) in
            Precondition_Failure'Identity
               |
            Property_Error'Identity
      ;
   end Properties_May_Raise;
   ----------------------
   -- Short_Text_Image --
   ----------------------
   function Short_Text_Image (Self : Bare_Ada_Node) return Text_Type
   is
   begin
      if Self = null then
         return "None";
      end if;
   case Self.Kind is
            when Ada_Char_Literal .. Ada_String_Literal =>
         return Base_Id_Short_Image (Self);
            when Ada_Abstract_State_Decl .. Ada_Single_Task_Decl =>
         return Basic_Decl_Short_Image (Self);
      when others => 
         return "<" & To_Text (Kind_Name (Self))
                & " "
                & To_Text
                  (Ada.Directories.Simple_Name
                     (Get_Filename (Unit (Self))))
                & ":" & To_Text (Image (Sloc_Range (Self))) & ">";
   end case;
   end Short_Text_Image;
   --------------------
   -- Snaps_At_Start --
   --------------------
   function Snaps_At_Start (Self : Bare_Ada_Node) return Boolean is
   begin
   case Self.Kind is
            when Ada_Handled_Stmts =>
         return True;
            when Ada_Declarative_Part .. Ada_Public_Part =>
         return True;
      when others => 
         return False;
   end case;
   end Snaps_At_Start;
   ------------------
   -- Snaps_At_End --
   ------------------
   function Snaps_At_End (Self : Bare_Ada_Node) return Boolean is
   begin
   case Self.Kind is
            when Ada_Handled_Stmts =>
         return True;
            when Ada_Declarative_Part .. Ada_Public_Part =>
         return True;
      when others => 
         return Is_Incomplete (Self);
   end case;
   end Snaps_At_End;
   -------------
   -- Parents --
   -------------
   function Parents
     (Node      : Bare_Ada_Node;
      With_Self : Boolean := True)
      return Bare_Ada_Node_Array_Access
   is
      Count : Natural := 0;
      Start : Bare_Ada_Node :=
        (if With_Self then Node else Node.Parent);
      Cur   : Bare_Ada_Node := Start;
   begin
      while Cur /= null loop
         Count := Count + 1;
         Cur := Cur.Parent;
      end loop;
      declare
         Result : constant Bare_Ada_Node_Array_Access :=
            Create_Bare_Ada_Node_Array (Count);
      begin
         Cur := Start;
         for I in Result.Items'Range loop
            Result.Items (I) := Cur;
            Cur := Cur.Parent;
         end loop;
         return Result;
      end;
   end Parents;
   -----------------------
   -- First_Child_Index --
   -----------------------
   function First_Child_Index (Node : Bare_Ada_Node) return Natural
   is (1);
   ----------------------
   -- Last_Child_Index --
   ----------------------
   function Last_Child_Index (Node : Bare_Ada_Node) return Natural
   is (Children_Count (Node));
   ---------------
   -- Get_Child --
   ---------------
   procedure Get_Child
     (Node            : Bare_Ada_Node;
      Index           : Positive;
      Index_In_Bounds : out Boolean;
      Result          : out Bare_Ada_Node)
   is
      K : constant Ada_Node_Kind_Type := Node.Kind;
   begin
      Index_In_Bounds := True;
      Result := null;
      case Ada_Ada_Node (K) is
when Ada_Ada_List =>
declare
N_Bare_Ada_List : constant Bare_Ada_List := Node;
begin
                    if Index > N_Bare_Ada_List.Count then
                        Index_In_Bounds := False;
                    else
                        Result := N_Bare_Ada_List.Nodes (Index);
                    end if;
                    return;
end;
when Ada_Constrained_Array_Indices_Range =>
declare
N_Bare_Constrained_Array_Indices : constant Bare_Constrained_Array_Indices := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Constrained_Array_Indices.Constrained_Array_Indices_F_List;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Unconstrained_Array_Indices_Range =>
declare
N_Bare_Unconstrained_Array_Indices : constant Bare_Unconstrained_Array_Indices := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Unconstrained_Array_Indices.Unconstrained_Array_Indices_F_Types;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Aspect_Assoc_Range =>
declare
N_Bare_Aspect_Assoc : constant Bare_Aspect_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Aspect_Assoc.Aspect_Assoc_F_Id;
                            return;
                        when 2 =>
                            Result := N_Bare_Aspect_Assoc.Aspect_Assoc_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_At_Clause_Range =>
declare
N_Bare_At_Clause : constant Bare_At_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_At_Clause.At_Clause_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_At_Clause.At_Clause_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Attribute_Def_Clause_Range =>
declare
N_Bare_Attribute_Def_Clause : constant Bare_Attribute_Def_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Attribute_Def_Clause.Attribute_Def_Clause_F_Attribute_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Attribute_Def_Clause.Attribute_Def_Clause_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Enum_Rep_Clause_Range =>
declare
N_Bare_Enum_Rep_Clause : constant Bare_Enum_Rep_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Enum_Rep_Clause.Enum_Rep_Clause_F_Type_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Enum_Rep_Clause.Enum_Rep_Clause_F_Aggregate;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Record_Rep_Clause_Range =>
declare
N_Bare_Record_Rep_Clause : constant Bare_Record_Rep_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Record_Rep_Clause.Record_Rep_Clause_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Record_Rep_Clause.Record_Rep_Clause_F_At_Expr;
                            return;
                        when 3 =>
                            Result := N_Bare_Record_Rep_Clause.Record_Rep_Clause_F_Components;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Aspect_Spec_Range =>
declare
N_Bare_Aspect_Spec : constant Bare_Aspect_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Aspect_Spec.Aspect_Spec_F_Aspect_Assocs;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Contract_Case_Assoc_Range =>
declare
N_Bare_Contract_Case_Assoc : constant Bare_Contract_Case_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Contract_Case_Assoc.Contract_Case_Assoc_F_Guard;
                            return;
                        when 2 =>
                            Result := N_Bare_Contract_Case_Assoc.Contract_Case_Assoc_F_Consequence;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Pragma_Argument_Assoc_Range =>
declare
N_Bare_Pragma_Argument_Assoc : constant Bare_Pragma_Argument_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Pragma_Argument_Assoc.Pragma_Argument_Assoc_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Pragma_Argument_Assoc.Pragma_Argument_Assoc_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Entry_Spec_Range =>
declare
N_Bare_Entry_Spec : constant Bare_Entry_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Entry_Spec.Entry_Spec_F_Entry_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Entry_Spec.Entry_Spec_F_Family_Type;
                            return;
                        when 3 =>
                            Result := N_Bare_Entry_Spec.Entry_Spec_F_Entry_Params;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subp_Spec_Range =>
declare
N_Bare_Subp_Spec : constant Bare_Subp_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Subp_Spec.Subp_Spec_F_Subp_Kind;
                            return;
                        when 2 =>
                            Result := N_Bare_Subp_Spec.Subp_Spec_F_Subp_Name;
                            return;
                        when 3 =>
                            Result := N_Bare_Subp_Spec.Subp_Spec_F_Subp_Params;
                            return;
                        when 4 =>
                            Result := N_Bare_Subp_Spec.Subp_Spec_F_Subp_Returns;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Synthetic_Binary_Spec_Range =>
declare
N_Bare_Synthetic_Binary_Spec : constant Bare_Synthetic_Binary_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Synthetic_Binary_Spec.Synthetic_Binary_Spec_F_Left_Param;
                            return;
                        when 2 =>
                            Result := N_Bare_Synthetic_Binary_Spec.Synthetic_Binary_Spec_F_Right_Param;
                            return;
                        when 3 =>
                            Result := N_Bare_Synthetic_Binary_Spec.Synthetic_Binary_Spec_F_Return_Type_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Synthetic_Unary_Spec_Range =>
declare
N_Bare_Synthetic_Unary_Spec : constant Bare_Synthetic_Unary_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Synthetic_Unary_Spec.Synthetic_Unary_Spec_F_Right_Param;
                            return;
                        when 2 =>
                            Result := N_Bare_Synthetic_Unary_Spec.Synthetic_Unary_Spec_F_Return_Type_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Component_List_Range =>
declare
N_Bare_Component_List : constant Bare_Component_List := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Component_List.Component_List_F_Components;
                            return;
                        when 2 =>
                            Result := N_Bare_Component_List.Component_List_F_Variant_Part;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Known_Discriminant_Part_Range =>
declare
N_Bare_Known_Discriminant_Part : constant Bare_Known_Discriminant_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Known_Discriminant_Part.Known_Discriminant_Part_F_Discr_Specs;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Entry_Completion_Formal_Params_Range =>
declare
N_Bare_Entry_Completion_Formal_Params : constant Bare_Entry_Completion_Formal_Params := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Entry_Completion_Formal_Params.Entry_Completion_Formal_Params_F_Params;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Formal_Part_Range =>
declare
N_Bare_Generic_Formal_Part : constant Bare_Generic_Formal_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Formal_Part.Generic_Formal_Part_F_Decls;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Base_Record_Def =>
declare
N_Bare_Base_Record_Def : constant Bare_Base_Record_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Base_Record_Def.Base_Record_Def_F_Components;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Aggregate_Assoc_Range =>
declare
N_Bare_Aggregate_Assoc : constant Bare_Aggregate_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Aggregate_Assoc.Aggregate_Assoc_F_Designators;
                            return;
                        when 2 =>
                            Result := N_Bare_Aggregate_Assoc.Aggregate_Assoc_F_R_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Composite_Constraint_Assoc_Range =>
declare
N_Bare_Composite_Constraint_Assoc : constant Bare_Composite_Constraint_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Composite_Constraint_Assoc.Composite_Constraint_Assoc_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Composite_Constraint_Assoc.Composite_Constraint_Assoc_F_Constraint_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Iterated_Assoc_Range =>
declare
N_Bare_Iterated_Assoc : constant Bare_Iterated_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Iterated_Assoc.Iterated_Assoc_F_Spec;
                            return;
                        when 2 =>
                            Result := N_Bare_Iterated_Assoc.Iterated_Assoc_F_R_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Param_Assoc_Range =>
declare
N_Bare_Param_Assoc : constant Bare_Param_Assoc := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Param_Assoc.Param_Assoc_F_Designator;
                            return;
                        when 2 =>
                            Result := N_Bare_Param_Assoc.Param_Assoc_F_R_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Abstract_State_Decl_Range =>
declare
N_Bare_Abstract_State_Decl : constant Bare_Abstract_State_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Abstract_State_Decl.Abstract_State_Decl_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Abstract_State_Decl.Abstract_State_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Anonymous_Expr_Decl_Range =>
declare
N_Bare_Anonymous_Expr_Decl : constant Bare_Anonymous_Expr_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Anonymous_Expr_Decl.Anonymous_Expr_Decl_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Component_Decl_Range =>
declare
N_Bare_Component_Decl : constant Bare_Component_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Component_Decl.Component_Decl_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Component_Decl.Component_Decl_F_Component_Def;
                            return;
                        when 3 =>
                            Result := N_Bare_Component_Decl.Component_Decl_F_Default_Expr;
                            return;
                        when 4 =>
                            Result := N_Bare_Component_Decl.Component_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Discriminant_Spec_Range =>
declare
N_Bare_Discriminant_Spec : constant Bare_Discriminant_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Discriminant_Spec.Discriminant_Spec_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Discriminant_Spec.Discriminant_Spec_F_Type_Expr;
                            return;
                        when 3 =>
                            Result := N_Bare_Discriminant_Spec.Discriminant_Spec_F_Default_Expr;
                            return;
                        when 4 =>
                            Result := N_Bare_Discriminant_Spec.Discriminant_Spec_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Formal =>
declare
N_Bare_Generic_Formal : constant Bare_Generic_Formal := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Formal.Generic_Formal_F_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Param_Spec_Range =>
declare
N_Bare_Param_Spec : constant Bare_Param_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Param_Spec.Param_Spec_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Param_Spec.Param_Spec_F_Has_Aliased;
                            return;
                        when 3 =>
                            Result := N_Bare_Param_Spec.Param_Spec_F_Mode;
                            return;
                        when 4 =>
                            Result := N_Bare_Param_Spec.Param_Spec_F_Type_Expr;
                            return;
                        when 5 =>
                            Result := N_Bare_Param_Spec.Param_Spec_F_Default_Expr;
                            return;
                        when 6 =>
                            Result := N_Bare_Param_Spec.Param_Spec_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Synthetic_Formal_Param_Decl_Range =>
declare
N_Bare_Synthetic_Formal_Param_Decl : constant Bare_Synthetic_Formal_Param_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Synthetic_Formal_Param_Decl.Synthetic_Formal_Param_Decl_F_Param_Type;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Base_Package_Decl =>
declare
N_Bare_Base_Package_Decl : constant Bare_Base_Package_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Base_Package_Decl.Base_Package_Decl_F_Package_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Base_Package_Decl.Base_Package_Decl_F_Aspects;
                            return;
                        when 3 =>
                            Result := N_Bare_Base_Package_Decl.Base_Package_Decl_F_Public_Part;
                            return;
                        when 4 =>
                            Result := N_Bare_Base_Package_Decl.Base_Package_Decl_F_Private_Part;
                            return;
                        when 5 =>
                            Result := N_Bare_Base_Package_Decl.Base_Package_Decl_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Base_Type_Decl =>
declare
N_Bare_Base_Type_Decl : constant Bare_Base_Type_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Base_Type_Decl.Base_Type_Decl_F_Name;
                            return;
                        when others => null;
                    end case;
case Ada_Base_Type_Decl (K) is
when Ada_Subtype_Decl_Range =>
declare
N_Bare_Subtype_Decl : constant Bare_Subtype_Decl := N_Bare_Base_Type_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Subtype_Decl.Subtype_Decl_F_Subtype;
                            return;
                        when 3 =>
                            Result := N_Bare_Subtype_Decl.Subtype_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Incomplete_Type_Decl_Range =>
declare
N_Bare_Incomplete_Type_Decl : constant Bare_Incomplete_Type_Decl := N_Bare_Base_Type_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Incomplete_Type_Decl.Incomplete_Type_Decl_F_Discriminants;
                            return;
                        when others => null;
                    end case;
case Ada_Incomplete_Type_Decl_Range (K) is
when Ada_Incomplete_Formal_Type_Decl_Range =>
declare
N_Bare_Incomplete_Formal_Type_Decl : constant Bare_Incomplete_Formal_Type_Decl := N_Bare_Incomplete_Type_Decl;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Incomplete_Formal_Type_Decl.Incomplete_Formal_Type_Decl_F_Is_Tagged;
                            return;
                        when 4 =>
                            Result := N_Bare_Incomplete_Formal_Type_Decl.Incomplete_Formal_Type_Decl_F_Default_Type;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Incomplete_Tagged_Type_Decl_Range =>
declare
N_Bare_Incomplete_Tagged_Type_Decl : constant Bare_Incomplete_Tagged_Type_Decl := N_Bare_Incomplete_Type_Decl;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Incomplete_Tagged_Type_Decl.Incomplete_Tagged_Type_Decl_F_Has_Abstract;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when Ada_Protected_Type_Decl_Range =>
declare
N_Bare_Protected_Type_Decl : constant Bare_Protected_Type_Decl := N_Bare_Base_Type_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Protected_Type_Decl.Protected_Type_Decl_F_Discriminants;
                            return;
                        when 3 =>
                            Result := N_Bare_Protected_Type_Decl.Protected_Type_Decl_F_Aspects;
                            return;
                        when 4 =>
                            Result := N_Bare_Protected_Type_Decl.Protected_Type_Decl_F_Interfaces;
                            return;
                        when 5 =>
                            Result := N_Bare_Protected_Type_Decl.Protected_Type_Decl_F_Definition;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Task_Type_Decl_Range =>
declare
N_Bare_Task_Type_Decl : constant Bare_Task_Type_Decl := N_Bare_Base_Type_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Task_Type_Decl.Task_Type_Decl_F_Discriminants;
                            return;
                        when 3 =>
                            Result := N_Bare_Task_Type_Decl.Task_Type_Decl_F_Aspects;
                            return;
                        when 4 =>
                            Result := N_Bare_Task_Type_Decl.Task_Type_Decl_F_Definition;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Type_Decl =>
declare
N_Bare_Type_Decl : constant Bare_Type_Decl := N_Bare_Base_Type_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Type_Decl.Type_Decl_F_Discriminants;
                            return;
                        when 3 =>
                            Result := N_Bare_Type_Decl.Type_Decl_F_Type_Def;
                            return;
                        when others => null;
                    end case;
case Ada_Type_Decl (K) is
when Ada_Concrete_Type_Decl_Range =>
declare
N_Bare_Concrete_Type_Decl : constant Bare_Concrete_Type_Decl := N_Bare_Type_Decl;
begin
case Index is
                        when 4 =>
                            Result := N_Bare_Concrete_Type_Decl.Concrete_Type_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Formal_Type_Decl_Range =>
declare
N_Bare_Formal_Type_Decl : constant Bare_Formal_Type_Decl := N_Bare_Type_Decl;
begin
case Index is
                        when 4 =>
                            Result := N_Bare_Formal_Type_Decl.Formal_Type_Decl_F_Default_Type;
                            return;
                        when 5 =>
                            Result := N_Bare_Formal_Type_Decl.Formal_Type_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when others => null;
end case;
end;
when Ada_Classic_Subp_Decl =>
declare
N_Bare_Classic_Subp_Decl : constant Bare_Classic_Subp_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Classic_Subp_Decl.Classic_Subp_Decl_F_Overriding;
                            return;
                        when 2 =>
                            Result := N_Bare_Classic_Subp_Decl.Classic_Subp_Decl_F_Subp_Spec;
                            return;
                        when others => null;
                    end case;
case Ada_Classic_Subp_Decl (K) is
when Ada_Abstract_Subp_Decl_Range =>
declare
N_Bare_Abstract_Subp_Decl : constant Bare_Abstract_Subp_Decl := N_Bare_Classic_Subp_Decl;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Abstract_Subp_Decl.Abstract_Subp_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Formal_Subp_Decl =>
declare
N_Bare_Formal_Subp_Decl : constant Bare_Formal_Subp_Decl := N_Bare_Classic_Subp_Decl;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Formal_Subp_Decl.Formal_Subp_Decl_F_Default_Expr;
                            return;
                        when 4 =>
                            Result := N_Bare_Formal_Subp_Decl.Formal_Subp_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subp_Decl_Range =>
declare
N_Bare_Subp_Decl : constant Bare_Subp_Decl := N_Bare_Classic_Subp_Decl;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Subp_Decl.Subp_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when Ada_Entry_Decl_Range =>
declare
N_Bare_Entry_Decl : constant Bare_Entry_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Entry_Decl.Entry_Decl_F_Overriding;
                            return;
                        when 2 =>
                            Result := N_Bare_Entry_Decl.Entry_Decl_F_Spec;
                            return;
                        when 3 =>
                            Result := N_Bare_Entry_Decl.Entry_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Enum_Literal_Decl_Range =>
declare
N_Bare_Enum_Literal_Decl : constant Bare_Enum_Literal_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Enum_Literal_Decl.Enum_Literal_Decl_F_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Subp_Internal_Range =>
declare
N_Bare_Generic_Subp_Internal : constant Bare_Generic_Subp_Internal := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Subp_Internal.Generic_Subp_Internal_F_Subp_Spec;
                            return;
                        when 2 =>
                            Result := N_Bare_Generic_Subp_Internal.Generic_Subp_Internal_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Synthetic_Subp_Decl_Range =>
declare
N_Bare_Synthetic_Subp_Decl : constant Bare_Synthetic_Subp_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Synthetic_Subp_Decl.Synthetic_Subp_Decl_F_Spec;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Base_Subp_Body =>
declare
N_Bare_Base_Subp_Body : constant Bare_Base_Subp_Body := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Base_Subp_Body.Base_Subp_Body_F_Overriding;
                            return;
                        when 2 =>
                            Result := N_Bare_Base_Subp_Body.Base_Subp_Body_F_Subp_Spec;
                            return;
                        when others => null;
                    end case;
case Ada_Base_Subp_Body (K) is
when Ada_Expr_Function_Range =>
declare
N_Bare_Expr_Function : constant Bare_Expr_Function := N_Bare_Base_Subp_Body;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Expr_Function.Expr_Function_F_Expr;
                            return;
                        when 4 =>
                            Result := N_Bare_Expr_Function.Expr_Function_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Null_Subp_Decl_Range =>
declare
N_Bare_Null_Subp_Decl : constant Bare_Null_Subp_Decl := N_Bare_Base_Subp_Body;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Null_Subp_Decl.Null_Subp_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subp_Body_Range =>
declare
N_Bare_Subp_Body : constant Bare_Subp_Body := N_Bare_Base_Subp_Body;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Subp_Body.Subp_Body_F_Aspects;
                            return;
                        when 4 =>
                            Result := N_Bare_Subp_Body.Subp_Body_F_Decls;
                            return;
                        when 5 =>
                            Result := N_Bare_Subp_Body.Subp_Body_F_Stmts;
                            return;
                        when 6 =>
                            Result := N_Bare_Subp_Body.Subp_Body_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subp_Renaming_Decl_Range =>
declare
N_Bare_Subp_Renaming_Decl : constant Bare_Subp_Renaming_Decl := N_Bare_Base_Subp_Body;
begin
case Index is
                        when 3 =>
                            Result := N_Bare_Subp_Renaming_Decl.Subp_Renaming_Decl_F_Renames;
                            return;
                        when 4 =>
                            Result := N_Bare_Subp_Renaming_Decl.Subp_Renaming_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when Ada_Package_Body_Stub_Range =>
declare
N_Bare_Package_Body_Stub : constant Bare_Package_Body_Stub := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Package_Body_Stub.Package_Body_Stub_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Package_Body_Stub.Package_Body_Stub_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Protected_Body_Stub_Range =>
declare
N_Bare_Protected_Body_Stub : constant Bare_Protected_Body_Stub := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Protected_Body_Stub.Protected_Body_Stub_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Protected_Body_Stub.Protected_Body_Stub_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subp_Body_Stub_Range =>
declare
N_Bare_Subp_Body_Stub : constant Bare_Subp_Body_Stub := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Subp_Body_Stub.Subp_Body_Stub_F_Overriding;
                            return;
                        when 2 =>
                            Result := N_Bare_Subp_Body_Stub.Subp_Body_Stub_F_Subp_Spec;
                            return;
                        when 3 =>
                            Result := N_Bare_Subp_Body_Stub.Subp_Body_Stub_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Task_Body_Stub_Range =>
declare
N_Bare_Task_Body_Stub : constant Bare_Task_Body_Stub := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Task_Body_Stub.Task_Body_Stub_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Task_Body_Stub.Task_Body_Stub_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Entry_Body_Range =>
declare
N_Bare_Entry_Body : constant Bare_Entry_Body := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Entry_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Index_Spec;
                            return;
                        when 3 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Params;
                            return;
                        when 4 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Aspects;
                            return;
                        when 5 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Barrier;
                            return;
                        when 6 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Decls;
                            return;
                        when 7 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_Stmts;
                            return;
                        when 8 =>
                            Result := N_Bare_Entry_Body.Entry_Body_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Package_Body_Range =>
declare
N_Bare_Package_Body : constant Bare_Package_Body := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Package_Body.Package_Body_F_Package_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Package_Body.Package_Body_F_Aspects;
                            return;
                        when 3 =>
                            Result := N_Bare_Package_Body.Package_Body_F_Decls;
                            return;
                        when 4 =>
                            Result := N_Bare_Package_Body.Package_Body_F_Stmts;
                            return;
                        when 5 =>
                            Result := N_Bare_Package_Body.Package_Body_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Protected_Body_Range =>
declare
N_Bare_Protected_Body : constant Bare_Protected_Body := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Protected_Body.Protected_Body_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Protected_Body.Protected_Body_F_Aspects;
                            return;
                        when 3 =>
                            Result := N_Bare_Protected_Body.Protected_Body_F_Decls;
                            return;
                        when 4 =>
                            Result := N_Bare_Protected_Body.Protected_Body_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Task_Body_Range =>
declare
N_Bare_Task_Body : constant Bare_Task_Body := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Task_Body.Task_Body_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Task_Body.Task_Body_F_Aspects;
                            return;
                        when 3 =>
                            Result := N_Bare_Task_Body.Task_Body_F_Decls;
                            return;
                        when 4 =>
                            Result := N_Bare_Task_Body.Task_Body_F_Stmts;
                            return;
                        when 5 =>
                            Result := N_Bare_Task_Body.Task_Body_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Entry_Index_Spec_Range =>
declare
N_Bare_Entry_Index_Spec : constant Bare_Entry_Index_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Entry_Index_Spec.Entry_Index_Spec_F_Id;
                            return;
                        when 2 =>
                            Result := N_Bare_Entry_Index_Spec.Entry_Index_Spec_F_Subtype;
                            return;
                        when 3 =>
                            Result := N_Bare_Entry_Index_Spec.Entry_Index_Spec_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Exception_Decl_Range =>
declare
N_Bare_Exception_Decl : constant Bare_Exception_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Exception_Decl.Exception_Decl_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Exception_Decl.Exception_Decl_F_Renames;
                            return;
                        when 3 =>
                            Result := N_Bare_Exception_Decl.Exception_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Exception_Handler_Range =>
declare
N_Bare_Exception_Handler : constant Bare_Exception_Handler := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Exception_Handler.Exception_Handler_F_Exception_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Exception_Handler.Exception_Handler_F_Handled_Exceptions;
                            return;
                        when 3 =>
                            Result := N_Bare_Exception_Handler.Exception_Handler_F_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_For_Loop_Var_Decl_Range =>
declare
N_Bare_For_Loop_Var_Decl : constant Bare_For_Loop_Var_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_For_Loop_Var_Decl.For_Loop_Var_Decl_F_Id;
                            return;
                        when 2 =>
                            Result := N_Bare_For_Loop_Var_Decl.For_Loop_Var_Decl_F_Id_Type;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Decl =>
declare
N_Bare_Generic_Decl : constant Bare_Generic_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Decl.Generic_Decl_F_Formal_Part;
                            return;
                        when others => null;
                    end case;
case Ada_Generic_Decl (K) is
when Ada_Generic_Package_Decl_Range =>
declare
N_Bare_Generic_Package_Decl : constant Bare_Generic_Package_Decl := N_Bare_Generic_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Generic_Package_Decl.Generic_Package_Decl_F_Package_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Subp_Decl_Range =>
declare
N_Bare_Generic_Subp_Decl : constant Bare_Generic_Subp_Decl := N_Bare_Generic_Decl;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Generic_Subp_Decl.Generic_Subp_Decl_F_Subp_Decl;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when Ada_Generic_Package_Instantiation_Range =>
declare
N_Bare_Generic_Package_Instantiation : constant Bare_Generic_Package_Instantiation := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Package_Instantiation.Generic_Package_Instantiation_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Generic_Package_Instantiation.Generic_Package_Instantiation_F_Generic_Pkg_Name;
                            return;
                        when 3 =>
                            Result := N_Bare_Generic_Package_Instantiation.Generic_Package_Instantiation_F_Params;
                            return;
                        when 4 =>
                            Result := N_Bare_Generic_Package_Instantiation.Generic_Package_Instantiation_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Subp_Instantiation_Range =>
declare
N_Bare_Generic_Subp_Instantiation : constant Bare_Generic_Subp_Instantiation := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Subp_Instantiation.Generic_Subp_Instantiation_F_Overriding;
                            return;
                        when 2 =>
                            Result := N_Bare_Generic_Subp_Instantiation.Generic_Subp_Instantiation_F_Kind;
                            return;
                        when 3 =>
                            Result := N_Bare_Generic_Subp_Instantiation.Generic_Subp_Instantiation_F_Subp_Name;
                            return;
                        when 4 =>
                            Result := N_Bare_Generic_Subp_Instantiation.Generic_Subp_Instantiation_F_Generic_Subp_Name;
                            return;
                        when 5 =>
                            Result := N_Bare_Generic_Subp_Instantiation.Generic_Subp_Instantiation_F_Params;
                            return;
                        when 6 =>
                            Result := N_Bare_Generic_Subp_Instantiation.Generic_Subp_Instantiation_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Package_Renaming_Decl_Range =>
declare
N_Bare_Generic_Package_Renaming_Decl : constant Bare_Generic_Package_Renaming_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Package_Renaming_Decl.Generic_Package_Renaming_Decl_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Generic_Package_Renaming_Decl.Generic_Package_Renaming_Decl_F_Renames;
                            return;
                        when 3 =>
                            Result := N_Bare_Generic_Package_Renaming_Decl.Generic_Package_Renaming_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Generic_Subp_Renaming_Decl_Range =>
declare
N_Bare_Generic_Subp_Renaming_Decl : constant Bare_Generic_Subp_Renaming_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Generic_Subp_Renaming_Decl.Generic_Subp_Renaming_Decl_F_Kind;
                            return;
                        when 2 =>
                            Result := N_Bare_Generic_Subp_Renaming_Decl.Generic_Subp_Renaming_Decl_F_Name;
                            return;
                        when 3 =>
                            Result := N_Bare_Generic_Subp_Renaming_Decl.Generic_Subp_Renaming_Decl_F_Renames;
                            return;
                        when 4 =>
                            Result := N_Bare_Generic_Subp_Renaming_Decl.Generic_Subp_Renaming_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Label_Decl_Range =>
declare
N_Bare_Label_Decl : constant Bare_Label_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Label_Decl.Label_Decl_F_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Named_Stmt_Decl_Range =>
declare
N_Bare_Named_Stmt_Decl : constant Bare_Named_Stmt_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Named_Stmt_Decl.Named_Stmt_Decl_F_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Number_Decl_Range =>
declare
N_Bare_Number_Decl : constant Bare_Number_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Number_Decl.Number_Decl_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Number_Decl.Number_Decl_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Object_Decl_Range =>
declare
N_Bare_Object_Decl : constant Bare_Object_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Ids;
                            return;
                        when 2 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Has_Aliased;
                            return;
                        when 3 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Has_Constant;
                            return;
                        when 4 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Mode;
                            return;
                        when 5 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Type_Expr;
                            return;
                        when 6 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Default_Expr;
                            return;
                        when 7 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Renaming_Clause;
                            return;
                        when 8 =>
                            Result := N_Bare_Object_Decl.Object_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Package_Renaming_Decl_Range =>
declare
N_Bare_Package_Renaming_Decl : constant Bare_Package_Renaming_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Package_Renaming_Decl.Package_Renaming_Decl_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Package_Renaming_Decl.Package_Renaming_Decl_F_Renames;
                            return;
                        when 3 =>
                            Result := N_Bare_Package_Renaming_Decl.Package_Renaming_Decl_F_Aspects;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Single_Protected_Decl_Range =>
declare
N_Bare_Single_Protected_Decl : constant Bare_Single_Protected_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Single_Protected_Decl.Single_Protected_Decl_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Single_Protected_Decl.Single_Protected_Decl_F_Aspects;
                            return;
                        when 3 =>
                            Result := N_Bare_Single_Protected_Decl.Single_Protected_Decl_F_Interfaces;
                            return;
                        when 4 =>
                            Result := N_Bare_Single_Protected_Decl.Single_Protected_Decl_F_Definition;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Single_Task_Decl_Range =>
declare
N_Bare_Single_Task_Decl : constant Bare_Single_Task_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Single_Task_Decl.Single_Task_Decl_F_Task_Type;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Case_Stmt_Alternative_Range =>
declare
N_Bare_Case_Stmt_Alternative : constant Bare_Case_Stmt_Alternative := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Case_Stmt_Alternative.Case_Stmt_Alternative_F_Choices;
                            return;
                        when 2 =>
                            Result := N_Bare_Case_Stmt_Alternative.Case_Stmt_Alternative_F_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Compilation_Unit_Range =>
declare
N_Bare_Compilation_Unit : constant Bare_Compilation_Unit := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Compilation_Unit.Compilation_Unit_F_Prelude;
                            return;
                        when 2 =>
                            Result := N_Bare_Compilation_Unit.Compilation_Unit_F_Body;
                            return;
                        when 3 =>
                            Result := N_Bare_Compilation_Unit.Compilation_Unit_F_Pragmas;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Component_Clause_Range =>
declare
N_Bare_Component_Clause : constant Bare_Component_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Component_Clause.Component_Clause_F_Id;
                            return;
                        when 2 =>
                            Result := N_Bare_Component_Clause.Component_Clause_F_Position;
                            return;
                        when 3 =>
                            Result := N_Bare_Component_Clause.Component_Clause_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Component_Def_Range =>
declare
N_Bare_Component_Def : constant Bare_Component_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Component_Def.Component_Def_F_Has_Aliased;
                            return;
                        when 2 =>
                            Result := N_Bare_Component_Def.Component_Def_F_Has_Constant;
                            return;
                        when 3 =>
                            Result := N_Bare_Component_Def.Component_Def_F_Type_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Composite_Constraint_Range =>
declare
N_Bare_Composite_Constraint : constant Bare_Composite_Constraint := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Composite_Constraint.Composite_Constraint_F_Constraints;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Delta_Constraint_Range =>
declare
N_Bare_Delta_Constraint : constant Bare_Delta_Constraint := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Delta_Constraint.Delta_Constraint_F_Digits;
                            return;
                        when 2 =>
                            Result := N_Bare_Delta_Constraint.Delta_Constraint_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Digits_Constraint_Range =>
declare
N_Bare_Digits_Constraint : constant Bare_Digits_Constraint := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Digits_Constraint.Digits_Constraint_F_Digits;
                            return;
                        when 2 =>
                            Result := N_Bare_Digits_Constraint.Digits_Constraint_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Range_Constraint_Range =>
declare
N_Bare_Range_Constraint : constant Bare_Range_Constraint := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Range_Constraint.Range_Constraint_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Declarative_Part_Range =>
declare
N_Bare_Declarative_Part : constant Bare_Declarative_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Declarative_Part.Declarative_Part_F_Decls;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Elsif_Expr_Part_Range =>
declare
N_Bare_Elsif_Expr_Part : constant Bare_Elsif_Expr_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Elsif_Expr_Part.Elsif_Expr_Part_F_Cond_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Elsif_Expr_Part.Elsif_Expr_Part_F_Then_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Elsif_Stmt_Part_Range =>
declare
N_Bare_Elsif_Stmt_Part : constant Bare_Elsif_Stmt_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Elsif_Stmt_Part.Elsif_Stmt_Part_F_Cond_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Elsif_Stmt_Part.Elsif_Stmt_Part_F_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Abstract_State_Decl_Expr_Range =>
declare
N_Bare_Abstract_State_Decl_Expr : constant Bare_Abstract_State_Decl_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Abstract_State_Decl_Expr.Abstract_State_Decl_Expr_F_State_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Allocator_Range =>
declare
N_Bare_Allocator : constant Bare_Allocator := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Allocator.Allocator_F_Subpool;
                            return;
                        when 2 =>
                            Result := N_Bare_Allocator.Allocator_F_Type_Or_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Base_Aggregate =>
declare
N_Bare_Base_Aggregate : constant Bare_Base_Aggregate := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Base_Aggregate.Base_Aggregate_F_Ancestor_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Base_Aggregate.Base_Aggregate_F_Assocs;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Bin_Op_Range =>
declare
N_Bare_Bin_Op : constant Bare_Bin_Op := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Bin_Op.Bin_Op_F_Left;
                            return;
                        when 2 =>
                            Result := N_Bare_Bin_Op.Bin_Op_F_Op;
                            return;
                        when 3 =>
                            Result := N_Bare_Bin_Op.Bin_Op_F_Right;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Case_Expr_Alternative_Range =>
declare
N_Bare_Case_Expr_Alternative : constant Bare_Case_Expr_Alternative := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Case_Expr_Alternative.Case_Expr_Alternative_F_Choices;
                            return;
                        when 2 =>
                            Result := N_Bare_Case_Expr_Alternative.Case_Expr_Alternative_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Concat_Op_Range =>
declare
N_Bare_Concat_Op : constant Bare_Concat_Op := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Concat_Op.Concat_Op_F_First_Operand;
                            return;
                        when 2 =>
                            Result := N_Bare_Concat_Op.Concat_Op_F_Other_Operands;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Concat_Operand_Range =>
declare
N_Bare_Concat_Operand : constant Bare_Concat_Operand := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Concat_Operand.Concat_Operand_F_Operator;
                            return;
                        when 2 =>
                            Result := N_Bare_Concat_Operand.Concat_Operand_F_Operand;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Case_Expr_Range =>
declare
N_Bare_Case_Expr : constant Bare_Case_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Case_Expr.Case_Expr_F_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Case_Expr.Case_Expr_F_Cases;
                            return;
                        when others => null;
                    end case;
end;
when Ada_If_Expr_Range =>
declare
N_Bare_If_Expr : constant Bare_If_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_If_Expr.If_Expr_F_Cond_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_If_Expr.If_Expr_F_Then_Expr;
                            return;
                        when 3 =>
                            Result := N_Bare_If_Expr.If_Expr_F_Alternatives;
                            return;
                        when 4 =>
                            Result := N_Bare_If_Expr.If_Expr_F_Else_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Contract_Cases_Range =>
declare
N_Bare_Contract_Cases : constant Bare_Contract_Cases := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Contract_Cases.Contract_Cases_F_Contract_Cases;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Decl_Expr_Range =>
declare
N_Bare_Decl_Expr : constant Bare_Decl_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Decl_Expr.Decl_Expr_F_Decls;
                            return;
                        when 2 =>
                            Result := N_Bare_Decl_Expr.Decl_Expr_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Membership_Expr_Range =>
declare
N_Bare_Membership_Expr : constant Bare_Membership_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Membership_Expr.Membership_Expr_F_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Membership_Expr.Membership_Expr_F_Op;
                            return;
                        when 3 =>
                            Result := N_Bare_Membership_Expr.Membership_Expr_F_Membership_Exprs;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Attribute_Ref_Range =>
declare
N_Bare_Attribute_Ref : constant Bare_Attribute_Ref := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Attribute_Ref.Attribute_Ref_F_Prefix;
                            return;
                        when 2 =>
                            Result := N_Bare_Attribute_Ref.Attribute_Ref_F_Attribute;
                            return;
                        when 3 =>
                            Result := N_Bare_Attribute_Ref.Attribute_Ref_F_Args;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Call_Expr_Range =>
declare
N_Bare_Call_Expr : constant Bare_Call_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Call_Expr.Call_Expr_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Call_Expr.Call_Expr_F_Suffix;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Defining_Name_Range =>
declare
N_Bare_Defining_Name : constant Bare_Defining_Name := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Defining_Name.Defining_Name_F_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Discrete_Subtype_Name_Range =>
declare
N_Bare_Discrete_Subtype_Name : constant Bare_Discrete_Subtype_Name := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Discrete_Subtype_Name.Discrete_Subtype_Name_F_Subtype;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Dotted_Name_Range =>
declare
N_Bare_Dotted_Name : constant Bare_Dotted_Name := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Dotted_Name.Dotted_Name_F_Prefix;
                            return;
                        when 2 =>
                            Result := N_Bare_Dotted_Name.Dotted_Name_F_Suffix;
                            return;
                        when others => null;
                    end case;
end;
when Ada_End_Name_Range =>
declare
N_Bare_End_Name : constant Bare_End_Name := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_End_Name.End_Name_F_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Explicit_Deref_Range =>
declare
N_Bare_Explicit_Deref : constant Bare_Explicit_Deref := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Explicit_Deref.Explicit_Deref_F_Prefix;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Qual_Expr_Range =>
declare
N_Bare_Qual_Expr : constant Bare_Qual_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Qual_Expr.Qual_Expr_F_Prefix;
                            return;
                        when 2 =>
                            Result := N_Bare_Qual_Expr.Qual_Expr_F_Suffix;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Reduce_Attribute_Ref_Range =>
declare
N_Bare_Reduce_Attribute_Ref : constant Bare_Reduce_Attribute_Ref := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Reduce_Attribute_Ref.Reduce_Attribute_Ref_F_Prefix;
                            return;
                        when 2 =>
                            Result := N_Bare_Reduce_Attribute_Ref.Reduce_Attribute_Ref_F_Attribute;
                            return;
                        when 3 =>
                            Result := N_Bare_Reduce_Attribute_Ref.Reduce_Attribute_Ref_F_Args;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Update_Attribute_Ref_Range =>
declare
N_Bare_Update_Attribute_Ref : constant Bare_Update_Attribute_Ref := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Update_Attribute_Ref.Update_Attribute_Ref_F_Prefix;
                            return;
                        when 2 =>
                            Result := N_Bare_Update_Attribute_Ref.Update_Attribute_Ref_F_Attribute;
                            return;
                        when 3 =>
                            Result := N_Bare_Update_Attribute_Ref.Update_Attribute_Ref_F_Values;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Paren_Expr_Range =>
declare
N_Bare_Paren_Expr : constant Bare_Paren_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Paren_Expr.Paren_Expr_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Quantified_Expr_Range =>
declare
N_Bare_Quantified_Expr : constant Bare_Quantified_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Quantified_Expr.Quantified_Expr_F_Quantifier;
                            return;
                        when 2 =>
                            Result := N_Bare_Quantified_Expr.Quantified_Expr_F_Loop_Spec;
                            return;
                        when 3 =>
                            Result := N_Bare_Quantified_Expr.Quantified_Expr_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Raise_Expr_Range =>
declare
N_Bare_Raise_Expr : constant Bare_Raise_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Raise_Expr.Raise_Expr_F_Exception_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Raise_Expr.Raise_Expr_F_Error_Message;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Un_Op_Range =>
declare
N_Bare_Un_Op : constant Bare_Un_Op := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Un_Op.Un_Op_F_Op;
                            return;
                        when 2 =>
                            Result := N_Bare_Un_Op.Un_Op_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Handled_Stmts_Range =>
declare
N_Bare_Handled_Stmts : constant Bare_Handled_Stmts := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Handled_Stmts.Handled_Stmts_F_Stmts;
                            return;
                        when 2 =>
                            Result := N_Bare_Handled_Stmts.Handled_Stmts_F_Exceptions;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Library_Item_Range =>
declare
N_Bare_Library_Item : constant Bare_Library_Item := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Library_Item.Library_Item_F_Has_Private;
                            return;
                        when 2 =>
                            Result := N_Bare_Library_Item.Library_Item_F_Item;
                            return;
                        when others => null;
                    end case;
end;
when Ada_For_Loop_Spec_Range =>
declare
N_Bare_For_Loop_Spec : constant Bare_For_Loop_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_For_Loop_Spec.For_Loop_Spec_F_Var_Decl;
                            return;
                        when 2 =>
                            Result := N_Bare_For_Loop_Spec.For_Loop_Spec_F_Loop_Type;
                            return;
                        when 3 =>
                            Result := N_Bare_For_Loop_Spec.For_Loop_Spec_F_Has_Reverse;
                            return;
                        when 4 =>
                            Result := N_Bare_For_Loop_Spec.For_Loop_Spec_F_Iter_Expr;
                            return;
                        when 5 =>
                            Result := N_Bare_For_Loop_Spec.For_Loop_Spec_F_Iter_Filter;
                            return;
                        when others => null;
                    end case;
end;
when Ada_While_Loop_Spec_Range =>
declare
N_Bare_While_Loop_Spec : constant Bare_While_Loop_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_While_Loop_Spec.While_Loop_Spec_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Multi_Abstract_State_Decl_Range =>
declare
N_Bare_Multi_Abstract_State_Decl : constant Bare_Multi_Abstract_State_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Multi_Abstract_State_Decl.Multi_Abstract_State_Decl_F_Decls;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Params_Range =>
declare
N_Bare_Params : constant Bare_Params := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Params.Params_F_Params;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Paren_Abstract_State_Decl_Range =>
declare
N_Bare_Paren_Abstract_State_Decl : constant Bare_Paren_Abstract_State_Decl := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Paren_Abstract_State_Decl.Paren_Abstract_State_Decl_F_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Pp_Elsif_Directive_Range =>
declare
N_Bare_Pp_Elsif_Directive : constant Bare_Pp_Elsif_Directive := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Pp_Elsif_Directive.Pp_Elsif_Directive_F_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Pp_Elsif_Directive.Pp_Elsif_Directive_F_Then_Kw;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Pp_If_Directive_Range =>
declare
N_Bare_Pp_If_Directive : constant Bare_Pp_If_Directive := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Pp_If_Directive.Pp_If_Directive_F_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Pp_If_Directive.Pp_If_Directive_F_Then_Kw;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Pragma_Node_Range =>
declare
N_Bare_Pragma_Node : constant Bare_Pragma_Node := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Pragma_Node.Pragma_Node_F_Id;
                            return;
                        when 2 =>
                            Result := N_Bare_Pragma_Node.Pragma_Node_F_Args;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Protected_Def_Range =>
declare
N_Bare_Protected_Def : constant Bare_Protected_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Protected_Def.Protected_Def_F_Public_Part;
                            return;
                        when 2 =>
                            Result := N_Bare_Protected_Def.Protected_Def_F_Private_Part;
                            return;
                        when 3 =>
                            Result := N_Bare_Protected_Def.Protected_Def_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Range_Spec_Range =>
declare
N_Bare_Range_Spec : constant Bare_Range_Spec := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Range_Spec.Range_Spec_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Renaming_Clause_Range =>
declare
N_Bare_Renaming_Clause : constant Bare_Renaming_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Renaming_Clause.Renaming_Clause_F_Renamed_Object;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Select_When_Part_Range =>
declare
N_Bare_Select_When_Part : constant Bare_Select_When_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Select_When_Part.Select_When_Part_F_Cond_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Select_When_Part.Select_When_Part_F_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Accept_Stmt_Range =>
declare
N_Bare_Accept_Stmt : constant Bare_Accept_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Accept_Stmt.Accept_Stmt_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Accept_Stmt.Accept_Stmt_F_Entry_Index_Expr;
                            return;
                        when 3 =>
                            Result := N_Bare_Accept_Stmt.Accept_Stmt_F_Params;
                            return;
                        when others => null;
                    end case;
case Ada_Accept_Stmt_Range (K) is
when Ada_Accept_Stmt_With_Stmts_Range =>
declare
N_Bare_Accept_Stmt_With_Stmts : constant Bare_Accept_Stmt_With_Stmts := N_Bare_Accept_Stmt;
begin
case Index is
                        when 4 =>
                            Result := N_Bare_Accept_Stmt_With_Stmts.Accept_Stmt_With_Stmts_F_Stmts;
                            return;
                        when 5 =>
                            Result := N_Bare_Accept_Stmt_With_Stmts.Accept_Stmt_With_Stmts_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when Ada_Base_Loop_Stmt =>
declare
N_Bare_Base_Loop_Stmt : constant Bare_Base_Loop_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Base_Loop_Stmt.Base_Loop_Stmt_F_Spec;
                            return;
                        when 2 =>
                            Result := N_Bare_Base_Loop_Stmt.Base_Loop_Stmt_F_Stmts;
                            return;
                        when 3 =>
                            Result := N_Bare_Base_Loop_Stmt.Base_Loop_Stmt_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Begin_Block_Range =>
declare
N_Bare_Begin_Block : constant Bare_Begin_Block := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Begin_Block.Begin_Block_F_Stmts;
                            return;
                        when 2 =>
                            Result := N_Bare_Begin_Block.Begin_Block_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Decl_Block_Range =>
declare
N_Bare_Decl_Block : constant Bare_Decl_Block := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Decl_Block.Decl_Block_F_Decls;
                            return;
                        when 2 =>
                            Result := N_Bare_Decl_Block.Decl_Block_F_Stmts;
                            return;
                        when 3 =>
                            Result := N_Bare_Decl_Block.Decl_Block_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Case_Stmt_Range =>
declare
N_Bare_Case_Stmt : constant Bare_Case_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Case_Stmt.Case_Stmt_F_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_Case_Stmt.Case_Stmt_F_Pragmas;
                            return;
                        when 3 =>
                            Result := N_Bare_Case_Stmt.Case_Stmt_F_Alternatives;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Extended_Return_Stmt_Range =>
declare
N_Bare_Extended_Return_Stmt : constant Bare_Extended_Return_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Extended_Return_Stmt.Extended_Return_Stmt_F_Decl;
                            return;
                        when 2 =>
                            Result := N_Bare_Extended_Return_Stmt.Extended_Return_Stmt_F_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_If_Stmt_Range =>
declare
N_Bare_If_Stmt : constant Bare_If_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_If_Stmt.If_Stmt_F_Cond_Expr;
                            return;
                        when 2 =>
                            Result := N_Bare_If_Stmt.If_Stmt_F_Then_Stmts;
                            return;
                        when 3 =>
                            Result := N_Bare_If_Stmt.If_Stmt_F_Alternatives;
                            return;
                        when 4 =>
                            Result := N_Bare_If_Stmt.If_Stmt_F_Else_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Named_Stmt_Range =>
declare
N_Bare_Named_Stmt : constant Bare_Named_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Named_Stmt.Named_Stmt_F_Decl;
                            return;
                        when 2 =>
                            Result := N_Bare_Named_Stmt.Named_Stmt_F_Stmt;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Select_Stmt_Range =>
declare
N_Bare_Select_Stmt : constant Bare_Select_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Select_Stmt.Select_Stmt_F_Guards;
                            return;
                        when 2 =>
                            Result := N_Bare_Select_Stmt.Select_Stmt_F_Else_Stmts;
                            return;
                        when 3 =>
                            Result := N_Bare_Select_Stmt.Select_Stmt_F_Abort_Stmts;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Abort_Stmt_Range =>
declare
N_Bare_Abort_Stmt : constant Bare_Abort_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Abort_Stmt.Abort_Stmt_F_Names;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Assign_Stmt_Range =>
declare
N_Bare_Assign_Stmt : constant Bare_Assign_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Assign_Stmt.Assign_Stmt_F_Dest;
                            return;
                        when 2 =>
                            Result := N_Bare_Assign_Stmt.Assign_Stmt_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Call_Stmt_Range =>
declare
N_Bare_Call_Stmt : constant Bare_Call_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Call_Stmt.Call_Stmt_F_Call;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Delay_Stmt_Range =>
declare
N_Bare_Delay_Stmt : constant Bare_Delay_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Delay_Stmt.Delay_Stmt_F_Has_Until;
                            return;
                        when 2 =>
                            Result := N_Bare_Delay_Stmt.Delay_Stmt_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Exit_Stmt_Range =>
declare
N_Bare_Exit_Stmt : constant Bare_Exit_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Exit_Stmt.Exit_Stmt_F_Loop_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Exit_Stmt.Exit_Stmt_F_Cond_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Goto_Stmt_Range =>
declare
N_Bare_Goto_Stmt : constant Bare_Goto_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Goto_Stmt.Goto_Stmt_F_Label_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Label_Range =>
declare
N_Bare_Label : constant Bare_Label := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Label.Label_F_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Raise_Stmt_Range =>
declare
N_Bare_Raise_Stmt : constant Bare_Raise_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Raise_Stmt.Raise_Stmt_F_Exception_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Raise_Stmt.Raise_Stmt_F_Error_Message;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Requeue_Stmt_Range =>
declare
N_Bare_Requeue_Stmt : constant Bare_Requeue_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Requeue_Stmt.Requeue_Stmt_F_Call_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Requeue_Stmt.Requeue_Stmt_F_Has_Abort;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Return_Stmt_Range =>
declare
N_Bare_Return_Stmt : constant Bare_Return_Stmt := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Return_Stmt.Return_Stmt_F_Return_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subunit_Range =>
declare
N_Bare_Subunit : constant Bare_Subunit := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Subunit.Subunit_F_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Subunit.Subunit_F_Body;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Task_Def_Range =>
declare
N_Bare_Task_Def : constant Bare_Task_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Task_Def.Task_Def_F_Interfaces;
                            return;
                        when 2 =>
                            Result := N_Bare_Task_Def.Task_Def_F_Public_Part;
                            return;
                        when 3 =>
                            Result := N_Bare_Task_Def.Task_Def_F_Private_Part;
                            return;
                        when 4 =>
                            Result := N_Bare_Task_Def.Task_Def_F_End_Name;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Access_Def =>
declare
N_Bare_Access_Def : constant Bare_Access_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Access_Def.Access_Def_F_Has_Not_Null;
                            return;
                        when others => null;
                    end case;
case Ada_Access_Def (K) is
when Ada_Access_To_Subp_Def_Range =>
declare
N_Bare_Access_To_Subp_Def : constant Bare_Access_To_Subp_Def := N_Bare_Access_Def;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Access_To_Subp_Def.Access_To_Subp_Def_F_Has_Protected;
                            return;
                        when 3 =>
                            Result := N_Bare_Access_To_Subp_Def.Access_To_Subp_Def_F_Subp_Spec;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Anonymous_Type_Access_Def_Range =>
declare
N_Bare_Anonymous_Type_Access_Def : constant Bare_Anonymous_Type_Access_Def := N_Bare_Access_Def;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Anonymous_Type_Access_Def.Anonymous_Type_Access_Def_F_Type_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Type_Access_Def_Range =>
declare
N_Bare_Type_Access_Def : constant Bare_Type_Access_Def := N_Bare_Access_Def;
begin
case Index is
                        when 2 =>
                            Result := N_Bare_Type_Access_Def.Type_Access_Def_F_Has_All;
                            return;
                        when 3 =>
                            Result := N_Bare_Type_Access_Def.Type_Access_Def_F_Has_Constant;
                            return;
                        when 4 =>
                            Result := N_Bare_Type_Access_Def.Type_Access_Def_F_Subtype_Indication;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
end;
when Ada_Array_Type_Def_Range =>
declare
N_Bare_Array_Type_Def : constant Bare_Array_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Array_Type_Def.Array_Type_Def_F_Indices;
                            return;
                        when 2 =>
                            Result := N_Bare_Array_Type_Def.Array_Type_Def_F_Component_Type;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Derived_Type_Def_Range =>
declare
N_Bare_Derived_Type_Def : constant Bare_Derived_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Has_Abstract;
                            return;
                        when 2 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Has_Limited;
                            return;
                        when 3 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Has_Synchronized;
                            return;
                        when 4 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Subtype_Indication;
                            return;
                        when 5 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Interfaces;
                            return;
                        when 6 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Record_Extension;
                            return;
                        when 7 =>
                            Result := N_Bare_Derived_Type_Def.Derived_Type_Def_F_Has_With_Private;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Enum_Type_Def_Range =>
declare
N_Bare_Enum_Type_Def : constant Bare_Enum_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Enum_Type_Def.Enum_Type_Def_F_Enum_Literals;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Interface_Type_Def_Range =>
declare
N_Bare_Interface_Type_Def : constant Bare_Interface_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Interface_Type_Def.Interface_Type_Def_F_Interface_Kind;
                            return;
                        when 2 =>
                            Result := N_Bare_Interface_Type_Def.Interface_Type_Def_F_Interfaces;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Mod_Int_Type_Def_Range =>
declare
N_Bare_Mod_Int_Type_Def : constant Bare_Mod_Int_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Mod_Int_Type_Def.Mod_Int_Type_Def_F_Expr;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Private_Type_Def_Range =>
declare
N_Bare_Private_Type_Def : constant Bare_Private_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Private_Type_Def.Private_Type_Def_F_Has_Abstract;
                            return;
                        when 2 =>
                            Result := N_Bare_Private_Type_Def.Private_Type_Def_F_Has_Tagged;
                            return;
                        when 3 =>
                            Result := N_Bare_Private_Type_Def.Private_Type_Def_F_Has_Limited;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Decimal_Fixed_Point_Def_Range =>
declare
N_Bare_Decimal_Fixed_Point_Def : constant Bare_Decimal_Fixed_Point_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Decimal_Fixed_Point_Def.Decimal_Fixed_Point_Def_F_Delta;
                            return;
                        when 2 =>
                            Result := N_Bare_Decimal_Fixed_Point_Def.Decimal_Fixed_Point_Def_F_Digits;
                            return;
                        when 3 =>
                            Result := N_Bare_Decimal_Fixed_Point_Def.Decimal_Fixed_Point_Def_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Floating_Point_Def_Range =>
declare
N_Bare_Floating_Point_Def : constant Bare_Floating_Point_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Floating_Point_Def.Floating_Point_Def_F_Num_Digits;
                            return;
                        when 2 =>
                            Result := N_Bare_Floating_Point_Def.Floating_Point_Def_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Ordinary_Fixed_Point_Def_Range =>
declare
N_Bare_Ordinary_Fixed_Point_Def : constant Bare_Ordinary_Fixed_Point_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Ordinary_Fixed_Point_Def.Ordinary_Fixed_Point_Def_F_Delta;
                            return;
                        when 2 =>
                            Result := N_Bare_Ordinary_Fixed_Point_Def.Ordinary_Fixed_Point_Def_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Record_Type_Def_Range =>
declare
N_Bare_Record_Type_Def : constant Bare_Record_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Record_Type_Def.Record_Type_Def_F_Has_Abstract;
                            return;
                        when 2 =>
                            Result := N_Bare_Record_Type_Def.Record_Type_Def_F_Has_Tagged;
                            return;
                        when 3 =>
                            Result := N_Bare_Record_Type_Def.Record_Type_Def_F_Has_Limited;
                            return;
                        when 4 =>
                            Result := N_Bare_Record_Type_Def.Record_Type_Def_F_Record_Def;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Signed_Int_Type_Def_Range =>
declare
N_Bare_Signed_Int_Type_Def : constant Bare_Signed_Int_Type_Def := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Signed_Int_Type_Def.Signed_Int_Type_Def_F_Range;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Anonymous_Type_Range =>
declare
N_Bare_Anonymous_Type : constant Bare_Anonymous_Type := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Anonymous_Type.Anonymous_Type_F_Type_Decl;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Subtype_Indication_Range =>
declare
N_Bare_Subtype_Indication : constant Bare_Subtype_Indication := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Subtype_Indication.Subtype_Indication_F_Has_Not_Null;
                            return;
                        when 2 =>
                            Result := N_Bare_Subtype_Indication.Subtype_Indication_F_Name;
                            return;
                        when 3 =>
                            Result := N_Bare_Subtype_Indication.Subtype_Indication_F_Constraint;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Synthetic_Type_Expr_Range =>
declare
N_Bare_Synthetic_Type_Expr : constant Bare_Synthetic_Type_Expr := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Synthetic_Type_Expr.Synthetic_Type_Expr_F_Target_Type;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Unconstrained_Array_Index_Range =>
declare
N_Bare_Unconstrained_Array_Index : constant Bare_Unconstrained_Array_Index := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Unconstrained_Array_Index.Unconstrained_Array_Index_F_Subtype_Indication;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Use_Package_Clause_Range =>
declare
N_Bare_Use_Package_Clause : constant Bare_Use_Package_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Use_Package_Clause.Use_Package_Clause_F_Packages;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Use_Type_Clause_Range =>
declare
N_Bare_Use_Type_Clause : constant Bare_Use_Type_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Use_Type_Clause.Use_Type_Clause_F_Has_All;
                            return;
                        when 2 =>
                            Result := N_Bare_Use_Type_Clause.Use_Type_Clause_F_Types;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Value_Sequence_Range =>
declare
N_Bare_Value_Sequence : constant Bare_Value_Sequence := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Value_Sequence.Value_Sequence_F_Iter_Assoc;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Variant_Range =>
declare
N_Bare_Variant : constant Bare_Variant := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Variant.Variant_F_Choices;
                            return;
                        when 2 =>
                            Result := N_Bare_Variant.Variant_F_Components;
                            return;
                        when others => null;
                    end case;
end;
when Ada_Variant_Part_Range =>
declare
N_Bare_Variant_Part : constant Bare_Variant_Part := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_Variant_Part.Variant_Part_F_Discr_Name;
                            return;
                        when 2 =>
                            Result := N_Bare_Variant_Part.Variant_Part_F_Variant;
                            return;
                        when others => null;
                    end case;
end;
when Ada_With_Clause_Range =>
declare
N_Bare_With_Clause : constant Bare_With_Clause := Node;
begin
case Index is
                        when 1 =>
                            Result := N_Bare_With_Clause.With_Clause_F_Has_Limited;
                            return;
                        when 2 =>
                            Result := N_Bare_With_Clause.With_Clause_F_Has_Private;
                            return;
                        when 3 =>
                            Result := N_Bare_With_Clause.With_Clause_F_Packages;
                            return;
                        when others => null;
                    end case;
end;
when others => null;
end case;
      --  Execution should reach this point iff nothing matched this index, so
      --  we must be out of bounds.
      Index_In_Bounds := False;
   end Get_Child;
   -----------
   -- Print --
   -----------
   procedure Print
     (Node        : Bare_Ada_Node;
      Show_Slocs  : Boolean;
      Line_Prefix : String := "")
   is
      K : Ada_Node_Kind_Type;
   begin
      if Node = null then
         Put_Line ("None");
         return;
      end if;
      K := Node.Kind;
      Put (Line_Prefix & Kind_Name (Node));
      if Show_Slocs then
         Put ("[" & Image (Sloc_Range (Node)) & "]");
      end if;
      if Is_Incomplete (Node) then
         Put (" <<INCOMPLETE>>");
      end if;
      if Is_Token_Node (Node.Kind) then
         Put_Line (": " & Image (Text (Node)));
      elsif Node.Kind not in Ada_Ada_List then
         New_Line;
      end if;
         --  List nodes are displayed in a special way (they have no field)
         if K in Ada_Ada_List then
            if Node.Count = 0 then
               Put_Line (": <empty list>");
               return;
            end if;
            New_Line;
            for Child of Node.Nodes (1 .. Node.Count) loop
               if Child /= null then
                  Print (Child, Show_Slocs, Line_Prefix & "|  ");
               end if;
            end loop;
            return;
         end if;
         --  This is for regular nodes: display each field
         declare
            use Libadalang.Introspection_Implementation;
            Attr_Prefix     : constant String := Line_Prefix & "|";
            Children_Prefix : constant String := Line_Prefix & "|  ";
            Field_List      : constant Syntax_Field_Reference_Array :=
              Syntax_Fields (K);
         begin
            for I in Field_List'Range loop
               declare
                  Child : constant Bare_Ada_Node :=
                     Implementation.Child (Node, I);
               begin
                  Put
                    (Attr_Prefix
                     & Image (Syntax_Field_Name (Field_List (I)))
                     & ":");
                  if Child /= null then
                     New_Line;
                     Print (Child, Show_Slocs, Children_Prefix);
                  else
                     Put_Line (" <null>");
                  end if;
               end;
            end loop;
         end;
   end Print;
   ------------
   -- Parent --
   ------------
   function Parent (Node : Bare_Ada_Node) return Bare_Ada_Node is
   begin
      return Node.Parent;
   end Parent;
   ------------------
   -- Stored_Token --
   ------------------
   function Stored_Token
     (Node  : Bare_Ada_Node;
      Token : Token_Reference) return Token_Index
   is
      Index : constant Token_Or_Trivia_Index := Get_Token_Index (Token);
   begin
      if Node.Unit.TDH'Access /= Get_Token_TDH (Token) then
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "Cannot associate a token and a node from different analysis"
            & " units");
      elsif Index.Trivia /= No_Token_Index then
         Raise_Property_Exception
           (Node,
            Property_Error'Identity,
            "A node cannot hold trivia");
      end if;
      return Index.Token;
   end Stored_Token;
   -------------------------
   -- Children_And_Trivia --
   -------------------------
   function Children_And_Trivia
     (Node : Bare_Ada_Node) return Bare_Children_Array
   is
      package Children_Vectors is new Ada.Containers.Vectors
        (Positive, Bare_Child_Record);
      use Children_Vectors;
      Ret_Vec : Vector;
      Ctx     : Internal_Context renames Node.Unit.Context;
      TDH     : Token_Data_Handler renames Node.Unit.TDH;
      procedure Append_Trivias (First, Last : Token_Index);
      --  Append all the trivias of tokens between indices First and Last to
      --  the returned vector.
      function Filter_Children
        (Parent : Bare_Ada_Node)
         return Internal_Bare_Ada_Node_Array;
      --  Return an array for all children in Parent that are not null
      --------------------
      -- Append_Trivias --
      --------------------
      procedure Append_Trivias (First, Last : Token_Index) is
      begin
         for I in First .. Last loop
            for D of Get_Trivias (TDH, I) loop
               Ret_Vec.Append
                 (Bare_Child_Record'
                    (Kind   => Trivia,
                     Trivia => Wrap_Token_Reference
                                 (Ctx, TDH'Access, (I, D))));
            end loop;
         end loop;
      end Append_Trivias;
      ---------------------
      -- Filter_Children --
      ---------------------
      function Filter_Children
        (Parent : Bare_Ada_Node)
         return Internal_Bare_Ada_Node_Array
      is
         Children : constant Internal_Bare_Ada_Node_Array :=
            Implementation.Children (Parent);
         Result   : Internal_Bare_Ada_Node_Array (Children'Range);
         Next     : Integer := Result'First;
      begin
         for I in Children'Range loop
            if Children (I) /= null then
               Result (Next) := Children (I);
               Next := Next + 1;
            end if;
         end loop;
         return Result (Result'First .. Next - 1);
      end Filter_Children;
      First_Child : constant Positive := 1;
      N_Children  : constant Internal_Bare_Ada_Node_Array :=
         Filter_Children (Node);
   begin
      if N_Children'Length > 0
        and then (Node.Token_Start_Index
                    /= N_Children (First_Child).Token_Start_Index)
      then
         Append_Trivias (Node.Token_Start_Index,
                         N_Children (First_Child).Token_Start_Index - 1);
      end if;
      --  Append each node to Ret_Vec, and append trivia that follow after each
      --  non-ghost nodes.
      for I in N_Children'Range loop
         Ret_Vec.Append (Bare_Child_Record'(Child, N_Children (I)));
         if not Is_Ghost (N_Children (I)) then
            Append_Trivias (N_Children (I).Token_End_Index,
                            (if I = N_Children'Last
                             then Node.Token_End_Index - 1
                             else N_Children (I + 1).Token_Start_Index - 1));
         end if;
      end loop;
      declare
         A : Bare_Children_Array (1 .. Natural (Ret_Vec.Length));
      begin
         for I in A'Range loop
            A (I) := Ret_Vec.Element (I);
         end loop;
         return A;
      end;
   end Children_And_Trivia;
   --------------
   -- Is_Ghost --
   --------------
   function Is_Ghost (Node : Bare_Ada_Node) return Boolean
   is (Node.Token_End_Index = No_Token_Index);
   -------------------
   -- Is_Incomplete --
   -------------------
   function Is_Incomplete (Node : Bare_Ada_Node) return Boolean
   is
      LGC : Bare_Ada_Node;
   begin
     if Is_List_Node (Node.Kind) then
        LGC := (if Last_Child_Index (Node) /= 0
                then Child (Node, Last_Child_Index (Node))
                else null);
        return LGC /= null and then Is_Incomplete (LGC);
      else
         return Node.Last_Attempted_Child > -1;
      end if;
   end;
   -----------------
   -- Token_Start --
   -----------------
   function Token_Start (Node : Bare_Ada_Node) return Token_Reference
   is (Token (Node, Node.Token_Start_Index));
   ---------------
   -- Token_End --
   ---------------
   function Token_End (Node : Bare_Ada_Node) return Token_Reference
   is
     (if Node.Token_End_Index = No_Token_Index
      then Token_Start (Node)
      else Token (Node, Node.Token_End_Index));
   -----------
   -- Token --
   -----------
   function Token
     (Node  : Bare_Ada_Node;
      Index : Token_Index) return Token_Reference
   is
      Unit    : constant Internal_Unit := Node.Unit;
      Context : constant Internal_Context := Unit.Context;
   begin
      return Wrap_Token_Reference
        (Context, Token_Data (Unit), (Index, No_Token_Index));
   end Token;
   ---------
   -- "<" --
   ---------
   function "<" (Left, Right : Bare_Ada_Node) return Boolean is
   begin
      --  Reject invalid inputs
      if Left /= null and Is_Synthetic (Left) then
         raise Property_Error with "left node is synthetic";
      elsif Right /= null and Is_Synthetic (Right) then
         raise Property_Error with "right node is synthetic";
      end if;
      --  Null nodes come first
      if Left = null then
         return Right /= null;
      elsif Right = null then
         return False;
      end if;
      --  So we have two non-null nodes. Sort by unit filename
      if Left.Unit < Right.Unit then
         return True;
      elsif Left.Unit /= Right.Unit then
         return False;
      end if;
      --  Both nodes come from the same unit: compare their token indexes
      if Left.Token_Start_Index < Right.Token_Start_Index then
         return True;
      elsif Left.Token_Start_Index > Right.Token_Start_Index then
         return False;
      else
         return Left.Token_End_Index < Right.Token_End_Index;
      end if;
   end "<";
   -------------
   -- Is_Null --
   -------------
   function Is_Null (Node : Bare_Ada_Node) return Boolean
   is (Node = null);
   ----------
   -- Kind --
   ----------
   function Kind (Node : Bare_Ada_Node) return Ada_Node_Kind_Type
   is (Node.Kind);
   -----------------
   -- Child_Index --
   -----------------
   function Child_Index (Node : Bare_Ada_Node) return Integer
   is
      N : Bare_Ada_Node := null;
   begin
      if Node.Parent = null then
         raise Property_Error with
            "Trying to get the child index of a root node";
      end if;
      for I in First_Child_Index (Node.Parent)
            .. Last_Child_Index (Node.Parent)
      loop
         N := Child (Node.Parent, I);
         if N = Node then
            return I - 1;
         end if;
      end loop;
      --  If we reach this point, then Node isn't a Child of Node.Parent. This
      --  is not supposed to happen.
      raise Program_Error;
   end Child_Index;
   -------------------
   -- Fetch_Sibling --
   -------------------
   function Fetch_Sibling
     (Node   : Bare_Ada_Node;
      Offset : Integer) return Bare_Ada_Node is
   begin
      --  Root nodes have no sibling: handle them now to avoid invalid requests
      --  in the code below.
      if Node.Parent = null then
         return null;
      end if;
      declare
         Node_Index : constant Positive := Child_Index (Node) + 1;
         --  Child_Index is 0-based, but the Child primitive expects a 1-based
         --  index.
         Sibling_Index : constant Integer := Node_Index + Offset;
      begin
         --  Child returns null for out-of-bound indexes
         return (if Sibling_Index >= 1
                 then Child (Node.Parent, Sibling_Index)
                 else null);
      end;
   end Fetch_Sibling;
   -------------------
   -- Fetch_Sibling --
   -------------------
   function Fetch_Sibling
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info;
      Offset : Integer) return Internal_Entity
   is
      Sibling : constant Bare_Ada_Node := Fetch_Sibling (Node, Offset);
   begin
      --  Don't forget to clear entity info if the result is nul
      return (if Sibling = null
              then No_Entity
              else (Sibling, E_Info));
   end Fetch_Sibling;
   ----------------------
   -- Previous_Sibling --
   ----------------------
   function Previous_Sibling
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info := No_Entity_Info)
      return Internal_Entity is
   begin
      return Fetch_Sibling (Node, E_Info, -1);
   end Previous_Sibling;
   ------------------
   -- Next_Sibling --
   ------------------
   function Next_Sibling
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info := No_Entity_Info)
      return Internal_Entity is
   begin
      return Fetch_Sibling (Node, E_Info, 1);
   end Next_Sibling;
   -------------
   -- Combine --
   -------------
   function Combine
     (L, R : Internal_Metadata) return Internal_Metadata
   is
      Ret : Internal_Metadata := No_Metadata;
   begin
         Ret.Dottable_Subp := L.Dottable_Subp or R.Dottable_Subp;
         if L.Primitive = No_Bare_Ada_Node then
            Ret.Primitive := R.Primitive;
         elsif R.Primitive = No_Bare_Ada_Node then
            Ret.Primitive := L.Primitive;
         else
            raise Property_Error with "Wrong combine for metadata field";
         end if;
         if L.Primitive_Real_Type = No_Bare_Ada_Node then
            Ret.Primitive_Real_Type := R.Primitive_Real_Type;
         elsif R.Primitive_Real_Type = No_Bare_Ada_Node then
            Ret.Primitive_Real_Type := L.Primitive_Real_Type;
         else
            raise Property_Error with "Wrong combine for metadata field";
         end if;
      return Ret;
   end Combine;
   -------------------------------
   -- Create_Static_Lexical_Env --
   -------------------------------
   function Create_Static_Lexical_Env
     (Parent            : Lexical_Env;
      Node              : Bare_Ada_Node;
      Transitive_Parent : Boolean := False) return Lexical_Env
   is
      Unit : constant Internal_Unit :=
        (if Node = null then null else Node.Unit);
   begin
      return Result : Lexical_Env := Create_Lexical_Env
        (Parent, Node, Transitive_Parent, Convert_Unit (Unit))
      do
         if Unit /= null then
            Register_Destroyable (Unit, Unwrap (Result.Env));
         end if;
      end return;
   end Create_Static_Lexical_Env;
   ---------
   -- Get --
   ---------
   function Get
     (Self  : Bare_Ada_Node;
      A     : AST_Envs.Entity_Array;
      Index : Integer) return Internal_Entity
   is
      function Length (A : AST_Envs.Entity_Array) return Natural
      is (A'Length);
      function Get
        (A     : AST_Envs.Entity_Array;
         Index : Integer) return Internal_Entity
      is (A (Index + 1)); --  A is 1-based but Index is 0-based
      function Relative_Get is new Langkit_Support.Relative_Get
        (Item_Type     => Entity,
         Sequence_Type => AST_Envs.Entity_Array,
         Length        => Length,
         Get           => Get);
      Result : Internal_Entity;
   begin
      if Relative_Get (A, Index, Result) then
         return Result;
      else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "out-of-bounds array access");
      end if;
   end Get;
   -----------
   -- Group --
   -----------
   function Group
     (Envs   : Lexical_Env_Array_Access;
      Env_Md : Internal_Metadata := No_Metadata) return Lexical_Env
   is (Group (Lexical_Env_Array (Envs.Items), Env_Md));
      --
      --  Untyped wrappers for Bare_Ada_Node
      --
function Ada_Node_P_Resolve_Generic_Actual
  (E : Entity
  ) return Internal_Entity;
function Ada_Node_P_Use_Clauses_In_Spec_Of_Subp_Body
  (E : Entity
  ) return Lexical_Env;
function Ada_Node_P_Use_Clauses_In_Generic_Formal_Part
  (E : Entity
  ) return Lexical_Env;
function Ada_Node_P_Nested_Generic_Formal_Part
  (E : Entity
  ) return Lexical_Env;
      --
      --  Untyped wrappers for Bare_Base_Type_Decl
      --
function Base_Type_Decl_P_Dottable_Subps
  (E : Entity
  ) return Internal_Inner_Env_Assoc_Array_Access;
      --
      --  Untyped wrappers for Bare_Type_Decl
      --
function Type_Decl_F_Direct_Primitive_Subps
  (E : Entity
  ) return Internal_Inner_Env_Assoc_Array_Access;
function Type_Decl_P_Refined_Parent_Primitives_Env
  (E : Entity
  ) return Lexical_Env;
      --
      --  Untyped wrappers for Bare_Body_Node
      --
function Body_Node_P_Subunit_Decl_Env
  (E : Entity
  ) return Lexical_Env;
function Body_Node_P_Body_Decl_Scope
  (E : Entity
  ) return Lexical_Env;
      --
      --  Untyped wrappers for Bare_Package_Body
      --
function Package_Body_P_Package_Decl_Uses_Clauses_Envs
  (E : Entity
  ) return Lexical_Env;
      --
      --  Untyped wrappers for Bare_Task_Body
      --
function Task_Body_P_Task_Type_Decl_Scope
  (E : Entity
  ) return Lexical_Env;
      --
      --  Untyped wrappers for Bare_Generic_Instantiation
      --
function Generic_Instantiation_P_Instantiation_Bindings
  (E : Entity
  ) return Internal_Inner_Env_Assoc_Array_Access;
      --
      --  Untyped wrappers for Bare_Name
      --
function Name_P_Name_Designated_Type_Env
  (E : Entity
  ) return Lexical_Env;
function Name_P_Use_Package_Name_Designated_Env
  (E : Entity
  ) return Lexical_Env;
   ------------------
   -- Children_Env --
   ------------------
   function Children_Env
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info := No_Entity_Info)
      return Lexical_Env
   is (Rebind_Env (Node.Self_Env, E_Info));
   --------------
   -- Node_Env --
   --------------
   function Node_Env
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info := No_Entity_Info)
      return Lexical_Env
   is
      function Get_Base_Env return Lexical_Env;
      --  Return the environment that we need to rebind before returning
      ------------------
      -- Get_Base_Env --
      ------------------
      function Get_Base_Env return Lexical_Env is
         pragma Warnings (Off, "referenced");
         function Get_Parent_Env return Lexical_Env;
         pragma Warnings (On, "referenced");
         --------------------
         -- Get_Parent_Env --
         --------------------
         function Get_Parent_Env return Lexical_Env is
            Parent : constant Lexical_Env := AST_Envs.Parent (Node.Self_Env);
         begin
            --  If Node is the root scope or the empty environment, Parent can
            --  be a wrapper around the null node. Turn this into the
            --  Empty_Env, as null envs are erroneous values in properties.
            return (if Unwrap (Parent) = null
                    then Empty_Env
                    else Parent);
         end Get_Parent_Env;
      begin
         return
           (if Node.Kind in Ada_Generic_Package_Internal | Ada_Package_Decl | Ada_Incomplete_Type_Decl | Ada_Incomplete_Formal_Type_Decl | Ada_Incomplete_Tagged_Type_Decl | Ada_Protected_Type_Decl | Ada_Task_Type_Decl | Ada_Single_Task_Type_Decl | Ada_Concrete_Type_Decl | Ada_Formal_Type_Decl | Ada_Abstract_Subp_Decl | Ada_Abstract_Formal_Subp_Decl | Ada_Concrete_Formal_Subp_Decl | Ada_Subp_Decl | Ada_Entry_Decl | Ada_Enum_Literal_Decl | Ada_Synthetic_Char_Enum_Lit | Ada_Generic_Subp_Internal | Ada_Synthetic_Subp_Decl | Ada_Expr_Function | Ada_Null_Subp_Decl | Ada_Subp_Body | Ada_Subp_Renaming_Decl | Ada_Package_Body_Stub | Ada_Protected_Body_Stub | Ada_Subp_Body_Stub | Ada_Task_Body_Stub | Ada_Entry_Body | Ada_Package_Body | Ada_Protected_Body | Ada_Task_Body | Ada_Exception_Handler | Ada_Generic_Package_Decl | Ada_Generic_Subp_Decl | Ada_Generic_Package_Instantiation | Ada_Generic_Subp_Instantiation | Ada_Generic_Package_Renaming_Decl | Ada_Generic_Subp_Renaming_Decl | Ada_Package_Renaming_Decl | Ada_Single_Protected_Decl | Ada_Single_Task_Decl | Ada_Private_Part | Ada_Decl_Expr | Ada_Accept_Stmt | Ada_Accept_Stmt_With_Stmts | Ada_For_Loop_Stmt | Ada_Begin_Block | Ada_Decl_Block | Ada_Extended_Return_Stmt | Ada_Named_Stmt | Ada_Access_To_Subp_Def
            then Get_Parent_Env
            else Node.Self_Env);
      end Get_Base_Env;
      Base_Env : Lexical_Env := Get_Base_Env;
      Result   : constant Lexical_Env := Rebind_Env (Base_Env, E_Info);
   begin
      Dec_Ref (Base_Env);
      return Result;
   end Node_Env;
   ------------
   -- Parent --
   ------------
   function Parent
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info := No_Entity_Info)
      return Internal_Entity is
   begin
      --  TODO: shed entity information as appropriate
      return (Node.Parent, E_Info);
   end Parent;
   -------------
   -- Parents --
   -------------
   function Parents
     (Node      : Bare_Ada_Node;
      With_Self : Boolean := True;
      E_Info    : Internal_Entity_Info := No_Entity_Info)
      return Internal_Entity_Array_Access
   is
      Bare_Parents : Bare_Ada_Node_Array_Access := Parents (Node, With_Self);
      Result       : Internal_Entity_Array_Access :=
         Create_Internal_Entity_Array (Bare_Parents.N);
   begin
      --  TODO: shed entity information as appropriate
      for I in Bare_Parents.Items'Range loop
         Result.Items (I) := (Bare_Parents.Items (I), E_Info);
      end loop;
      Dec_Ref (Bare_Parents);
      return Result;
   end Parents;
   --------------
   -- Children --
   --------------
   function Children
     (Node   : Bare_Ada_Node;
      E_Info : Internal_Entity_Info := No_Entity_Info)
      return Internal_Entity_Array_Access
   is
      Bare_Children : Bare_Ada_Node_Array_Access := Children (Node);
      Result        : Internal_Entity_Array_Access :=
         Create_Internal_Entity_Array (Bare_Children.N);
   begin
      --  TODO: shed entity information as appropriate
      for I in Bare_Children.Items'Range loop
         Result.Items (I) := (Bare_Children.Items (I), E_Info);
      end loop;
      Dec_Ref (Bare_Children);
      return Result;
   end Children;
   ---------------------
   -- New_Unit_String --
   ---------------------
   function New_Unit_String
     (Unit : Internal_Unit; Str : String) return String_Access
   is
      procedure Register_Destroyable_String is new Register_Destroyable_Gen
        (String, String_Access, Free);
   begin
      return Ret : String_Access := new String'(Str) do
         Register_Destroyable_String (Unit, Ret);
      end return;
   end New_Unit_String;
   --------------------------------
   -- Assign_Names_To_Logic_Vars --
   --------------------------------
   procedure Assign_Names_To_Logic_Vars (Node : Bare_Ada_Node) is
      pragma Warnings (Off, "referenced");
      procedure Assign
        (Node  : Bare_Ada_Node;
         LV    : in out Logic_Var_Record;
         Field : String);
      --  Assign a name to the LV logic variable. Node must be the node that
      --  owns LV, and Field must be the name of the field in Node that holds
      --  LV.
      ------------
      -- Assign --
      ------------
      procedure Assign
        (Node  : Bare_Ada_Node;
         LV    : in out Logic_Var_Record;
         Field : String) is
      begin
         LV.Dbg_Name :=
           new String'(Image (Short_Text_Image (Node)) & "." & Field);
      end Assign;
      K : constant Ada_Node_Kind_Type := Node.Kind;
      pragma Warnings (On, "referenced");
   begin
      case Ada_Ada_Node (K) is
when Ada_Attribute_Ref_Range =>
declare
N_Bare_Attribute_Ref : constant Bare_Attribute_Ref := Node;
begin
Assign (N_Bare_Attribute_Ref,        N_Bare_Attribute_Ref.Attribute_Ref_R_Ref_Var,        "r_ref_var");
end;
when Ada_Call_Expr_Range =>
declare
N_Bare_Call_Expr : constant Bare_Call_Expr := Node;
begin
Assign (N_Bare_Call_Expr,        N_Bare_Call_Expr.Call_Expr_R_Called_Spec,        "r_called_spec");
end;
when Ada_Explicit_Deref_Range =>
declare
N_Bare_Explicit_Deref : constant Bare_Explicit_Deref := Node;
begin
Assign (N_Bare_Explicit_Deref,        N_Bare_Explicit_Deref.Explicit_Deref_R_Called_Spec,        "r_called_spec");
end;
when Ada_Reduce_Attribute_Ref_Range =>
declare
N_Bare_Reduce_Attribute_Ref : constant Bare_Reduce_Attribute_Ref := Node;
begin
Assign (N_Bare_Reduce_Attribute_Ref,        N_Bare_Reduce_Attribute_Ref.Reduce_Attribute_Ref_R_Ref_Var,        "r_ref_var");
end;
when Ada_Target_Name_Range =>
declare
N_Bare_Target_Name : constant Bare_Target_Name := Node;
begin
Assign (N_Bare_Target_Name,        N_Bare_Target_Name.Target_Name_R_Ref_Var,        "r_ref_var");
end;
when Ada_Update_Attribute_Ref_Range =>
declare
N_Bare_Update_Attribute_Ref : constant Bare_Update_Attribute_Ref := Node;
begin
Assign (N_Bare_Update_Attribute_Ref,        N_Bare_Update_Attribute_Ref.Update_Attribute_Ref_R_Ref_Var,        "r_ref_var");
end;
when others => null;
end case;
      for Child of Internal_Bare_Ada_Node_Array'(Children (Node)) loop
         if Child /= null then
            Assign_Names_To_Logic_Vars (Child);
         end if;
      end loop;
   end Assign_Names_To_Logic_Vars;
   ----------------
   -- Text_Image --
   ----------------
   function Text_Image (Ent : Internal_Entity) return Text_Type is
   begin
      if Ent.Node /= null then
         declare
            Node_Image : constant Text_Type := Short_Text_Image (Ent.Node);
         begin
            return
            (if Ent.Info.Rebindings /= null
             then "<| "
             & Node_Image (Node_Image'First + 1 .. Node_Image'Last - 1) & " "
             & AST_Envs.Text_Image (Ent.Info.Rebindings) & " |>"
             else Node_Image);
         end;
      else
         return "None";
      end if;
   end Text_Image;
   ---------------------
   -- Full_Sloc_Image --
   ---------------------
   function Full_Sloc_Image (Node : Bare_Ada_Node) return String_Type
   is
      Res      : constant Text_Type :=
        To_Text
          (Ada.Directories.Simple_Name
             (Get_Filename (Unit (Node))))
           & ":" & To_Text (Image (Start_Sloc (Sloc_Range (Node)))) & ": ";
   begin
      return Create_String (Res);
   end Full_Sloc_Image;
   -----------
   -- Image --
   -----------
   function Image (Ent : Internal_Entity) return String is
      Result : constant Text_Type := Text_Image (Ent);
   begin
      return Image (Result);
   end Image;
   ---------------
   -- Can_Reach --
   ---------------
   function Can_Reach (El, From : Bare_Ada_Node) return Boolean is
   begin
      --  Since this function is only used to implement sequential semantics in
      --  envs, we consider that elements coming from different units are
      --  always visible for each other, and let the user implement language
      --  specific visibility rules in the DSL.
      if El = null or else From = null or else El.Unit /= From.Unit then
         return True;
      end if;
      return El.Token_Start_Index < From.Token_Start_Index;
   end Can_Reach;
   -----------------
   -- Hash_Entity --
   -----------------
   function Hash_Entity (Self : Internal_Entity) return Hash_Type is
   begin
      return Combine (Hash (Self.Node), Hash (Self.Info.Rebindings));
   end Hash_Entity;
   --------------------
   -- Compare_Entity --
   --------------------
   function Compare_Entity (Left, Right : Internal_Entity) return Boolean
   is
   begin
      return (Left.Node = Right.Node
              and then Left.Info.Rebindings = Right.Info.Rebindings);
   end Compare_Entity;
   --------------------------------
   -- Create_Dynamic_Lexical_Env --
   --------------------------------
   function Create_Dynamic_Lexical_Env
     (Self              : Bare_Ada_Node;
      Assocs_Getter     : Inner_Env_Assocs_Resolver;
      Assoc_Resolver    : Entity_Resolver;
      Transitive_Parent : Boolean) return Lexical_Env
   is
      Unit : constant Internal_Unit := Self.Unit;
   begin
      --  This restriction is necessary to avoid relocation issues when
      --  Self.Self_Env is terminated.
      if Is_Foreign_Strict (Self.Self_Env, Self) then
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            "cannot create a dynamic lexical env when Self.Self_Env is"
            & " foreign");
      end if;
      return Result : constant Lexical_Env := Create_Dynamic_Lexical_Env
        (Parent            => Null_Lexical_Env,
         Node              => Self,
         Transitive_Parent => Transitive_Parent,
         Owner             => Convert_Unit (Unit),
         Assocs_Getter     => Assocs_Getter,
         Assoc_Resolver    => Assoc_Resolver)
      do
         --  Since dynamic lexical environments can only be created in lazy
         --  field initializers, it is fine to tie Result's lifetime to the
         --  its owning unit's lifetime.
         Register_Destroyable (Unit, Unwrap (Result));
      end return;
   end Create_Dynamic_Lexical_Env;
   procedure Destroy_Synthetic_Node (Node : in out Bare_Ada_Node);
   --  Helper for the Register_Destroyable above
   ------------
   -- Length --
   ------------
   function Length (Node : Bare_Ada_List) return Natural
   is (if Node = null then 0 else Children_Count (Node));
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (B : Boolean) return String is
      begin
         return (if B then "True" else "False");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (I : Integer) return String is
      begin
         return Integer'Image (I);
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (S : Symbol_Type) return String is
      begin
         return (if S = null
                 then "None"
                 else Image (S.all, With_Quotes => True));
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (C : Character_Type) return String is
         C_Str : constant Text_Type := (1 => C);
      begin
         return "'" & Image (C_Str) & "'";
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (S : String_Type) return String is
      begin
         return Image (S.Content, With_Quotes => True);
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (Env : Lexical_Env) return String is
      begin
         case Env.Kind is
         when Static_Primary =>
            return "<LexicalEnv static-primary for "
                   & Trace_Image (Env_Node (Env)) & ">";
         when others =>
            return "<LexicalEnv synthetic>";
         end case;
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (R : Env_Rebindings) return String is
      begin
         return Image (Text_Image (R));
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (Unit : Internal_Unit) return String is
      begin
         return "Internal_Unit (""" & Basename (Unit) & """)";
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (Eq : Logic_Equation) return String is
         pragma Unreferenced (Eq);
      begin
         return "<LogicEquation>";
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (Var : Logic_Var) return String is
         pragma Unreferenced (Var);
      begin
         return "<LogicVariable>";
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (K : Analysis_Unit_Kind) return String is
      begin
         return Analysis_Unit_Kind'Image (K);
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image (Self : Ref_Categories) return String is
         Result : Unbounded_String;
         First  : Boolean := True;
      begin
         Append (Result, "RefCategories(");
         for C in Ref_Category loop
            if Self (C) then
               if First then
                  First := False;
               else
                  Append (Result, ", ");
               end if;
               Append (Result, C'Image);
            end if;
         end loop;
         Append (Result, ")");
         return To_String (Result);
      end Trace_Image;
      ----------
      -- Hash --
      ----------
      pragma Warnings (Off, "referenced");
      function Hash (R : Internal_Metadata) return Hash_Type is
         pragma Warnings (On, "referenced");
      begin
            return Combine ((Hash (R.Dottable_Subp), Hash (R.Primitive), Hash (R.Primitive_Real_Type)));
      end Hash;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Metadata) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Dottable_Subp => " & Trace_Image (R.Dottable_Subp)
                        & ", "
                     & "Primitive => " & Trace_Image (R.Primitive)
                        & ", "
                     & "Primitive_Real_Type => " & Trace_Image (R.Primitive_Real_Type)
               & ")");
      end Trace_Image;
      ----------
      -- Hash --
      ----------
      pragma Warnings (Off, "referenced");
      function Hash (R : Internal_Entity_Info) return Hash_Type is
         pragma Warnings (On, "referenced");
      begin
            return Combine ((Hash (R.Md), Hash (R.Rebindings), Hash (R.From_Rebound)));
      end Hash;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Info) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Md => " & Trace_Image (R.Md)
                        & ", "
                     & "Rebindings => " & Trace_Image (R.Rebindings)
                        & ", "
                     & "From_Rebound => " & Trace_Image (R.From_Rebound)
               & ")");
      end Trace_Image;
      function Create_Internal_Entity
        (Node : Bare_Ada_Node; Info : Internal_Entity_Info)
         return Internal_Entity is
      begin
         if Node = null then
            return No_Entity;
         end if;
         return (Node => Node, Info => Info);
      end;
      ----------
      -- Hash --
      ----------
      pragma Warnings (Off, "referenced");
      function Hash (R : Internal_Entity) return Hash_Type is
         pragma Warnings (On, "referenced");
      begin
            return Combine
              (Hash (R.Node), Hash (R.Info));
      end Hash;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Expr
        (Node : Bare_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Expr is
      begin
         if Node = null then
            return No_Entity_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Aspect) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Exists => " & Trace_Image (R.Exists)
                        & ", "
                     & "Node => " & Trace_Image (R.Node)
                        & ", "
                     & "Value => " & Trace_Image (R.Value)
               & ")");
      end Trace_Image;
      function Create_Internal_Entity_Basic_Decl
        (Node : Bare_Basic_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Basic_Decl is
      begin
         if Node = null then
            return No_Entity_Basic_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      ----------
      -- Hash --
      ----------
      pragma Warnings (Off, "referenced");
      function Hash (R : Internal_Entity_Basic_Decl) return Hash_Type is
         pragma Warnings (On, "referenced");
      begin
            return Combine
              (Hash (R.Node), Hash (R.Info));
      end Hash;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Basic_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Completion_Item) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Decl => " & Trace_Image (R.Decl)
                        & ", "
                     & "Is_Dot_Call => " & Trace_Image (R.Is_Dot_Call)
                        & ", "
                     & "Is_Visible => " & Trace_Image (R.Is_Visible)
                        & ", "
                     & "Weight => " & Trace_Image (R.Weight)
               & ")");
      end Trace_Image;
      -------------
      -- Inc_Ref --
      -------------
      procedure Inc_Ref (R : Internal_Designated_Env) is
      begin
               Inc_Ref (R.Direct_Env);
      end Inc_Ref;
      -------------
      -- Dec_Ref --
      -------------
      procedure Dec_Ref (R : in out Internal_Designated_Env) is
      begin
               Dec_Ref (R.Direct_Env);
      end Dec_Ref;
      ----------------
      -- Equivalent --
      ----------------
      function Equivalent (L, R : Internal_Designated_Env) return Boolean is
      begin
         return L.Kind = R.Kind and then L.Env_Name = R.Env_Name and then Equivalent (L.Direct_Env, R.Direct_Env);
      end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Designated_Env) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Kind => " & Trace_Image (R.Kind)
                        & ", "
                     & "Env_Name => " & Trace_Image (R.Env_Name)
                        & ", "
                     & "Direct_Env => " & Trace_Image (R.Direct_Env)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Discrete_Range) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Low_Bound => " & Trace_Image (R.Low_Bound)
                        & ", "
                     & "High_Bound => " & Trace_Image (R.High_Bound)
               & ")");
      end Trace_Image;
      function Create_Internal_Entity_Ada_List
        (Node : Bare_Ada_List; Info : Internal_Entity_Info)
         return Internal_Entity_Ada_List is
      begin
         if Node = null then
            return No_Entity_Ada_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Ada_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Ada_Node_List
        (Node : Bare_Ada_Node_List; Info : Internal_Entity_Info)
         return Internal_Entity_Ada_Node_List is
      begin
         if Node = null then
            return No_Entity_Ada_Node_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Ada_Node_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Alternatives_List
        (Node : Bare_Alternatives_List; Info : Internal_Entity_Info)
         return Internal_Entity_Alternatives_List is
      begin
         if Node = null then
            return No_Entity_Alternatives_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Alternatives_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Name
        (Node : Bare_Name; Info : Internal_Entity_Info)
         return Internal_Entity_Name is
      begin
         if Node = null then
            return No_Entity_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Single_Tok_Node
        (Node : Bare_Single_Tok_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Single_Tok_Node is
      begin
         if Node = null then
            return No_Entity_Single_Tok_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Single_Tok_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Id
        (Node : Bare_Base_Id; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Id is
      begin
         if Node = null then
            return No_Entity_Base_Id;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Id) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Identifier
        (Node : Bare_Identifier; Info : Internal_Entity_Info)
         return Internal_Entity_Identifier is
      begin
         if Node = null then
            return No_Entity_Identifier;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Identifier) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Discriminant_Values) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Discriminant => " & Trace_Image (R.Discriminant)
                        & ", "
                     & "Values => " & Trace_Image (R.Values)
               & ")");
      end Trace_Image;
      -------------
      -- Inc_Ref --
      -------------
      procedure Inc_Ref (R : Internal_Doc_Annotation) is
      begin
               Inc_Ref (R.Key);
               Inc_Ref (R.Value);
      end Inc_Ref;
      -------------
      -- Dec_Ref --
      -------------
      procedure Dec_Ref (R : in out Internal_Doc_Annotation) is
      begin
               Dec_Ref (R.Key);
               Dec_Ref (R.Value);
      end Dec_Ref;
      ----------------
      -- Equivalent --
      ----------------
      function Equivalent (L, R : Internal_Doc_Annotation) return Boolean is
      begin
         return Equivalent (L.Key, R.Key) and then Equivalent (L.Value, R.Value);
      end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Doc_Annotation) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Key => " & Trace_Image (R.Key)
                        & ", "
                     & "Value => " & Trace_Image (R.Value)
               & ")");
      end Trace_Image;
      function Create_Internal_Entity_Abort_Node
        (Node : Bare_Abort_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Abort_Node is
      begin
         if Node = null then
            return No_Entity_Abort_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abort_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abort_Absent
        (Node : Bare_Abort_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Abort_Absent is
      begin
         if Node = null then
            return No_Entity_Abort_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abort_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abort_Present
        (Node : Bare_Abort_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Abort_Present is
      begin
         if Node = null then
            return No_Entity_Abort_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abort_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Stmt
        (Node : Bare_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Stmt is
      begin
         if Node = null then
            return No_Entity_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Simple_Stmt
        (Node : Bare_Simple_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Simple_Stmt is
      begin
         if Node = null then
            return No_Entity_Simple_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Simple_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abort_Stmt
        (Node : Bare_Abort_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Abort_Stmt is
      begin
         if Node = null then
            return No_Entity_Abort_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abort_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_Node
        (Node : Bare_Abstract_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_Node is
      begin
         if Node = null then
            return No_Entity_Abstract_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_Absent
        (Node : Bare_Abstract_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_Absent is
      begin
         if Node = null then
            return No_Entity_Abstract_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Basic_Subp_Decl
        (Node : Bare_Basic_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Basic_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Basic_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Basic_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Classic_Subp_Decl
        (Node : Bare_Classic_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Classic_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Classic_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Classic_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Formal_Subp_Decl
        (Node : Bare_Formal_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Formal_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Formal_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Formal_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_Formal_Subp_Decl
        (Node : Bare_Abstract_Formal_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_Formal_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Abstract_Formal_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_Formal_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_Present
        (Node : Bare_Abstract_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_Present is
      begin
         if Node = null then
            return No_Entity_Abstract_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_State_Decl
        (Node : Bare_Abstract_State_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_State_Decl is
      begin
         if Node = null then
            return No_Entity_Abstract_State_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_State_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_State_Decl_Expr
        (Node : Bare_Abstract_State_Decl_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_State_Decl_Expr is
      begin
         if Node = null then
            return No_Entity_Abstract_State_Decl_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_State_Decl_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_State_Decl_List
        (Node : Bare_Abstract_State_Decl_List; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_State_Decl_List is
      begin
         if Node = null then
            return No_Entity_Abstract_State_Decl_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_State_Decl_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Abstract_Subp_Decl
        (Node : Bare_Abstract_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Abstract_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Abstract_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Abstract_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Composite_Stmt
        (Node : Bare_Composite_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Composite_Stmt is
      begin
         if Node = null then
            return No_Entity_Composite_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Composite_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Accept_Stmt
        (Node : Bare_Accept_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Accept_Stmt is
      begin
         if Node = null then
            return No_Entity_Accept_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Accept_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Accept_Stmt_With_Stmts
        (Node : Bare_Accept_Stmt_With_Stmts; Info : Internal_Entity_Info)
         return Internal_Entity_Accept_Stmt_With_Stmts is
      begin
         if Node = null then
            return No_Entity_Accept_Stmt_With_Stmts;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Accept_Stmt_With_Stmts) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Type_Def
        (Node : Bare_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Type_Def is
      begin
         if Node = null then
            return No_Entity_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Access_Def
        (Node : Bare_Access_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Access_Def is
      begin
         if Node = null then
            return No_Entity_Access_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Access_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Access_To_Subp_Def
        (Node : Bare_Access_To_Subp_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Access_To_Subp_Def is
      begin
         if Node = null then
            return No_Entity_Access_To_Subp_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Access_To_Subp_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Aggregate
        (Node : Bare_Base_Aggregate; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Aggregate is
      begin
         if Node = null then
            return No_Entity_Base_Aggregate;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Aggregate) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aggregate
        (Node : Bare_Aggregate; Info : Internal_Entity_Info)
         return Internal_Entity_Aggregate is
      begin
         if Node = null then
            return No_Entity_Aggregate;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aggregate) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Basic_Assoc
        (Node : Bare_Basic_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Basic_Assoc is
      begin
         if Node = null then
            return No_Entity_Basic_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Basic_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aggregate_Assoc
        (Node : Bare_Aggregate_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Aggregate_Assoc is
      begin
         if Node = null then
            return No_Entity_Aggregate_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aggregate_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aliased_Node
        (Node : Bare_Aliased_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Aliased_Node is
      begin
         if Node = null then
            return No_Entity_Aliased_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aliased_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aliased_Absent
        (Node : Bare_Aliased_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Aliased_Absent is
      begin
         if Node = null then
            return No_Entity_Aliased_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aliased_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aliased_Present
        (Node : Bare_Aliased_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Aliased_Present is
      begin
         if Node = null then
            return No_Entity_Aliased_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aliased_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_All_Node
        (Node : Bare_All_Node; Info : Internal_Entity_Info)
         return Internal_Entity_All_Node is
      begin
         if Node = null then
            return No_Entity_All_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_All_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_All_Absent
        (Node : Bare_All_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_All_Absent is
      begin
         if Node = null then
            return No_Entity_All_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_All_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_All_Present
        (Node : Bare_All_Present; Info : Internal_Entity_Info)
         return Internal_Entity_All_Present is
      begin
         if Node = null then
            return No_Entity_All_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_All_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Allocator
        (Node : Bare_Allocator; Info : Internal_Entity_Info)
         return Internal_Entity_Allocator is
      begin
         if Node = null then
            return No_Entity_Allocator;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Allocator) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Anonymous_Expr_Decl
        (Node : Bare_Anonymous_Expr_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Anonymous_Expr_Decl is
      begin
         if Node = null then
            return No_Entity_Anonymous_Expr_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Anonymous_Expr_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Type_Expr
        (Node : Bare_Type_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Type_Expr is
      begin
         if Node = null then
            return No_Entity_Type_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Type_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Anonymous_Type
        (Node : Bare_Anonymous_Type; Info : Internal_Entity_Info)
         return Internal_Entity_Anonymous_Type is
      begin
         if Node = null then
            return No_Entity_Anonymous_Type;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Anonymous_Type) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Type_Access_Def
        (Node : Bare_Base_Type_Access_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Type_Access_Def is
      begin
         if Node = null then
            return No_Entity_Base_Type_Access_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Type_Access_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Anonymous_Type_Access_Def
        (Node : Bare_Anonymous_Type_Access_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Anonymous_Type_Access_Def is
      begin
         if Node = null then
            return No_Entity_Anonymous_Type_Access_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Anonymous_Type_Access_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Type_Decl
        (Node : Bare_Base_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Base_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      ----------
      -- Hash --
      ----------
      pragma Warnings (Off, "referenced");
      function Hash (R : Internal_Entity_Base_Type_Decl) return Hash_Type is
         pragma Warnings (On, "referenced");
      begin
            return Combine
              (Hash (R.Node), Hash (R.Info));
      end Hash;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Type_Decl
        (Node : Bare_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Anonymous_Type_Decl
        (Node : Bare_Anonymous_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Anonymous_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Anonymous_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Anonymous_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Array_Indices
        (Node : Bare_Array_Indices; Info : Internal_Entity_Info)
         return Internal_Entity_Array_Indices is
      begin
         if Node = null then
            return No_Entity_Array_Indices;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Array_Indices) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Array_Type_Def
        (Node : Bare_Array_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Array_Type_Def is
      begin
         if Node = null then
            return No_Entity_Array_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Array_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aspect_Assoc
        (Node : Bare_Aspect_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Aspect_Assoc is
      begin
         if Node = null then
            return No_Entity_Aspect_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aspect_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aspect_Assoc_List
        (Node : Bare_Aspect_Assoc_List; Info : Internal_Entity_Info)
         return Internal_Entity_Aspect_Assoc_List is
      begin
         if Node = null then
            return No_Entity_Aspect_Assoc_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aspect_Assoc_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aspect_Clause
        (Node : Bare_Aspect_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Aspect_Clause is
      begin
         if Node = null then
            return No_Entity_Aspect_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aspect_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Aspect_Spec
        (Node : Bare_Aspect_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Aspect_Spec is
      begin
         if Node = null then
            return No_Entity_Aspect_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Aspect_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Assign_Stmt
        (Node : Bare_Assign_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Assign_Stmt is
      begin
         if Node = null then
            return No_Entity_Assign_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Assign_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Basic_Assoc_List
        (Node : Bare_Basic_Assoc_List; Info : Internal_Entity_Info)
         return Internal_Entity_Basic_Assoc_List is
      begin
         if Node = null then
            return No_Entity_Basic_Assoc_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Basic_Assoc_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Assoc_List
        (Node : Bare_Assoc_List; Info : Internal_Entity_Info)
         return Internal_Entity_Assoc_List is
      begin
         if Node = null then
            return No_Entity_Assoc_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Assoc_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_At_Clause
        (Node : Bare_At_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_At_Clause is
      begin
         if Node = null then
            return No_Entity_At_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_At_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Attribute_Def_Clause
        (Node : Bare_Attribute_Def_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Attribute_Def_Clause is
      begin
         if Node = null then
            return No_Entity_Attribute_Def_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Attribute_Def_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Attribute_Ref
        (Node : Bare_Attribute_Ref; Info : Internal_Entity_Info)
         return Internal_Entity_Attribute_Ref is
      begin
         if Node = null then
            return No_Entity_Attribute_Ref;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Attribute_Ref) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Assoc
        (Node : Bare_Base_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Assoc is
      begin
         if Node = null then
            return No_Entity_Base_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Assoc_List
        (Node : Bare_Base_Assoc_List; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Assoc_List is
      begin
         if Node = null then
            return No_Entity_Base_Assoc_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Assoc_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Formal_Param_Decl
        (Node : Bare_Base_Formal_Param_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Formal_Param_Decl is
      begin
         if Node = null then
            return No_Entity_Base_Formal_Param_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Formal_Param_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Formal_Param_Holder
        (Node : Bare_Base_Formal_Param_Holder; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Formal_Param_Holder is
      begin
         if Node = null then
            return No_Entity_Base_Formal_Param_Holder;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Formal_Param_Holder) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Loop_Stmt
        (Node : Bare_Base_Loop_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Loop_Stmt is
      begin
         if Node = null then
            return No_Entity_Base_Loop_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Loop_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Package_Decl
        (Node : Bare_Base_Package_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Package_Decl is
      begin
         if Node = null then
            return No_Entity_Base_Package_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Package_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Record_Def
        (Node : Bare_Base_Record_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Record_Def is
      begin
         if Node = null then
            return No_Entity_Base_Record_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Record_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Body_Node
        (Node : Bare_Body_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Body_Node is
      begin
         if Node = null then
            return No_Entity_Body_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Body_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Subp_Body
        (Node : Bare_Base_Subp_Body; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Subp_Body is
      begin
         if Node = null then
            return No_Entity_Base_Subp_Body;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Subp_Body) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Subp_Spec
        (Node : Bare_Base_Subp_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Subp_Spec is
      begin
         if Node = null then
            return No_Entity_Base_Subp_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Subp_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Base_Subtype_Decl
        (Node : Bare_Base_Subtype_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Base_Subtype_Decl is
      begin
         if Node = null then
            return No_Entity_Base_Subtype_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Base_Subtype_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Basic_Decl_List
        (Node : Bare_Basic_Decl_List; Info : Internal_Entity_Info)
         return Internal_Entity_Basic_Decl_List is
      begin
         if Node = null then
            return No_Entity_Basic_Decl_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Basic_Decl_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Block_Stmt
        (Node : Bare_Block_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Block_Stmt is
      begin
         if Node = null then
            return No_Entity_Block_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Block_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Begin_Block
        (Node : Bare_Begin_Block; Info : Internal_Entity_Info)
         return Internal_Entity_Begin_Block is
      begin
         if Node = null then
            return No_Entity_Begin_Block;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Begin_Block) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Bin_Op
        (Node : Bare_Bin_Op; Info : Internal_Entity_Info)
         return Internal_Entity_Bin_Op is
      begin
         if Node = null then
            return No_Entity_Bin_Op;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Bin_Op) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Body_Stub
        (Node : Bare_Body_Stub; Info : Internal_Entity_Info)
         return Internal_Entity_Body_Stub is
      begin
         if Node = null then
            return No_Entity_Body_Stub;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Body_Stub) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Box_Expr
        (Node : Bare_Box_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Box_Expr is
      begin
         if Node = null then
            return No_Entity_Box_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Box_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Bracket_Aggregate
        (Node : Bare_Bracket_Aggregate; Info : Internal_Entity_Info)
         return Internal_Entity_Bracket_Aggregate is
      begin
         if Node = null then
            return No_Entity_Bracket_Aggregate;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Bracket_Aggregate) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Delta_Aggregate
        (Node : Bare_Delta_Aggregate; Info : Internal_Entity_Info)
         return Internal_Entity_Delta_Aggregate is
      begin
         if Node = null then
            return No_Entity_Delta_Aggregate;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Delta_Aggregate) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Bracket_Delta_Aggregate
        (Node : Bare_Bracket_Delta_Aggregate; Info : Internal_Entity_Info)
         return Internal_Entity_Bracket_Delta_Aggregate is
      begin
         if Node = null then
            return No_Entity_Bracket_Delta_Aggregate;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Bracket_Delta_Aggregate) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Call_Expr
        (Node : Bare_Call_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Call_Expr is
      begin
         if Node = null then
            return No_Entity_Call_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Call_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Call_Stmt
        (Node : Bare_Call_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Call_Stmt is
      begin
         if Node = null then
            return No_Entity_Call_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Call_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Cond_Expr
        (Node : Bare_Cond_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Cond_Expr is
      begin
         if Node = null then
            return No_Entity_Cond_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Cond_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Case_Expr
        (Node : Bare_Case_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Case_Expr is
      begin
         if Node = null then
            return No_Entity_Case_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Case_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Case_Expr_Alternative
        (Node : Bare_Case_Expr_Alternative; Info : Internal_Entity_Info)
         return Internal_Entity_Case_Expr_Alternative is
      begin
         if Node = null then
            return No_Entity_Case_Expr_Alternative;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Case_Expr_Alternative) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Case_Expr_Alternative_List
        (Node : Bare_Case_Expr_Alternative_List; Info : Internal_Entity_Info)
         return Internal_Entity_Case_Expr_Alternative_List is
      begin
         if Node = null then
            return No_Entity_Case_Expr_Alternative_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Case_Expr_Alternative_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Case_Stmt
        (Node : Bare_Case_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Case_Stmt is
      begin
         if Node = null then
            return No_Entity_Case_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Case_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Case_Stmt_Alternative
        (Node : Bare_Case_Stmt_Alternative; Info : Internal_Entity_Info)
         return Internal_Entity_Case_Stmt_Alternative is
      begin
         if Node = null then
            return No_Entity_Case_Stmt_Alternative;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Case_Stmt_Alternative) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Case_Stmt_Alternative_List
        (Node : Bare_Case_Stmt_Alternative_List; Info : Internal_Entity_Info)
         return Internal_Entity_Case_Stmt_Alternative_List is
      begin
         if Node = null then
            return No_Entity_Case_Stmt_Alternative_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Case_Stmt_Alternative_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Char_Literal
        (Node : Bare_Char_Literal; Info : Internal_Entity_Info)
         return Internal_Entity_Char_Literal is
      begin
         if Node = null then
            return No_Entity_Char_Literal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Char_Literal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Classwide_Type_Decl
        (Node : Bare_Classwide_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Classwide_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Classwide_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Classwide_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Compilation_Unit
        (Node : Bare_Compilation_Unit; Info : Internal_Entity_Info)
         return Internal_Entity_Compilation_Unit is
      begin
         if Node = null then
            return No_Entity_Compilation_Unit;
         end if;
         return (Node => Node, Info => Info);
      end;
      ----------
      -- Hash --
      ----------
      pragma Warnings (Off, "referenced");
      function Hash (R : Internal_Entity_Compilation_Unit) return Hash_Type is
         pragma Warnings (On, "referenced");
      begin
            return Combine
              (Hash (R.Node), Hash (R.Info));
      end Hash;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Compilation_Unit) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Compilation_Unit_List
        (Node : Bare_Compilation_Unit_List; Info : Internal_Entity_Info)
         return Internal_Entity_Compilation_Unit_List is
      begin
         if Node = null then
            return No_Entity_Compilation_Unit_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Compilation_Unit_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Component_Clause
        (Node : Bare_Component_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Component_Clause is
      begin
         if Node = null then
            return No_Entity_Component_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Component_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Component_Decl
        (Node : Bare_Component_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Component_Decl is
      begin
         if Node = null then
            return No_Entity_Component_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Component_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Component_Def
        (Node : Bare_Component_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Component_Def is
      begin
         if Node = null then
            return No_Entity_Component_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Component_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Component_List
        (Node : Bare_Component_List; Info : Internal_Entity_Info)
         return Internal_Entity_Component_List is
      begin
         if Node = null then
            return No_Entity_Component_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Component_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constraint
        (Node : Bare_Constraint; Info : Internal_Entity_Info)
         return Internal_Entity_Constraint is
      begin
         if Node = null then
            return No_Entity_Constraint;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constraint) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Composite_Constraint
        (Node : Bare_Composite_Constraint; Info : Internal_Entity_Info)
         return Internal_Entity_Composite_Constraint is
      begin
         if Node = null then
            return No_Entity_Composite_Constraint;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Composite_Constraint) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Composite_Constraint_Assoc
        (Node : Bare_Composite_Constraint_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Composite_Constraint_Assoc is
      begin
         if Node = null then
            return No_Entity_Composite_Constraint_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Composite_Constraint_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Concat_Op
        (Node : Bare_Concat_Op; Info : Internal_Entity_Info)
         return Internal_Entity_Concat_Op is
      begin
         if Node = null then
            return No_Entity_Concat_Op;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Concat_Op) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Concat_Operand
        (Node : Bare_Concat_Operand; Info : Internal_Entity_Info)
         return Internal_Entity_Concat_Operand is
      begin
         if Node = null then
            return No_Entity_Concat_Operand;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Concat_Operand) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Concat_Operand_List
        (Node : Bare_Concat_Operand_List; Info : Internal_Entity_Info)
         return Internal_Entity_Concat_Operand_List is
      begin
         if Node = null then
            return No_Entity_Concat_Operand_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Concat_Operand_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Concrete_Formal_Subp_Decl
        (Node : Bare_Concrete_Formal_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Concrete_Formal_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Concrete_Formal_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Concrete_Formal_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Concrete_Type_Decl
        (Node : Bare_Concrete_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Concrete_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Concrete_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Concrete_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constant_Node
        (Node : Bare_Constant_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Constant_Node is
      begin
         if Node = null then
            return No_Entity_Constant_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constant_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constant_Absent
        (Node : Bare_Constant_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Constant_Absent is
      begin
         if Node = null then
            return No_Entity_Constant_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constant_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constant_Present
        (Node : Bare_Constant_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Constant_Present is
      begin
         if Node = null then
            return No_Entity_Constant_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constant_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constrained_Array_Indices
        (Node : Bare_Constrained_Array_Indices; Info : Internal_Entity_Info)
         return Internal_Entity_Constrained_Array_Indices is
      begin
         if Node = null then
            return No_Entity_Constrained_Array_Indices;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constrained_Array_Indices) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subtype_Indication
        (Node : Bare_Subtype_Indication; Info : Internal_Entity_Info)
         return Internal_Entity_Subtype_Indication is
      begin
         if Node = null then
            return No_Entity_Subtype_Indication;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subtype_Indication) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constrained_Subtype_Indication
        (Node : Bare_Constrained_Subtype_Indication; Info : Internal_Entity_Info)
         return Internal_Entity_Constrained_Subtype_Indication is
      begin
         if Node = null then
            return No_Entity_Constrained_Subtype_Indication;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constrained_Subtype_Indication) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Constraint_List
        (Node : Bare_Constraint_List; Info : Internal_Entity_Info)
         return Internal_Entity_Constraint_List is
      begin
         if Node = null then
            return No_Entity_Constraint_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Constraint_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Contract_Case_Assoc
        (Node : Bare_Contract_Case_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Contract_Case_Assoc is
      begin
         if Node = null then
            return No_Entity_Contract_Case_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Contract_Case_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Contract_Case_Assoc_List
        (Node : Bare_Contract_Case_Assoc_List; Info : Internal_Entity_Info)
         return Internal_Entity_Contract_Case_Assoc_List is
      begin
         if Node = null then
            return No_Entity_Contract_Case_Assoc_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Contract_Case_Assoc_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Contract_Cases
        (Node : Bare_Contract_Cases; Info : Internal_Entity_Info)
         return Internal_Entity_Contract_Cases is
      begin
         if Node = null then
            return No_Entity_Contract_Cases;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Contract_Cases) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Real_Type_Def
        (Node : Bare_Real_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Real_Type_Def is
      begin
         if Node = null then
            return No_Entity_Real_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Real_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Decimal_Fixed_Point_Def
        (Node : Bare_Decimal_Fixed_Point_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Decimal_Fixed_Point_Def is
      begin
         if Node = null then
            return No_Entity_Decimal_Fixed_Point_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Decimal_Fixed_Point_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Decl_Block
        (Node : Bare_Decl_Block; Info : Internal_Entity_Info)
         return Internal_Entity_Decl_Block is
      begin
         if Node = null then
            return No_Entity_Decl_Block;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Decl_Block) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Decl_Expr
        (Node : Bare_Decl_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Decl_Expr is
      begin
         if Node = null then
            return No_Entity_Decl_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Decl_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Decl_List
        (Node : Bare_Decl_List; Info : Internal_Entity_Info)
         return Internal_Entity_Decl_List is
      begin
         if Node = null then
            return No_Entity_Decl_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Decl_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Declarative_Part
        (Node : Bare_Declarative_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Declarative_Part is
      begin
         if Node = null then
            return No_Entity_Declarative_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Declarative_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Defining_Name
        (Node : Bare_Defining_Name; Info : Internal_Entity_Info)
         return Internal_Entity_Defining_Name is
      begin
         if Node = null then
            return No_Entity_Defining_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Defining_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Defining_Name_List
        (Node : Bare_Defining_Name_List; Info : Internal_Entity_Info)
         return Internal_Entity_Defining_Name_List is
      begin
         if Node = null then
            return No_Entity_Defining_Name_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Defining_Name_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Delay_Stmt
        (Node : Bare_Delay_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Delay_Stmt is
      begin
         if Node = null then
            return No_Entity_Delay_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Delay_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Delta_Constraint
        (Node : Bare_Delta_Constraint; Info : Internal_Entity_Info)
         return Internal_Entity_Delta_Constraint is
      begin
         if Node = null then
            return No_Entity_Delta_Constraint;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Delta_Constraint) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Derived_Type_Def
        (Node : Bare_Derived_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Derived_Type_Def is
      begin
         if Node = null then
            return No_Entity_Derived_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Derived_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Digits_Constraint
        (Node : Bare_Digits_Constraint; Info : Internal_Entity_Info)
         return Internal_Entity_Digits_Constraint is
      begin
         if Node = null then
            return No_Entity_Digits_Constraint;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Digits_Constraint) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discrete_Base_Subtype_Decl
        (Node : Bare_Discrete_Base_Subtype_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Discrete_Base_Subtype_Decl is
      begin
         if Node = null then
            return No_Entity_Discrete_Base_Subtype_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discrete_Base_Subtype_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discrete_Subtype_Indication
        (Node : Bare_Discrete_Subtype_Indication; Info : Internal_Entity_Info)
         return Internal_Entity_Discrete_Subtype_Indication is
      begin
         if Node = null then
            return No_Entity_Discrete_Subtype_Indication;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discrete_Subtype_Indication) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discrete_Subtype_Name
        (Node : Bare_Discrete_Subtype_Name; Info : Internal_Entity_Info)
         return Internal_Entity_Discrete_Subtype_Name is
      begin
         if Node = null then
            return No_Entity_Discrete_Subtype_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discrete_Subtype_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Identifier_List
        (Node : Bare_Identifier_List; Info : Internal_Entity_Info)
         return Internal_Entity_Identifier_List is
      begin
         if Node = null then
            return No_Entity_Identifier_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Identifier_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discriminant_Choice_List
        (Node : Bare_Discriminant_Choice_List; Info : Internal_Entity_Info)
         return Internal_Entity_Discriminant_Choice_List is
      begin
         if Node = null then
            return No_Entity_Discriminant_Choice_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discriminant_Choice_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discriminant_Part
        (Node : Bare_Discriminant_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Discriminant_Part is
      begin
         if Node = null then
            return No_Entity_Discriminant_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discriminant_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discriminant_Spec
        (Node : Bare_Discriminant_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Discriminant_Spec is
      begin
         if Node = null then
            return No_Entity_Discriminant_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discriminant_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Discriminant_Spec_List
        (Node : Bare_Discriminant_Spec_List; Info : Internal_Entity_Info)
         return Internal_Entity_Discriminant_Spec_List is
      begin
         if Node = null then
            return No_Entity_Discriminant_Spec_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Discriminant_Spec_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Dotted_Name
        (Node : Bare_Dotted_Name; Info : Internal_Entity_Info)
         return Internal_Entity_Dotted_Name is
      begin
         if Node = null then
            return No_Entity_Dotted_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Dotted_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Elsif_Expr_Part
        (Node : Bare_Elsif_Expr_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Elsif_Expr_Part is
      begin
         if Node = null then
            return No_Entity_Elsif_Expr_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Elsif_Expr_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Elsif_Expr_Part_List
        (Node : Bare_Elsif_Expr_Part_List; Info : Internal_Entity_Info)
         return Internal_Entity_Elsif_Expr_Part_List is
      begin
         if Node = null then
            return No_Entity_Elsif_Expr_Part_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Elsif_Expr_Part_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Elsif_Stmt_Part
        (Node : Bare_Elsif_Stmt_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Elsif_Stmt_Part is
      begin
         if Node = null then
            return No_Entity_Elsif_Stmt_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Elsif_Stmt_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Elsif_Stmt_Part_List
        (Node : Bare_Elsif_Stmt_Part_List; Info : Internal_Entity_Info)
         return Internal_Entity_Elsif_Stmt_Part_List is
      begin
         if Node = null then
            return No_Entity_Elsif_Stmt_Part_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Elsif_Stmt_Part_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_End_Name
        (Node : Bare_End_Name; Info : Internal_Entity_Info)
         return Internal_Entity_End_Name is
      begin
         if Node = null then
            return No_Entity_End_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_End_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Entry_Body
        (Node : Bare_Entry_Body; Info : Internal_Entity_Info)
         return Internal_Entity_Entry_Body is
      begin
         if Node = null then
            return No_Entity_Entry_Body;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Entry_Body) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Entry_Completion_Formal_Params
        (Node : Bare_Entry_Completion_Formal_Params; Info : Internal_Entity_Info)
         return Internal_Entity_Entry_Completion_Formal_Params is
      begin
         if Node = null then
            return No_Entity_Entry_Completion_Formal_Params;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Entry_Completion_Formal_Params) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Entry_Decl
        (Node : Bare_Entry_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Entry_Decl is
      begin
         if Node = null then
            return No_Entity_Entry_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Entry_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Entry_Index_Spec
        (Node : Bare_Entry_Index_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Entry_Index_Spec is
      begin
         if Node = null then
            return No_Entity_Entry_Index_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Entry_Index_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Entry_Spec
        (Node : Bare_Entry_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Entry_Spec is
      begin
         if Node = null then
            return No_Entity_Entry_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Entry_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Enum_Lit_Synth_Type_Expr
        (Node : Bare_Enum_Lit_Synth_Type_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Enum_Lit_Synth_Type_Expr is
      begin
         if Node = null then
            return No_Entity_Enum_Lit_Synth_Type_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Enum_Lit_Synth_Type_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Enum_Literal_Decl
        (Node : Bare_Enum_Literal_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Enum_Literal_Decl is
      begin
         if Node = null then
            return No_Entity_Enum_Literal_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Enum_Literal_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Enum_Literal_Decl_List
        (Node : Bare_Enum_Literal_Decl_List; Info : Internal_Entity_Info)
         return Internal_Entity_Enum_Literal_Decl_List is
      begin
         if Node = null then
            return No_Entity_Enum_Literal_Decl_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Enum_Literal_Decl_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Enum_Rep_Clause
        (Node : Bare_Enum_Rep_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Enum_Rep_Clause is
      begin
         if Node = null then
            return No_Entity_Enum_Rep_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Enum_Rep_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Enum_Subp_Spec
        (Node : Bare_Enum_Subp_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Enum_Subp_Spec is
      begin
         if Node = null then
            return No_Entity_Enum_Subp_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Enum_Subp_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Enum_Type_Def
        (Node : Bare_Enum_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Enum_Type_Def is
      begin
         if Node = null then
            return No_Entity_Enum_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Enum_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Error_Decl
        (Node : Bare_Error_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Error_Decl is
      begin
         if Node = null then
            return No_Entity_Error_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Error_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Error_Stmt
        (Node : Bare_Error_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Error_Stmt is
      begin
         if Node = null then
            return No_Entity_Error_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Error_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Exception_Decl
        (Node : Bare_Exception_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Exception_Decl is
      begin
         if Node = null then
            return No_Entity_Exception_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Exception_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Exception_Handler
        (Node : Bare_Exception_Handler; Info : Internal_Entity_Info)
         return Internal_Entity_Exception_Handler is
      begin
         if Node = null then
            return No_Entity_Exception_Handler;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Exception_Handler) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Exit_Stmt
        (Node : Bare_Exit_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Exit_Stmt is
      begin
         if Node = null then
            return No_Entity_Exit_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Exit_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Explicit_Deref
        (Node : Bare_Explicit_Deref; Info : Internal_Entity_Info)
         return Internal_Entity_Explicit_Deref is
      begin
         if Node = null then
            return No_Entity_Explicit_Deref;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Explicit_Deref) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Expr_List
        (Node : Bare_Expr_List; Info : Internal_Entity_Info)
         return Internal_Entity_Expr_List is
      begin
         if Node = null then
            return No_Entity_Expr_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Expr_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Expr_Alternatives_List
        (Node : Bare_Expr_Alternatives_List; Info : Internal_Entity_Info)
         return Internal_Entity_Expr_Alternatives_List is
      begin
         if Node = null then
            return No_Entity_Expr_Alternatives_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Expr_Alternatives_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Expr_Function
        (Node : Bare_Expr_Function; Info : Internal_Entity_Info)
         return Internal_Entity_Expr_Function is
      begin
         if Node = null then
            return No_Entity_Expr_Function;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Expr_Function) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Extended_Return_Stmt
        (Node : Bare_Extended_Return_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Extended_Return_Stmt is
      begin
         if Node = null then
            return No_Entity_Extended_Return_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Extended_Return_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Object_Decl
        (Node : Bare_Object_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Object_Decl is
      begin
         if Node = null then
            return No_Entity_Object_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Object_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Extended_Return_Stmt_Object_Decl
        (Node : Bare_Extended_Return_Stmt_Object_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Extended_Return_Stmt_Object_Decl is
      begin
         if Node = null then
            return No_Entity_Extended_Return_Stmt_Object_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Extended_Return_Stmt_Object_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Floating_Point_Def
        (Node : Bare_Floating_Point_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Floating_Point_Def is
      begin
         if Node = null then
            return No_Entity_Floating_Point_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Floating_Point_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Loop_Spec
        (Node : Bare_Loop_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Loop_Spec is
      begin
         if Node = null then
            return No_Entity_Loop_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Loop_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_For_Loop_Spec
        (Node : Bare_For_Loop_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_For_Loop_Spec is
      begin
         if Node = null then
            return No_Entity_For_Loop_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_For_Loop_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_For_Loop_Stmt
        (Node : Bare_For_Loop_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_For_Loop_Stmt is
      begin
         if Node = null then
            return No_Entity_For_Loop_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_For_Loop_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_For_Loop_Var_Decl
        (Node : Bare_For_Loop_Var_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_For_Loop_Var_Decl is
      begin
         if Node = null then
            return No_Entity_For_Loop_Var_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_For_Loop_Var_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Formal_Discrete_Type_Def
        (Node : Bare_Formal_Discrete_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Formal_Discrete_Type_Def is
      begin
         if Node = null then
            return No_Entity_Formal_Discrete_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Formal_Discrete_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Formal_Type_Decl
        (Node : Bare_Formal_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Formal_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Formal_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Formal_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Decl
        (Node : Bare_Generic_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Formal
        (Node : Bare_Generic_Formal; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Formal is
      begin
         if Node = null then
            return No_Entity_Generic_Formal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Formal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Formal_Obj_Decl
        (Node : Bare_Generic_Formal_Obj_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Formal_Obj_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Formal_Obj_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Formal_Obj_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Formal_Package
        (Node : Bare_Generic_Formal_Package; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Formal_Package is
      begin
         if Node = null then
            return No_Entity_Generic_Formal_Package;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Formal_Package) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Formal_Part
        (Node : Bare_Generic_Formal_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Formal_Part is
      begin
         if Node = null then
            return No_Entity_Generic_Formal_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Formal_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Formal_Subp_Decl
        (Node : Bare_Generic_Formal_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Formal_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Formal_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Formal_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Formal_Type_Decl
        (Node : Bare_Generic_Formal_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Formal_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Formal_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Formal_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Instantiation
        (Node : Bare_Generic_Instantiation; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Instantiation is
      begin
         if Node = null then
            return No_Entity_Generic_Instantiation;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Instantiation) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Package_Decl
        (Node : Bare_Generic_Package_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Package_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Package_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Package_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Package_Instantiation
        (Node : Bare_Generic_Package_Instantiation; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Package_Instantiation is
      begin
         if Node = null then
            return No_Entity_Generic_Package_Instantiation;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Package_Instantiation) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Package_Internal
        (Node : Bare_Generic_Package_Internal; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Package_Internal is
      begin
         if Node = null then
            return No_Entity_Generic_Package_Internal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Package_Internal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Renaming_Decl
        (Node : Bare_Generic_Renaming_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Renaming_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Renaming_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Renaming_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Package_Renaming_Decl
        (Node : Bare_Generic_Package_Renaming_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Package_Renaming_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Package_Renaming_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Package_Renaming_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Subp_Decl
        (Node : Bare_Generic_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Subp_Instantiation
        (Node : Bare_Generic_Subp_Instantiation; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Subp_Instantiation is
      begin
         if Node = null then
            return No_Entity_Generic_Subp_Instantiation;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Subp_Instantiation) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Subp_Internal
        (Node : Bare_Generic_Subp_Internal; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Subp_Internal is
      begin
         if Node = null then
            return No_Entity_Generic_Subp_Internal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Subp_Internal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Generic_Subp_Renaming_Decl
        (Node : Bare_Generic_Subp_Renaming_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Generic_Subp_Renaming_Decl is
      begin
         if Node = null then
            return No_Entity_Generic_Subp_Renaming_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Generic_Subp_Renaming_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Goto_Stmt
        (Node : Bare_Goto_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Goto_Stmt is
      begin
         if Node = null then
            return No_Entity_Goto_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Goto_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Handled_Stmts
        (Node : Bare_Handled_Stmts; Info : Internal_Entity_Info)
         return Internal_Entity_Handled_Stmts is
      begin
         if Node = null then
            return No_Entity_Handled_Stmts;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Handled_Stmts) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_If_Expr
        (Node : Bare_If_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_If_Expr is
      begin
         if Node = null then
            return No_Entity_If_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_If_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_If_Stmt
        (Node : Bare_If_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_If_Stmt is
      begin
         if Node = null then
            return No_Entity_If_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_If_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Incomplete_Type_Decl
        (Node : Bare_Incomplete_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Incomplete_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Incomplete_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Incomplete_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Incomplete_Formal_Type_Decl
        (Node : Bare_Incomplete_Formal_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Incomplete_Formal_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Incomplete_Formal_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Incomplete_Formal_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Incomplete_Tagged_Type_Decl
        (Node : Bare_Incomplete_Tagged_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Incomplete_Tagged_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Incomplete_Tagged_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Incomplete_Tagged_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Num_Literal
        (Node : Bare_Num_Literal; Info : Internal_Entity_Info)
         return Internal_Entity_Num_Literal is
      begin
         if Node = null then
            return No_Entity_Num_Literal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Num_Literal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Int_Literal
        (Node : Bare_Int_Literal; Info : Internal_Entity_Info)
         return Internal_Entity_Int_Literal is
      begin
         if Node = null then
            return No_Entity_Int_Literal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Int_Literal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Interface_Kind
        (Node : Bare_Interface_Kind; Info : Internal_Entity_Info)
         return Internal_Entity_Interface_Kind is
      begin
         if Node = null then
            return No_Entity_Interface_Kind;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Interface_Kind) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Interface_Kind_Limited
        (Node : Bare_Interface_Kind_Limited; Info : Internal_Entity_Info)
         return Internal_Entity_Interface_Kind_Limited is
      begin
         if Node = null then
            return No_Entity_Interface_Kind_Limited;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Interface_Kind_Limited) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Interface_Kind_Protected
        (Node : Bare_Interface_Kind_Protected; Info : Internal_Entity_Info)
         return Internal_Entity_Interface_Kind_Protected is
      begin
         if Node = null then
            return No_Entity_Interface_Kind_Protected;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Interface_Kind_Protected) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Interface_Kind_Synchronized
        (Node : Bare_Interface_Kind_Synchronized; Info : Internal_Entity_Info)
         return Internal_Entity_Interface_Kind_Synchronized is
      begin
         if Node = null then
            return No_Entity_Interface_Kind_Synchronized;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Interface_Kind_Synchronized) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Interface_Kind_Task
        (Node : Bare_Interface_Kind_Task; Info : Internal_Entity_Info)
         return Internal_Entity_Interface_Kind_Task is
      begin
         if Node = null then
            return No_Entity_Interface_Kind_Task;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Interface_Kind_Task) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Interface_Type_Def
        (Node : Bare_Interface_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Interface_Type_Def is
      begin
         if Node = null then
            return No_Entity_Interface_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Interface_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Iter_Type
        (Node : Bare_Iter_Type; Info : Internal_Entity_Info)
         return Internal_Entity_Iter_Type is
      begin
         if Node = null then
            return No_Entity_Iter_Type;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Iter_Type) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Iter_Type_In
        (Node : Bare_Iter_Type_In; Info : Internal_Entity_Info)
         return Internal_Entity_Iter_Type_In is
      begin
         if Node = null then
            return No_Entity_Iter_Type_In;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Iter_Type_In) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Iter_Type_Of
        (Node : Bare_Iter_Type_Of; Info : Internal_Entity_Info)
         return Internal_Entity_Iter_Type_Of is
      begin
         if Node = null then
            return No_Entity_Iter_Type_Of;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Iter_Type_Of) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Iterated_Assoc
        (Node : Bare_Iterated_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Iterated_Assoc is
      begin
         if Node = null then
            return No_Entity_Iterated_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Iterated_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Known_Discriminant_Part
        (Node : Bare_Known_Discriminant_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Known_Discriminant_Part is
      begin
         if Node = null then
            return No_Entity_Known_Discriminant_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Known_Discriminant_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Label
        (Node : Bare_Label; Info : Internal_Entity_Info)
         return Internal_Entity_Label is
      begin
         if Node = null then
            return No_Entity_Label;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Label) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Label_Decl
        (Node : Bare_Label_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Label_Decl is
      begin
         if Node = null then
            return No_Entity_Label_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Label_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Library_Item
        (Node : Bare_Library_Item; Info : Internal_Entity_Info)
         return Internal_Entity_Library_Item is
      begin
         if Node = null then
            return No_Entity_Library_Item;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Library_Item) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Limited_Node
        (Node : Bare_Limited_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Limited_Node is
      begin
         if Node = null then
            return No_Entity_Limited_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Limited_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Limited_Absent
        (Node : Bare_Limited_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Limited_Absent is
      begin
         if Node = null then
            return No_Entity_Limited_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Limited_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Limited_Present
        (Node : Bare_Limited_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Limited_Present is
      begin
         if Node = null then
            return No_Entity_Limited_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Limited_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Loop_Stmt
        (Node : Bare_Loop_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Loop_Stmt is
      begin
         if Node = null then
            return No_Entity_Loop_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Loop_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Membership_Expr
        (Node : Bare_Membership_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Membership_Expr is
      begin
         if Node = null then
            return No_Entity_Membership_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Membership_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Mod_Int_Type_Def
        (Node : Bare_Mod_Int_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Mod_Int_Type_Def is
      begin
         if Node = null then
            return No_Entity_Mod_Int_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Mod_Int_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Mode
        (Node : Bare_Mode; Info : Internal_Entity_Info)
         return Internal_Entity_Mode is
      begin
         if Node = null then
            return No_Entity_Mode;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Mode) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Mode_Default
        (Node : Bare_Mode_Default; Info : Internal_Entity_Info)
         return Internal_Entity_Mode_Default is
      begin
         if Node = null then
            return No_Entity_Mode_Default;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Mode_Default) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Mode_In
        (Node : Bare_Mode_In; Info : Internal_Entity_Info)
         return Internal_Entity_Mode_In is
      begin
         if Node = null then
            return No_Entity_Mode_In;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Mode_In) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Mode_In_Out
        (Node : Bare_Mode_In_Out; Info : Internal_Entity_Info)
         return Internal_Entity_Mode_In_Out is
      begin
         if Node = null then
            return No_Entity_Mode_In_Out;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Mode_In_Out) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Mode_Out
        (Node : Bare_Mode_Out; Info : Internal_Entity_Info)
         return Internal_Entity_Mode_Out is
      begin
         if Node = null then
            return No_Entity_Mode_Out;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Mode_Out) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Multi_Abstract_State_Decl
        (Node : Bare_Multi_Abstract_State_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Multi_Abstract_State_Decl is
      begin
         if Node = null then
            return No_Entity_Multi_Abstract_State_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Multi_Abstract_State_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Multi_Dim_Array_Assoc
        (Node : Bare_Multi_Dim_Array_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Multi_Dim_Array_Assoc is
      begin
         if Node = null then
            return No_Entity_Multi_Dim_Array_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Multi_Dim_Array_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Name_List
        (Node : Bare_Name_List; Info : Internal_Entity_Info)
         return Internal_Entity_Name_List is
      begin
         if Node = null then
            return No_Entity_Name_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Name_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Named_Stmt
        (Node : Bare_Named_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Named_Stmt is
      begin
         if Node = null then
            return No_Entity_Named_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Named_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Named_Stmt_Decl
        (Node : Bare_Named_Stmt_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Named_Stmt_Decl is
      begin
         if Node = null then
            return No_Entity_Named_Stmt_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Named_Stmt_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_No_Type_Object_Renaming_Decl
        (Node : Bare_No_Type_Object_Renaming_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_No_Type_Object_Renaming_Decl is
      begin
         if Node = null then
            return No_Entity_No_Type_Object_Renaming_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_No_Type_Object_Renaming_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Not_Null
        (Node : Bare_Not_Null; Info : Internal_Entity_Info)
         return Internal_Entity_Not_Null is
      begin
         if Node = null then
            return No_Entity_Not_Null;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Not_Null) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Not_Null_Absent
        (Node : Bare_Not_Null_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Not_Null_Absent is
      begin
         if Node = null then
            return No_Entity_Not_Null_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Not_Null_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Not_Null_Present
        (Node : Bare_Not_Null_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Not_Null_Present is
      begin
         if Node = null then
            return No_Entity_Not_Null_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Not_Null_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Null_Component_Decl
        (Node : Bare_Null_Component_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Null_Component_Decl is
      begin
         if Node = null then
            return No_Entity_Null_Component_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Null_Component_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Null_Literal
        (Node : Bare_Null_Literal; Info : Internal_Entity_Info)
         return Internal_Entity_Null_Literal is
      begin
         if Node = null then
            return No_Entity_Null_Literal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Null_Literal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Null_Record_Aggregate
        (Node : Bare_Null_Record_Aggregate; Info : Internal_Entity_Info)
         return Internal_Entity_Null_Record_Aggregate is
      begin
         if Node = null then
            return No_Entity_Null_Record_Aggregate;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Null_Record_Aggregate) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Null_Record_Def
        (Node : Bare_Null_Record_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Null_Record_Def is
      begin
         if Node = null then
            return No_Entity_Null_Record_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Null_Record_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Null_Stmt
        (Node : Bare_Null_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Null_Stmt is
      begin
         if Node = null then
            return No_Entity_Null_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Null_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Null_Subp_Decl
        (Node : Bare_Null_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Null_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Null_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Null_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Number_Decl
        (Node : Bare_Number_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Number_Decl is
      begin
         if Node = null then
            return No_Entity_Number_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Number_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op
        (Node : Bare_Op; Info : Internal_Entity_Info)
         return Internal_Entity_Op is
      begin
         if Node = null then
            return No_Entity_Op;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Abs
        (Node : Bare_Op_Abs; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Abs is
      begin
         if Node = null then
            return No_Entity_Op_Abs;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Abs) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_And
        (Node : Bare_Op_And; Info : Internal_Entity_Info)
         return Internal_Entity_Op_And is
      begin
         if Node = null then
            return No_Entity_Op_And;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_And) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_And_Then
        (Node : Bare_Op_And_Then; Info : Internal_Entity_Info)
         return Internal_Entity_Op_And_Then is
      begin
         if Node = null then
            return No_Entity_Op_And_Then;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_And_Then) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Concat
        (Node : Bare_Op_Concat; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Concat is
      begin
         if Node = null then
            return No_Entity_Op_Concat;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Concat) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Div
        (Node : Bare_Op_Div; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Div is
      begin
         if Node = null then
            return No_Entity_Op_Div;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Div) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Double_Dot
        (Node : Bare_Op_Double_Dot; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Double_Dot is
      begin
         if Node = null then
            return No_Entity_Op_Double_Dot;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Double_Dot) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Eq
        (Node : Bare_Op_Eq; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Eq is
      begin
         if Node = null then
            return No_Entity_Op_Eq;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Eq) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Gt
        (Node : Bare_Op_Gt; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Gt is
      begin
         if Node = null then
            return No_Entity_Op_Gt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Gt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Gte
        (Node : Bare_Op_Gte; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Gte is
      begin
         if Node = null then
            return No_Entity_Op_Gte;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Gte) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_In
        (Node : Bare_Op_In; Info : Internal_Entity_Info)
         return Internal_Entity_Op_In is
      begin
         if Node = null then
            return No_Entity_Op_In;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_In) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Lt
        (Node : Bare_Op_Lt; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Lt is
      begin
         if Node = null then
            return No_Entity_Op_Lt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Lt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Lte
        (Node : Bare_Op_Lte; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Lte is
      begin
         if Node = null then
            return No_Entity_Op_Lte;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Lte) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Minus
        (Node : Bare_Op_Minus; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Minus is
      begin
         if Node = null then
            return No_Entity_Op_Minus;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Minus) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Mod
        (Node : Bare_Op_Mod; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Mod is
      begin
         if Node = null then
            return No_Entity_Op_Mod;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Mod) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Mult
        (Node : Bare_Op_Mult; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Mult is
      begin
         if Node = null then
            return No_Entity_Op_Mult;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Mult) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Neq
        (Node : Bare_Op_Neq; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Neq is
      begin
         if Node = null then
            return No_Entity_Op_Neq;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Neq) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Not
        (Node : Bare_Op_Not; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Not is
      begin
         if Node = null then
            return No_Entity_Op_Not;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Not) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Not_In
        (Node : Bare_Op_Not_In; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Not_In is
      begin
         if Node = null then
            return No_Entity_Op_Not_In;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Not_In) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Or
        (Node : Bare_Op_Or; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Or is
      begin
         if Node = null then
            return No_Entity_Op_Or;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Or) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Or_Else
        (Node : Bare_Op_Or_Else; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Or_Else is
      begin
         if Node = null then
            return No_Entity_Op_Or_Else;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Or_Else) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Plus
        (Node : Bare_Op_Plus; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Plus is
      begin
         if Node = null then
            return No_Entity_Op_Plus;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Plus) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Pow
        (Node : Bare_Op_Pow; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Pow is
      begin
         if Node = null then
            return No_Entity_Op_Pow;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Pow) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Rem
        (Node : Bare_Op_Rem; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Rem is
      begin
         if Node = null then
            return No_Entity_Op_Rem;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Rem) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Op_Xor
        (Node : Bare_Op_Xor; Info : Internal_Entity_Info)
         return Internal_Entity_Op_Xor is
      begin
         if Node = null then
            return No_Entity_Op_Xor;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Op_Xor) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Ordinary_Fixed_Point_Def
        (Node : Bare_Ordinary_Fixed_Point_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Ordinary_Fixed_Point_Def is
      begin
         if Node = null then
            return No_Entity_Ordinary_Fixed_Point_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Ordinary_Fixed_Point_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Others_Designator
        (Node : Bare_Others_Designator; Info : Internal_Entity_Info)
         return Internal_Entity_Others_Designator is
      begin
         if Node = null then
            return No_Entity_Others_Designator;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Others_Designator) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Overriding_Node
        (Node : Bare_Overriding_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Overriding_Node is
      begin
         if Node = null then
            return No_Entity_Overriding_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Overriding_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Overriding_Not_Overriding
        (Node : Bare_Overriding_Not_Overriding; Info : Internal_Entity_Info)
         return Internal_Entity_Overriding_Not_Overriding is
      begin
         if Node = null then
            return No_Entity_Overriding_Not_Overriding;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Overriding_Not_Overriding) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Overriding_Overriding
        (Node : Bare_Overriding_Overriding; Info : Internal_Entity_Info)
         return Internal_Entity_Overriding_Overriding is
      begin
         if Node = null then
            return No_Entity_Overriding_Overriding;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Overriding_Overriding) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Overriding_Unspecified
        (Node : Bare_Overriding_Unspecified; Info : Internal_Entity_Info)
         return Internal_Entity_Overriding_Unspecified is
      begin
         if Node = null then
            return No_Entity_Overriding_Unspecified;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Overriding_Unspecified) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Package_Body
        (Node : Bare_Package_Body; Info : Internal_Entity_Info)
         return Internal_Entity_Package_Body is
      begin
         if Node = null then
            return No_Entity_Package_Body;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Package_Body) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Package_Body_Stub
        (Node : Bare_Package_Body_Stub; Info : Internal_Entity_Info)
         return Internal_Entity_Package_Body_Stub is
      begin
         if Node = null then
            return No_Entity_Package_Body_Stub;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Package_Body_Stub) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Package_Decl
        (Node : Bare_Package_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Package_Decl is
      begin
         if Node = null then
            return No_Entity_Package_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Package_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Package_Renaming_Decl
        (Node : Bare_Package_Renaming_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Package_Renaming_Decl is
      begin
         if Node = null then
            return No_Entity_Package_Renaming_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Package_Renaming_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Param_Assoc
        (Node : Bare_Param_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Param_Assoc is
      begin
         if Node = null then
            return No_Entity_Param_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Param_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Param_Spec
        (Node : Bare_Param_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Param_Spec is
      begin
         if Node = null then
            return No_Entity_Param_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Param_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Param_Spec_List
        (Node : Bare_Param_Spec_List; Info : Internal_Entity_Info)
         return Internal_Entity_Param_Spec_List is
      begin
         if Node = null then
            return No_Entity_Param_Spec_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Param_Spec_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Params
        (Node : Bare_Params; Info : Internal_Entity_Info)
         return Internal_Entity_Params is
      begin
         if Node = null then
            return No_Entity_Params;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Params) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Paren_Abstract_State_Decl
        (Node : Bare_Paren_Abstract_State_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Paren_Abstract_State_Decl is
      begin
         if Node = null then
            return No_Entity_Paren_Abstract_State_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Paren_Abstract_State_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Paren_Expr
        (Node : Bare_Paren_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Paren_Expr is
      begin
         if Node = null then
            return No_Entity_Paren_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Paren_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Parent_List
        (Node : Bare_Parent_List; Info : Internal_Entity_Info)
         return Internal_Entity_Parent_List is
      begin
         if Node = null then
            return No_Entity_Parent_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Parent_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pp_Directive
        (Node : Bare_Pp_Directive; Info : Internal_Entity_Info)
         return Internal_Entity_Pp_Directive is
      begin
         if Node = null then
            return No_Entity_Pp_Directive;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pp_Directive) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pp_Else_Directive
        (Node : Bare_Pp_Else_Directive; Info : Internal_Entity_Info)
         return Internal_Entity_Pp_Else_Directive is
      begin
         if Node = null then
            return No_Entity_Pp_Else_Directive;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pp_Else_Directive) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pp_Elsif_Directive
        (Node : Bare_Pp_Elsif_Directive; Info : Internal_Entity_Info)
         return Internal_Entity_Pp_Elsif_Directive is
      begin
         if Node = null then
            return No_Entity_Pp_Elsif_Directive;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pp_Elsif_Directive) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pp_End_If_Directive
        (Node : Bare_Pp_End_If_Directive; Info : Internal_Entity_Info)
         return Internal_Entity_Pp_End_If_Directive is
      begin
         if Node = null then
            return No_Entity_Pp_End_If_Directive;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pp_End_If_Directive) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pp_If_Directive
        (Node : Bare_Pp_If_Directive; Info : Internal_Entity_Info)
         return Internal_Entity_Pp_If_Directive is
      begin
         if Node = null then
            return No_Entity_Pp_If_Directive;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pp_If_Directive) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pp_Then_Kw
        (Node : Bare_Pp_Then_Kw; Info : Internal_Entity_Info)
         return Internal_Entity_Pp_Then_Kw is
      begin
         if Node = null then
            return No_Entity_Pp_Then_Kw;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pp_Then_Kw) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pragma_Argument_Assoc
        (Node : Bare_Pragma_Argument_Assoc; Info : Internal_Entity_Info)
         return Internal_Entity_Pragma_Argument_Assoc is
      begin
         if Node = null then
            return No_Entity_Pragma_Argument_Assoc;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pragma_Argument_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pragma_Node
        (Node : Bare_Pragma_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Pragma_Node is
      begin
         if Node = null then
            return No_Entity_Pragma_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pragma_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Pragma_Node_List
        (Node : Bare_Pragma_Node_List; Info : Internal_Entity_Info)
         return Internal_Entity_Pragma_Node_List is
      begin
         if Node = null then
            return No_Entity_Pragma_Node_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Pragma_Node_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Private_Node
        (Node : Bare_Private_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Private_Node is
      begin
         if Node = null then
            return No_Entity_Private_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Private_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Private_Absent
        (Node : Bare_Private_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Private_Absent is
      begin
         if Node = null then
            return No_Entity_Private_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Private_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Private_Part
        (Node : Bare_Private_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Private_Part is
      begin
         if Node = null then
            return No_Entity_Private_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Private_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Private_Present
        (Node : Bare_Private_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Private_Present is
      begin
         if Node = null then
            return No_Entity_Private_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Private_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Private_Type_Def
        (Node : Bare_Private_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Private_Type_Def is
      begin
         if Node = null then
            return No_Entity_Private_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Private_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Node
        (Node : Bare_Protected_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Node is
      begin
         if Node = null then
            return No_Entity_Protected_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Absent
        (Node : Bare_Protected_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Absent is
      begin
         if Node = null then
            return No_Entity_Protected_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Body
        (Node : Bare_Protected_Body; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Body is
      begin
         if Node = null then
            return No_Entity_Protected_Body;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Body) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Body_Stub
        (Node : Bare_Protected_Body_Stub; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Body_Stub is
      begin
         if Node = null then
            return No_Entity_Protected_Body_Stub;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Body_Stub) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Def
        (Node : Bare_Protected_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Def is
      begin
         if Node = null then
            return No_Entity_Protected_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Present
        (Node : Bare_Protected_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Present is
      begin
         if Node = null then
            return No_Entity_Protected_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Protected_Type_Decl
        (Node : Bare_Protected_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Protected_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Protected_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Protected_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Public_Part
        (Node : Bare_Public_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Public_Part is
      begin
         if Node = null then
            return No_Entity_Public_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Public_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Qual_Expr
        (Node : Bare_Qual_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Qual_Expr is
      begin
         if Node = null then
            return No_Entity_Qual_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Qual_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Quantified_Expr
        (Node : Bare_Quantified_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Quantified_Expr is
      begin
         if Node = null then
            return No_Entity_Quantified_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Quantified_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Quantifier
        (Node : Bare_Quantifier; Info : Internal_Entity_Info)
         return Internal_Entity_Quantifier is
      begin
         if Node = null then
            return No_Entity_Quantifier;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Quantifier) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Quantifier_All
        (Node : Bare_Quantifier_All; Info : Internal_Entity_Info)
         return Internal_Entity_Quantifier_All is
      begin
         if Node = null then
            return No_Entity_Quantifier_All;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Quantifier_All) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Quantifier_Some
        (Node : Bare_Quantifier_Some; Info : Internal_Entity_Info)
         return Internal_Entity_Quantifier_Some is
      begin
         if Node = null then
            return No_Entity_Quantifier_Some;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Quantifier_Some) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Raise_Expr
        (Node : Bare_Raise_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Raise_Expr is
      begin
         if Node = null then
            return No_Entity_Raise_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Raise_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Raise_Stmt
        (Node : Bare_Raise_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Raise_Stmt is
      begin
         if Node = null then
            return No_Entity_Raise_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Raise_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Range_Constraint
        (Node : Bare_Range_Constraint; Info : Internal_Entity_Info)
         return Internal_Entity_Range_Constraint is
      begin
         if Node = null then
            return No_Entity_Range_Constraint;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Range_Constraint) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Range_Spec
        (Node : Bare_Range_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Range_Spec is
      begin
         if Node = null then
            return No_Entity_Range_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Range_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Real_Literal
        (Node : Bare_Real_Literal; Info : Internal_Entity_Info)
         return Internal_Entity_Real_Literal is
      begin
         if Node = null then
            return No_Entity_Real_Literal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Real_Literal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Record_Def
        (Node : Bare_Record_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Record_Def is
      begin
         if Node = null then
            return No_Entity_Record_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Record_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Record_Rep_Clause
        (Node : Bare_Record_Rep_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Record_Rep_Clause is
      begin
         if Node = null then
            return No_Entity_Record_Rep_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Record_Rep_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Record_Type_Def
        (Node : Bare_Record_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Record_Type_Def is
      begin
         if Node = null then
            return No_Entity_Record_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Record_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Reduce_Attribute_Ref
        (Node : Bare_Reduce_Attribute_Ref; Info : Internal_Entity_Info)
         return Internal_Entity_Reduce_Attribute_Ref is
      begin
         if Node = null then
            return No_Entity_Reduce_Attribute_Ref;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Reduce_Attribute_Ref) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Relation_Op
        (Node : Bare_Relation_Op; Info : Internal_Entity_Info)
         return Internal_Entity_Relation_Op is
      begin
         if Node = null then
            return No_Entity_Relation_Op;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Relation_Op) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Renaming_Clause
        (Node : Bare_Renaming_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Renaming_Clause is
      begin
         if Node = null then
            return No_Entity_Renaming_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Renaming_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Requeue_Stmt
        (Node : Bare_Requeue_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Requeue_Stmt is
      begin
         if Node = null then
            return No_Entity_Requeue_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Requeue_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Return_Stmt
        (Node : Bare_Return_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Return_Stmt is
      begin
         if Node = null then
            return No_Entity_Return_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Return_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Reverse_Node
        (Node : Bare_Reverse_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Reverse_Node is
      begin
         if Node = null then
            return No_Entity_Reverse_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Reverse_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Reverse_Absent
        (Node : Bare_Reverse_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Reverse_Absent is
      begin
         if Node = null then
            return No_Entity_Reverse_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Reverse_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Reverse_Present
        (Node : Bare_Reverse_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Reverse_Present is
      begin
         if Node = null then
            return No_Entity_Reverse_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Reverse_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Select_Stmt
        (Node : Bare_Select_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_Select_Stmt is
      begin
         if Node = null then
            return No_Entity_Select_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Select_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Select_When_Part
        (Node : Bare_Select_When_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Select_When_Part is
      begin
         if Node = null then
            return No_Entity_Select_When_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Select_When_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Select_When_Part_List
        (Node : Bare_Select_When_Part_List; Info : Internal_Entity_Info)
         return Internal_Entity_Select_When_Part_List is
      begin
         if Node = null then
            return No_Entity_Select_When_Part_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Select_When_Part_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Signed_Int_Type_Def
        (Node : Bare_Signed_Int_Type_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Signed_Int_Type_Def is
      begin
         if Node = null then
            return No_Entity_Signed_Int_Type_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Signed_Int_Type_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Single_Protected_Decl
        (Node : Bare_Single_Protected_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Single_Protected_Decl is
      begin
         if Node = null then
            return No_Entity_Single_Protected_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Single_Protected_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Single_Task_Decl
        (Node : Bare_Single_Task_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Single_Task_Decl is
      begin
         if Node = null then
            return No_Entity_Single_Task_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Single_Task_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Task_Type_Decl
        (Node : Bare_Task_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Task_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Task_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Task_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Single_Task_Type_Decl
        (Node : Bare_Single_Task_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Single_Task_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Single_Task_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Single_Task_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Stmt_List
        (Node : Bare_Stmt_List; Info : Internal_Entity_Info)
         return Internal_Entity_Stmt_List is
      begin
         if Node = null then
            return No_Entity_Stmt_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Stmt_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_String_Literal
        (Node : Bare_String_Literal; Info : Internal_Entity_Info)
         return Internal_Entity_String_Literal is
      begin
         if Node = null then
            return No_Entity_String_Literal;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_String_Literal) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Body
        (Node : Bare_Subp_Body; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Body is
      begin
         if Node = null then
            return No_Entity_Subp_Body;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Body) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Body_Stub
        (Node : Bare_Subp_Body_Stub; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Body_Stub is
      begin
         if Node = null then
            return No_Entity_Subp_Body_Stub;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Body_Stub) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Decl
        (Node : Bare_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Kind
        (Node : Bare_Subp_Kind; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Kind is
      begin
         if Node = null then
            return No_Entity_Subp_Kind;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Kind) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Kind_Function
        (Node : Bare_Subp_Kind_Function; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Kind_Function is
      begin
         if Node = null then
            return No_Entity_Subp_Kind_Function;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Kind_Function) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Kind_Procedure
        (Node : Bare_Subp_Kind_Procedure; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Kind_Procedure is
      begin
         if Node = null then
            return No_Entity_Subp_Kind_Procedure;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Kind_Procedure) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Renaming_Decl
        (Node : Bare_Subp_Renaming_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Renaming_Decl is
      begin
         if Node = null then
            return No_Entity_Subp_Renaming_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Renaming_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subp_Spec
        (Node : Bare_Subp_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Subp_Spec is
      begin
         if Node = null then
            return No_Entity_Subp_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subp_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subtype_Decl
        (Node : Bare_Subtype_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Subtype_Decl is
      begin
         if Node = null then
            return No_Entity_Subtype_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subtype_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Subunit
        (Node : Bare_Subunit; Info : Internal_Entity_Info)
         return Internal_Entity_Subunit is
      begin
         if Node = null then
            return No_Entity_Subunit;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Subunit) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synchronized_Node
        (Node : Bare_Synchronized_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Synchronized_Node is
      begin
         if Node = null then
            return No_Entity_Synchronized_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synchronized_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synchronized_Absent
        (Node : Bare_Synchronized_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Synchronized_Absent is
      begin
         if Node = null then
            return No_Entity_Synchronized_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synchronized_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synchronized_Present
        (Node : Bare_Synchronized_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Synchronized_Present is
      begin
         if Node = null then
            return No_Entity_Synchronized_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synchronized_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synth_Anonymous_Type_Decl
        (Node : Bare_Synth_Anonymous_Type_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Synth_Anonymous_Type_Decl is
      begin
         if Node = null then
            return No_Entity_Synth_Anonymous_Type_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synth_Anonymous_Type_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Binary_Spec
        (Node : Bare_Synthetic_Binary_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Binary_Spec is
      begin
         if Node = null then
            return No_Entity_Synthetic_Binary_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Binary_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Char_Enum_Lit
        (Node : Bare_Synthetic_Char_Enum_Lit; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Char_Enum_Lit is
      begin
         if Node = null then
            return No_Entity_Synthetic_Char_Enum_Lit;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Char_Enum_Lit) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Defining_Name
        (Node : Bare_Synthetic_Defining_Name; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Defining_Name is
      begin
         if Node = null then
            return No_Entity_Synthetic_Defining_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Defining_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Formal_Param_Decl
        (Node : Bare_Synthetic_Formal_Param_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Formal_Param_Decl is
      begin
         if Node = null then
            return No_Entity_Synthetic_Formal_Param_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Formal_Param_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Identifier
        (Node : Bare_Synthetic_Identifier; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Identifier is
      begin
         if Node = null then
            return No_Entity_Synthetic_Identifier;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Identifier) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Renaming_Clause
        (Node : Bare_Synthetic_Renaming_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Renaming_Clause is
      begin
         if Node = null then
            return No_Entity_Synthetic_Renaming_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Renaming_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Subp_Decl
        (Node : Bare_Synthetic_Subp_Decl; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Subp_Decl is
      begin
         if Node = null then
            return No_Entity_Synthetic_Subp_Decl;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Subp_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Type_Expr
        (Node : Bare_Synthetic_Type_Expr; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Type_Expr is
      begin
         if Node = null then
            return No_Entity_Synthetic_Type_Expr;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Type_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Synthetic_Unary_Spec
        (Node : Bare_Synthetic_Unary_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_Synthetic_Unary_Spec is
      begin
         if Node = null then
            return No_Entity_Synthetic_Unary_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Synthetic_Unary_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Tagged_Node
        (Node : Bare_Tagged_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Tagged_Node is
      begin
         if Node = null then
            return No_Entity_Tagged_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Tagged_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Tagged_Absent
        (Node : Bare_Tagged_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Tagged_Absent is
      begin
         if Node = null then
            return No_Entity_Tagged_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Tagged_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Tagged_Present
        (Node : Bare_Tagged_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Tagged_Present is
      begin
         if Node = null then
            return No_Entity_Tagged_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Tagged_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Target_Name
        (Node : Bare_Target_Name; Info : Internal_Entity_Info)
         return Internal_Entity_Target_Name is
      begin
         if Node = null then
            return No_Entity_Target_Name;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Target_Name) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Task_Body
        (Node : Bare_Task_Body; Info : Internal_Entity_Info)
         return Internal_Entity_Task_Body is
      begin
         if Node = null then
            return No_Entity_Task_Body;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Task_Body) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Task_Body_Stub
        (Node : Bare_Task_Body_Stub; Info : Internal_Entity_Info)
         return Internal_Entity_Task_Body_Stub is
      begin
         if Node = null then
            return No_Entity_Task_Body_Stub;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Task_Body_Stub) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Task_Def
        (Node : Bare_Task_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Task_Def is
      begin
         if Node = null then
            return No_Entity_Task_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Task_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Terminate_Alternative
        (Node : Bare_Terminate_Alternative; Info : Internal_Entity_Info)
         return Internal_Entity_Terminate_Alternative is
      begin
         if Node = null then
            return No_Entity_Terminate_Alternative;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Terminate_Alternative) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Type_Access_Def
        (Node : Bare_Type_Access_Def; Info : Internal_Entity_Info)
         return Internal_Entity_Type_Access_Def is
      begin
         if Node = null then
            return No_Entity_Type_Access_Def;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Type_Access_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Type_Attributes_Repository
        (Node : Bare_Type_Attributes_Repository; Info : Internal_Entity_Info)
         return Internal_Entity_Type_Attributes_Repository is
      begin
         if Node = null then
            return No_Entity_Type_Attributes_Repository;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Type_Attributes_Repository) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Un_Op
        (Node : Bare_Un_Op; Info : Internal_Entity_Info)
         return Internal_Entity_Un_Op is
      begin
         if Node = null then
            return No_Entity_Un_Op;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Un_Op) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Unconstrained_Array_Index
        (Node : Bare_Unconstrained_Array_Index; Info : Internal_Entity_Info)
         return Internal_Entity_Unconstrained_Array_Index is
      begin
         if Node = null then
            return No_Entity_Unconstrained_Array_Index;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Unconstrained_Array_Index) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Unconstrained_Array_Index_List
        (Node : Bare_Unconstrained_Array_Index_List; Info : Internal_Entity_Info)
         return Internal_Entity_Unconstrained_Array_Index_List is
      begin
         if Node = null then
            return No_Entity_Unconstrained_Array_Index_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Unconstrained_Array_Index_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Unconstrained_Array_Indices
        (Node : Bare_Unconstrained_Array_Indices; Info : Internal_Entity_Info)
         return Internal_Entity_Unconstrained_Array_Indices is
      begin
         if Node = null then
            return No_Entity_Unconstrained_Array_Indices;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Unconstrained_Array_Indices) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Unknown_Discriminant_Part
        (Node : Bare_Unknown_Discriminant_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Unknown_Discriminant_Part is
      begin
         if Node = null then
            return No_Entity_Unknown_Discriminant_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Unknown_Discriminant_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Until_Node
        (Node : Bare_Until_Node; Info : Internal_Entity_Info)
         return Internal_Entity_Until_Node is
      begin
         if Node = null then
            return No_Entity_Until_Node;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Until_Node) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Until_Absent
        (Node : Bare_Until_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_Until_Absent is
      begin
         if Node = null then
            return No_Entity_Until_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Until_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Until_Present
        (Node : Bare_Until_Present; Info : Internal_Entity_Info)
         return Internal_Entity_Until_Present is
      begin
         if Node = null then
            return No_Entity_Until_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Until_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Update_Attribute_Ref
        (Node : Bare_Update_Attribute_Ref; Info : Internal_Entity_Info)
         return Internal_Entity_Update_Attribute_Ref is
      begin
         if Node = null then
            return No_Entity_Update_Attribute_Ref;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Update_Attribute_Ref) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Use_Clause
        (Node : Bare_Use_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Use_Clause is
      begin
         if Node = null then
            return No_Entity_Use_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Use_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Use_Package_Clause
        (Node : Bare_Use_Package_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Use_Package_Clause is
      begin
         if Node = null then
            return No_Entity_Use_Package_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Use_Package_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Use_Type_Clause
        (Node : Bare_Use_Type_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_Use_Type_Clause is
      begin
         if Node = null then
            return No_Entity_Use_Type_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Use_Type_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Value_Sequence
        (Node : Bare_Value_Sequence; Info : Internal_Entity_Info)
         return Internal_Entity_Value_Sequence is
      begin
         if Node = null then
            return No_Entity_Value_Sequence;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Value_Sequence) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Variant
        (Node : Bare_Variant; Info : Internal_Entity_Info)
         return Internal_Entity_Variant is
      begin
         if Node = null then
            return No_Entity_Variant;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Variant) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Variant_List
        (Node : Bare_Variant_List; Info : Internal_Entity_Info)
         return Internal_Entity_Variant_List is
      begin
         if Node = null then
            return No_Entity_Variant_List;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Variant_List) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_Variant_Part
        (Node : Bare_Variant_Part; Info : Internal_Entity_Info)
         return Internal_Entity_Variant_Part is
      begin
         if Node = null then
            return No_Entity_Variant_Part;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_Variant_Part) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_While_Loop_Spec
        (Node : Bare_While_Loop_Spec; Info : Internal_Entity_Info)
         return Internal_Entity_While_Loop_Spec is
      begin
         if Node = null then
            return No_Entity_While_Loop_Spec;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_While_Loop_Spec) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_While_Loop_Stmt
        (Node : Bare_While_Loop_Stmt; Info : Internal_Entity_Info)
         return Internal_Entity_While_Loop_Stmt is
      begin
         if Node = null then
            return No_Entity_While_Loop_Stmt;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_While_Loop_Stmt) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_With_Clause
        (Node : Bare_With_Clause; Info : Internal_Entity_Info)
         return Internal_Entity_With_Clause is
      begin
         if Node = null then
            return No_Entity_With_Clause;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_With_Clause) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_With_Private
        (Node : Bare_With_Private; Info : Internal_Entity_Info)
         return Internal_Entity_With_Private is
      begin
         if Node = null then
            return No_Entity_With_Private;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_With_Private) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_With_Private_Absent
        (Node : Bare_With_Private_Absent; Info : Internal_Entity_Info)
         return Internal_Entity_With_Private_Absent is
      begin
         if Node = null then
            return No_Entity_With_Private_Absent;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_With_Private_Absent) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      function Create_Internal_Entity_With_Private_Present
        (Node : Bare_With_Private_Present; Info : Internal_Entity_Info)
         return Internal_Entity_With_Private_Present is
      begin
         if Node = null then
            return No_Entity_With_Private_Present;
         end if;
         return (Node => Node, Info => Info);
      end;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Entity_With_Private_Present) return String is
         pragma Warnings (On, "referenced");
      begin
            return Image (Entity'(Node => R.Node, Info => R.Info));
      end Trace_Image;
      -------------
      -- Inc_Ref --
      -------------
      procedure Inc_Ref (R : Internal_Env_Assoc) is
      begin
               Inc_Ref (R.Dest_Env);
      end Inc_Ref;
      -------------
      -- Dec_Ref --
      -------------
      procedure Dec_Ref (R : in out Internal_Env_Assoc) is
      begin
               Dec_Ref (R.Dest_Env);
      end Dec_Ref;
      ----------------
      -- Equivalent --
      ----------------
      function Equivalent (L, R : Internal_Env_Assoc) return Boolean is
      begin
         return L.Key = R.Key and then L.Value = R.Value and then Equivalent (L.Dest_Env, R.Dest_Env) and then L.Metadata = R.Metadata;
      end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Env_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Key => " & Trace_Image (R.Key)
                        & ", "
                     & "Value => " & Trace_Image (R.Value)
                        & ", "
                     & "Dest_Env => " & Trace_Image (R.Dest_Env)
                        & ", "
                     & "Metadata => " & Trace_Image (R.Metadata)
               & ")");
      end Trace_Image;
      -------------
      -- Inc_Ref --
      -------------
      procedure Inc_Ref (R : Internal_Eval_Discrete_Range) is
      begin
               Inc_Ref (R.Low_Bound);
               Inc_Ref (R.High_Bound);
      end Inc_Ref;
      -------------
      -- Dec_Ref --
      -------------
      procedure Dec_Ref (R : in out Internal_Eval_Discrete_Range) is
      begin
               Dec_Ref (R.Low_Bound);
               Dec_Ref (R.High_Bound);
      end Dec_Ref;
      ----------------
      -- Equivalent --
      ----------------
      function Equivalent (L, R : Internal_Eval_Discrete_Range) return Boolean is
      begin
         return Equivalent (L.Low_Bound, R.Low_Bound) and then Equivalent (L.High_Bound, R.High_Bound);
      end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Eval_Discrete_Range) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Low_Bound => " & Trace_Image (R.Low_Bound)
                        & ", "
                     & "High_Bound => " & Trace_Image (R.High_Bound)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Expected_Type_For_Expr) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Expected_Type => " & Trace_Image (R.Expected_Type)
                        & ", "
                     & "Expr => " & Trace_Image (R.Expr)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Inner_Env_Assoc) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Key => " & Trace_Image (R.Key)
                        & ", "
                     & "Value => " & Trace_Image (R.Value)
                        & ", "
                     & "Metadata => " & Trace_Image (R.Metadata)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Logic_Val_Result) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Success => " & Trace_Image (R.Success)
                        & ", "
                     & "Value => " & Trace_Image (R.Value)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Multidim_Aggregate_Info) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Agg => " & Trace_Image (R.Agg)
                        & ", "
                     & "Typ => " & Trace_Image (R.Typ)
                        & ", "
                     & "Rank => " & Trace_Image (R.Rank)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Param_Actual) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Param => " & Trace_Image (R.Param)
                        & ", "
                     & "Actual => " & Trace_Image (R.Actual)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Single_Actual) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Name => " & Trace_Image (R.Name)
                        & ", "
                     & "Assoc => " & Trace_Image (R.Assoc)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Param_Match) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Has_Matched => " & Trace_Image (R.Has_Matched)
                        & ", "
                     & "Actual => " & Trace_Image (R.Actual)
                        & ", "
                     & "Formal => " & Trace_Image (R.Formal)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Ref_Result) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Ref => " & Trace_Image (R.Ref)
                        & ", "
                     & "Kind => " & Trace_Image (R.Kind)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Refd_Decl) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Decl => " & Trace_Image (R.Decl)
                        & ", "
                     & "Kind => " & Trace_Image (R.Kind)
               & ")");
      end Trace_Image;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Refd_Def) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Def_Name => " & Trace_Image (R.Def_Name)
                        & ", "
                     & "Kind => " & Trace_Image (R.Kind)
               & ")");
      end Trace_Image;
      -------------
      -- Inc_Ref --
      -------------
      procedure Inc_Ref (R : Internal_Shape) is
      begin
               Inc_Ref (R.Components);
               Inc_Ref (R.Discriminants_Values);
      end Inc_Ref;
      -------------
      -- Dec_Ref --
      -------------
      procedure Dec_Ref (R : in out Internal_Shape) is
      begin
               Dec_Ref (R.Components);
               Dec_Ref (R.Discriminants_Values);
      end Dec_Ref;
      ----------------
      -- Equivalent --
      ----------------
      function Equivalent (L, R : Internal_Shape) return Boolean is
      begin
         return Equivalent (L.Components, R.Components) and then Equivalent (L.Discriminants_Values, R.Discriminants_Values);
      end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Shape) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "Components => " & Trace_Image (R.Components)
                        & ", "
                     & "Discriminants_Values => " & Trace_Image (R.Discriminants_Values)
               & ")");
      end Trace_Image;
      -------------
      -- Inc_Ref --
      -------------
      procedure Inc_Ref (R : Internal_Substitution) is
      begin
               Inc_Ref (R.To_Value);
      end Inc_Ref;
      -------------
      -- Dec_Ref --
      -------------
      procedure Dec_Ref (R : in out Internal_Substitution) is
      begin
               Dec_Ref (R.To_Value);
      end Dec_Ref;
      ----------------
      -- Equivalent --
      ----------------
      function Equivalent (L, R : Internal_Substitution) return Boolean is
      begin
         return L.From_Decl = R.From_Decl and then Equivalent (L.To_Value, R.To_Value) and then L.Value_Type = R.Value_Type;
      end Equivalent;
      -----------------
      -- Trace_Image --
      -----------------
      pragma Warnings (Off, "referenced");
      function Trace_Image (R : Internal_Substitution) return String is
         pragma Warnings (On, "referenced");
      begin
            return
              ("("
                     & "From_Decl => " & Trace_Image (R.From_Decl)
                        & ", "
                     & "To_Value => " & Trace_Image (R.To_Value)
                        & ", "
                     & "Value_Type => " & Trace_Image (R.Value_Type)
               & ")");
      end Trace_Image;
   type Ada_Node_P_Is_Not_Null_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Ada_Node_P_Is_Not_Null_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Ada_Node_P_Is_Not_Null_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Ada_Node_P_Is_Not_Null_0_Predicate);
   function Create_Ada_Node_P_Is_Not_Null_0_Predicate
      return Ada_Node_P_Is_Not_Null_0_Predicate is
   begin
      return Ada_Node_P_Is_Not_Null_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Ada_Node_P_Is_Not_Null_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
         pragma Unreferenced (Self);
      Node : constant Bare_Ada_Node := Entity.Node;
   begin
      return Ada_Node_P_Is_Not_Null (Node, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Ada_Node_P_Is_Not_Null_0_Predicate) return String is
   begin
      return "AdaNode.is_not_null";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Ada_Node_P_Is_Not_Null_0_Predicate) is
      begin
         null;
      end Destroy;
   type Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Internal_Entity_Basic_Decl;
   end record;
      overriding function Call
        (Self : Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate);
   function Create_Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate
   (
         Field_0 : Internal_Entity_Basic_Decl
   )
      return Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate is
   begin
      return Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Basic_Decl := Entity.Node;
   begin
      return Basic_Decl_P_Subp_Decl_Match_Signature (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate) return String is
   begin
      return "BasicDecl.subp_decl_match_signature";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate) is
      begin
         null;
      end Destroy;
   type Basic_Decl_P_Is_Subprogram_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Basic_Decl_P_Is_Subprogram_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Basic_Decl_P_Is_Subprogram_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Basic_Decl_P_Is_Subprogram_0_Predicate);
   function Create_Basic_Decl_P_Is_Subprogram_0_Predicate
      return Basic_Decl_P_Is_Subprogram_0_Predicate is
   begin
      return Basic_Decl_P_Is_Subprogram_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Basic_Decl_P_Is_Subprogram_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
         pragma Unreferenced (Self);
      Node : constant Bare_Basic_Decl := Entity.Node;
   begin
      return Basic_Decl_P_Is_Subprogram (Node);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Basic_Decl_P_Is_Subprogram_0_Predicate) return String is
   begin
      return "BasicDecl.is_subprogram";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Basic_Decl_P_Is_Subprogram_0_Predicate) is
      begin
         null;
      end Destroy;
   type Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Internal_Entity_Base_Type_Decl;
         Field_1 : Boolean;
   end record;
      overriding function Call
        (Self : Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate);
   function Create_Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate
   (
         Field_0 : Internal_Entity_Base_Type_Decl;
         Field_1 : Boolean
   )
      return Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate is
   begin
      return Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0, Field_1 => Field_1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Basic_Decl := Entity.Node;
   begin
      return Basic_Decl_P_Is_Stream_Subprogram_For_Type (Node, Self.Field_0, Self.Field_1, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate) return String is
   begin
      return "BasicDecl.is_stream_subprogram_for_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Internal_Entity_Base_Type_Decl;
   end record;
      overriding function Call
        (Self : Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate);
   function Create_Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate
   (
         Field_0 : Internal_Entity_Base_Type_Decl
   )
      return Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate is
   begin
      return Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Basic_Decl := Entity.Node;
   begin
      return Basic_Decl_P_Is_Put_Image_Subprogram_For_Type (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate) return String is
   begin
      return "BasicDecl.is_put_image_subprogram_for_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Array_Or_Rec (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_array_or_rec";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Task_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Task_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Task_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Task_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Task_Type_0_Predicate
      return Base_Type_Decl_P_Is_Task_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Task_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Task_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
         pragma Unreferenced (Self);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Dispatcher_Base_Type_Decl_P_Is_Task_Type (Node);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Task_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_task_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Task_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_One_Non_Universal_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_One_Non_Universal_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_One_Non_Universal_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_One_Non_Universal_0_Predicate);
   function Create_Base_Type_Decl_P_One_Non_Universal_0_Predicate
      return Base_Type_Decl_P_One_Non_Universal_0_Predicate is
   begin
      return Base_Type_Decl_P_One_Non_Universal_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_One_Non_Universal_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         pragma Unreferenced (Self);
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_One_Non_Universal (Node, (Node => Entities (2).Node, Info => Entities (2).Info), E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_One_Non_Universal_0_Predicate) return String is
   begin
      return "BaseTypeDecl.one_non_universal";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_One_Non_Universal_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Non_Null_Char_Type (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_non_null_char_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Universal_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Universal_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Universal_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Universal_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Universal_Type_0_Predicate
      return Base_Type_Decl_P_Is_Universal_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Universal_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Universal_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
         pragma Unreferenced (Self);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Universal_Type (Node, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Universal_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_universal_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Universal_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate
      return Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
         pragma Unreferenced (Self);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Not_Universal_Type (Node, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_not_universal_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Access_Type_Predicate (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_access_type_predicate";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Iterator_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Iterator_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Iterator_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Iterator_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Iterator_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Iterator_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Iterator_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Iterator_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Iterator_Type (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Iterator_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_iterator_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Iterator_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Discrete_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Discrete_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Discrete_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Discrete_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Discrete_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Discrete_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Discrete_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Discrete_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Dispatcher_Base_Type_Decl_P_Is_Discrete_Type (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Discrete_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_discrete_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Discrete_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         null;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate
      return Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
         pragma Unreferenced (Self);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Not_Root_Int_Type (Node, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_not_root_int_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Allows_String_Literal_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Allows_String_Literal_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Allows_String_Literal_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Allows_String_Literal_0_Predicate);
   function Create_Base_Type_Decl_P_Allows_String_Literal_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Allows_String_Literal_0_Predicate is
   begin
      return Base_Type_Decl_P_Allows_String_Literal_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Allows_String_Literal_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Allows_String_Literal (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Allows_String_Literal_0_Predicate) return String is
   begin
      return "BaseTypeDecl.allows_string_literal";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Allows_String_Literal_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Subp_Access_Of (Node, (Node => Entities (2).Node, Info => Entities (2).Info), Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_subp_access_of";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Tagged_Type_With_Deref (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_tagged_type_with_deref";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Array_Def_With_Deref (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_array_def_with_deref";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate);
   function Create_Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate is
   begin
      return Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null (Node, Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate) return String is
   begin
      return "BaseTypeDecl.is_array_def_with_deref_or_null";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Matching_Prefix_Type (Node, (Node => Entities (2).Node, Info => Entities (2).Info), Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.matching_prefix_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Matching_Formal_Prim_Type (Node, (Node => Entities (2).Node, Info => Entities (2).Info), Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.matching_formal_prim_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Matching_Formal_Type_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Formal_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Matching_Formal_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Formal_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Matching_Formal_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Matching_Formal_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Matching_Formal_Type_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Formal_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Matching_Formal_Type (Node, (Node => Entities (2).Node, Info => Entities (2).Info), Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Matching_Formal_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.matching_formal_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Formal_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Matching_Assign_Type_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Assign_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Matching_Assign_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Assign_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Matching_Assign_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Matching_Assign_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Matching_Assign_Type_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Assign_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Matching_Assign_Type (Node, (Node => Entities (2).Node, Info => Entities (2).Info), Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Matching_Assign_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.matching_assign_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Assign_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Matching_Type_0_Predicate is
   new Solver_Ifc.N_Predicate_Type
   with record
         Field_0 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Matching_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Matching_Type_0_Predicate
   (
         Field_0 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Matching_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Matching_Type_0_Predicate'(N => 2, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Type_0_Predicate;
            Entities : Entity_Vars.Value_Array
        ) return Boolean
   is
         Entity : Internal_Entity := Entities (1);
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Matching_Type (Node, (Node => Entities (2).Node, Info => Entities (2).Info), Self.Field_0, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Matching_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.matching_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate is
   new Solver_Ifc.Predicate_Type
   with record
         Field_0 : Internal_Entity_Base_Type_Decl;
         Field_1 : Bare_Ada_Node;
   end record;
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   ;
   overriding function Image (Self : Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate) return String;
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate);
   function Create_Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate
   (
         Field_0 : Internal_Entity_Base_Type_Decl;
         Field_1 : Bare_Ada_Node
   )
      return Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate is
   begin
      return Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate'(Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Ref_Count => 1, Field_0 => Field_0, Field_1 => Field_1);
   end;
   ----------
   -- Call --
   ----------
      overriding function Call
        (Self : Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate;
            Entity : Internal_Entity
        ) return Boolean
   is
      Node : constant Bare_Base_Type_Decl := Entity.Node;
   begin
      return Base_Type_Decl_P_Matching_Allocator_Type (Node, Self.Field_0, Self.Field_1, E_Info => Entity.Info);
   end Call;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate) return String is
   begin
      return "BaseTypeDecl.matching_allocator_type";
   end Image;
      -------------
      -- Destroy --
      -------------
      overriding procedure Destroy (Self : in out Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate) is
      begin
         null;
      end Destroy;
   type Logic_Functor_656 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_656; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_656) return String;
   overriding function Convert (Self : Logic_Functor_656; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Accessed_Type_No_Call (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_656) return String is
   begin
      return ("BaseTypeDecl.accessed_type_no_call");
   end Image;
   type Logic_Functor_604 is new Solver_Ifc.Converter_Type with
      null record;
   overriding function Convert (Self : Logic_Functor_604; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_604) return String;
   overriding function Convert (Self : Logic_Functor_604; From : Internal_Entity) return Internal_Entity is
         pragma Unreferenced (Self);
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Anonymous_Access_Type_Or_Null (Node => From.Node, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_604) return String is
   begin
      return ("BaseTypeDecl.anonymous_access_type_or_null");
   end Image;
   type Logic_Functor_633 is new Solver_Ifc.Combiner_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Combine (Self : Logic_Functor_633; Vals : Entity_Vars.Value_Array) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_633) return String;
   overriding function Combine (Self : Logic_Functor_633; Vals : Entity_Vars.Value_Array) return Internal_Entity is
         From : constant Internal_Entity := Vals (1);
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for comb_prop");
            end if;
            if Vals (2).Node /= null
               and then Vals (2).Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for comb_prop");
            end if;
      Ret := Base_Type_Decl_P_Array_Concat_Result_Type (Node => From.Node, Other => (Node => Vals (2).Node,  Info => Vals (2).Info), Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Combine;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_633) return String is
   begin
      return ("BaseTypeDecl.array_concat_result_type");
   end Image;
   type Logic_Functor_602 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_602; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_602) return String;
   overriding function Convert (Self : Logic_Functor_602; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Base_Subtype (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_602) return String is
   begin
      return ("BaseTypeDecl.base_subtype");
   end Image;
   type Logic_Functor_672 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_672; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_672) return String;
   overriding function Convert (Self : Logic_Functor_672; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Comp_Type (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_672) return String is
   begin
      return ("BaseTypeDecl.comp_type");
   end Image;
   type Logic_Functor_697 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_697; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_697) return String;
   overriding function Convert (Self : Logic_Functor_697; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Basic_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Corresponding_Char_Literal (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_697) return String is
   begin
      return ("BaseTypeDecl.corresponding_char_literal");
   end Image;
   type Logic_Functor_630 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_630; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_630) return String;
   overriding function Convert (Self : Logic_Functor_630; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Derefed_Base_Subtype (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_630) return String is
   begin
      return ("BaseTypeDecl.derefed_base_subtype");
   end Image;
   type Logic_Functor_629 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_629; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_629) return String;
   overriding function Convert (Self : Logic_Functor_629; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Derefed_Type (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_629) return String is
   begin
      return ("BaseTypeDecl.derefed_type");
   end Image;
   type Logic_Functor_634 is new Solver_Ifc.Combiner_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Combine (Self : Logic_Functor_634; Vals : Entity_Vars.Value_Array) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_634) return String;
   overriding function Combine (Self : Logic_Functor_634; Vals : Entity_Vars.Value_Array) return Internal_Entity is
         From : constant Internal_Entity := Vals (1);
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for comb_prop");
            end if;
            if Vals (2).Node /= null
               and then Vals (2).Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for comb_prop");
            end if;
      Ret := Base_Type_Decl_P_Expected_Array_Concat_Operand_Type (Node => From.Node, Operand_Type => (Node => Vals (2).Node,  Info => Vals (2).Info), Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Combine;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_634) return String is
   begin
      return ("BaseTypeDecl.expected_array_concat_operand_type");
   end Image;
   type Logic_Functor_632 is new Solver_Ifc.Combiner_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Combine (Self : Logic_Functor_632; Vals : Entity_Vars.Value_Array) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_632) return String;
   overriding function Combine (Self : Logic_Functor_632; Vals : Entity_Vars.Value_Array) return Internal_Entity is
         From : constant Internal_Entity := Vals (1);
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for comb_prop");
            end if;
            if Vals (2).Node /= null
               and then Vals (2).Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for comb_prop");
            end if;
      Ret := Base_Type_Decl_P_Non_Universal_Base_Subtype (Node => From.Node, Second => (Node => Vals (2).Node,  Info => Vals (2).Info), Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Combine;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_632) return String is
   begin
      return ("BaseTypeDecl.non_universal_base_subtype");
   end Image;
   type Logic_Functor_639 is new Solver_Ifc.Converter_Type with
      null record;
   overriding function Convert (Self : Logic_Functor_639; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_639) return String;
   overriding function Convert (Self : Logic_Functor_639; From : Internal_Entity) return Internal_Entity is
         pragma Unreferenced (Self);
      Ret : Internal_Entity_Discrete_Base_Subtype_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Base_Type_Decl_P_Scalar_Base_Type (Node => From.Node, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_639) return String is
   begin
      return ("BaseTypeDecl.scalar_base_type");
   end Image;
   type Logic_Functor_208 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_208; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_208) return String;
   overriding function Convert (Self : Logic_Functor_208; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Basic_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Basic_Decl_P_Identity_Type (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_208) return String is
   begin
      return ("BasicDecl.identity_type");
   end Image;
   type Logic_Functor_213 is new Solver_Ifc.Converter_Type with
      null record;
   overriding function Convert (Self : Logic_Functor_213; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_213) return String;
   overriding function Convert (Self : Logic_Functor_213; From : Internal_Entity) return Internal_Entity is
         pragma Unreferenced (Self);
      Ret : Internal_Entity_Base_Subp_Spec;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Basic_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Basic_Decl_P_Subp_Spec_Or_Null (Node => From.Node, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_213) return String is
   begin
      return ("BasicDecl.subp_spec_or_null");
   end Image;
   type Logic_Functor_638 is new Solver_Ifc.Converter_Type with
      null record;
   overriding function Convert (Self : Logic_Functor_638; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_638) return String;
   overriding function Convert (Self : Logic_Functor_638; From : Internal_Entity) return Internal_Entity is
         pragma Unreferenced (Self);
      Ret : Internal_Entity_Classwide_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Base_Type_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => From.Node, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_638) return String is
   begin
      return ("BaseTypeDecl.classwide_type");
   end Image;
   type Logic_Functor_211 is new Solver_Ifc.Converter_Type with
      record
            Origin : Bare_Ada_Node;
      end record;
   overriding function Convert (Self : Logic_Functor_211; From : Internal_Entity) return Internal_Entity with Inline;
   overriding function Image (Self : Logic_Functor_211) return String;
   overriding function Convert (Self : Logic_Functor_211; From : Internal_Entity) return Internal_Entity is
      Ret : Internal_Entity_Base_Type_Decl;
   begin
            if From.Node /= null
               and then From.Node.Kind not in Ada_Basic_Decl
            then
               Raise_Property_Exception
                 (From.Node,
                  Property_Error'Identity,
                  "mismatching node type for conv_prop");
            end if;
      Ret := Dispatcher_Basic_Decl_P_Expr_Type (Node => From.Node, Origin => Self.Origin, E_Info => From.Info);
      return (Node => Ret.Node, Info => Ret.Info);
   end Convert;
   -----------
   -- Image --
   -----------
   overriding function Image (Self : Logic_Functor_211) return String is
   begin
      return ("BasicDecl.expr_type");
   end Image;
   --
   --  Primitives for Bare_Ada_Node
   --
--# property-start AdaNode.declarative_scope /tmp/lal-23.0.0/ada/ast.py:128
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Declarative_Scope
  (Node : Bare_Ada_Node
  )
   return Bare_Declarative_Part
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Declarative_Part;
            procedure Finalizer_Scope_2 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Declarative_Part;
            procedure Finalizer_Scope_2 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_2;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4 '<Cast to DeclarativePart at ast.py:131>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:131
--# expr-start 3 '<Find at ast.py:129>' Find_Result /tmp/lal-23.0.0/ada/ast.py:129
   --# expr-start 1 '<FieldAccess for parents at ast.py:129>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:129
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 1
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_0 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_0
      --# expr-start 2 '<IsA DeclarativePart at ast.py:130>' Is_A /tmp/lal-23.0.0/ada/ast.py:130
Is_A := Item_0 /= null 
and then Item_0.Kind in Ada_Declarative_Part_Range; 
--# expr-done 2
      if Is_A then
         Find_Result := Item_0;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 3
   if Find_Result = null
      or else Find_Result.Kind in Ada_Declarative_Part_Range
   then
      Cast_Result := Find_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 4
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_2;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Declarative_Scope;
--# end
--# property-start AdaNode.owning_unit_kind /tmp/lal-23.0.0/ada/ast.py:138
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Owning_Unit_Kind
  (Node : Bare_Ada_Node
  )
   return Analysis_Unit_Kind
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Analysis_Unit_Kind;
      Fld : Internal_Unit;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_2 : Analysis_Unit_Kind;
Let_Result : Analysis_Unit_Kind;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8 '<FieldAccess for unit_kind at ast.py:142>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:142
--# expr-start 7 '<Cast to CompilationUnit at ast.py:142>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:142
--# expr-start 6 '<FieldAccess for root at ast.py:142>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:142
--# expr-start 5 '<FieldAccess for unit at ast.py:142>' Fld /tmp/lal-23.0.0/ada/ast.py:142
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 5
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Ast_Root;
--# expr-done 6
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Fld_1;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 7
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.unit_kind
Fld_2 := Libadalang.Implementation.Compilation_Unit_P_Unit_Kind (Node => Cast_Result);
--# end
--# expr-done 8
Let_Result := Fld_2; 
--# end
--# expr-done 9
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Owning_Unit_Kind;
--# end
--# property-start AdaNode.withed_unit_helper /tmp/lal-23.0.0/ada/ast.py:145
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Withed_Unit_Helper
  (Node : Bare_Ada_Node
      ; Unit_Name : Bare_Name
  )
   return Bare_Compilation_Unit
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind unit_name Unit_Name
   Property_Result : Bare_Compilation_Unit;
            procedure Finalizer_Scope_4 with Inline_Always;
      Block_Var : Symbol_Type_Array_Access;
Block_Var_1 : Bare_Compilation_Unit;
Block_Var_2 : Bare_Compilation_Unit;
Block_Var_3 : Bare_Compilation_Unit;
Var_Expr : Bare_Compilation_Unit;
Var_Expr_1 : Bare_Compilation_Unit;
Fld : Symbol_Type_Array_Access;
Fld_1 : Bare_Compilation_Unit;
Fld_2 : Bare_Compilation_Unit;
Is_Null : Boolean;
If_Result : Bare_Compilation_Unit;
Fld_3 : Bare_Compilation_Unit;
Fld_4 : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Result_Var : Bare_Basic_Decl;
Is_A : Boolean;
Is_Null_1 : Boolean;
If_Result_1 : Boolean;
Is_Null_2 : Boolean;
Is_Null_3 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Bare_Compilation_Unit;
Scope_Result_1 : Bare_Compilation_Unit;
Result_Var_1 : Bare_Compilation_Unit;
Let_Result : Bare_Compilation_Unit;
            procedure Finalizer_Scope_4 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_4;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 22 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10 '<FieldAccess for as_symbol_array at ast.py:156>' Fld /tmp/lal-23.0.0/ada/ast.py:156
      if Unit_Name = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Unit_Name);
--# end
--# expr-done 10
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind unit_name_array Block_Var
--# expr-start 11 '<FieldAccess for designated_compilation_unit at ast.py:157>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:157
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.designated_compilation_unit
Fld_1 := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Block_Var, Kind => Unit_Specification, Not_Found_Is_Error => False);
--# end
--# expr-done 11
Block_Var_1 := Fld_1; 
--# bind spec Block_Var_1
--# expr-start 14 '<If at ast.py:162>' If_Result /tmp/lal-23.0.0/ada/ast.py:162
--# expr-start 12 '<IsNull at ast.py:163>' Is_Null /tmp/lal-23.0.0/ada/ast.py:163
Is_Null := Block_Var_1 = null; 
--# expr-done 12
if Is_Null then
   --# expr-start 13 '<FieldAccess for designated_compilation_unit at ast.py:164>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:164
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.designated_compilation_unit
Fld_2 := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Block_Var, Kind => Unit_Body, Not_Found_Is_Error => False);
--# end
--# expr-done 13
   If_Result := Fld_2;
else
   If_Result := No_Bare_Ada_Node;
end if;
--# expr-done 14
Block_Var_2 := If_Result; 
--# bind body Block_Var_2
--# expr-start 21 '<If at ast.py:176>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:176
--# expr-start 16 '<IsA PackageBody at ast.py:177>' Is_A /tmp/lal-23.0.0/ada/ast.py:177
Var_Expr := Block_Var_2;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 15 '<FieldAccess for decl at ast.py:177>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:177
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_4 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr);
--# end
--# expr-done 15
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_A := Result_Var /= null 
and then Result_Var.Kind in Ada_Package_Body_Range; 
--# expr-done 16
if Is_A then
   --# expr-start 17 '<IsNull at ast.py:177>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:177
Is_Null_1 := Block_Var_1 = null; 
--# expr-done 17
   If_Result_1 := Is_Null_1;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_3 := True;
else
--# expr-start 18 '<IsNull at ast.py:178>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:178
Is_Null_2 := Block_Var_1 = null; 
--# expr-done 18
if Is_Null_2 then
   --# expr-start 19 '<IsNull at ast.py:178>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:178
Is_Null_3 := Block_Var_2 = null; 
--# expr-done 19
   If_Result_2 := Is_Null_3;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
if If_Result_3 then
   --# expr-start 20 '<FieldAccess for designated_compilation_unit at ast.py:180>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:180
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.designated_compilation_unit
Fld_3 := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Block_Var, Kind => Unit_Specification, Not_Found_Is_Error => True);
--# end
--# expr-done 20
   If_Result_4 := Fld_3;
else
   If_Result_4 := No_Bare_Ada_Node;
end if;
--# expr-done 21
Block_Var_3 := If_Result_4; 
Var_Expr_1 := Block_Var_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result_1 := Var_Expr_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Block_Var_2;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 22
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_4;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_4;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Withed_Unit_Helper;
--# end
--# property-start '[dispatcher]AdaNode.custom_id_text' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Custom_Id_Text
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : String_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_Signed_Int_Type_Def | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.custom_id_text
                  Property_Result := Ada_Node_P_Custom_Id_Text
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_State_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.custom_id_text
                  Property_Result := Basic_Decl_P_Custom_Id_Text
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type =>
                  --# property-call-start AnonymousType.custom_id_text
                  Property_Result := Anonymous_Type_P_Custom_Id_Text
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Lit_Synth_Type_Expr =>
                  --# property-call-start EnumLitSynthTypeExpr.custom_id_text
                  Property_Result := Enum_Lit_Synth_Type_Expr_P_Custom_Id_Text
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
                  --# property-call-start SubtypeIndication.custom_id_text
                  Property_Result := Subtype_Indication_P_Custom_Id_Text
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Custom_Id_Text;
--# end
--# property-start AdaNode.is_contract_aspect /tmp/lal-23.0.0/ada/ast.py:201
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Is_Contract_Aspect
  (Node : Bare_Ada_Node
      ; Name : Symbol_Type
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind name Name
   Property_Result : Boolean;
      Sym : Symbol_Type;
Is_Equal : Boolean;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_3 : Boolean;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_4 : Boolean;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_5 : Boolean;
Sym_7 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_6 : Boolean;
Sym_8 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_7 : Boolean;
Sym_9 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_8 : Boolean;
Sym_10 : Symbol_Type;
Is_Equal_10 : Boolean;
If_Result_9 : Boolean;
Sym_11 : Symbol_Type;
Is_Equal_11 : Boolean;
If_Result_10 : Boolean;
Sym_12 : Symbol_Type;
Is_Equal_12 : Boolean;
If_Result_11 : Boolean;
Sym_13 : Symbol_Type;
Is_Equal_13 : Boolean;
If_Result_12 : Boolean;
Sym_14 : Symbol_Type;
Is_Equal_14 : Boolean;
If_Result_13 : Boolean;
Sym_15 : Symbol_Type;
Is_Equal_15 : Boolean;
If_Result_14 : Boolean;
Sym_16 : Symbol_Type;
Is_Equal_16 : Boolean;
If_Result_15 : Boolean;
Sym_17 : Symbol_Type;
Is_Equal_17 : Boolean;
If_Result_16 : Boolean;
Sym_18 : Symbol_Type;
Is_Equal_18 : Boolean;
If_Result_17 : Boolean;
Sym_19 : Symbol_Type;
Is_Equal_19 : Boolean;
If_Result_18 : Boolean;
Sym_20 : Symbol_Type;
Is_Equal_20 : Boolean;
If_Result_19 : Boolean;
Sym_21 : Symbol_Type;
Is_Equal_21 : Boolean;
If_Result_20 : Boolean;
Sym_22 : Symbol_Type;
Is_Equal_22 : Boolean;
If_Result_21 : Boolean;
Sym_23 : Symbol_Type;
Is_Equal_23 : Boolean;
If_Result_22 : Boolean;
Sym_24 : Symbol_Type;
Is_Equal_24 : Boolean;
If_Result_23 : Boolean;
Sym_25 : Symbol_Type;
Is_Equal_25 : Boolean;
If_Result_24 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 75 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 24 '<Eq at ast.py:202>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 23 '<Symbol Pre at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre); 
--# expr-done 23
Is_Equal := Name = Sym; 
--# expr-done 24
if Is_Equal then
   If_Result := True;
else
   --# expr-start 26 '<Eq at ast.py:202>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 25 '<Symbol Pre'"'"'Class at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre_Class); 
--# expr-done 25
Is_Equal_1 := Name = Sym_1; 
--# expr-done 26
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 28 '<Eq at ast.py:202>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 27 '<Symbol Post at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post); 
--# expr-done 27
Is_Equal_2 := Name = Sym_2; 
--# expr-done 28
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 30 '<Eq at ast.py:202>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 29 '<Symbol Post'"'"'Class at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post_Class); 
--# expr-done 29
Is_Equal_3 := Name = Sym_3; 
--# expr-done 30
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 32 '<Eq at ast.py:202>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 31 '<Symbol Refined_Post at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Post); 
--# expr-done 31
Is_Equal_4 := Name = Sym_4; 
--# expr-done 32
   If_Result_3 := Is_Equal_4;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 34 '<Eq at ast.py:202>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 33 '<Symbol Precondition at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Precondition); 
--# expr-done 33
Is_Equal_5 := Name = Sym_5; 
--# expr-done 34
   If_Result_4 := Is_Equal_5;
end if;
if If_Result_4 then
   If_Result_5 := True;
else
   --# expr-start 36 '<Eq at ast.py:202>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 35 '<Symbol Postcondition at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Postcondition); 
--# expr-done 35
Is_Equal_6 := Name = Sym_6; 
--# expr-done 36
   If_Result_5 := Is_Equal_6;
end if;
if If_Result_5 then
   If_Result_6 := True;
else
   --# expr-start 38 '<Eq at ast.py:202>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 37 '<Symbol Precondition'"'"'Class at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Precondition_Class); 
--# expr-done 37
Is_Equal_7 := Name = Sym_7; 
--# expr-done 38
   If_Result_6 := Is_Equal_7;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 40 '<Eq at ast.py:202>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 39 '<Symbol Postcondition'"'"'Class at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Postcondition_Class); 
--# expr-done 39
Is_Equal_8 := Name = Sym_8; 
--# expr-done 40
   If_Result_7 := Is_Equal_8;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 42 '<Eq at ast.py:202>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 41 '<Symbol Invariant at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Invariant); 
--# expr-done 41
Is_Equal_9 := Name = Sym_9; 
--# expr-done 42
   If_Result_8 := Is_Equal_9;
end if;
if If_Result_8 then
   If_Result_9 := True;
else
   --# expr-start 44 '<Eq at ast.py:202>' Is_Equal_10 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 43 '<Symbol Invariant'"'"'Class at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Invariant_Class); 
--# expr-done 43
Is_Equal_10 := Name = Sym_10; 
--# expr-done 44
   If_Result_9 := Is_Equal_10;
end if;
if If_Result_9 then
   If_Result_10 := True;
else
   --# expr-start 46 '<Eq at ast.py:202>' Is_Equal_11 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 45 '<Symbol Type_Invariant at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Type_Invariant); 
--# expr-done 45
Is_Equal_11 := Name = Sym_11; 
--# expr-done 46
   If_Result_10 := Is_Equal_11;
end if;
if If_Result_10 then
   If_Result_11 := True;
else
   --# expr-start 48 '<Eq at ast.py:202>' Is_Equal_12 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 47 '<Symbol Type_Invariant'"'"'Class at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Type_Invariant_Class); 
--# expr-done 47
Is_Equal_12 := Name = Sym_12; 
--# expr-done 48
   If_Result_11 := Is_Equal_12;
end if;
if If_Result_11 then
   If_Result_12 := True;
else
   --# expr-start 50 '<Eq at ast.py:202>' Is_Equal_13 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 49 '<Symbol Predicate at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Predicate); 
--# expr-done 49
Is_Equal_13 := Name = Sym_13; 
--# expr-done 50
   If_Result_12 := Is_Equal_13;
end if;
if If_Result_12 then
   If_Result_13 := True;
else
   --# expr-start 52 '<Eq at ast.py:202>' Is_Equal_14 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 51 '<Symbol Static_Predicate at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Static_Predicate); 
--# expr-done 51
Is_Equal_14 := Name = Sym_14; 
--# expr-done 52
   If_Result_13 := Is_Equal_14;
end if;
if If_Result_13 then
   If_Result_14 := True;
else
   --# expr-start 54 '<Eq at ast.py:202>' Is_Equal_15 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 53 '<Symbol Dynamic_Predicate at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Dynamic_Predicate); 
--# expr-done 53
Is_Equal_15 := Name = Sym_15; 
--# expr-done 54
   If_Result_14 := Is_Equal_15;
end if;
if If_Result_14 then
   If_Result_15 := True;
else
   --# expr-start 56 '<Eq at ast.py:202>' Is_Equal_16 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 55 '<Symbol Default_Initial_Condition at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Default_Initial_Condition); 
--# expr-done 55
Is_Equal_16 := Name = Sym_16; 
--# expr-done 56
   If_Result_15 := Is_Equal_16;
end if;
if If_Result_15 then
   If_Result_16 := True;
else
   --# expr-start 58 '<Eq at ast.py:202>' Is_Equal_17 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 57 '<Symbol Contract_Cases at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 57
Is_Equal_17 := Name = Sym_17; 
--# expr-done 58
   If_Result_16 := Is_Equal_17;
end if;
if If_Result_16 then
   If_Result_17 := True;
else
   --# expr-start 60 '<Eq at ast.py:202>' Is_Equal_18 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 59 '<Symbol Test_Case at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Test_Case); 
--# expr-done 59
Is_Equal_18 := Name = Sym_18; 
--# expr-done 60
   If_Result_17 := Is_Equal_18;
end if;
if If_Result_17 then
   If_Result_18 := True;
else
   --# expr-start 62 '<Eq at ast.py:202>' Is_Equal_19 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 61 '<Symbol Global at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Global); 
--# expr-done 61
Is_Equal_19 := Name = Sym_19; 
--# expr-done 62
   If_Result_18 := Is_Equal_19;
end if;
if If_Result_18 then
   If_Result_19 := True;
else
   --# expr-start 64 '<Eq at ast.py:202>' Is_Equal_20 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 63 '<Symbol Refined_Global at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Global); 
--# expr-done 63
Is_Equal_20 := Name = Sym_20; 
--# expr-done 64
   If_Result_19 := Is_Equal_20;
end if;
if If_Result_19 then
   If_Result_20 := True;
else
   --# expr-start 66 '<Eq at ast.py:202>' Is_Equal_21 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 65 '<Symbol Refined_State at ???>' Sym_21 None
Sym_21 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_State); 
--# expr-done 65
Is_Equal_21 := Name = Sym_21; 
--# expr-done 66
   If_Result_20 := Is_Equal_21;
end if;
if If_Result_20 then
   If_Result_21 := True;
else
   --# expr-start 68 '<Eq at ast.py:202>' Is_Equal_22 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 67 '<Symbol Stable_Properties at ???>' Sym_22 None
Sym_22 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Stable_Properties); 
--# expr-done 67
Is_Equal_22 := Name = Sym_22; 
--# expr-done 68
   If_Result_21 := Is_Equal_22;
end if;
if If_Result_21 then
   If_Result_22 := True;
else
   --# expr-start 70 '<Eq at ast.py:202>' Is_Equal_23 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 69 '<Symbol Depends at ???>' Sym_23 None
Sym_23 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Depends); 
--# expr-done 69
Is_Equal_23 := Name = Sym_23; 
--# expr-done 70
   If_Result_22 := Is_Equal_23;
end if;
if If_Result_22 then
   If_Result_23 := True;
else
   --# expr-start 72 '<Eq at ast.py:202>' Is_Equal_24 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 71 '<Symbol Refined_Depends at ???>' Sym_24 None
Sym_24 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Depends); 
--# expr-done 71
Is_Equal_24 := Name = Sym_24; 
--# expr-done 72
   If_Result_23 := Is_Equal_24;
end if;
if If_Result_23 then
   If_Result_24 := True;
else
   --# expr-start 74 '<Eq at ast.py:202>' Is_Equal_25 /tmp/lal-23.0.0/ada/ast.py:202
--# expr-start 73 '<Symbol Predicate_Failure at ???>' Sym_25 None
Sym_25 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Predicate_Failure); 
--# expr-done 73
Is_Equal_25 := Name = Sym_25; 
--# expr-done 74
   If_Result_24 := Is_Equal_25;
end if;
Let_Result := If_Result_24; 
--# end
--# expr-done 75
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Is_Contract_Aspect;
--# end
--# property-start AdaNode.in_contract /tmp/lal-23.0.0/ada/ast.py:216
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_In_Contract
  (Node : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
            procedure Finalizer_Scope_7 with Inline_Always;
      Var_Expr : Boolean;
Var_Expr_1 : Bare_Aspect_Assoc;
Var_Expr_2 : Bare_Pragma_Node;
Node_Parents : Bare_Ada_Node_Array_Access;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Aspect_Assoc;
Fld : Bare_Name;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_1 : Symbol_Type;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Scope_Result_1 : Boolean;
Cast_Expr_1 : Bare_Ada_Node;
Cast_Result_1 : Bare_Pragma_Node;
Fld_3 : Bare_Identifier;
As_Entity_1 : Internal_Entity_Identifier;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Identifier;
Fld_4 : Symbol_Type;
Fld_5 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_1 : Boolean;
Result_Var_2 : Boolean;
Find_Result : Bare_Ada_Node;
Is_Null_2 : Boolean;
Not_Val : Boolean;
            procedure Finalizer_Scope_7 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_7;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 89 '<Not at ast.py:216>' Not_Val /tmp/lal-23.0.0/ada/ast.py:216
--# expr-start 88 '<IsNull at ast.py:222>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:222
--# expr-start 87 '<Find at ast.py:216>' Find_Result /tmp/lal-23.0.0/ada/ast.py:216
   --# expr-start 76 '<FieldAccess for parents at ast.py:216>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:216
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 76
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_1 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_1
--# expr-start 77 '<Cast to AspectAssoc at ast.py:217>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:217
Cast_Expr := Item_1; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Aspect_Assoc_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 77
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind a Var_Expr_1
--# expr-start 81 '<FieldAccess for is_contract_aspect at ast.py:218>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:218
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 80 '<FieldAccess for name_symbol at ast.py:218>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:218
--# expr-start 79 '<as_bare_entity at ast.py:218>' If_Result /tmp/lal-23.0.0/ada/ast.py:218
--# expr-start 78 '<FieldAccess for id at ast.py:218>' Fld /tmp/lal-23.0.0/ada/ast.py:218
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Var_Expr_1.Aspect_Assoc_F_Id;
--# expr-done 78
Is_Null := Fld = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
As_Entity := (Info => No_Entity_Info, Node => Fld); 
   If_Result := As_Entity;
end if;
--# expr-done 79
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => If_Result.Node);
--# end
--# expr-done 80
--# property-call-start AdaNode.is_contract_aspect
Fld_2 := Libadalang.Implementation.Ada_Node_P_Is_Contract_Aspect (Node => Self, Name => Fld_1);
--# end
--# expr-done 81
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Var_Expr := Result_Var;
if Var_Expr /= False then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_1 := Var_Expr;
   --# end
   Result_Var_2 := Scope_Result_1;
else
--# expr-start 82 '<Cast to Pragma at ast.py:219>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:219
Cast_Expr_1 := Item_1; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Pragma_Node_Range
   then
      Cast_Result_1 := Cast_Expr_1;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 82
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind p Var_Expr_2
--# expr-start 86 '<FieldAccess for is_contract_aspect at ast.py:220>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:220
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 85 '<FieldAccess for name_symbol at ast.py:220>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:220
--# expr-start 84 '<as_bare_entity at ast.py:220>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:220
--# expr-start 83 '<FieldAccess for id at ast.py:220>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:220
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Var_Expr_2.Pragma_Node_F_Id;
--# expr-done 83
Is_Null_1 := Fld_3 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Identifier;
else
As_Entity_1 := (Info => No_Entity_Info, Node => Fld_3); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 84
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => If_Result_1.Node);
--# end
--# expr-done 85
--# property-call-start AdaNode.is_contract_aspect
Fld_5 := Libadalang.Implementation.Ada_Node_P_Is_Contract_Aspect (Node => Self, Name => Fld_4);
--# end
--# expr-done 86
Scope_Result_2 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_2;
else
   Result_Var_1 := False;
end if;
   Result_Var_2 := Result_Var_1;
end if;
      if Result_Var_2 then
         Find_Result := Item_1;
      end if;
   --# end
               exit when Result_Var_2;
         end loop;
      end;
--# expr-done 87
Is_Null_2 := Find_Result = null; 
--# expr-done 88
Not_Val := not (Is_Null_2); 
--# expr-done 89
      Property_Result := Not_Val;
   --# end
      Finalizer_Scope_7;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_7;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_In_Contract;
--# end
--# property-start AdaNode.in_aspect /tmp/lal-23.0.0/ada/ast.py:225
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_In_Aspect
  (Node : Bare_Ada_Node
      ; Name : Symbol_Type
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind name Name
   Property_Result : Boolean;
            procedure Finalizer_Scope_8 with Inline_Always;
      Var_Expr : Bare_Aspect_Assoc;
Node_Parents : Bare_Ada_Node_Array_Access;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Aspect_Assoc;
Fld : Bare_Name;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Quantifier_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_8 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_8;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 95 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 94 '<AnyQuantifier at ast.py:229>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:229
   --# expr-start 90 '<FieldAccess for parents at ast.py:229>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:229
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 90
      Quantifier_Result := False;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_2 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_2
--# expr-start 91 '<Cast to AspectAssoc at ast.py:230>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:230
Cast_Expr := Item_2; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Aspect_Assoc_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 91
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind a Var_Expr
--# expr-start 93 '<FieldAccess for name_is at ast.py:230>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:230
--# expr-start 92 '<FieldAccess for id at ast.py:230>' Fld /tmp/lal-23.0.0/ada/ast.py:230
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Var_Expr.Aspect_Assoc_F_Id;
--# expr-done 92
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_1 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld, Sym => Name);
--# end
--# expr-done 93
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      Quantifier_Result := Result_Var;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 94
Let_Result := Quantifier_Result; 
--# end
--# expr-done 95
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_8;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_8;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_In_Aspect;
--# end
--# property-start AdaNode.empty_env /tmp/lal-23.0.0/ada/ast.py:233
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Empty_Env
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_9 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_9 is
            begin
                     Dec_Ref (Node_Parents);
                     Dec_Ref (Fld);
            end Finalizer_Scope_9;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 100 '<FieldAccess for get_empty_env at ast.py:235>' Fld /tmp/lal-23.0.0/ada/ast.py:235
--# expr-start 99 '<Cast to CompilationUnit at ast.py:235>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:235
--# expr-start 98 '<Find at ast.py:234>' Find_Result /tmp/lal-23.0.0/ada/ast.py:234
   --# expr-start 96 '<FieldAccess for parents at ast.py:234>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:234
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 96
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_3 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_3
      --# expr-start 97 '<IsA CompilationUnit at ast.py:234>' Is_A /tmp/lal-23.0.0/ada/ast.py:234
Is_A := Item_3 /= null 
and then Item_3.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 97
      if Is_A then
         Find_Result := Item_3;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 98
   if Find_Result = null
      or else Find_Result.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Find_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 99
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Compilation_Unit_P_Get_Empty_Env (Node => Cast_Result);
--# expr-done 100
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_9;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_9;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Empty_Env;
--# end
--# property-start AdaNode.is_not_null /tmp/lal-23.0.0/ada/ast.py:239
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Is_Not_Null
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 103 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 102 '<Not at ast.py:247>' Not_Val /tmp/lal-23.0.0/ada/ast.py:247
--# expr-start 101 '<IsNull at ast.py:247>' Is_Null /tmp/lal-23.0.0/ada/ast.py:247
Is_Null := Ent.Node = null; 
--# expr-done 101
Not_Val := not (Is_Null); 
--# expr-done 102
Let_Result := Not_Val; 
--# end
--# expr-done 103
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Is_Not_Null;
--# end
--# property-start AdaNode.eval_discrete_range /tmp/lal-23.0.0/ada/ast.py:250
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Eval_Discrete_Range
  (Node : Bare_Ada_Node
      ; Dr : Internal_Discrete_Range
  )
   return Internal_Eval_Discrete_Range
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind dr Dr
   Property_Result : Internal_Eval_Discrete_Range;
            procedure Finalizer_Scope_11 with Inline_Always;
            procedure Finalizer_Scope_1743 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Expr;
Fld_1 : Big_Integer_Type;
Scope_Result : Big_Integer_Type;
Big_Int : Big_Integer_Type;
Result_Var : Big_Integer_Type;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Big_Integer_Type;
New_Struct : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
Is_Equal : Boolean;
If_Result : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
Let_Result : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
            procedure Finalizer_Scope_11 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Big_Int);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (New_Struct);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_11;
            procedure Finalizer_Scope_1743 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1743;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 112 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 111 '<If at ast.py:254>' If_Result /tmp/lal-23.0.0/ada/ast.py:254
--# expr-start 104 '<Eq at ast.py:255>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:255
Is_Equal := Dr = No_Discrete_Range; 
--# expr-done 104
if Is_Equal then
   If_Result := raise Property_Error with "Attempting to evaluate a null discrete range";
else
   --# expr-start 110 '<New EvalDiscreteRange at ast.py:260>' New_Struct /tmp/lal-23.0.0/ada/ast.py:260
--# expr-start 106 '<FieldAccess for eval_as_int at ast.py:265>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:265
--# expr-start 105 '<FieldAccess for high_bound at ast.py:265>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:265
Fld_2 := Dr.High_Bound;
--# expr-done 105
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_3 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 106
--# expr-start 107 '<FieldAccess for low_bound at ast.py:261>' Fld /tmp/lal-23.0.0/ada/ast.py:261
Fld := Dr.Low_Bound;
--# expr-done 107
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind lb Var_Expr
--# expr-start 108 '<FieldAccess for eval_as_int at ast.py:262>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:262
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_1 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 108
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1743;
   Result_Var := Scope_Result;
else
   --# expr-start 109 '<BigInteger 0 at ast.py:263>' Big_Int /tmp/lal-23.0.0/ada/ast.py:263
Big_Int := Create_Big_Integer ("0"); 
--# expr-done 109
   Result_Var := Big_Int;
end if;
      Inc_Ref (Result_Var);
Inc_Ref (Fld_3);
Inc_Ref (Result_Var);
New_Struct := (High_Bound => Fld_3, Low_Bound => Result_Var); 
--# expr-done 110
   If_Result := New_Struct;
end if;
      Inc_Ref (If_Result);
--# expr-done 111
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 112
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_11;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_11;
               Finalizer_Scope_1743;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Eval_Discrete_Range;
--# end
--# property-start AdaNode.sym_join /tmp/lal-23.0.0/ada/ast.py:270
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Sym_Join
  (Node : Bare_Ada_Node
      ; Syms : Symbol_Type_Array_Access
      ; Sep : String_Type
  )
   return String_Type
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind syms Syms
   --# bind sep Sep
   Property_Result : String_Type;
            procedure Finalizer_Scope_12 with Inline_Always;
            procedure Finalizer_Scope_1744 with Inline_Always;
      Fld : String_Type;
Map_Result : String_Type_Array_Access;
Join_Result : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_12 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Join_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_12;
            procedure Finalizer_Scope_1744 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1744;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 116 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 115 '<Join at ast.py:274>' Join_Result /tmp/lal-23.0.0/ada/ast.py:274
--# expr-start 114 '<Map at ast.py:274>' Map_Result /tmp/lal-23.0.0/ada/ast.py:274
      declare
         Map_Result_Vec : String_Type_Vectors.Vector;
      begin
      declare
         Collection : constant Symbol_Type_Array_Access := Syms;
      begin
         for Item_4 of
               Collection.Items
         loop
   --# scope-start
               --# bind s Item_4
      --# expr-start 113 '<FieldAccess for image at ast.py:274>' Fld /tmp/lal-23.0.0/ada/ast.py:274
      if Item_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Image (Self => Item_4);
--# expr-done 113
         declare
            Item_To_Append : constant String_Type := Fld;
         begin
               Inc_Ref (Item_To_Append);
            String_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1744;
         end loop;
      end;
         Map_Result := Create_String_Type_Array
           (Items_Count => Natural (String_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := String_Type_Vectors.Get
              (Map_Result_Vec,
               I + String_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         String_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 114
Join_Result := Join_Strings (Sep, Map_Result); 
--# expr-done 115
Let_Result := Join_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 116
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_12;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_12;
               Finalizer_Scope_1744;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Sym_Join;
--# end
--# property-start AdaNode.enclosing_compilation_unit /tmp/lal-23.0.0/ada/ast.py:278
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Enclosing_Compilation_Unit
  (Node : Bare_Ada_Node
  )
   return Bare_Compilation_Unit
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit;
            procedure Finalizer_Scope_13 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Let_Result : Bare_Compilation_Unit;
            procedure Finalizer_Scope_13 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_13;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 121 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 120 '<Cast to CompilationUnit at ast.py:288>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:288
--# expr-start 119 '<Find at ast.py:286>' Find_Result /tmp/lal-23.0.0/ada/ast.py:286
   --# expr-start 117 '<FieldAccess for parents at ast.py:286>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:286
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 117
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_5 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_5
      --# expr-start 118 '<IsA CompilationUnit at ast.py:287>' Is_A /tmp/lal-23.0.0/ada/ast.py:287
Is_A := Item_5 /= null 
and then Item_5.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 118
      if Is_A then
         Find_Result := Item_5;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 119
   if Find_Result = null
      or else Find_Result.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Find_Result;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 120
Let_Result := Cast_Result; 
--# end
--# expr-done 121
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_13;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_13;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Enclosing_Compilation_Unit;
--# end
--# property-start AdaNode.is_children_env /tmp/lal-23.0.0/ada/ast.py:291
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Is_Children_Env
  (Node : Bare_Ada_Node
      ; Parent : Lexical_Env
      ; Current_Env : Lexical_Env
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind parent Parent
   --# bind current_env Current_Env
   Property_Result : Boolean;
            procedure Finalizer_Scope_14 with Inline_Always;
      Is_Equal : Boolean;
Is_Equal_1 : Boolean;
Is_Equal_2 : Boolean;
Env_Parent : Lexical_Env := Empty_Env;
Fld : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_14 is
            begin
                     Dec_Ref (Env_Parent);
            end Finalizer_Scope_14;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 128 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 127 '<Cond at ast.py:296>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:296
--# expr-start 122 '<Eq at ast.py:297>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:297
Is_Equal := Equivalent (Parent, Empty_Env); 
--# expr-done 122
if Is_Equal then
   If_Result_2 := False;
else
--# expr-start 123 '<Eq at ast.py:298>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:298
Is_Equal_1 := Equivalent (Current_Env, Parent); 
--# expr-done 123
if Is_Equal_1 then
   If_Result_1 := True;
else
--# expr-start 124 '<IsNull at ast.py:299>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:299
Is_Equal_2 := Equivalent (Current_Env, Empty_Env); 
--# expr-done 124
if Is_Equal_2 then
   If_Result := False;
else
   --# expr-start 126 '<FieldAccess for is_children_env at ast.py:300>' Fld /tmp/lal-23.0.0/ada/ast.py:300
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 125 '<env_parent at ast.py:300>' Env_Parent /tmp/lal-23.0.0/ada/ast.py:300
Env_Parent := AST_Envs.Parent (Current_Env); 
--# expr-done 125
--# property-call-start AdaNode.is_children_env
Fld := Libadalang.Implementation.Ada_Node_P_Is_Children_Env (Node => Self, Parent => Parent, Current_Env => Env_Parent);
--# end
--# expr-done 126
   If_Result := Fld;
end if;
   If_Result_1 := If_Result;
end if;
   If_Result_2 := If_Result_1;
end if;
--# expr-done 127
Let_Result := If_Result_2; 
--# end
--# expr-done 128
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_14;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_14;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Is_Children_Env;
--# end
--# property-start AdaNode.without_md /tmp/lal-23.0.0/ada/ast.py:304
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Without_Md
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity;
      Fld : Bare_Ada_Node;
Fld_1 : Internal_Entity_Info;
Fld_2 : Env_Rebindings;
Fld_3 : Internal_Entity_Info;
Fld_4 : Boolean;
New_Struct : Internal_Entity_Info;
New_Struct_1 : Internal_Entity;
Let_Result : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 136 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 135 '<New AdaNode.entity at ???>' New_Struct_1 None
--# expr-start 133 '<New EntityInfo at ast.py:309>' New_Struct /tmp/lal-23.0.0/ada/ast.py:309
--# expr-start 130 '<FieldAccess for from_rebound at ast.py:312>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:312
--# expr-start 129 '<FieldAccess for info at ast.py:312>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:312
Fld_3 := Ent.Info;
--# expr-done 129
Fld_4 := Fld_3.From_Rebound;
--# expr-done 130
--# expr-start 132 '<FieldAccess for rebindings at ast.py:310>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:310
--# expr-start 131 '<FieldAccess for info at ast.py:310>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:310
Fld_1 := Ent.Info;
--# expr-done 131
Fld_2 := Fld_1.Rebindings;
--# expr-done 132
New_Struct := (From_Rebound => Fld_4, Md => No_Metadata, Rebindings => Fld_2); 
--# expr-done 133
--# expr-start 134 '<FieldAccess for node at ast.py:309>' Fld /tmp/lal-23.0.0/ada/ast.py:309
Fld := Ent.Node;
--# expr-done 134
New_Struct_1 := (Info => New_Struct, Node => Fld); 
--# expr-done 135
Let_Result := New_Struct_1; 
--# end
--# expr-done 136
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Without_Md;
--# end
--# property-start AdaNode.get_uninstantiated_node /tmp/lal-23.0.0/ada/ast.py:317
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Get_Uninstantiated_Node
  (Node : Bare_Ada_Node
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity;
      As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Let_Result : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 138 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 137 '<as_bare_entity at ast.py:323>' If_Result /tmp/lal-23.0.0/ada/ast.py:323
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 137
Let_Result := If_Result; 
--# end
--# expr-done 138
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Get_Uninstantiated_Node;
--# end
--# property-start AdaNode.complete /tmp/lal-23.0.0/ada/ast.py:327
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Complete
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Iterator_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Completion_Item_Iterator_Access;
            procedure Finalizer_Scope_17 with Inline_Always;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Completion_Item_Array_Access;
Fld_2 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Synthetic_Subp_Decl;
Is_Null : Boolean;
Map_Result : Internal_Completion_Item_Array_Access;
Iter : Internal_Completion_Item_Iterator_Access;
Dyn_Var_Bind_Result : Internal_Completion_Item_Iterator_Access;
Let_Result : Internal_Completion_Item_Iterator_Access;
            procedure Finalizer_Scope_17 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Iter);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_17;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 147 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 146 '<bind at ast.py:331>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:331
--# expr-start 139 '<FieldAccess for origin_node at ast.py:332>' Fld /tmp/lal-23.0.0/ada/ast.py:332
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 139
Bound_Origin := Fld; 
--# expr-start 145 '<FieldAccess for to_iterator at ast.py:338>' Iter /tmp/lal-23.0.0/ada/ast.py:338
--# expr-start 144 '<Filter at ast.py:333>' Map_Result /tmp/lal-23.0.0/ada/ast.py:333
   --# expr-start 140 '<FieldAccess for complete_items at ast.py:333>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:333
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.complete_items'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Complete_Items (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 140
      declare
         Map_Result_Vec : Internal_Completion_Item_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Completion_Item_Array_Access := Fld_1;
      begin
         for Item_6 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_6
         --# expr-start 143 '<IsNull at ast.py:337>' Is_Null /tmp/lal-23.0.0/ada/ast.py:337
--# expr-start 142 '<Cast to SyntheticSubpDecl at ast.py:337>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:337
--# expr-start 141 '<FieldAccess for decl at ast.py:337>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:337
Fld_2 := Item_6.Decl;
--# expr-done 141
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Synthetic_Subp_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Synthetic_Subp_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result := No_Entity_Synthetic_Subp_Decl;
   end if;
--# expr-done 142
Is_Null := Cast_Result.Node = null; 
--# expr-done 143
         if Is_Null then
         declare
            Item_To_Append : constant Internal_Completion_Item := Item_6;
         begin
            Internal_Completion_Item_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Completion_Item_Array
           (Items_Count => Natural (Internal_Completion_Item_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Completion_Item_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Completion_Item_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Completion_Item_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 144
Iter := To_Iterator (Map_Result, Self.Unit.Context); 
--# expr-done 145
Dyn_Var_Bind_Result := Iter; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 146
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 147
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_17;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_17;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Complete;
--# end
--# property-start '[dispatcher]AdaNode.complete_items' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Complete_Items
  (Node : Bare_Ada_Node
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Completion_Item_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Abstract_State_Decl_List | Ada_Constraint_List .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Char_Literal | Ada_Op_Abs .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.complete_items
                  Property_Result := Ada_Node_P_Complete_Items
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Alternatives_List =>
                  --# property-call-start AlternativesList.complete_items
                  Property_Result := Alternatives_List_P_Complete_Items
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.complete_items
                  Property_Result := Dotted_Name_P_Complete_Items
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Identifier =>
                  --# property-call-start Identifier.complete_items
                  Property_Result := Identifier_P_Complete_Items
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
                  --# property-call-start SubtypeIndication.complete_items
                  Property_Result := Subtype_Indication_P_Complete_Items
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Complete_Items;
--# end
--# property-start '[dispatcher]AdaNode.complete_item_weight' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Complete_Item_Weight
  (Node : Bare_Ada_Node
      ; Item : Internal_Entity_Basic_Decl
      ; Origin : Bare_Ada_Node
  )
   return Integer
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind item Item
   --# bind origin Origin
   Property_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Abort_Stmt | Ada_Call_Stmt .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.complete_item_weight
                  Property_Result := Ada_Node_P_Complete_Item_Weight
                    (Self
                        , Item
                        , Origin
                    );
                  --# end
               when Ada_Assign_Stmt =>
                  --# property-call-start AssignStmt.complete_item_weight
                  Property_Result := Assign_Stmt_P_Complete_Item_Weight
                    (Self
                        , Item
                        , Origin
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Complete_Item_Weight;
--# end
--# property-start AdaNode.valid_keywords /tmp/lal-23.0.0/ada/ast.py:371
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Valid_Keywords
  (Node : Bare_Ada_Node
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_22 with Inline_Always;
      Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Sym_2 : Symbol_Type;
Sym_3 : Symbol_Type;
Sym_4 : Symbol_Type;
Sym_5 : Symbol_Type;
Sym_6 : Symbol_Type;
Sym_7 : Symbol_Type;
Sym_8 : Symbol_Type;
Sym_9 : Symbol_Type;
Sym_10 : Symbol_Type;
Sym_11 : Symbol_Type;
Sym_12 : Symbol_Type;
Sym_13 : Symbol_Type;
Sym_14 : Symbol_Type;
Sym_15 : Symbol_Type;
Sym_16 : Symbol_Type;
Sym_17 : Symbol_Type;
Sym_18 : Symbol_Type;
Sym_19 : Symbol_Type;
Sym_20 : Symbol_Type;
Sym_21 : Symbol_Type;
Sym_22 : Symbol_Type;
Sym_23 : Symbol_Type;
Sym_24 : Symbol_Type;
Sym_25 : Symbol_Type;
Sym_26 : Symbol_Type;
Sym_27 : Symbol_Type;
Sym_28 : Symbol_Type;
Sym_29 : Symbol_Type;
Sym_30 : Symbol_Type;
Sym_31 : Symbol_Type;
Sym_32 : Symbol_Type;
Sym_33 : Symbol_Type;
Sym_34 : Symbol_Type;
Sym_35 : Symbol_Type;
Sym_36 : Symbol_Type;
Sym_37 : Symbol_Type;
Sym_38 : Symbol_Type;
Sym_39 : Symbol_Type;
Sym_40 : Symbol_Type;
Sym_41 : Symbol_Type;
Sym_42 : Symbol_Type;
Sym_43 : Symbol_Type;
Sym_44 : Symbol_Type;
Sym_45 : Symbol_Type;
Sym_46 : Symbol_Type;
Sym_47 : Symbol_Type;
Sym_48 : Symbol_Type;
Sym_49 : Symbol_Type;
Sym_50 : Symbol_Type;
Sym_51 : Symbol_Type;
Sym_52 : Symbol_Type;
Sym_53 : Symbol_Type;
Sym_54 : Symbol_Type;
Sym_55 : Symbol_Type;
Sym_56 : Symbol_Type;
Sym_57 : Symbol_Type;
Sym_58 : Symbol_Type;
Sym_59 : Symbol_Type;
Sym_60 : Symbol_Type;
Sym_61 : Symbol_Type;
Sym_62 : Symbol_Type;
Sym_63 : Symbol_Type;
Sym_64 : Symbol_Type;
Sym_65 : Symbol_Type;
Sym_66 : Symbol_Type;
Sym_67 : Symbol_Type;
Sym_68 : Symbol_Type;
Sym_69 : Symbol_Type;
Sym_70 : Symbol_Type;
Sym_71 : Symbol_Type;
Sym_72 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_22 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_22;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 222 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 221 '<ArrayLiteral at ast.py:379>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:379
--# expr-start 148 '<Symbol abort at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abort); 
--# expr-done 148
--# expr-start 149 '<Symbol abs at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs_260); 
--# expr-done 149
--# expr-start 150 '<Symbol abstract at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abstract); 
--# expr-done 150
--# expr-start 151 '<Symbol accept at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Accept); 
--# expr-done 151
--# expr-start 152 '<Symbol access at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Access_263); 
--# expr-done 152
--# expr-start 153 '<Symbol aliased at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Aliased); 
--# expr-done 153
--# expr-start 154 '<Symbol all at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_All); 
--# expr-done 154
--# expr-start 155 '<Symbol and at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_And_268); 
--# expr-done 155
--# expr-start 156 '<Symbol array at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Array); 
--# expr-done 156
--# expr-start 157 '<Symbol at at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_At); 
--# expr-done 157
--# expr-start 158 '<Symbol begin at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Begin); 
--# expr-done 158
--# expr-start 159 '<Symbol body at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Body); 
--# expr-done 159
--# expr-start 160 '<Symbol case at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Case); 
--# expr-done 160
--# expr-start 161 '<Symbol constant at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Constant); 
--# expr-done 161
--# expr-start 162 '<Symbol declare at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Declare); 
--# expr-done 162
--# expr-start 163 '<Symbol delay at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Delay); 
--# expr-done 163
--# expr-start 164 '<Symbol delta at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Delta_282); 
--# expr-done 164
--# expr-start 165 '<Symbol digits at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Digits_283); 
--# expr-done 165
--# expr-start 166 '<Symbol do at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Do); 
--# expr-done 166
--# expr-start 167 '<Symbol else at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Else); 
--# expr-done 167
--# expr-start 168 '<Symbol elsif at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Elsif); 
--# expr-done 168
--# expr-start 169 '<Symbol end at ???>' Sym_21 None
Sym_21 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_End); 
--# expr-done 169
--# expr-start 170 '<Symbol entry at ???>' Sym_22 None
Sym_22 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Entry); 
--# expr-done 170
--# expr-start 171 '<Symbol exception at ???>' Sym_23 None
Sym_23 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exception); 
--# expr-done 171
--# expr-start 172 '<Symbol exit at ???>' Sym_24 None
Sym_24 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exit); 
--# expr-done 172
--# expr-start 173 '<Symbol for at ???>' Sym_25 None
Sym_25 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_For); 
--# expr-done 173
--# expr-start 174 '<Symbol function at ???>' Sym_26 None
Sym_26 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Function); 
--# expr-done 174
--# expr-start 175 '<Symbol generic at ???>' Sym_27 None
Sym_27 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Generic); 
--# expr-done 175
--# expr-start 176 '<Symbol goto at ???>' Sym_28 None
Sym_28 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Goto); 
--# expr-done 176
--# expr-start 177 '<Symbol if at ???>' Sym_29 None
Sym_29 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_If); 
--# expr-done 177
--# expr-start 178 '<Symbol in at ???>' Sym_30 None
Sym_30 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_In); 
--# expr-done 178
--# expr-start 179 '<Symbol interface at ???>' Sym_31 None
Sym_31 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Interface_306); 
--# expr-done 179
--# expr-start 180 '<Symbol is at ???>' Sym_32 None
Sym_32 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Is); 
--# expr-done 180
--# expr-start 181 '<Symbol limited at ???>' Sym_33 None
Sym_33 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Limited); 
--# expr-done 181
--# expr-start 182 '<Symbol loop at ???>' Sym_34 None
Sym_34 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Loop); 
--# expr-done 182
--# expr-start 183 '<Symbol mod at ???>' Sym_35 None
Sym_35 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod_315); 
--# expr-done 183
--# expr-start 184 '<Symbol new at ???>' Sym_36 None
Sym_36 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_New); 
--# expr-done 184
--# expr-start 185 '<Symbol not at ???>' Sym_37 None
Sym_37 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Not_317); 
--# expr-done 185
--# expr-start 186 '<Symbol null at ???>' Sym_38 None
Sym_38 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Null); 
--# expr-done 186
--# expr-start 187 '<Symbol others at ???>' Sym_39 None
Sym_39 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Others); 
--# expr-done 187
--# expr-start 188 '<Symbol out at ???>' Sym_40 None
Sym_40 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Out); 
--# expr-done 188
--# expr-start 189 '<Symbol of at ???>' Sym_41 None
Sym_41 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Of); 
--# expr-done 189
--# expr-start 190 '<Symbol or at ???>' Sym_42 None
Sym_42 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Or_320); 
--# expr-done 190
--# expr-start 191 '<Symbol overriding at ???>' Sym_43 None
Sym_43 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Overriding); 
--# expr-done 191
--# expr-start 192 '<Symbol package at ???>' Sym_44 None
Sym_44 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Package); 
--# expr-done 192
--# expr-start 193 '<Symbol pragma at ???>' Sym_45 None
Sym_45 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pragma); 
--# expr-done 193
--# expr-start 194 '<Symbol private at ???>' Sym_46 None
Sym_46 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Private); 
--# expr-done 194
--# expr-start 195 '<Symbol procedure at ???>' Sym_47 None
Sym_47 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Procedure); 
--# expr-done 195
--# expr-start 196 '<Symbol protected at ???>' Sym_48 None
Sym_48 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Protected); 
--# expr-done 196
--# expr-start 197 '<Symbol raise at ???>' Sym_49 None
Sym_49 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Raise); 
--# expr-done 197
--# expr-start 198 '<Symbol range at ???>' Sym_50 None
Sym_50 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range_334); 
--# expr-done 198
--# expr-start 199 '<Symbol record at ???>' Sym_51 None
Sym_51 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Record); 
--# expr-done 199
--# expr-start 200 '<Symbol rem at ???>' Sym_52 None
Sym_52 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rem_337); 
--# expr-done 200
--# expr-start 201 '<Symbol renames at ???>' Sym_53 None
Sym_53 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Renames); 
--# expr-done 201
--# expr-start 202 '<Symbol requeue at ???>' Sym_54 None
Sym_54 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Requeue); 
--# expr-done 202
--# expr-start 203 '<Symbol return at ???>' Sym_55 None
Sym_55 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Return); 
--# expr-done 203
--# expr-start 204 '<Symbol reverse at ???>' Sym_56 None
Sym_56 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Reverse); 
--# expr-done 204
--# expr-start 205 '<Symbol select at ???>' Sym_57 None
Sym_57 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Select); 
--# expr-done 205
--# expr-start 206 '<Symbol separate at ???>' Sym_58 None
Sym_58 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Separate); 
--# expr-done 206
--# expr-start 207 '<Symbol some at ???>' Sym_59 None
Sym_59 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Some); 
--# expr-done 207
--# expr-start 208 '<Symbol subtype at ???>' Sym_60 None
Sym_60 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Subtype); 
--# expr-done 208
--# expr-start 209 '<Symbol synchronized at ???>' Sym_61 None
Sym_61 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Synchronized); 
--# expr-done 209
--# expr-start 210 '<Symbol tagged at ???>' Sym_62 None
Sym_62 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Tagged); 
--# expr-done 210
--# expr-start 211 '<Symbol task at ???>' Sym_63 None
Sym_63 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Task); 
--# expr-done 211
--# expr-start 212 '<Symbol terminate at ???>' Sym_64 None
Sym_64 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Terminate); 
--# expr-done 212
--# expr-start 213 '<Symbol then at ???>' Sym_65 None
Sym_65 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Then); 
--# expr-done 213
--# expr-start 214 '<Symbol type at ???>' Sym_66 None
Sym_66 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Type); 
--# expr-done 214
--# expr-start 215 '<Symbol until at ???>' Sym_67 None
Sym_67 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Until); 
--# expr-done 215
--# expr-start 216 '<Symbol use at ???>' Sym_68 None
Sym_68 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Use); 
--# expr-done 216
--# expr-start 217 '<Symbol when at ???>' Sym_69 None
Sym_69 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_When); 
--# expr-done 217
--# expr-start 218 '<Symbol while at ???>' Sym_70 None
Sym_70 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_While); 
--# expr-done 218
--# expr-start 219 '<Symbol with at ???>' Sym_71 None
Sym_71 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_With); 
--# expr-done 219
--# expr-start 220 '<Symbol xor at ???>' Sym_72 None
Sym_72 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Xor_377); 
--# expr-done 220
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1, 3 => Sym_2, 4 => Sym_3, 5 => Sym_4, 6 => Sym_5, 7 => Sym_6, 8 => Sym_7, 9 => Sym_8, 10 => Sym_9, 11 => Sym_10, 12 => Sym_11, 13 => Sym_12, 14 => Sym_13, 15 => Sym_14, 16 => Sym_15, 17 => Sym_16, 18 => Sym_17, 19 => Sym_18, 20 => Sym_19, 21 => Sym_20, 22 => Sym_21, 23 => Sym_22, 24 => Sym_23, 25 => Sym_24, 26 => Sym_25, 27 => Sym_26, 28 => Sym_27, 29 => Sym_28, 30 => Sym_29, 31 => Sym_30, 32 => Sym_31, 33 => Sym_32, 34 => Sym_33, 35 => Sym_34, 36 => Sym_35, 37 => Sym_36, 38 => Sym_37, 39 => Sym_38, 40 => Sym_39, 41 => Sym_40, 42 => Sym_41, 43 => Sym_42, 44 => Sym_43, 45 => Sym_44, 46 => Sym_45, 47 => Sym_46, 48 => Sym_47, 49 => Sym_48, 50 => Sym_49, 51 => Sym_50, 52 => Sym_51, 53 => Sym_52, 54 => Sym_53, 55 => Sym_54, 56 => Sym_55, 57 => Sym_56, 58 => Sym_57, 59 => Sym_58, 60 => Sym_59, 61 => Sym_60, 62 => Sym_61, 63 => Sym_62, 64 => Sym_63, 65 => Sym_64, 66 => Sym_65, 67 => Sym_66, 68 => Sym_67, 69 => Sym_68, 70 => Sym_69, 71 => Sym_70, 72 => Sym_71, 73 => Sym_72)); 
--# expr-done 221
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 222
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_22;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_22;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Valid_Keywords;
--# end
--# property-start AdaNode.generic_instantiations /tmp/lal-23.0.0/ada/ast.py:394
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Generic_Instantiations
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Generic_Instantiation_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Generic_Instantiation_Array_Access;
            procedure Finalizer_Scope_23 with Inline_Always;
      Fld : Internal_Entity_Info;
Fld_1 : Env_Rebindings;
Fld_2 : Internal_Entity_Generic_Instantiation_Array_Access;
Let_Result : Internal_Entity_Generic_Instantiation_Array_Access;
            procedure Finalizer_Scope_23 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_23;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 226 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 225 '<FieldAccess for generic_instantiations_internal at ast.py:400>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:400
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 224 '<FieldAccess for rebindings at ast.py:400>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:400
--# expr-start 223 '<FieldAccess for info at ast.py:400>' Fld /tmp/lal-23.0.0/ada/ast.py:400
Fld := Ent.Info;
--# expr-done 223
Fld_1 := Fld.Rebindings;
--# expr-done 224
--# property-call-start AdaNode.generic_instantiations_internal
Fld_2 := Libadalang.Implementation.Ada_Node_P_Generic_Instantiations_Internal (Node => Self, R => Fld_1);
--# end
--# expr-done 225
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 226
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_23;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_23;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Generic_Instantiations;
--# end
--# property-start AdaNode.generic_instantiations_internal /tmp/lal-23.0.0/ada/ast.py:403
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Generic_Instantiations_Internal
  (Node : Bare_Ada_Node
      ; R : Env_Rebindings
  )
   return Internal_Entity_Generic_Instantiation_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind r R
   Property_Result : Internal_Entity_Generic_Instantiation_Array_Access;
            procedure Finalizer_Scope_24 with Inline_Always;
      Head : Internal_Entity_Generic_Instantiation;
Tail : Internal_Entity_Generic_Instantiation_Array_Access;
Fld : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Cast_Result : Bare_Generic_Instantiation;
As_Entity : Internal_Entity_Generic_Instantiation;
Is_Null : Boolean;
If_Result : Internal_Entity_Generic_Instantiation;
Fld_1 : Env_Rebindings;
Fld_2 : Internal_Entity_Generic_Instantiation_Array_Access;
Singleton : Internal_Entity_Generic_Instantiation_Array_Access;
Concat_Result : Internal_Entity_Generic_Instantiation_Array_Access;
Let_Result : Internal_Entity_Generic_Instantiation_Array_Access;
Is_Equal : Boolean;
If_Result_1 : Internal_Entity_Generic_Instantiation_Array_Access;
Let_Result_1 : Internal_Entity_Generic_Instantiation_Array_Access;
            procedure Finalizer_Scope_24 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Tail);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_24;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 237 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 236 '<If at ast.py:404>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:404
--# expr-start 227 '<Eq at ast.py:405>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:405
Is_Equal := R = null; 
--# expr-done 227
if Is_Equal then
   If_Result_1 := No_Internal_Entity_Generic_Instantiation_Array_Type;
else
   --# expr-start 235 '<Let at ast.py:408>' Let_Result /tmp/lal-23.0.0/ada/ast.py:408
--# scope-start
--# expr-start 231 '<as_bare_entity at ast.py:410>' If_Result /tmp/lal-23.0.0/ada/ast.py:410
--# expr-start 230 '<Cast to GenericInstantiation at ast.py:410>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:410
--# expr-start 229 '<env_node at ast.py:409>' Env_Node /tmp/lal-23.0.0/ada/ast.py:409
--# expr-start 228 '<FieldAccess for new_env at ast.py:409>' Fld /tmp/lal-23.0.0/ada/ast.py:409
      if R = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := R.New_Env;
Inc_Ref (Fld);
--# expr-done 228
Env_Node := AST_Envs.Env_Node (Fld); 
--# expr-done 229
   if Env_Node = null
      or else Env_Node.Kind in Ada_Generic_Instantiation
   then
      Cast_Result := Env_Node;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 230
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Generic_Instantiation;
else
As_Entity := (Info => No_Entity_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 231
Head := If_Result; 
--# bind head Head
--# expr-start 233 '<FieldAccess for generic_instantiations_internal at ast.py:411>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:411
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 232 '<FieldAccess for get_parent at ast.py:411>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:411
      if R = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := R.Parent;
--# expr-done 232
--# property-call-start AdaNode.generic_instantiations_internal
Fld_2 := Libadalang.Implementation.Ada_Node_P_Generic_Instantiations_Internal (Node => Self, R => Fld_1);
--# end
--# expr-done 233
Tail := Fld_2; Inc_Ref (Tail);
--# bind tail Tail
--# expr-start 234 '<Concat at ast.py:412>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:412
                Singleton := Create_Internal_Entity_Generic_Instantiation_Array (Items_Count => 1);
                Singleton.Items (1) := Head;
Concat_Result := Concat (Singleton, Tail); 
--# expr-done 234
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 235
   If_Result_1 := Let_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 236
Let_Result_1 := If_Result_1; Inc_Ref (Let_Result_1);
--# end
--# expr-done 237
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_24;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_24;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Generic_Instantiations_Internal;
--# end
--# property-start AdaNode.remove_rebindings /tmp/lal-23.0.0/ada/ast.py:416
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Remove_Rebindings
  (Node : Bare_Ada_Node
      ; Base : Env_Rebindings
      ; Suffix : Env_Rebindings
  )
   return Env_Rebindings
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind base Base
   --# bind suffix Suffix
   Property_Result : Env_Rebindings;
            procedure Finalizer_Scope_25 with Inline_Always;
      Is_Equal : Boolean;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Is_Equal_2 : Boolean;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Lexical_Env := Empty_Env;
Is_Equal_3 : Boolean;
If_Result_1 : Boolean;
Fld_4 : Env_Rebindings;
Fld_5 : Env_Rebindings;
Fld_6 : Env_Rebindings;
If_Result_2 : Env_Rebindings;
If_Result_3 : Env_Rebindings;
Let_Result : Env_Rebindings;
            procedure Finalizer_Scope_25 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_25;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 250 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 249 '<Cond at ast.py:421>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:421
--# expr-start 238 '<IsNull at ast.py:422>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:422
Is_Equal := Base = null; 
--# expr-done 238
if Is_Equal then
   If_Result := True;
else
   --# expr-start 239 '<IsNull at ast.py:422>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:422
Is_Equal_1 := Suffix = null; 
--# expr-done 239
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_3 := Base;
else
--# expr-start 242 '<Eq at ast.py:425>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:425
--# expr-start 240 '<FieldAccess for old_env at ast.py:425>' Fld /tmp/lal-23.0.0/ada/ast.py:425
      if Base = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Base.Old_Env;
Inc_Ref (Fld);
--# expr-done 240
--# expr-start 241 '<FieldAccess for old_env at ast.py:425>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:425
      if Suffix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Suffix.Old_Env;
Inc_Ref (Fld_1);
--# expr-done 241
Is_Equal_2 := Equivalent (Fld, Fld_1); 
--# expr-done 242
if Is_Equal_2 then
   --# expr-start 245 '<Eq at ast.py:426>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:426
--# expr-start 243 '<FieldAccess for new_env at ast.py:426>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:426
      if Base = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Base.New_Env;
Inc_Ref (Fld_2);
--# expr-done 243
--# expr-start 244 '<FieldAccess for new_env at ast.py:426>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:426
      if Suffix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Suffix.New_Env;
Inc_Ref (Fld_3);
--# expr-done 244
Is_Equal_3 := Equivalent (Fld_2, Fld_3); 
--# expr-done 245
   If_Result_1 := Is_Equal_3;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 248 '<FieldAccess for remove_rebindings at ast.py:427>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:427
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 246 '<FieldAccess for get_parent at ast.py:427>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:427
      if Base = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Base.Parent;
--# expr-done 246
--# expr-start 247 '<FieldAccess for get_parent at ast.py:427>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:427
      if Suffix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Suffix.Parent;
--# expr-done 247
--# property-call-start AdaNode.remove_rebindings
Fld_6 := Libadalang.Implementation.Ada_Node_P_Remove_Rebindings (Node => Self, Base => Fld_4, Suffix => Fld_5);
--# end
--# expr-done 248
   If_Result_2 := Fld_6;
else
   If_Result_2 := Base;
end if;
   If_Result_3 := If_Result_2;
end if;
--# expr-done 249
Let_Result := If_Result_3; 
--# end
--# expr-done 250
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_25;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_25;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Remove_Rebindings;
--# end
--# property-start AdaNode.logic_val /tmp/lal-23.0.0/ada/ast.py:437
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Logic_Val
  (Node : Bare_Ada_Node
      ; From_Node : Internal_Entity
      ; Lvar : Logic_Var
  )
   return Internal_Logic_Val_Result
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind from_node From_Node
   --# bind lvar Lvar
   Property_Result : Internal_Logic_Val_Result;
      Block_Var : Boolean;
Fld : Boolean;
Is_Logic_Var_Defined : Boolean;
Eq_Solution : Internal_Entity;
If_Result : Internal_Entity;
If_Result_1 : Internal_Entity;
New_Struct : Internal_Logic_Val_Result;
Let_Result : Internal_Logic_Val_Result;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 255 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 251 '<FieldAccess for resolve_names_from_closest_entry_point at ast.py:438>' Fld /tmp/lal-23.0.0/ada/ast.py:438
      if From_Node.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_from_closest_entry_point
Fld := Libadalang.Implementation.Ada_Node_P_Resolve_Names_From_Closest_Entry_Point (Node => From_Node.Node, E_Info => From_Node.Info);
--# end
--# expr-done 251
Block_Var := Fld; 
--# bind success Block_Var
--# expr-start 254 '<New LogicValResult at ast.py:440>' New_Struct /tmp/lal-23.0.0/ada/ast.py:440
--# expr-start 253 '<If at ast.py:440>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:440
if Block_Var then
   --# expr-start 252 '<get_value at ast.py:441>' If_Result /tmp/lal-23.0.0/ada/ast.py:441
Is_Logic_Var_Defined := Entity_Vars.Is_Defined (Lvar); 
if Is_Logic_Var_Defined then
Eq_Solution := Entity_Vars.Get_Value (Lvar); 
   If_Result := Eq_Solution;
else
   If_Result := No_Entity;
end if;
--# expr-done 252
   If_Result_1 := If_Result;
else
   If_Result_1 := No_Entity;
end if;
--# expr-done 253
New_Struct := (Success => Block_Var, Value => If_Result_1); 
--# expr-done 254
Let_Result := New_Struct; 
--# end
--# expr-done 255
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Logic_Val;
--# end
--# property-start AdaNode.semantic_parent_helper /tmp/lal-23.0.0/ada/ast.py:445
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Semantic_Parent_Helper
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity;
            procedure Finalizer_Scope_1756 with Inline_Always;
      Var_Expr : Lexical_Env := Empty_Env;
Var_Expr_1 : Internal_Entity;
Env_Node : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Scope_Result : Internal_Entity;
Env_Parent : Lexical_Env := Empty_Env;
Fld : Internal_Entity;
Result_Var : Internal_Entity;
Scope_Result_1 : Internal_Entity;
Result_Var_1 : Internal_Entity;
Let_Result : Internal_Entity;
            procedure Finalizer_Scope_1756 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Env_Parent);
            end Finalizer_Scope_1756;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 260 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr := Env;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_Env then
   --# scope-start
   --# bind env Var_Expr
--# expr-start 257 '<as_entity at ast.py:446>' If_Result /tmp/lal-23.0.0/ada/ast.py:446
--# expr-start 256 '<env_node at ast.py:446>' Env_Node /tmp/lal-23.0.0/ada/ast.py:446
Env_Node := AST_Envs.Env_Node (Var_Expr); 
--# expr-done 256
Is_Null := Env_Node = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Env_Node); 
   If_Result := As_Entity;
end if;
--# expr-done 257
Var_Expr_1 := If_Result;
if Var_Expr_1 /= No_Entity then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result := Var_Expr_1;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 259 '<FieldAccess for semantic_parent_helper at ast.py:447>' Fld /tmp/lal-23.0.0/ada/ast.py:447
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 258 '<env_parent at ast.py:447>' Env_Parent /tmp/lal-23.0.0/ada/ast.py:447
Env_Parent := AST_Envs.Parent (Var_Expr); 
--# expr-done 258
--# property-call-start AdaNode.semantic_parent_helper
Fld := Libadalang.Implementation.Ada_Node_P_Semantic_Parent_Helper (Node => Ent.Node, Env => Env_Parent, E_Info => Ent.Info);
--# end
--# expr-done 259
   Result_Var := Fld;
end if;
Scope_Result_1 := Result_Var;
   --# end
      Finalizer_Scope_1756;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 260
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1756;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Semantic_Parent_Helper;
--# end
--# property-start AdaNode.semantic_parent /tmp/lal-23.0.0/ada/ast.py:451
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Semantic_Parent
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity;
            procedure Finalizer_Scope_28 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity;
Let_Result : Internal_Entity;
            procedure Finalizer_Scope_28 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_28;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 263 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 262 '<FieldAccess for semantic_parent_helper at ast.py:460>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:460
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 261 '<FieldAccess for node_env at ast.py:460>' Fld /tmp/lal-23.0.0/ada/ast.py:460
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 261
--# property-call-start AdaNode.semantic_parent_helper
Fld_1 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent_Helper (Node => Ent.Node, Env => Fld, E_Info => Ent.Info);
--# end
--# expr-done 262
Let_Result := Fld_1; 
--# end
--# expr-done 263
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_28;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_28;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Semantic_Parent;
--# end
--# property-start AdaNode.is_in_top_level_public_part /tmp/lal-23.0.0/ada/ast.py:463
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Is_In_Top_Level_Public_Part
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Block_Var : Internal_Entity;
Var_Expr : Internal_Entity_Base_Package_Decl;
Fld : Internal_Entity;
Is_Null : Boolean;
Is_A : Boolean;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Package_Decl;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Is_A_1 : Boolean;
Cast_Expr : Internal_Entity;
Cast_Result_1 : Internal_Entity_Package_Body;
Fld_3 : Boolean;
If_Result_1 : Boolean;
Is_A_2 : Boolean;
Cast_Expr_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Base_Package_Decl;
Fld_4 : Boolean;
If_Result_2 : Boolean;
Fld_5 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Boolean;
If_Result_5 : Boolean;
If_Result_6 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 278 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 264 '<FieldAccess for semantic_parent at ast.py:468>' Fld /tmp/lal-23.0.0/ada/ast.py:468
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 264
Block_Var := Fld; 
--# bind node Block_Var
--# expr-start 277 '<Cond at ast.py:469>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:469
--# expr-start 265 '<IsNull at ast.py:470>' Is_Null /tmp/lal-23.0.0/ada/ast.py:470
Is_Null := Block_Var.Node = null; 
--# expr-done 265
if Is_Null then
   If_Result_6 := False;
else
--# expr-start 266 '<IsA PrivatePart at ast.py:473>' Is_A /tmp/lal-23.0.0/ada/ast.py:473
Is_A := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Private_Part_Range; 
--# expr-done 266
if Is_A then
--# expr-start 268 '<Cast to BasePackageDecl at ast.py:474>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:474
--# expr-start 267 '<parent at ast.py:474>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:474
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 267
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Package_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Package_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Base_Package_Decl;
   end if;
--# expr-done 268
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Base_Package_Decl then
   --# scope-start
--# expr-start 269 '<FieldAccess for is_compilation_unit_root at ast.py:474>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:474
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Var_Expr.Node);
--# end
--# expr-done 269
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_5 := False;
else
--# expr-start 270 '<IsA PackageBody at ast.py:477>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:477
Is_A_1 := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Package_Body_Range; 
--# expr-done 270
if Is_A_1 then
   --# expr-start 272 '<FieldAccess for is_compilation_unit_root at ast.py:478>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:478
--# expr-start 271 '<Cast to PackageBody at ast.py:478>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:478
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Package_Body_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Package_Body
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Package_Body;
   end if;
--# expr-done 271
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Cast_Result_1.Node);
--# end
--# expr-done 272
   If_Result_1 := Fld_3;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_4 := False;
else
--# expr-start 273 '<IsA BasePackageDecl at ast.py:481>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:481
Is_A_2 := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Base_Package_Decl; 
--# expr-done 273
if Is_A_2 then
   --# expr-start 275 '<FieldAccess for is_compilation_unit_root at ast.py:482>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:482
--# expr-start 274 '<Cast to BasePackageDecl at ast.py:482>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:482
Cast_Expr_1 := Block_Var; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Base_Package_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Base_Package_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Base_Package_Decl;
   end if;
--# expr-done 274
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Cast_Result_2.Node);
--# end
--# expr-done 275
   If_Result_2 := Fld_4;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 276 '<FieldAccess for is_in_top_level_public_part at ast.py:485>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:485
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.is_in_top_level_public_part
Fld_5 := Libadalang.Implementation.Ada_Node_P_Is_In_Top_Level_Public_Part (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 276
   If_Result_3 := Fld_5;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
   If_Result_6 := If_Result_5;
end if;
--# expr-done 277
Let_Result := If_Result_6; 
--# end
--# expr-done 278
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Is_In_Top_Level_Public_Part;
--# end
--# property-start AdaNode.parent_basic_decl /tmp/lal-23.0.0/ada/ast.py:489
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Parent_Basic_Decl
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Generic_Instantiation;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Is_A : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Is_A_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 290 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 289 '<If at ast.py:504>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:504
--# expr-start 279 '<IsA ClasswideTypeDecl, DiscreteBaseSubtypeDecl, SynthAnonymousTypeDecl at ast.py:509>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:509
Is_A_1 := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Classwide_Type_Decl_Range | Ada_Discrete_Base_Subtype_Decl_Range | Ada_Synth_Anonymous_Type_Decl_Range; 
--# expr-done 279
if Is_A_1 then
   --# expr-start 281 '<FieldAccess for parent_basic_decl at ast.py:511>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:511
--# expr-start 280 '<FieldAccess for semantic_parent at ast.py:511>' Fld /tmp/lal-23.0.0/ada/ast.py:511
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 280
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_1 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 281
   If_Result_1 := Fld_1;
else
--# expr-start 282 '<FieldAccess for semantic_parent at ast.py:512>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:512
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_2 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 282
Var_Expr := Fld_2;
if Var_Expr /= No_Entity then
   --# scope-start
   --# bind sp Var_Expr
--# expr-start 287 '<If at ast.py:513>' If_Result /tmp/lal-23.0.0/ada/ast.py:513
--# expr-start 283 '<IsA GenericSubpInternal, GenericPackageInternal at ast.py:514>' Is_A /tmp/lal-23.0.0/ada/ast.py:514
Is_A := Var_Expr.Node /= null 
and then Var_Expr.Node.Kind in Ada_Generic_Subp_Internal_Range | Ada_Generic_Package_Internal_Range; 
--# expr-done 283
if Is_A then
--# expr-start 285 '<FieldAccess for get_instantiation at ast.py:515>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:515
--# expr-start 284 '<Cast to BasicDecl at ast.py:515>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:515
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 284
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.get_instantiation
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Get_Instantiation (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 285
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   If_Result := Cast_Result_2;
else
   --# expr-start 286 '<Cast to BasicDecl at ast.py:516>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:516
Cast_Expr_1 := Var_Expr; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 286
   If_Result := Cast_Result_1;
end if;
--# expr-done 287
Var_Expr_1 := If_Result;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result := Var_Expr_1;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 288 '<FieldAccess for parent_basic_decl at ast.py:517>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:517
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_4 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 288
   Result_Var := Fld_4;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
   If_Result_1 := Result_Var_1;
end if;
--# expr-done 289
Let_Result := If_Result_1; 
--# end
--# expr-done 290
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Parent_Basic_Decl;
--# end
--# property-start '[dispatcher]AdaNode.immediate_declarative_region' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Immediate_Declarative_Region
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_Declarative_Part | Ada_Public_Part .. Ada_Begin_Block | Ada_Case_Stmt .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.immediate_declarative_region
                  Property_Result := Ada_Node_P_Immediate_Declarative_Region
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_State_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.immediate_declarative_region
                  Property_Result := Basic_Decl_P_Immediate_Declarative_Region
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Private_Part =>
                  --# property-call-start PrivatePart.immediate_declarative_region
                  Property_Result := Private_Part_P_Immediate_Declarative_Region
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Decl_Block =>
                  --# property-call-start DeclBlock.immediate_declarative_region
                  Property_Result := Decl_Block_P_Immediate_Declarative_Region
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Immediate_Declarative_Region;
--# end
--# property-start AdaNode.designated_compilation_unit /tmp/lal-23.0.0/ada/ast.py:565
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Designated_Compilation_Unit
  (Node : Bare_Ada_Node
      ; Name : Symbol_Type_Array_Access
      ; Kind : Analysis_Unit_Kind
      ; Load_If_Needed : Boolean
         := True
      ; Not_Found_Is_Error : Boolean
         := True
      ; Process_Parents : Boolean
         := True
  )
   return Bare_Compilation_Unit
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind name Name
   --# bind kind Kind
   --# bind load_if_needed Load_If_Needed
   --# bind not_found_is_error Not_Found_Is_Error
   --# bind process_parents Process_Parents
   Property_Result : Bare_Compilation_Unit;
      Block_Var : Internal_Unit;
Fld : Internal_Unit;
Fld_1 : Bare_Compilation_Unit;
Let_Result : Bare_Compilation_Unit;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 293 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 291 '<FieldAccess for get_unit at ast.py:575>' Fld /tmp/lal-23.0.0/ada/ast.py:575
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Ada_Node_P_Get_Unit (Node => Self, Name => Name, Kind => Kind, Load_If_Needed => Load_If_Needed, Not_Found_Is_Error => Not_Found_Is_Error, Process_Parents => Process_Parents);
--# expr-done 291
Block_Var := Fld; 
--# bind designated_analysis_unit Block_Var
--# expr-start 292 '<FieldAccess for compilation_unit_with_name at ast.py:579>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:579
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.compilation_unit_with_name
Fld_1 := Libadalang.Implementation.Ada_Node_P_Compilation_Unit_With_Name (Node => Self, Unit => Block_Var, Name => Name);
--# end
--# expr-done 292
Let_Result := Fld_1; 
--# end
--# expr-done 293
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Designated_Compilation_Unit;
--# end
--# property-start AdaNode.compilation_unit_with_name /tmp/lal-23.0.0/ada/ast.py:582
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Compilation_Unit_With_Name
  (Node : Bare_Ada_Node
      ; Unit : Internal_Unit
      ; Name : Symbol_Type_Array_Access
  )
   return Bare_Compilation_Unit
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind unit Unit
   --# bind name Name
   Property_Result : Bare_Compilation_Unit;
            procedure Finalizer_Scope_1770 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Match_0 : Bare_Compilation_Unit;
Match_1 : Bare_Compilation_Unit_List;
Match_2 : Bare_Ada_Node;
Fld : Bare_Ada_Node;
Fld_1 : Symbol_Type_Array_Access;
Is_Equal : Boolean;
Item_8 : Bare_Compilation_Unit;
Find_Result : Bare_Compilation_Unit;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Let_Result : Bare_Compilation_Unit;
Scope_Result : Bare_Compilation_Unit;
Cast_Result_1 : Bare_Compilation_Unit_List;
Let_Result_1 : Bare_Compilation_Unit;
Scope_Result_1 : Bare_Compilation_Unit;
Cast_Result_2 : Bare_Ada_Node;
Let_Result_2 : Bare_Compilation_Unit;
Scope_Result_2 : Bare_Compilation_Unit;
Match_Result : Bare_Compilation_Unit;
Scope_Result_3 : Bare_Compilation_Unit;
Result_Var : Bare_Compilation_Unit;
Let_Result_3 : Bare_Compilation_Unit;
            procedure Finalizer_Scope_1770 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1770;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 299 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 294 '<FieldAccess for root at ast.py:588>' Fld /tmp/lal-23.0.0/ada/ast.py:588
      if Unit = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Unit.Ast_Root;
--# expr-done 294
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 298 '<Match at ast.py:588>' Match_Result /tmp/lal-23.0.0/ada/ast.py:588
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Compilation_Unit =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind single Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Compilation_Unit_List =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind multi Match_1
--# expr-start 297 '<Find at ast.py:595>' Find_Result /tmp/lal-23.0.0/ada/ast.py:595
      Find_Result := No_Bare_Ada_Node;
      if Match_1 = null then
      Find_Result := No_Bare_Ada_Node;
      else
      declare
         Collection : constant Bare_Compilation_Unit_List := Match_1;
      begin
         for Untyped_Item_8 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_8 := Untyped_Item_8; 
   --# scope-start
               --# bind c Item_8
      --# expr-start 296 '<Eq at ast.py:596>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:596
--# expr-start 295 '<FieldAccess for syntactic_fully_qualified_name at ast.py:596>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:596
      if Item_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.syntactic_fully_qualified_name
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Syntactic_Fully_Qualified_Name (Node => Item_8);
--# end
--# expr-done 295
Is_Equal := Equivalent (Fld_1, Name); 
--# expr-done 296
      if Is_Equal then
         Find_Result := Item_8;
      end if;
   --# end
      Finalizer_Scope_1770;
               exit when Is_Equal;
         end loop;
      end;
      end if;
--# expr-done 297
Let_Result_1 := Find_Result; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Case_Stmt_Alternative_List | Ada_Concat_Operand_List .. Ada_Case_Stmt_Alternative | Ada_Component_Clause .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error with "Unexpected analysis unit root"; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 298
Scope_Result_3 := Match_Result;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Let_Result_3 := Result_Var; 
--# end
--# expr-done 299
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1770;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Compilation_Unit_With_Name;
--# end
--# property-start AdaNode.get_unit_root_decl /tmp/lal-23.0.0/ada/ast.py:605
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Get_Unit_Root_Decl
  (Node : Bare_Ada_Node
      ; Name : Symbol_Type_Array_Access
      ; Kind : Analysis_Unit_Kind
      ; Load_If_Needed : Boolean
         := True
      ; Not_Found_Is_Error : Boolean
         := True
      ; Process_Parents : Boolean
         := True
  )
   return Bare_Basic_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind name Name
   --# bind kind Kind
   --# bind load_if_needed Load_If_Needed
   --# bind not_found_is_error Not_Found_Is_Error
   --# bind process_parents Process_Parents
   Property_Result : Bare_Basic_Decl;
      Block_Var : Bare_Compilation_Unit;
Var_Expr : Bare_Compilation_Unit;
Fld : Bare_Compilation_Unit;
Fld_1 : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Result_Var : Bare_Basic_Decl;
Let_Result : Bare_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 302 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 300 '<FieldAccess for designated_compilation_unit at ast.py:614>' Fld /tmp/lal-23.0.0/ada/ast.py:614
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.designated_compilation_unit
Fld := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Name, Kind => Kind, Load_If_Needed => Load_If_Needed, Not_Found_Is_Error => Not_Found_Is_Error, Process_Parents => Process_Parents);
--# end
--# expr-done 300
Block_Var := Fld; 
--# bind cu Block_Var
Var_Expr := Block_Var;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 301 '<FieldAccess for decl at ast.py:617>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:617
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr);
--# end
--# expr-done 301
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 302
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Get_Unit_Root_Decl;
--# end
--# property-start '[dispatcher]AdaNode.xref_equation' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Xref_Equation
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_All_Present | Ada_Aspect_Spec .. Ada_Pragma_Argument_Assoc | Ada_Component_List .. Ada_Record_Def | Ada_Composite_Constraint_Assoc | Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Synthetic_Formal_Param_Decl .. Ada_Discrete_Base_Subtype_Decl | Ada_Classwide_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl | Ada_Abstract_Subp_Decl | Ada_Subp_Decl .. Ada_Synthetic_Subp_Decl | Ada_Null_Subp_Decl .. Ada_Subp_Body | Ada_Package_Body_Stub .. Ada_Task_Body_Stub | Ada_Package_Body .. Ada_Task_Body | Ada_Error_Decl | Ada_Generic_Package_Decl .. Ada_Generic_Subp_Decl | Ada_Label_Decl .. Ada_Named_Stmt_Decl | Ada_Single_Task_Decl | Ada_Compilation_Unit | Ada_Constant_Absent .. Ada_Constant_Present | Ada_Declarative_Part .. Ada_Elsif_Expr_Part | Ada_Case_Expr_Alternative | Ada_Concat_Operand | Ada_Contract_Cases | Ada_Discrete_Subtype_Name | Ada_Synthetic_Identifier | Ada_Handled_Stmts .. Ada_Limited_Present | Ada_Mode_Default .. Ada_Null_Component_Decl | Ada_Overriding_Not_Overriding .. Ada_Pp_Then_Kw | Ada_Private_Absent .. Ada_Quantifier_Some | Ada_Renaming_Clause .. Ada_Reverse_Present | Ada_Error_Stmt | Ada_Subp_Kind_Function .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_Tagged_Present | Ada_Type_Attributes_Repository | Ada_Anonymous_Type_Access_Def | Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_Until_Present | Ada_Variant | Ada_With_Private_Absent .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.xref_equation
                  Property_Result := Ada_Node_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Constrained_Array_Indices =>
                  --# property-call-start ConstrainedArrayIndices.xref_equation
                  Property_Result := Constrained_Array_Indices_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Unconstrained_Array_Indices =>
                  --# property-call-start UnconstrainedArrayIndices.xref_equation
                  Property_Result := Unconstrained_Array_Indices_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Aspect_Assoc =>
                  --# property-call-start AspectAssoc.xref_equation
                  Property_Result := Aspect_Assoc_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_At_Clause =>
                  --# property-call-start AtClause.xref_equation
                  Property_Result := At_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Def_Clause =>
                  --# property-call-start AttributeDefClause.xref_equation
                  Property_Result := Attribute_Def_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Rep_Clause =>
                  --# property-call-start EnumRepClause.xref_equation
                  Property_Result := Enum_Rep_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Record_Rep_Clause =>
                  --# property-call-start RecordRepClause.xref_equation
                  Property_Result := Record_Rep_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Subp_Spec .. Ada_Synthetic_Unary_Spec =>
                  --# property-call-start BaseSubpSpec.xref_equation
                  Property_Result := Base_Subp_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Spec =>
                  --# property-call-start EntrySpec.xref_equation
                  Property_Result := Entry_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Aggregate_Assoc .. Ada_Multi_Dim_Array_Assoc =>
                  --# property-call-start AggregateAssoc.xref_equation
                  Property_Result := Aggregate_Assoc_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Iterated_Assoc =>
                  --# property-call-start IteratedAssoc.xref_equation
                  Property_Result := Iterated_Assoc_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Param_Assoc =>
                  --# property-call-start ParamAssoc.xref_equation
                  Property_Result := Param_Assoc_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.xref_equation
                  Property_Result := Component_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discriminant_Spec =>
                  --# property-call-start DiscriminantSpec.xref_equation
                  Property_Result := Discriminant_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Formal_Obj_Decl .. Ada_Generic_Formal_Type_Decl =>
                  --# property-call-start GenericFormal.xref_equation
                  Property_Result := Generic_Formal_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.xref_equation
                  Property_Result := Param_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Decl =>
                  --# property-call-start SubtypeDecl.xref_equation
                  Property_Result := Subtype_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.xref_equation
                  Property_Result := Protected_Type_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.xref_equation
                  Property_Result := Task_Type_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Concrete_Type_Decl =>
                  --# property-call-start TypeDecl.xref_equation
                  Property_Result := Type_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Formal_Type_Decl =>
                  --# property-call-start FormalTypeDecl.xref_equation
                  Property_Result := Formal_Type_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Formal_Subp_Decl .. Ada_Concrete_Formal_Subp_Decl =>
                  --# property-call-start FormalSubpDecl.xref_equation
                  Property_Result := Formal_Subp_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function =>
                  --# property-call-start ExprFunction.xref_equation
                  Property_Result := Expr_Function_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Renaming_Decl =>
                  --# property-call-start SubpRenamingDecl.xref_equation
                  Property_Result := Subp_Renaming_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Body =>
                  --# property-call-start EntryBody.xref_equation
                  Property_Result := Entry_Body_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Index_Spec =>
                  --# property-call-start EntryIndexSpec.xref_equation
                  Property_Result := Entry_Index_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Decl =>
                  --# property-call-start ExceptionDecl.xref_equation
                  Property_Result := Exception_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Handler =>
                  --# property-call-start ExceptionHandler.xref_equation
                  Property_Result := Exception_Handler_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Var_Decl =>
                  --# property-call-start ForLoopVarDecl.xref_equation
                  Property_Result := For_Loop_Var_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Instantiation .. Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericInstantiation.xref_equation
                  Property_Result := Generic_Instantiation_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Renaming_Decl .. Ada_Generic_Subp_Renaming_Decl =>
                  --# property-call-start GenericRenamingDecl.xref_equation
                  Property_Result := Generic_Renaming_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Number_Decl =>
                  --# property-call-start NumberDecl.xref_equation
                  Property_Result := Number_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_Extended_Return_Stmt_Object_Decl =>
                  --# property-call-start ObjectDecl.xref_equation
                  Property_Result := Object_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start NoTypeObjectRenamingDecl.xref_equation
                  Property_Result := No_Type_Object_Renaming_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Package_Renaming_Decl =>
                  --# property-call-start PackageRenamingDecl.xref_equation
                  Property_Result := Package_Renaming_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Single_Protected_Decl =>
                  --# property-call-start SingleProtectedDecl.xref_equation
                  Property_Result := Single_Protected_Decl_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Case_Stmt_Alternative =>
                  --# property-call-start CaseStmtAlternative.xref_equation
                  Property_Result := Case_Stmt_Alternative_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Component_Clause =>
                  --# property-call-start ComponentClause.xref_equation
                  Property_Result := Component_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Component_Def =>
                  --# property-call-start ComponentDef.xref_equation
                  Property_Result := Component_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Composite_Constraint =>
                  --# property-call-start CompositeConstraint.xref_equation
                  Property_Result := Composite_Constraint_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Delta_Constraint =>
                  --# property-call-start DeltaConstraint.xref_equation
                  Property_Result := Delta_Constraint_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Digits_Constraint =>
                  --# property-call-start DigitsConstraint.xref_equation
                  Property_Result := Digits_Constraint_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Range_Constraint =>
                  --# property-call-start RangeConstraint.xref_equation
                  Property_Result := Range_Constraint_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Elsif_Stmt_Part =>
                  --# property-call-start ElsifStmtPart.xref_equation
                  Property_Result := Elsif_Stmt_Part_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_State_Decl_Expr =>
                  --# property-call-start AbstractStateDeclExpr.xref_equation
                  Property_Result := Abstract_State_Decl_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Allocator =>
                  --# property-call-start Allocator.xref_equation
                  Property_Result := Allocator_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Aggregate .. Ada_Null_Record_Aggregate =>
                  --# property-call-start BaseAggregate.xref_equation
                  Property_Result := Base_Aggregate_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Bin_Op .. Ada_Relation_Op =>
                  --# property-call-start BinOp.xref_equation
                  Property_Result := Bin_Op_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Box_Expr =>
                  --# property-call-start BoxExpr.xref_equation
                  Property_Result := Box_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Concat_Op =>
                  --# property-call-start ConcatOp.xref_equation
                  Property_Result := Concat_Op_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Case_Expr =>
                  --# property-call-start CaseExpr.xref_equation
                  Property_Result := Case_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_If_Expr =>
                  --# property-call-start IfExpr.xref_equation
                  Property_Result := If_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Decl_Expr =>
                  --# property-call-start DeclExpr.xref_equation
                  Property_Result := Decl_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Membership_Expr =>
                  --# property-call-start MembershipExpr.xref_equation
                  Property_Result := Membership_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.xref_equation
                  Property_Result := Attribute_Ref_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.xref_equation
                  Property_Result := Call_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.xref_equation
                  Property_Result := Defining_Name_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.xref_equation
                  Property_Result := Dotted_Name_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.xref_equation
                  Property_Result := End_Name_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.xref_equation
                  Property_Result := Explicit_Deref_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Qual_Expr =>
                  --# property-call-start QualExpr.xref_equation
                  Property_Result := Qual_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Reduce_Attribute_Ref =>
                  --# property-call-start ReduceAttributeRef.xref_equation
                  Property_Result := Reduce_Attribute_Ref_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Identifier =>
                  --# property-call-start BaseId.xref_equation
                  Property_Result := Base_Id_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal =>
                  --# property-call-start CharLiteral.xref_equation
                  Property_Result := Char_Literal_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Op_Abs .. Ada_Op_Xor =>
                  --# property-call-start Op.xref_equation
                  Property_Result := Op_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_String_Literal =>
                  --# property-call-start StringLiteral.xref_equation
                  Property_Result := String_Literal_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Null_Literal =>
                  --# property-call-start NullLiteral.xref_equation
                  Property_Result := Null_Literal_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Int_Literal =>
                  --# property-call-start IntLiteral.xref_equation
                  Property_Result := Int_Literal_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Real_Literal =>
                  --# property-call-start RealLiteral.xref_equation
                  Property_Result := Real_Literal_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Target_Name =>
                  --# property-call-start TargetName.xref_equation
                  Property_Result := Target_Name_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Update_Attribute_Ref =>
                  --# property-call-start UpdateAttributeRef.xref_equation
                  Property_Result := Update_Attribute_Ref_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Paren_Expr =>
                  --# property-call-start ParenExpr.xref_equation
                  Property_Result := Paren_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Quantified_Expr =>
                  --# property-call-start QuantifiedExpr.xref_equation
                  Property_Result := Quantified_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Raise_Expr =>
                  --# property-call-start RaiseExpr.xref_equation
                  Property_Result := Raise_Expr_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Un_Op =>
                  --# property-call-start UnOp.xref_equation
                  Property_Result := Un_Op_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Spec =>
                  --# property-call-start ForLoopSpec.xref_equation
                  Property_Result := For_Loop_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_While_Loop_Spec =>
                  --# property-call-start WhileLoopSpec.xref_equation
                  Property_Result := While_Loop_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Others_Designator =>
                  --# property-call-start OthersDesignator.xref_equation
                  Property_Result := Others_Designator_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Pragma_Node =>
                  --# property-call-start Pragma.xref_equation
                  Property_Result := Pragma_Node_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Range_Spec =>
                  --# property-call-start RangeSpec.xref_equation
                  Property_Result := Range_Spec_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Select_When_Part =>
                  --# property-call-start SelectWhenPart.xref_equation
                  Property_Result := Select_When_Part_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Accept_Stmt .. Ada_Accept_Stmt_With_Stmts =>
                  --# property-call-start AcceptStmt.xref_equation
                  Property_Result := Accept_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Stmt .. Ada_While_Loop_Stmt =>
                  --# property-call-start BaseLoopStmt.xref_equation
                  Property_Result := Base_Loop_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Begin_Block .. Ada_Decl_Block =>
                  --# property-call-start BlockStmt.xref_equation
                  Property_Result := Block_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Case_Stmt =>
                  --# property-call-start CaseStmt.xref_equation
                  Property_Result := Case_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Extended_Return_Stmt =>
                  --# property-call-start ExtendedReturnStmt.xref_equation
                  Property_Result := Extended_Return_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_If_Stmt =>
                  --# property-call-start IfStmt.xref_equation
                  Property_Result := If_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Named_Stmt =>
                  --# property-call-start NamedStmt.xref_equation
                  Property_Result := Named_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Select_Stmt =>
                  --# property-call-start SelectStmt.xref_equation
                  Property_Result := Select_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Abort_Stmt =>
                  --# property-call-start AbortStmt.xref_equation
                  Property_Result := Abort_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Assign_Stmt =>
                  --# property-call-start AssignStmt.xref_equation
                  Property_Result := Assign_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Call_Stmt =>
                  --# property-call-start CallStmt.xref_equation
                  Property_Result := Call_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Delay_Stmt =>
                  --# property-call-start DelayStmt.xref_equation
                  Property_Result := Delay_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Exit_Stmt =>
                  --# property-call-start ExitStmt.xref_equation
                  Property_Result := Exit_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Goto_Stmt =>
                  --# property-call-start GotoStmt.xref_equation
                  Property_Result := Goto_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Label =>
                  --# property-call-start Label.xref_equation
                  Property_Result := Label_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Null_Stmt =>
                  --# property-call-start NullStmt.xref_equation
                  Property_Result := Null_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Raise_Stmt =>
                  --# property-call-start RaiseStmt.xref_equation
                  Property_Result := Raise_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Requeue_Stmt =>
                  --# property-call-start RequeueStmt.xref_equation
                  Property_Result := Requeue_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Return_Stmt =>
                  --# property-call-start ReturnStmt.xref_equation
                  Property_Result := Return_Stmt_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Terminate_Alternative =>
                  --# property-call-start TerminateAlternative.xref_equation
                  Property_Result := Terminate_Alternative_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subunit =>
                  --# property-call-start Subunit.xref_equation
                  Property_Result := Subunit_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Task_Def =>
                  --# property-call-start TaskDef.xref_equation
                  Property_Result := Task_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Access_To_Subp_Def =>
                  --# property-call-start AccessToSubpDef.xref_equation
                  Property_Result := Access_To_Subp_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Type_Access_Def =>
                  --# property-call-start TypeAccessDef.xref_equation
                  Property_Result := Type_Access_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Array_Type_Def =>
                  --# property-call-start ArrayTypeDef.xref_equation
                  Property_Result := Array_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.xref_equation
                  Property_Result := Derived_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Type_Def =>
                  --# property-call-start EnumTypeDef.xref_equation
                  Property_Result := Enum_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Formal_Discrete_Type_Def =>
                  --# property-call-start FormalDiscreteTypeDef.xref_equation
                  Property_Result := Formal_Discrete_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Interface_Type_Def =>
                  --# property-call-start InterfaceTypeDef.xref_equation
                  Property_Result := Interface_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Mod_Int_Type_Def =>
                  --# property-call-start ModIntTypeDef.xref_equation
                  Property_Result := Mod_Int_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Private_Type_Def =>
                  --# property-call-start PrivateTypeDef.xref_equation
                  Property_Result := Private_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Decimal_Fixed_Point_Def =>
                  --# property-call-start DecimalFixedPointDef.xref_equation
                  Property_Result := Decimal_Fixed_Point_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Floating_Point_Def =>
                  --# property-call-start FloatingPointDef.xref_equation
                  Property_Result := Floating_Point_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Ordinary_Fixed_Point_Def =>
                  --# property-call-start OrdinaryFixedPointDef.xref_equation
                  Property_Result := Ordinary_Fixed_Point_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Record_Type_Def =>
                  --# property-call-start RecordTypeDef.xref_equation
                  Property_Result := Record_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Signed_Int_Type_Def =>
                  --# property-call-start SignedIntTypeDef.xref_equation
                  Property_Result := Signed_Int_Type_Def_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type =>
                  --# property-call-start AnonymousType.xref_equation
                  Property_Result := Anonymous_Type_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
                  --# property-call-start SubtypeIndication.xref_equation
                  Property_Result := Subtype_Indication_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Use_Package_Clause =>
                  --# property-call-start UsePackageClause.xref_equation
                  Property_Result := Use_Package_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Use_Type_Clause =>
                  --# property-call-start UseTypeClause.xref_equation
                  Property_Result := Use_Type_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Value_Sequence =>
                  --# property-call-start ValueSequence.xref_equation
                  Property_Result := Value_Sequence_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Variant_Part =>
                  --# property-call-start VariantPart.xref_equation
                  Property_Result := Variant_Part_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_With_Clause =>
                  --# property-call-start WithClause.xref_equation
                  Property_Result := With_Clause_P_Xref_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Xref_Equation;
--# end
--# property-start '[dispatcher]AdaNode.xref_stop_resolution' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Xref_Stop_Resolution
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Record_Def | Ada_Composite_Constraint_Assoc | Ada_Param_Assoc .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Quantifier_Some | Ada_Renaming_Clause .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.xref_stop_resolution
                  Property_Result := Ada_Node_P_Xref_Stop_Resolution
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Aggregate_Assoc .. Ada_Multi_Dim_Array_Assoc =>
                  --# property-call-start AggregateAssoc.xref_stop_resolution
                  Property_Result := Aggregate_Assoc_P_Xref_Stop_Resolution
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Iterated_Assoc =>
                  --# property-call-start IteratedAssoc.xref_stop_resolution
                  Property_Result := Iterated_Assoc_P_Xref_Stop_Resolution
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_State_Decl_Expr .. Ada_Attribute_Ref | Ada_Defining_Name .. Ada_Un_Op =>
                  --# property-call-start Expr.xref_stop_resolution
                  Property_Result := Expr_P_Xref_Stop_Resolution
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.xref_stop_resolution
                  Property_Result := Call_Expr_P_Xref_Stop_Resolution
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Range_Spec =>
                  --# property-call-start RangeSpec.xref_stop_resolution
                  Property_Result := Range_Spec_P_Xref_Stop_Resolution
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Xref_Stop_Resolution;
--# end
--# property-start '[dispatcher]AdaNode.stop_resolution_equation' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Stop_Resolution_Equation
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Attribute_Ref | Ada_Defining_Name .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.stop_resolution_equation
                  Property_Result := Ada_Node_P_Stop_Resolution_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.stop_resolution_equation
                  Property_Result := Call_Expr_P_Stop_Resolution_Equation
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Stop_Resolution_Equation;
--# end
--# property-start '[dispatcher]AdaNode.xref_initial_env' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Xref_Initial_Env
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Pp_Then_Kw | Ada_Private_Absent .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.xref_initial_env
                  Property_Result := Ada_Node_P_Xref_Initial_Env
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Pragma_Node =>
                  --# property-call-start Pragma.xref_initial_env
                  Property_Result := Pragma_Node_P_Xref_Initial_Env
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Xref_Initial_Env;
--# end
--# property-start AdaNode.sub_equation /tmp/lal-23.0.0/ada/ast.py:662
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Sub_Equation
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_41 with Inline_Always;
      Fld : Logic_Equation;
Fld_1 : Logic_Equation;
Fld_2 : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_41 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_41;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 307 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 306 '<If at ast.py:670>' If_Result /tmp/lal-23.0.0/ada/ast.py:670
--# expr-start 303 '<FieldAccess for xref_stop_resolution at ast.py:670>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:670
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_stop_resolution'
Fld_2 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Stop_Resolution (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 303
if Fld_2 then
   --# expr-start 304 '<FieldAccess for stop_resolution_equation at ast.py:671>' Fld /tmp/lal-23.0.0/ada/ast.py:671
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.stop_resolution_equation'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Stop_Resolution_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 304
   If_Result := Fld;
else
   --# expr-start 305 '<FieldAccess for xref_equation at ast.py:672>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:672
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 305
   If_Result := Fld_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 306
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 307
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_41;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_41;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Sub_Equation;
--# end
--# property-start AdaNode.resolve_children_names /tmp/lal-23.0.0/ada/ast.py:685
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Children_Names
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Boolean;
            procedure Finalizer_Scope_43 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Node_Children : Bare_Ada_Node_Array_Access;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld : Boolean;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Fld_1 : Boolean;
If_Result_2 : Boolean;
As_Entity_2 : Internal_Entity;
Is_Null_2 : Boolean;
If_Result_3 : Internal_Entity;
Fld_2 : Boolean;
If_Result_4 : Boolean;
Fld_3 : Boolean;
If_Result_5 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Quantifier_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_43 is
            begin
                     Dec_Ref (Node_Children);
            end Finalizer_Scope_43;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 319 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 318 '<AllQuantifier at ast.py:690>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:690
   --# expr-start 308 '<children at ast.py:690>' Node_Children /tmp/lal-23.0.0/ada/ast.py:690
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Children := Children (Self); 
--# expr-done 308
      Quantifier_Result := True;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Children;
      begin
         for Item_9 of
               Collection.Items
         loop
   --# scope-start
               --# bind c Item_9
Var_Expr := Item_9;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 317 '<If at ast.py:693>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:693
--# expr-start 309 '<FieldAccess for xref_entry_point at ast.py:694>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:694
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_entry_point'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Entry_Point (Node => Var_Expr);
--# end
--# expr-done 309
if Fld_3 then
   If_Result_5 := True;
else
--# expr-start 314 '<If at ast.py:696>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:696
--# expr-start 311 '<FieldAccess for xref_stop_resolution at ast.py:697>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:697
--# expr-start 310 '<as_entity at ast.py:697>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:697
Is_Null_1 := Var_Expr = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
As_Entity_1 := (Info => E_Info, Node => Var_Expr); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 310
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_stop_resolution'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Stop_Resolution (Node => If_Result_1.Node, E_Info => If_Result_1.Info);
--# end
--# expr-done 311
if Fld_1 then
   --# expr-start 313 '<FieldAccess for resolve_own_names at ast.py:698>' Fld /tmp/lal-23.0.0/ada/ast.py:698
--# expr-start 312 '<as_entity at ast.py:698>' If_Result /tmp/lal-23.0.0/ada/ast.py:698
Is_Null := Var_Expr = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Var_Expr); 
   If_Result := As_Entity;
end if;
--# expr-done 312
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Ada_Node_P_Resolve_Own_Names (Node => If_Result.Node, Env => Env, Origin => Origin, E_Info => If_Result.Info);
--# expr-done 313
   If_Result_2 := Fld;
else
   If_Result_2 := True;
end if;
--# expr-done 314
if If_Result_2 then
   --# expr-start 316 '<FieldAccess for resolve_children_names at ast.py:700>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:700
--# expr-start 315 '<as_entity at ast.py:700>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:700
Is_Null_2 := Var_Expr = null; 
if Is_Null_2 then
   If_Result_3 := No_Entity;
else
As_Entity_2 := (Info => E_Info, Node => Var_Expr); 
   If_Result_3 := As_Entity_2;
end if;
--# expr-done 315
      if If_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_children_names
Fld_2 := Libadalang.Implementation.Ada_Node_P_Resolve_Children_Names (Node => If_Result_3.Node, Env => Env, Origin => Origin, E_Info => If_Result_3.Info);
--# end
--# expr-done 316
   If_Result_4 := Fld_2;
else
   If_Result_4 := False;
end if;
   If_Result_5 := If_Result_4;
end if;
--# expr-done 317
Scope_Result := If_Result_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
      Quantifier_Result := Result_Var;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
--# expr-done 318
Let_Result := Quantifier_Result; 
--# end
--# expr-done 319
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_43;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_43;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Children_Names;
--# end
--# property-start AdaNode.resolve_names_internal /tmp/lal-23.0.0/ada/ast.py:706
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Names_Internal
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 322 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 320 '<FieldAccess for resolve_own_names at ast.py:710>' Fld /tmp/lal-23.0.0/ada/ast.py:710
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Ada_Node_P_Resolve_Own_Names (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# expr-done 320
if Fld then
   --# expr-start 321 '<FieldAccess for resolve_children_names at ast.py:710>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:710
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_children_names
Fld_1 := Libadalang.Implementation.Ada_Node_P_Resolve_Children_Names (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 321
   If_Result := Fld_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 322
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Names_Internal;
--# end
--# property-start AdaNode.resolve_names_internal_with_eq /tmp/lal-23.0.0/ada/ast.py:713
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Names_Internal_With_Eq
  (Node : Bare_Ada_Node
      ; Additional_Equation : Logic_Equation
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind additional_equation Additional_Equation
   --# bind env Env
   --# bind origin Origin
   Property_Result : Boolean;
            procedure Finalizer_Scope_45 with Inline_Always;
      Fld : Logic_Equation;
And_Pred : Logic_Equation;
Solve_Success : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_45 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_45;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 327 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 325 '<solve at ast.py:718>' Solve_Success /tmp/lal-23.0.0/ada/ast.py:718
--# expr-start 324 '<And at ast.py:718>' And_Pred /tmp/lal-23.0.0/ada/ast.py:718
--# expr-start 323 '<FieldAccess for xref_equation at ast.py:718>' Fld /tmp/lal-23.0.0/ada/ast.py:718
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 323
And_Pred := Create_And (Fld, Additional_Equation, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:718") else null)); 
--# expr-done 324
Solve_Success := Solve_Wrapper (And_Pred, Self); 
--# expr-done 325
if Solve_Success then
   --# expr-start 326 '<FieldAccess for resolve_children_names at ast.py:719>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:719
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_children_names
Fld_1 := Libadalang.Implementation.Ada_Node_P_Resolve_Children_Names (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 326
   If_Result := Fld_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 327
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_45;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_45;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Names_Internal_With_Eq;
--# end
--# property-start '[dispatcher]AdaNode.xref_entry_point' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Ada_Node_P_Xref_Entry_Point
  (Node : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Ada_Node (Self.Kind) is
               when Ada_Abort_Absent .. Ada_Unconstrained_Array_Indices | Ada_Aspect_Spec .. Ada_Pragma_Argument_Assoc | Ada_Component_List .. Ada_Iterated_Assoc | Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Synthetic_Formal_Param_Decl .. Ada_Discrete_Base_Subtype_Decl | Ada_Classwide_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl | Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl | Ada_Null_Subp_Decl .. Ada_Subp_Body | Ada_Package_Body_Stub .. Ada_Task_Body_Stub | Ada_Package_Body .. Ada_Task_Body | Ada_Error_Decl | Ada_For_Loop_Var_Decl .. Ada_Generic_Subp_Decl | Ada_Label_Decl .. Ada_Named_Stmt_Decl | Ada_Single_Task_Decl | Ada_Compilation_Unit | Ada_Component_Def .. Ada_Elsif_Expr_Part | Ada_Abstract_State_Decl_Expr .. Ada_Call_Expr | Ada_Discrete_Subtype_Name .. Ada_Dotted_Name | Ada_Explicit_Deref .. Ada_Limited_Present | Ada_While_Loop_Spec .. Ada_Pp_Then_Kw | Ada_Private_Absent .. Ada_Select_When_Part | Ada_Subp_Kind_Function .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_Type_Access_Def | Ada_Derived_Type_Def .. Ada_Until_Present | Ada_Value_Sequence .. Ada_Variant | Ada_With_Private_Absent .. Ada_With_Private_Present =>
                  --# property-call-start AdaNode.xref_entry_point
                  Property_Result := Ada_Node_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Aspect_Assoc =>
                  --# property-call-start AspectAssoc.xref_entry_point
                  Property_Result := Aspect_Assoc_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_At_Clause .. Ada_Record_Rep_Clause =>
                  --# property-call-start AspectClause.xref_entry_point
                  Property_Result := Aspect_Clause_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Entry_Spec .. Ada_Synthetic_Unary_Spec =>
                  --# property-call-start BaseSubpSpec.xref_entry_point
                  Property_Result := Base_Subp_Spec_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Param_Assoc =>
                  --# property-call-start ParamAssoc.xref_entry_point
                  Property_Result := Param_Assoc_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.xref_entry_point
                  Property_Result := Component_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Discriminant_Spec =>
                  --# property-call-start DiscriminantSpec.xref_entry_point
                  Property_Result := Discriminant_Spec_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Generic_Formal_Obj_Decl .. Ada_Generic_Formal_Type_Decl =>
                  --# property-call-start GenericFormal.xref_entry_point
                  Property_Result := Generic_Formal_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.xref_entry_point
                  Property_Result := Param_Spec_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Subtype_Decl =>
                  --# property-call-start SubtypeDecl.xref_entry_point
                  Property_Result := Subtype_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.xref_entry_point
                  Property_Result := Protected_Type_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.xref_entry_point
                  Property_Result := Task_Type_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Concrete_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.xref_entry_point
                  Property_Result := Type_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Synth_Anonymous_Type_Decl =>
                  --# property-call-start AnonymousTypeDecl.xref_entry_point
                  Property_Result := Anonymous_Type_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Expr_Function =>
                  --# property-call-start ExprFunction.xref_entry_point
                  Property_Result := Expr_Function_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Subp_Renaming_Decl =>
                  --# property-call-start SubpRenamingDecl.xref_entry_point
                  Property_Result := Subp_Renaming_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Entry_Body =>
                  --# property-call-start EntryBody.xref_entry_point
                  Property_Result := Entry_Body_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Entry_Index_Spec =>
                  --# property-call-start EntryIndexSpec.xref_entry_point
                  Property_Result := Entry_Index_Spec_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Exception_Decl =>
                  --# property-call-start ExceptionDecl.xref_entry_point
                  Property_Result := Exception_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Exception_Handler =>
                  --# property-call-start ExceptionHandler.xref_entry_point
                  Property_Result := Exception_Handler_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Generic_Package_Instantiation .. Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericInstantiation.xref_entry_point
                  Property_Result := Generic_Instantiation_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Generic_Package_Renaming_Decl .. Ada_Generic_Subp_Renaming_Decl =>
                  --# property-call-start GenericRenamingDecl.xref_entry_point
                  Property_Result := Generic_Renaming_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Number_Decl =>
                  --# property-call-start NumberDecl.xref_entry_point
                  Property_Result := Number_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.xref_entry_point
                  Property_Result := Object_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Package_Renaming_Decl =>
                  --# property-call-start PackageRenamingDecl.xref_entry_point
                  Property_Result := Package_Renaming_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Single_Protected_Decl =>
                  --# property-call-start SingleProtectedDecl.xref_entry_point
                  Property_Result := Single_Protected_Decl_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Case_Stmt_Alternative =>
                  --# property-call-start CaseStmtAlternative.xref_entry_point
                  Property_Result := Case_Stmt_Alternative_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Component_Clause =>
                  --# property-call-start ComponentClause.xref_entry_point
                  Property_Result := Component_Clause_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Elsif_Stmt_Part =>
                  --# property-call-start ElsifStmtPart.xref_entry_point
                  Property_Result := Elsif_Stmt_Part_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.xref_entry_point
                  Property_Result := Defining_Name_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.xref_entry_point
                  Property_Result := End_Name_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_For_Loop_Spec =>
                  --# property-call-start ForLoopSpec.xref_entry_point
                  Property_Result := For_Loop_Spec_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Pragma_Node =>
                  --# property-call-start Pragma.xref_entry_point
                  Property_Result := Pragma_Node_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Accept_Stmt .. Ada_Terminate_Alternative =>
                  --# property-call-start Stmt.xref_entry_point
                  Property_Result := Stmt_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Subunit =>
                  --# property-call-start Subunit.xref_entry_point
                  Property_Result := Subunit_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Array_Type_Def =>
                  --# property-call-start ArrayTypeDef.xref_entry_point
                  Property_Result := Array_Type_Def_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Use_Package_Clause .. Ada_Use_Type_Clause =>
                  --# property-call-start UseClause.xref_entry_point
                  Property_Result := Use_Clause_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_Variant_Part =>
                  --# property-call-start VariantPart.xref_entry_point
                  Property_Result := Variant_Part_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
               when Ada_With_Clause =>
                  --# property-call-start WithClause.xref_entry_point
                  Property_Result := With_Clause_P_Xref_Entry_Point
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Ada_Node_P_Xref_Entry_Point;
--# end
--# property-start AdaNode.resolve_names /tmp/lal-23.0.0/ada/ast.py:738
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Names
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
            procedure Finalizer_Scope_47 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Dyn_Var_Bind_Result_1 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_47 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_47;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Resolve_Names,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 333 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 332 '<bind at ast.py:744>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:744
--# expr-start 328 '<FieldAccess for xref_initial_env at ast.py:745>' Fld /tmp/lal-23.0.0/ada/ast.py:745
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_initial_env'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Initial_Env (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 328
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 331 '<bind at ast.py:746>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:746
--# expr-start 329 '<FieldAccess for origin_node at ast.py:746>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:746
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 329
Bound_Origin := Fld_1; 
--# expr-start 330 '<FieldAccess for resolve_names_internal at ast.py:746>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:746
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_internal
Fld_2 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal (Node => Ent.Node, Env => Bound_Env, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 330
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 331
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; 
--# expr-done 332
Let_Result := Dyn_Var_Bind_Result_1; 
--# end
--# expr-done 333
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_47;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_47;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Names;
--# end
--# property-start AdaNode.resolve_names_from_closest_entry_point_impl /tmp/lal-23.0.0/ada/ast.py:750
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Names_From_Closest_Entry_Point_Impl
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_48 with Inline_Always;
            procedure Finalizer_Scope_1779 with Inline_Always;
      Res : Lexical_Env := Empty_Env;
Var_Expr : Internal_Entity;
Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Boolean;
If_Result : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result_1 : Lexical_Env := Empty_Env;
Fld_3 : Internal_Entity;
Fld_4 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Is_Equal : Boolean;
Fld_5 : Boolean;
Bound_Env_1 : Lexical_Env := Empty_Env;
Fld_6 : Bare_Ada_Node;
Bound_Origin_1 : Bare_Ada_Node;
Fld_7 : Boolean;
If_Result_1 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result_2 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result_3 : Lexical_Env := Empty_Env;
If_Result_2 : Lexical_Env := Empty_Env;
If_Result_3 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
Fld_8 : Boolean;
If_Result_4 : Lexical_Env := Empty_Env;
Let_Result_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_48 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (If_Result);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Res);
                     Dec_Ref (Bound_Env_1);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result_2);
                     Dec_Ref (Dyn_Var_Bind_Result_3);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (Let_Result);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_48;
            procedure Finalizer_Scope_1779 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_1779;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 353 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 352 '<If at ast.py:760>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:760
--# expr-start 334 '<FieldAccess for xref_entry_point at ast.py:764>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:764
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_entry_point'
Fld_8 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Entry_Point (Node => Ent.Node);
--# end
--# expr-done 334
if Fld_8 then
   --# expr-start 340 '<bind at ast.py:765>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:765
--# expr-start 335 '<FieldAccess for xref_initial_env at ast.py:766>' Fld /tmp/lal-23.0.0/ada/ast.py:766
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_initial_env'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Initial_Env (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 335
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 339 '<bind at ast.py:767>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:767
--# expr-start 336 '<FieldAccess for origin_node at ast.py:768>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:768
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 336
Bound_Origin := Fld_1; 
--# expr-start 338 '<If at ast.py:769>' If_Result /tmp/lal-23.0.0/ada/ast.py:769
--# expr-start 337 '<FieldAccess for resolve_own_names at ast.py:769>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:769
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Ada_Node_P_Resolve_Own_Names (Node => Ent.Node, Env => Bound_Env, Origin => Bound_Origin, E_Info => Ent.Info);
--# expr-done 337
if Fld_2 then
   If_Result := Bound_Env;
else
   If_Result := Empty_Env;
end if;
      Inc_Ref (If_Result);
--# expr-done 338
Dyn_Var_Bind_Result := If_Result; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 339
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 340
   If_Result_4 := Dyn_Var_Bind_Result_1;
else
   --# expr-start 351 '<Let at ast.py:773>' Let_Result /tmp/lal-23.0.0/ada/ast.py:773
--# scope-start
--# expr-start 341 '<parent at ast.py:778>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:778
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 341
Var_Expr := Fld_3;
if Var_Expr /= No_Entity then
   --# scope-start
--# expr-start 342 '<FieldAccess for resolve_names_from_closest_entry_point_impl at ast.py:779>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:779
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_from_closest_entry_point_impl
Fld_4 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_From_Closest_Entry_Point_Impl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 342
Scope_Result := Fld_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1779;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
Res := Result_Var; Inc_Ref (Res);
--# bind res Res
--# expr-start 350 '<Cond at ast.py:781>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:781
--# expr-start 343 '<Eq at ast.py:783>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:783
Is_Equal := Equivalent (Res, Empty_Env); 
--# expr-done 343
if Is_Equal then
   If_Result_3 := Res;
else
--# expr-start 344 '<FieldAccess for xref_stop_resolution at ast.py:789>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:789
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_stop_resolution'
Fld_5 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Stop_Resolution (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 344
if Fld_5 then
   --# expr-start 349 '<bind at ast.py:790>' Dyn_Var_Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:790
Bound_Env_1 := Res; Inc_Ref (Bound_Env_1);
--# expr-start 348 '<bind at ast.py:792>' Dyn_Var_Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:792
--# expr-start 345 '<FieldAccess for origin_node at ast.py:793>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:793
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_6 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 345
Bound_Origin_1 := Fld_6; 
--# expr-start 347 '<If at ast.py:794>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:794
--# expr-start 346 '<FieldAccess for resolve_own_names at ast.py:794>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:794
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Ada_Node_P_Resolve_Own_Names (Node => Ent.Node, Env => Bound_Env_1, Origin => Bound_Origin_1, E_Info => Ent.Info);
--# expr-done 346
if Fld_7 then
   If_Result_1 := Res;
else
   If_Result_1 := Empty_Env;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 347
Dyn_Var_Bind_Result_2 := If_Result_1; Inc_Ref (Dyn_Var_Bind_Result_2);
--# expr-done 348
Dyn_Var_Bind_Result_3 := Dyn_Var_Bind_Result_2; Inc_Ref (Dyn_Var_Bind_Result_3);
--# expr-done 349
   If_Result_2 := Dyn_Var_Bind_Result_3;
else
   If_Result_2 := Res;
end if;
      Inc_Ref (If_Result_2);
   If_Result_3 := If_Result_2;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 350
Let_Result := If_Result_3; Inc_Ref (Let_Result);
--# end
--# expr-done 351
   If_Result_4 := Let_Result;
end if;
      Inc_Ref (If_Result_4);
--# expr-done 352
Let_Result_1 := If_Result_4; Inc_Ref (Let_Result_1);
--# end
--# expr-done 353
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_48;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_48;
               Finalizer_Scope_1779;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Names_From_Closest_Entry_Point_Impl;
--# end
--# property-start AdaNode.resolve_names_from_closest_entry_point /tmp/lal-23.0.0/ada/ast.py:807
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Names_From_Closest_Entry_Point
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
            procedure Finalizer_Scope_49 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Fld : Lexical_Env := Empty_Env;
Is_Equal : Boolean;
Not_Val : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_49 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_49;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 357 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 354 '<FieldAccess for resolve_names_from_closest_entry_point_impl at ast.py:829>' Fld /tmp/lal-23.0.0/ada/ast.py:829
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_from_closest_entry_point_impl
Fld := Libadalang.Implementation.Ada_Node_P_Resolve_Names_From_Closest_Entry_Point_Impl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 354
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind result Block_Var
--# expr-start 356 '<Not at ast.py:830>' Not_Val /tmp/lal-23.0.0/ada/ast.py:830
--# expr-start 355 '<Eq at ast.py:830>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:830
Is_Equal := Equivalent (Block_Var, Empty_Env); 
--# expr-done 355
Not_Val := not (Is_Equal); 
--# expr-done 356
Let_Result := Not_Val; 
--# end
--# expr-done 357
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_49;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_49;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Names_From_Closest_Entry_Point;
--# end
--# property-start AdaNode.parent_unit_env_helper /tmp/lal-23.0.0/ada/ast.py:833
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Parent_Unit_Env_Helper
  (Node : Bare_Ada_Node
      ; Unit : Internal_Unit
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind unit Unit
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_50 with Inline_Always;
            procedure Finalizer_Scope_1780 with Inline_Always;
            procedure Finalizer_Scope_1781 with Inline_Always;
      Var_Expr : Lexical_Env := Empty_Env;
Var_Expr_1 : Bare_Ada_Node;
Env_Parent : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Fld : Lexical_Env := Empty_Env;
Fld_1 : Internal_Unit;
Is_Equal : Boolean;
If_Result : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_50 is
            begin
                     Dec_Ref (Env_Parent);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_50;
            procedure Finalizer_Scope_1780 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1780;
            procedure Finalizer_Scope_1781 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_1781;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 364 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 358 '<env_parent at ast.py:834>' Env_Parent /tmp/lal-23.0.0/ada/ast.py:834
Env_Parent := AST_Envs.Parent (Env); 
--# expr-done 358
Var_Expr := Env_Parent;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_Env then
   --# scope-start
   --# bind parent_env Var_Expr
--# expr-start 359 '<env_node at ast.py:834>' Env_Node /tmp/lal-23.0.0/ada/ast.py:834
Env_Node := AST_Envs.Env_Node (Var_Expr); 
--# expr-done 359
Var_Expr_1 := Env_Node;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind parent_node Var_Expr_1
--# expr-start 363 '<If at ast.py:835>' If_Result /tmp/lal-23.0.0/ada/ast.py:835
--# expr-start 361 '<Eq at ast.py:836>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:836
--# expr-start 360 '<FieldAccess for unit at ast.py:836>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:836
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Unit (Node => Var_Expr_1);
--# expr-done 360
Is_Equal := Fld_1 = Unit; 
--# expr-done 361
if Is_Equal then
   --# expr-start 362 '<FieldAccess for parent_unit_env_helper at ast.py:837>' Fld /tmp/lal-23.0.0/ada/ast.py:837
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_unit_env_helper
Fld := Libadalang.Implementation.Ada_Node_P_Parent_Unit_Env_Helper (Node => Self, Unit => Unit, Env => Var_Expr);
--# end
--# expr-done 362
   If_Result := Fld;
else
   If_Result := Var_Expr;
end if;
      Inc_Ref (If_Result);
--# expr-done 363
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1781;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
Scope_Result_1 := Result_Var;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1780;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Empty_Env;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
--# expr-done 364
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_50;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_50;
               Finalizer_Scope_1780;
               Finalizer_Scope_1781;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Parent_Unit_Env_Helper;
--# end
--# property-start AdaNode.parent_unit_env /tmp/lal-23.0.0/ada/ast.py:843
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Parent_Unit_Env
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_51 with Inline_Always;
            procedure Finalizer_Scope_1782 with Inline_Always;
      Var_Expr : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Fld : Internal_Unit;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_51 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_51;
            procedure Finalizer_Scope_1782 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1782;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 368 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr := Env;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_Env then
   --# scope-start
   --# bind env Var_Expr
--# expr-start 367 '<FieldAccess for parent_unit_env_helper at ast.py:849>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:849
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 366 '<FieldAccess for unit at ast.py:849>' Fld /tmp/lal-23.0.0/ada/ast.py:849
--# expr-start 365 '<env_node at ast.py:849>' Env_Node /tmp/lal-23.0.0/ada/ast.py:849
Env_Node := AST_Envs.Env_Node (Var_Expr); 
--# expr-done 365
      if Env_Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Env_Node);
--# expr-done 366
--# property-call-start AdaNode.parent_unit_env_helper
Fld_1 := Libadalang.Implementation.Ada_Node_P_Parent_Unit_Env_Helper (Node => Self, Unit => Fld, Env => Var_Expr);
--# end
--# expr-done 367
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1782;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 368
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_51;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_51;
               Finalizer_Scope_1782;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Parent_Unit_Env;
--# end
--# property-start AdaNode.std /tmp/lal-23.0.0/ada/ast.py:861
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Unit;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_2 : Bare_Ada_Node;
Cast_Result_1 : Bare_Library_Item;
Fld_3 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 375 '<as_bare_entity at ast.py:863>' If_Result /tmp/lal-23.0.0/ada/ast.py:863
--# expr-start 374 '<FieldAccess for item at ast.py:863>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:863
--# expr-start 373 '<Cast to LibraryItem at ast.py:863>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:863
--# expr-start 372 '<FieldAccess for body at ast.py:863>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:863
--# expr-start 371 '<Cast to CompilationUnit at ast.py:862>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:862
--# expr-start 370 '<FieldAccess for root at ast.py:862>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:862
--# expr-start 369 '<FieldAccess for standard_unit at ast.py:862>' Fld /tmp/lal-23.0.0/ada/ast.py:862
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Ada_Node_P_Standard_Unit (Node => Self);
--# expr-done 369
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Ast_Root;
--# expr-done 370
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 371
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Compilation_Unit_F_Body;
--# expr-done 372
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Library_Item_Range
   then
      Cast_Result_1 := Fld_2;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 373
      if Cast_Result_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Cast_Result_1.Library_Item_F_Item;
--# expr-done 374
Is_Null := Fld_3 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_3); 
   If_Result := As_Entity;
end if;
--# expr-done 375
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std;
--# end
--# property-start AdaNode.std_env /tmp/lal-23.0.0/ada/ast.py:870
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Env
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_54 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_54 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_54;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 377 '<FieldAccess for children_env at ast.py:871>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:871
--# expr-start 376 '<FieldAccess for std at ast.py:871>' Fld /tmp/lal-23.0.0/ada/ast.py:871
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std
Fld := Libadalang.Implementation.Ada_Node_P_Std (Node => Self);
--# end
--# expr-done 376
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 377
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_54;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_54;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Env;
--# end
--# property-start AdaNode.std_entity /tmp/lal-23.0.0/ada/ast.py:875
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Entity
  (Node : Bare_Ada_Node
      ; Sym : Symbol_Type
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   Property_Result : Internal_Entity;
      Fld : Internal_Unit;
Fld_1 : Bare_Ada_Node;
Fld_2 : Internal_Entity;
Let_Result : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 381 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 380 '<FieldAccess for std_entity_implem at ast.py:876>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:876
--# expr-start 379 '<FieldAccess for root at ast.py:876>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:876
--# expr-start 378 '<FieldAccess for unit at ast.py:876>' Fld /tmp/lal-23.0.0/ada/ast.py:876
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 378
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Ast_Root;
--# expr-done 379
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_entity_implem
Fld_2 := Libadalang.Implementation.Ada_Node_P_Std_Entity_Implem (Node => Fld_1, Sym => Sym);
--# end
--# expr-done 380
Let_Result := Fld_2; 
--# end
--# expr-done 381
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Entity;
--# end
--# property-start AdaNode.std_entity_implem /tmp/lal-23.0.0/ada/ast.py:882
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Entity_Implem
  (Node : Bare_Ada_Node
      ; Sym : Symbol_Type
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   Property_Result : Internal_Entity;
            procedure Finalizer_Scope_56 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity;
Let_Result : Internal_Entity;
            procedure Finalizer_Scope_56 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_56;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Std_Entity_Implem,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Sym);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 384 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 383 '<EnvGet at ast.py:883>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:883
--# expr-start 382 '<FieldAccess for std_env at ast.py:883>' Fld /tmp/lal-23.0.0/ada/ast.py:883
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_env
Fld := Libadalang.Implementation.Ada_Node_P_Std_Env (Node => Self);
--# end
--# expr-done 382
Env_Get_Result := AST_Envs.Get_First (Self => Fld, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 383
Let_Result := Env_Get_Result; 
--# end
--# expr-done 384
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_56;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity,
                        As_Internal_Entity => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_56;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Entity_Implem;
--# end
--# property-start AdaNode.bool_type /tmp/lal-23.0.0/ada/ast.py:887
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Bool_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 387 '<Cast to BaseTypeDecl at ast.py:888>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:888
--# expr-start 386 '<FieldAccess for std_entity at ast.py:888>' Fld /tmp/lal-23.0.0/ada/ast.py:888
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 385 '<Symbol Boolean at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Boolean); 
--# expr-done 385
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 386
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 387
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Bool_Type;
--# end
--# property-start AdaNode.int_type /tmp/lal-23.0.0/ada/ast.py:892
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Int_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 390 '<Cast to BaseTypeDecl at ast.py:893>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:893
--# expr-start 389 '<FieldAccess for std_entity at ast.py:893>' Fld /tmp/lal-23.0.0/ada/ast.py:893
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 388 '<Symbol Integer at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Integer); 
--# expr-done 388
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 389
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 390
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Int_Type;
--# end
--# property-start AdaNode.universal_int_type /tmp/lal-23.0.0/ada/ast.py:897
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Universal_Int_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity;
      Sym : Symbol_Type;
Fld : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 392 '<FieldAccess for std_entity at ast.py:898>' Fld /tmp/lal-23.0.0/ada/ast.py:898
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 391 '<Symbol Universal_Int_Type_ at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Universal_Int_Type); 
--# expr-done 391
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 392
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Universal_Int_Type;
--# end
--# property-start AdaNode.universal_real_type /tmp/lal-23.0.0/ada/ast.py:902
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Universal_Real_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity;
      Sym : Symbol_Type;
Fld : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 394 '<FieldAccess for std_entity at ast.py:903>' Fld /tmp/lal-23.0.0/ada/ast.py:903
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 393 '<Symbol Universal_Real_Type_ at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Universal_Real_Type); 
--# expr-done 393
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 394
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Universal_Real_Type;
--# end
--# property-start AdaNode.std_char_type /tmp/lal-23.0.0/ada/ast.py:907
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Char_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 397 '<Cast to BaseTypeDecl at ast.py:908>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:908
--# expr-start 396 '<FieldAccess for std_entity at ast.py:908>' Fld /tmp/lal-23.0.0/ada/ast.py:908
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 395 '<Symbol Character at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Character); 
--# expr-done 395
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 396
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 397
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Char_Type;
--# end
--# property-start AdaNode.std_wide_char_type /tmp/lal-23.0.0/ada/ast.py:912
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Wide_Char_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 400 '<Cast to BaseTypeDecl at ast.py:913>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:913
--# expr-start 399 '<FieldAccess for std_entity at ast.py:913>' Fld /tmp/lal-23.0.0/ada/ast.py:913
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 398 '<Symbol Wide_Character at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Character); 
--# expr-done 398
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 399
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 400
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Wide_Char_Type;
--# end
--# property-start AdaNode.std_wide_wide_char_type /tmp/lal-23.0.0/ada/ast.py:918
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Wide_Wide_Char_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 403 '<Cast to BaseTypeDecl at ast.py:919>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:919
--# expr-start 402 '<FieldAccess for std_entity at ast.py:919>' Fld /tmp/lal-23.0.0/ada/ast.py:919
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 401 '<Symbol Wide_Wide_Character at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Character); 
--# expr-done 401
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 402
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 403
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Wide_Wide_Char_Type;
--# end
--# property-start AdaNode.std_root_types /tmp/lal-23.0.0/ada/ast.py:925
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Std_Root_Types
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_64 with Inline_Always;
            procedure Finalizer_Scope_1783 with Inline_Always;
      Var_Expr : Internal_Entity_Package_Decl;
Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Package_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_64 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_64;
            procedure Finalizer_Scope_1783 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1783;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 406 '<Cast to PackageDecl at ast.py:926>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:926
--# expr-start 405 '<FieldAccess for std_entity at ast.py:926>' Fld /tmp/lal-23.0.0/ada/ast.py:926
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 404 '<Symbol root_types_ at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Types); 
--# expr-done 404
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 405
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Package_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Package_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Package_Decl;
   end if;
--# expr-done 406
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Package_Decl then
   --# scope-start
--# expr-start 407 '<FieldAccess for children_env at ast.py:926>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:926
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# expr-done 407
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1783;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_64;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_64;
               Finalizer_Scope_1783;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Std_Root_Types;
--# end
--# property-start AdaNode.root_int_type /tmp/lal-23.0.0/ada/ast.py:932
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Root_Int_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_65 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_65 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_65;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 411 '<Cast to BaseTypeDecl at ast.py:935>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:935
--# expr-start 410 '<EnvGet at ast.py:933>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:933
--# expr-start 408 '<FieldAccess for std_root_types at ast.py:933>' Fld /tmp/lal-23.0.0/ada/ast.py:933
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_root_types
Fld := Libadalang.Implementation.Ada_Node_P_Std_Root_Types (Node => Self);
--# end
--# expr-done 408
--# expr-start 409 '<Symbol root_integer at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Integer); 
--# expr-done 409
Env_Get_Result := AST_Envs.Get_First (Self => Fld, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 410
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 411
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_65;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_65;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Root_Int_Type;
--# end
--# property-start AdaNode.root_real_type /tmp/lal-23.0.0/ada/ast.py:938
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Root_Real_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_66 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_66 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_66;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 415 '<Cast to BaseTypeDecl at ast.py:941>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:941
--# expr-start 414 '<EnvGet at ast.py:939>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:939
--# expr-start 412 '<FieldAccess for std_root_types at ast.py:939>' Fld /tmp/lal-23.0.0/ada/ast.py:939
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_root_types
Fld := Libadalang.Implementation.Ada_Node_P_Std_Root_Types (Node => Self);
--# end
--# expr-done 412
--# expr-start 413 '<Symbol root_real at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Real); 
--# expr-done 413
Env_Get_Result := AST_Envs.Get_First (Self => Fld, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 414
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 415
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_66;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_66;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Root_Real_Type;
--# end
--# property-start AdaNode.root_type_ops_impl /tmp/lal-23.0.0/ada/ast.py:947
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Root_Type_Ops_Impl
  (Node : Bare_Ada_Node
      ; Sym : Symbol_Type
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_67 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_1 : Boolean;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_67 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_67;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Root_Type_Ops_Impl,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Sym);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
      end if;
   --# scope-start
      --# expr-start 422 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 421 '<FilterMap at ast.py:953>' Map_Result /tmp/lal-23.0.0/ada/ast.py:953
   --# expr-start 417 '<EnvGet at ast.py:951>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:951
--# expr-start 416 '<FieldAccess for std_root_types at ast.py:951>' Fld /tmp/lal-23.0.0/ada/ast.py:951
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_root_types
Fld := Libadalang.Implementation.Ada_Node_P_Std_Root_Types (Node => Self);
--# end
--# expr-done 416
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 417
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_10 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_10
         --# expr-start 419 '<FieldAccess for is_subprogram at ast.py:955>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:955
--# expr-start 418 '<Cast to BasicDecl at ast.py:955>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:955
Cast_Expr_1 := Item_10; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 418
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Cast_Result_1.Node);
--# end
--# expr-done 419
         if Fld_1 then
      --# expr-start 420 '<Cast to BasicDecl at ast.py:954>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:954
Cast_Expr := Item_10; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 420
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 421
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 422
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_67;
      if Self /= null then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl_Array_Access,
                        As_Internal_Entity_Basic_Decl_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_67;
         if Self /= null then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Root_Type_Ops_Impl;
--# end
--# property-start AdaNode.root_type_ops /tmp/lal-23.0.0/ada/ast.py:959
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Root_Type_Ops
  (Node : Bare_Ada_Node
      ; Sym : Symbol_Type
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_68 with Inline_Always;
      Fld : Internal_Unit;
Fld_1 : Bare_Ada_Node;
Fld_2 : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_68 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_68;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 426 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 425 '<FieldAccess for root_type_ops_impl at ast.py:965>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:965
--# expr-start 424 '<FieldAccess for root at ast.py:965>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:965
--# expr-start 423 '<FieldAccess for unit at ast.py:965>' Fld /tmp/lal-23.0.0/ada/ast.py:965
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 423
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Ast_Root;
--# expr-done 424
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_type_ops_impl
Fld_2 := Libadalang.Implementation.Ada_Node_P_Root_Type_Ops_Impl (Node => Fld_1, Sym => Sym);
--# end
--# expr-done 425
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 426
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_68;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_68;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Root_Type_Ops;
--# end
--# property-start AdaNode.exc_id_type /tmp/lal-23.0.0/ada/ast.py:967
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Exc_Id_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_69 with Inline_Always;
            procedure Finalizer_Scope_1785 with Inline_Always;
      Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_69 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_69;
            procedure Finalizer_Scope_1785 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1785;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 434 '<Cast to BaseTypeDecl at ast.py:971>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:971
--# expr-start 433 '<EnvGet at ast.py:968>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:968
--# expr-start 430 '<FieldAccess for get_unit_root_decl at ast.py:969>' Fld /tmp/lal-23.0.0/ada/ast.py:969
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 429 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 427 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 427
--# expr-start 428 '<Symbol Exceptions at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exceptions); 
--# expr-done 428
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 429
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 430
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 431 '<FieldAccess for children_env at ast.py:970>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:970
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 431
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1785;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 432 '<Symbol Exception_Id at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exception_Id); 
--# expr-done 432
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 433
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 434
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_69;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_69;
               Finalizer_Scope_1785;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Exc_Id_Type;
--# end
--# property-start AdaNode.task_id_type /tmp/lal-23.0.0/ada/ast.py:977
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Task_Id_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_70 with Inline_Always;
            procedure Finalizer_Scope_1786 with Inline_Always;
      Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_70 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_70;
            procedure Finalizer_Scope_1786 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1786;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 442 '<Cast to BaseTypeDecl at ast.py:981>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:981
--# expr-start 441 '<EnvGet at ast.py:978>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:978
--# expr-start 438 '<FieldAccess for get_unit_root_decl at ast.py:978>' Fld /tmp/lal-23.0.0/ada/ast.py:978
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 437 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 435 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 435
--# expr-start 436 '<Symbol Task_Identification at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Task_Identification); 
--# expr-done 436
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 437
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 438
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 439 '<FieldAccess for children_env at ast.py:980>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:980
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 439
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1786;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 440 '<Symbol Task_Id at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Task_Id); 
--# expr-done 440
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 441
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 442
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_70;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_70;
               Finalizer_Scope_1786;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Task_Id_Type;
--# end
--# property-start AdaNode.root_buffer_type /tmp/lal-23.0.0/ada/ast.py:986
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Root_Buffer_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_71 with Inline_Always;
            procedure Finalizer_Scope_1787 with Inline_Always;
      Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Sym_2 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_3 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_71 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_71;
            procedure Finalizer_Scope_1787 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1787;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 451 '<Cast to BaseTypeDecl at ast.py:990>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:990
--# expr-start 450 '<EnvGet at ast.py:987>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:987
--# expr-start 447 '<FieldAccess for get_unit_root_decl at ast.py:987>' Fld /tmp/lal-23.0.0/ada/ast.py:987
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 446 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 443 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 443
--# expr-start 444 '<Symbol Strings at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Strings); 
--# expr-done 444
--# expr-start 445 '<Symbol Text_Buffers at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Text_Buffers); 
--# expr-done 445
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1, 3 => Sym_2)); 
--# expr-done 446
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 447
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 448 '<FieldAccess for children_env at ast.py:989>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:989
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 448
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1787;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 449 '<Symbol Root_Buffer_Type at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Buffer_Type); 
--# expr-done 449
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_3, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 450
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 451
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_71;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_71;
               Finalizer_Scope_1787;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Root_Buffer_Type;
--# end
--# property-start AdaNode.root_stream_type /tmp/lal-23.0.0/ada/ast.py:995
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Root_Stream_Type
  (Node : Bare_Ada_Node
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_72 with Inline_Always;
            procedure Finalizer_Scope_1788 with Inline_Always;
      Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Classwide_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_72 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_72;
            procedure Finalizer_Scope_1788 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1788;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 461 '<Cast to BaseTypeDecl at ast.py:998>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:998
--# expr-start 460 '<FieldAccess for classwide_type at ast.py:998>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:998
--# expr-start 459 '<Cast to BaseTypeDecl at ast.py:998>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:998
--# expr-start 458 '<EnvGet at ast.py:996>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:996
--# expr-start 455 '<FieldAccess for get_unit_root_decl at ast.py:996>' Fld /tmp/lal-23.0.0/ada/ast.py:996
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 454 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 452 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 452
--# expr-start 453 '<Symbol Streams at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Streams); 
--# expr-done 453
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 454
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 455
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 456 '<FieldAccess for children_env at ast.py:997>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:997
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 456
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1788;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 457 '<Symbol Root_Stream_Type at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Stream_Type); 
--# expr-done 457
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 458
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 459
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 460
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# expr-done 461
      Property_Result := Cast_Result_1;
   --# end
      Finalizer_Scope_72;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_72;
               Finalizer_Scope_1788;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Root_Stream_Type;
--# end
--# property-start AdaNode.has_with_visibility /tmp/lal-23.0.0/ada/ast.py:1004
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Has_With_Visibility
  (Node : Bare_Ada_Node
      ; Refd_Unit : Internal_Unit
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind refd_unit Refd_Unit
   Property_Result : Boolean;
            procedure Finalizer_Scope_73 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Var_Expr_1 : Internal_Entity_Base_Subp_Body;
Var_Expr_2 : Internal_Unit;
Var_Expr_3 : Bare_Ada_Node;
Var_Expr_4 : Bare_Compilation_Unit;
Fld : Internal_Unit;
Fld_1 : Boolean;
Fld_2 : Internal_Unit;
Fld_3 : Bare_Basic_Decl;
Fld_4 : Lexical_Env := Empty_Env;
Fld_5 : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Fld_6 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Fld_7 : Internal_Unit;
Fld_8 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Base_Subp_Body;
Fld_9 : Internal_Entity_Defining_Name;
Fld_10 : Internal_Unit;
Fld_11 : Bare_Ada_Node;
Fld_12 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Fld_13 : Boolean;
If_Result_2 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
If_Result_3 : Boolean;
Fld_14 : Bare_Ada_Node;
Cast_Result_1 : Bare_Compilation_Unit;
Fld_15 : Boolean;
Scope_Result_4 : Boolean;
Result_Var_4 : Boolean;
If_Result_4 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_73 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_73;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 483 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 463 '<FieldAccess for is_referenced_from at ast.py:1012>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1012
      if Refd_Unit = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 462 '<FieldAccess for unit at ast.py:1012>' Fld /tmp/lal-23.0.0/ada/ast.py:1012
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 462
Fld_1 := Libadalang.Implementation.Is_Referenced_From (Self => Refd_Unit, Unit => Fld);
--# expr-done 463
if Fld_1 then
   If_Result := True;
else
--# expr-start 468 '<env_node at ast.py:1020>' Env_Node /tmp/lal-23.0.0/ada/ast.py:1020
--# expr-start 467 '<FieldAccess for parent_unit_env at ast.py:1013>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1013
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 466 '<FieldAccess for children_env at ast.py:1018>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1018
--# expr-start 465 '<FieldAccess for top_level_decl at ast.py:1018>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1018
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 464 '<FieldAccess for unit at ast.py:1018>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1018
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 464
--# property-call-start AdaNode.top_level_decl
Fld_3 := Libadalang.Implementation.Ada_Node_P_Top_Level_Decl (Node => Self, Unit => Fld_2);
--# end
--# expr-done 465
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Children_Env (Node => Fld_3);
--# expr-done 466
--# property-call-start AdaNode.parent_unit_env
Fld_5 := Libadalang.Implementation.Ada_Node_P_Parent_Unit_Env (Node => Self, Env => Fld_4);
--# end
--# expr-done 467
Env_Node := AST_Envs.Env_Node (Fld_5); 
--# expr-done 468
Var_Expr := Env_Node;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 469 '<FieldAccess for has_with_visibility at ast.py:1020>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:1020
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_with_visibility
Fld_6 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Var_Expr, Refd_Unit => Refd_Unit);
--# end
--# expr-done 469
Scope_Result := Fld_6;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
if If_Result then
   If_Result_3 := True;
else
--# expr-start 473 '<Cast to BaseSubpBody at ast.py:1028>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1028
--# expr-start 472 '<as_bare_entity at ast.py:1028>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1028
--# expr-start 471 '<FieldAccess for top_level_decl at ast.py:1026>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:1026
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 470 '<FieldAccess for unit at ast.py:1027>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:1027
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 470
--# property-call-start AdaNode.top_level_decl
Fld_8 := Libadalang.Implementation.Ada_Node_P_Top_Level_Decl (Node => Self, Unit => Fld_7);
--# end
--# expr-done 471
Is_Null := Fld_8 = null; 
if Is_Null then
   If_Result_1 := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_8); 
   If_Result_1 := As_Entity;
end if;
--# expr-done 472
   if If_Result_1.Node = null
      or else If_Result_1.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Body
        (Node => If_Result_1.Node,
         Info => If_Result_1.Info);
   else
         Cast_Result := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 473
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Base_Subp_Body then
   --# scope-start
   --# bind b Var_Expr_1
--# expr-start 479 '<If at ast.py:1029>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:1029
--# expr-start 474 '<FieldAccess for is_library_item at ast.py:1030>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:1030
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_13 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Var_Expr_1.Node);
--# end
--# expr-done 474
if Fld_13 then
--# expr-start 476 '<FieldAccess for referenced_unit at ast.py:1031>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:1031
--# expr-start 475 '<FieldAccess for defining_name at ast.py:1031>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:1031
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 475
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_unit
Fld_10 := Libadalang.Implementation.Name_P_Referenced_Unit (Node => Fld_9.Node, Kind => Unit_Specification, Not_Found_Is_Error => False);
--# end
--# expr-done 476
Var_Expr_2 := Fld_10;
if Var_Expr_2 /= null then
   --# scope-start
   --# bind u Var_Expr_2
--# expr-start 477 '<FieldAccess for root at ast.py:1034>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:1034
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Var_Expr_2.Ast_Root;
--# expr-done 477
Var_Expr_3 := Fld_11;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 478 '<FieldAccess for has_with_visibility at ast.py:1034>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:1034
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_with_visibility
Fld_12 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Var_Expr_3, Refd_Unit => Refd_Unit);
--# end
--# expr-done 478
Scope_Result_1 := Fld_12;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
   If_Result_2 := Result_Var_2;
else
   If_Result_2 := False;
end if;
--# expr-done 479
Scope_Result_3 := If_Result_2;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
   If_Result_3 := Result_Var_3;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
--# expr-start 481 '<Cast to CompilationUnit at ast.py:1047>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1047
--# expr-start 480 '<FieldAccess for root at ast.py:1047>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:1047
      if Refd_Unit = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Refd_Unit.Ast_Root;
--# expr-done 480
   if Fld_14 = null
      or else Fld_14.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result_1 := Fld_14;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 481
Var_Expr_4 := Cast_Result_1;
if Var_Expr_4 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 482 '<FieldAccess for is_text_io_child at ast.py:1047>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:1047
      if Var_Expr_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.is_text_io_child
Fld_15 := Libadalang.Implementation.Compilation_Unit_P_Is_Text_Io_Child (Node => Var_Expr_4);
--# end
--# expr-done 482
Scope_Result_4 := Fld_15;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := False;
end if;
   If_Result_4 := Result_Var_4;
end if;
Let_Result := If_Result_4; 
--# end
--# expr-done 483
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_73;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_73;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Has_With_Visibility;
--# end
--# property-start AdaNode.has_visibility /tmp/lal-23.0.0/ada/ast.py:1051
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Has_Visibility
  (Node : Bare_Ada_Node
      ; Other_Entity : Internal_Entity
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind other_entity Other_Entity
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Generic_Package_Instantiation;
Var_Expr_1 : Internal_Entity_Package_Renaming_Decl;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Generic_Package_Instantiation;
Fld : Internal_Entity_Info;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Package_Renaming_Decl;
Fld_2 : Internal_Entity_Info;
Fld_3 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result : Boolean;
Cast_Expr_2 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_4 : Boolean;
Not_Val : Boolean;
If_Result_1 : Boolean;
Fld_5 : Bare_Ada_Node;
Fld_6 : Internal_Unit;
Fld_7 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 496 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 484 '<Cast to GenericPackageInstantiation at ast.py:1055>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1055
Cast_Expr := Other_Entity; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Generic_Package_Instantiation_Range
   then
      Cast_Result := Create_Internal_Entity_Generic_Package_Instantiation
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Generic_Package_Instantiation;
   end if;
--# expr-done 484
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Generic_Package_Instantiation then
   --# scope-start
--# expr-start 486 '<FieldAccess for from_rebound at ast.py:1055>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1055
--# expr-start 485 '<FieldAccess for info at ast.py:1055>' Fld /tmp/lal-23.0.0/ada/ast.py:1055
Fld := Var_Expr.Info;
--# expr-done 485
Fld_1 := Fld.From_Rebound;
--# expr-done 486
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   If_Result := True;
else
--# expr-start 487 '<Cast to PackageRenamingDecl at ast.py:1057>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1057
Cast_Expr_1 := Other_Entity; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Package_Renaming_Decl_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Package_Renaming_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Package_Renaming_Decl;
   end if;
--# expr-done 487
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Package_Renaming_Decl then
   --# scope-start
--# expr-start 489 '<FieldAccess for from_rebound at ast.py:1057>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1057
--# expr-start 488 '<FieldAccess for info at ast.py:1057>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1057
Fld_2 := Var_Expr_1.Info;
--# expr-done 488
Fld_3 := Fld_2.From_Rebound;
--# expr-done 489
Scope_Result_1 := Fld_3;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result := Result_Var_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 492 '<Not at ast.py:1060>' Not_Val /tmp/lal-23.0.0/ada/ast.py:1060
--# expr-start 491 '<FieldAccess for is_compilation_unit_root at ast.py:1060>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1060
--# expr-start 490 '<Cast to BasicDecl at ast.py:1060>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1060
Cast_Expr_2 := Other_Entity; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 490
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Cast_Result_2.Node);
--# end
--# expr-done 491
Not_Val := not (Fld_4); 
--# expr-done 492
   If_Result_1 := Not_Val;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 495 '<FieldAccess for has_with_visibility at ast.py:1063>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:1063
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 494 '<FieldAccess for unit at ast.py:1063>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:1063
--# expr-start 493 '<FieldAccess for node at ast.py:1063>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1063
Fld_5 := Other_Entity.Node;
--# expr-done 493
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Unit (Node => Fld_5);
--# expr-done 494
--# property-call-start AdaNode.has_with_visibility
Fld_7 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Self, Refd_Unit => Fld_6);
--# end
--# expr-done 495
   If_Result_2 := Fld_7;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 496
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Has_Visibility;
--# end
--# property-start AdaNode.resolve_generic_actual /tmp/lal-23.0.0/ada/ast.py:1067
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Resolve_Generic_Actual
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity;
            procedure Finalizer_Scope_1799 with Inline_Always;
      Match_0 : Internal_Entity_Anonymous_Expr_Decl;
Match_1 : Internal_Entity_Name;
Match_2 : Internal_Entity;
Var_Expr : Internal_Entity;
Var_Expr_1 : Internal_Entity;
Var_Expr_2 : Internal_Entity_Attribute_Ref;
Fld : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Scope_Result : Internal_Entity;
Cast_Expr : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Attribute_Ref;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity;
Result_Var_1 : Internal_Entity;
Scope_Result_2 : Internal_Entity;
Fld_2 : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Result_Var_2 : Internal_Entity;
Match_Prefix : Internal_Entity;
Cast_Result_3 : Internal_Entity_Anonymous_Expr_Decl;
Cast_Expr_1 : Internal_Entity_Anonymous_Expr_Decl;
Cast_Result_4 : Internal_Entity;
Let_Result : Internal_Entity;
Scope_Result_3 : Internal_Entity;
Cast_Result_5 : Internal_Entity_Name;
Let_Result_1 : Internal_Entity;
Scope_Result_4 : Internal_Entity;
Cast_Result_6 : Internal_Entity;
Let_Result_2 : Internal_Entity;
Scope_Result_5 : Internal_Entity;
Match_Result : Internal_Entity;
Let_Result_3 : Internal_Entity;
            procedure Finalizer_Scope_1799 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_1799;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 504 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 503 '<Match at ast.py:1071>' Match_Result /tmp/lal-23.0.0/ada/ast.py:1071
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Expr_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Anonymous_Expr_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_3; 
--# bind aod Match_0
Cast_Expr_1 := Match_0; 
      Cast_Result_4 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Let_Result := Cast_Result_4; 
--# end
Scope_Result_3 := Let_Result;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Attribute_Ref .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_5; 
--# bind n Match_1
--# expr-start 498 '<Cast to AdaNode.entity at ast.py:1081>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1081
--# expr-start 497 '<FieldAccess for name_designated_type at ast.py:1081>' Fld /tmp/lal-23.0.0/ada/ast.py:1081
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 497
      Cast_Result := Create_Internal_Entity
        (Node => Fld.Node,
         Info => Fld.Info);
--# expr-done 498
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result := Var_Expr_1;
   --# end
   Result_Var_1 := Scope_Result;
else
--# expr-start 499 '<Cast to AttributeRef at ast.py:1083>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1083
Cast_Expr := Match_1; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Attribute_Ref
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Attribute_Ref;
   end if;
--# expr-done 499
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Entity_Attribute_Ref then
   --# scope-start
--# expr-start 500 '<FieldAccess for attribute_subprogram at ast.py:1083>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1083
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.attribute_subprogram
Fld_1 := Libadalang.Implementation.Attribute_Ref_P_Attribute_Subprogram (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 500
Scope_Result_1 := Fld_1;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
      Cast_Result_2 := Create_Internal_Entity
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   Result_Var_1 := Cast_Result_2;
end if;
Var_Expr := Result_Var_1;
if Var_Expr /= No_Entity then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_2 := Var_Expr;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   --# expr-start 502 '<at at ast.py:1085>' Get_Result /tmp/lal-23.0.0/ada/ast.py:1085
--# expr-start 501 '<FieldAccess for all_env_elements at ast.py:1085>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1085
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_env_elements
Fld_2 := Libadalang.Implementation.Name_P_All_Env_Elements (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 501
Get_Result := Get (Self, Fld_2, 0, True); 
--# expr-done 502
   Result_Var_2 := Get_Result;
end if;
Let_Result_1 := Result_Var_2; 
--# end
Scope_Result_4 := Let_Result_1;
   --# end
      Finalizer_Scope_1799;
            Match_Result := Scope_Result_4; 
         when Ada_Abort_Absent .. Ada_Abstract_State_Decl | Ada_Component_Decl .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_6; 
--# bind _ Match_2
Let_Result_2 := No_Entity; 
--# end
Scope_Result_5 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_5; 
end case;
--# expr-done 503
Let_Result_3 := Match_Result; 
--# end
--# expr-done 504
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1799;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Resolve_Generic_Actual;
--# end
--# property-start AdaNode.top_level_use_package_clauses /tmp/lal-23.0.0/ada/ast.py:1091
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Top_Level_Use_Package_Clauses
  (Node : Bare_Ada_Node
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_76 with Inline_Always;
            procedure Finalizer_Scope_1805 with Inline_Always;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_2 : Bare_Ada_Node_List;
Item_12 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Bare_Ada_Node_Array_Access;
Cast_Expr : Bare_Ada_Node;
Cast_Result_1 : Bare_Use_Package_Clause;
Fld_3 : Bare_Name_List;
Cast_Expr_1 : Bare_Name;
Cast_Result_2 : Bare_Ada_Node;
Item_13 : Bare_Name;
Map_Result_1 : Bare_Ada_Node_Array_Access;
Map_Result_2 : Bare_Ada_Node_Array_Access;
Let_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_76 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_76;
            procedure Finalizer_Scope_1805 is
            begin
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_1805;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 516 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 515 '<Mapcat at ast.py:1101>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:1101
   --# expr-start 510 '<Filter at ast.py:1100>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1100
   --# expr-start 508 '<FieldAccess for prelude at ast.py:1099>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1099
--# expr-start 507 '<Cast to CompilationUnit at ast.py:1098>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1098
--# expr-start 506 '<parent at ast.py:1098>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1098
--# expr-start 505 '<parent at ast.py:1098>' Fld /tmp/lal-23.0.0/ada/ast.py:1098
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 505
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 506
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Fld_1;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 507
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Compilation_Unit_F_Prelude;
--# expr-done 508
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_12 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_12 := Untyped_Item_12; 
   --# scope-start
               --# bind p Item_12
         --# expr-start 509 '<IsA UsePackageClause at ast.py:1100>' Is_A /tmp/lal-23.0.0/ada/ast.py:1100
Is_A := Item_12 /= null 
and then Item_12.Kind in Ada_Use_Package_Clause_Range; 
--# expr-done 509
         if Is_A then
         declare
            Item_To_Append : constant Bare_Ada_Node := Item_12;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 510
      declare
         Map_Result_2_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Map_Result;
      begin
         for Item_11 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_11
      --# expr-start 514 '<Map at ast.py:1102>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:1102
   --# expr-start 512 '<FieldAccess for packages at ast.py:1102>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1102
--# expr-start 511 '<Cast to UsePackageClause at ast.py:1102>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1102
Cast_Expr := Item_11; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Use_Package_Clause_Range
   then
      Cast_Result_1 := Cast_Expr;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 511
      if Cast_Result_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Cast_Result_1.Use_Package_Clause_F_Packages;
--# expr-done 512
      declare
         Map_Result_1_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld_3 = null then
      Map_Result_1 := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld_3;
      begin
         for Untyped_Item_13 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_13 := Untyped_Item_13; 
   --# scope-start
               --# bind n Item_13
      --# expr-start 513 '<Cast to AdaNode at ast.py:1103>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1103
Cast_Expr_1 := Item_13; 
      Cast_Result_2 := Cast_Expr_1;
--# expr-done 513
         declare
            Item_To_Append : constant Bare_Ada_Node := Cast_Result_2;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_1_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 514
         for Item_To_Append of
               Map_Result_1.Items
         loop
            Bare_Ada_Node_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_1805;
         end loop;
      end;
         Map_Result_2 := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_2_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 515
Let_Result := Map_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 516
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_76;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_76;
               Finalizer_Scope_1805;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Top_Level_Use_Package_Clauses;
--# end
--# property-start AdaNode.top_level_use_type_clauses /tmp/lal-23.0.0/ada/ast.py:1109
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Top_Level_Use_Type_Clauses
  (Node : Bare_Ada_Node
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_77 with Inline_Always;
            procedure Finalizer_Scope_1808 with Inline_Always;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_2 : Bare_Ada_Node_List;
Item_15 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Bare_Ada_Node_Array_Access;
Cast_Expr : Bare_Ada_Node;
Cast_Result_1 : Bare_Use_Type_Clause;
Fld_3 : Bare_Name_List;
Cast_Expr_1 : Bare_Name;
Cast_Result_2 : Bare_Ada_Node;
Item_16 : Bare_Name;
Map_Result_1 : Bare_Ada_Node_Array_Access;
Map_Result_2 : Bare_Ada_Node_Array_Access;
Let_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_77 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_77;
            procedure Finalizer_Scope_1808 is
            begin
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_1808;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 528 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 527 '<Mapcat at ast.py:1119>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:1119
   --# expr-start 522 '<Filter at ast.py:1118>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1118
   --# expr-start 520 '<FieldAccess for prelude at ast.py:1117>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1117
--# expr-start 519 '<Cast to CompilationUnit at ast.py:1116>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1116
--# expr-start 518 '<parent at ast.py:1116>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1116
--# expr-start 517 '<parent at ast.py:1116>' Fld /tmp/lal-23.0.0/ada/ast.py:1116
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 517
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 518
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Fld_1;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 519
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Compilation_Unit_F_Prelude;
--# expr-done 520
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_15 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_15 := Untyped_Item_15; 
   --# scope-start
               --# bind p Item_15
         --# expr-start 521 '<IsA UseTypeClause at ast.py:1118>' Is_A /tmp/lal-23.0.0/ada/ast.py:1118
Is_A := Item_15 /= null 
and then Item_15.Kind in Ada_Use_Type_Clause_Range; 
--# expr-done 521
         if Is_A then
         declare
            Item_To_Append : constant Bare_Ada_Node := Item_15;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 522
      declare
         Map_Result_2_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Map_Result;
      begin
         for Item_14 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_14
      --# expr-start 526 '<Map at ast.py:1120>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:1120
   --# expr-start 524 '<FieldAccess for types at ast.py:1120>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1120
--# expr-start 523 '<Cast to UseTypeClause at ast.py:1120>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1120
Cast_Expr := Item_14; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Use_Type_Clause_Range
   then
      Cast_Result_1 := Cast_Expr;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 523
      if Cast_Result_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Cast_Result_1.Use_Type_Clause_F_Types;
--# expr-done 524
      declare
         Map_Result_1_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld_3 = null then
      Map_Result_1 := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld_3;
      begin
         for Untyped_Item_16 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_16 := Untyped_Item_16; 
   --# scope-start
               --# bind n Item_16
      --# expr-start 525 '<Cast to AdaNode at ast.py:1121>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1121
Cast_Expr_1 := Item_16; 
      Cast_Result_2 := Cast_Expr_1;
--# expr-done 525
         declare
            Item_To_Append : constant Bare_Ada_Node := Cast_Result_2;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_1_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 526
         for Item_To_Append of
               Map_Result_1.Items
         loop
            Bare_Ada_Node_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_1808;
         end loop;
      end;
         Map_Result_2 := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_2_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 527
Let_Result := Map_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 528
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_77;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_77;
               Finalizer_Scope_1808;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Top_Level_Use_Type_Clauses;
--# end
--# property-start AdaNode.top_level_use_clauses /tmp/lal-23.0.0/ada/ast.py:1127
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Top_Level_Use_Clauses
  (Node : Bare_Ada_Node
  )
   return Bare_Use_Clause_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Use_Clause_Array_Access;
            procedure Finalizer_Scope_78 with Inline_Always;
      Block_Var : Bare_Compilation_Unit;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_2 : Bare_Ada_Node_List;
Cast_Expr : Bare_Ada_Node;
Cast_Result_1 : Bare_Use_Clause;
Item_17 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Bare_Use_Clause_Array_Access;
Let_Result : Bare_Use_Clause_Array_Access;
            procedure Finalizer_Scope_78 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_78;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 536 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 531 '<Cast to CompilationUnit at ast.py:1132>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1132
--# expr-start 530 '<parent at ast.py:1132>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1132
--# expr-start 529 '<parent at ast.py:1132>' Fld /tmp/lal-23.0.0/ada/ast.py:1132
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 529
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 530
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Fld_1;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 531
Block_Var := Cast_Result; 
--# bind cu Block_Var
--# expr-start 535 '<FilterMap at ast.py:1133>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1133
   --# expr-start 532 '<FieldAccess for prelude at ast.py:1133>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1133
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Block_Var.Compilation_Unit_F_Prelude;
--# expr-done 532
      declare
         Map_Result_Vec : Bare_Use_Clause_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Bare_Use_Clause_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_17 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_17 := Untyped_Item_17; 
   --# scope-start
               --# bind p Item_17
         --# expr-start 533 '<IsA UseClause at ast.py:1135>' Is_A /tmp/lal-23.0.0/ada/ast.py:1135
Is_A := Item_17 /= null 
and then Item_17.Kind in Ada_Use_Clause; 
--# expr-done 533
         if Is_A then
      --# expr-start 534 '<Cast to UseClause at ast.py:1134>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1134
Cast_Expr := Item_17; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Use_Clause
   then
      Cast_Result_1 := Cast_Expr;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 534
         declare
            Item_To_Append : constant Bare_Use_Clause := Cast_Result_1;
         begin
            Bare_Use_Clause_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Use_Clause_Array
           (Items_Count => Natural (Bare_Use_Clause_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Use_Clause_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Use_Clause_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Use_Clause_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 535
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 536
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_78;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_78;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Top_Level_Use_Clauses;
--# end
--# property-start AdaNode.top_level_with_package_clauses /tmp/lal-23.0.0/ada/ast.py:1139
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Top_Level_With_Package_Clauses
  (Node : Bare_Ada_Node
  )
   return Bare_Name_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Name_Array_Access;
            procedure Finalizer_Scope_79 with Inline_Always;
            procedure Finalizer_Scope_1811 with Inline_Always;
      Var_Expr : Bare_With_Clause;
Fld : Bare_Compilation_Unit;
Fld_1 : Bare_Ada_Node_List;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_With_Clause;
Fld_2 : Bare_Name_List;
Scope_Result : Bare_Name_List;
Result_Var : Bare_Name_List;
Item_358 : Bare_Name;
Map_Result : Bare_Name_Array_Access;
Item_18 : Bare_Ada_Node;
Map_Result_1 : Bare_Name_Array_Access;
Let_Result : Bare_Name_Array_Access;
            procedure Finalizer_Scope_79 is
            begin
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_79;
            procedure Finalizer_Scope_1811 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1811;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 543 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 542 '<Mapcat at ast.py:1147>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:1147
   --# expr-start 538 '<FieldAccess for prelude at ast.py:1146>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1146
--# expr-start 537 '<FieldAccess for enclosing_compilation_unit at ast.py:1145>' Fld /tmp/lal-23.0.0/ada/ast.py:1145
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Self);
--# end
--# expr-done 537
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Compilation_Unit_F_Prelude;
--# expr-done 538
      declare
         Map_Result_1_Vec : Bare_Name_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result_1 := Create_Bare_Name_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_18 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_18 := Untyped_Item_18; 
   --# scope-start
               --# bind p Item_18
      --# expr-start 541 '<TakeWhile at ???>' Map_Result None
--# expr-start 539 '<Cast to WithClause at ast.py:1147>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1147
Cast_Expr := Item_18; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_With_Clause_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 539
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 540 '<FieldAccess for packages at ast.py:1147>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1147
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr.With_Clause_F_Packages;
--# expr-done 540
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
      declare
         Map_Result_Vec : Bare_Name_Vectors.Vector;
      begin
      if Result_Var = null then
      Map_Result := Create_Bare_Name_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Result_Var;
      begin
         for Untyped_Item_358 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_358 := Untyped_Item_358; 
   --# scope-start
         declare
            Item_To_Append : constant Bare_Name := Item_358;
         begin
            Bare_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Name_Array
           (Items_Count => Natural (Bare_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Name_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 541
         for Item_To_Append of
               Map_Result.Items
         loop
            Bare_Name_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_1811;
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Bare_Name_Array
           (Items_Count => Natural (Bare_Name_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Bare_Name_Vectors.Get
              (Map_Result_1_Vec,
               I + Bare_Name_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Bare_Name_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 542
Let_Result := Map_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 543
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_79;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_79;
               Finalizer_Scope_1811;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Top_Level_With_Package_Clauses;
--# end
--# property-start AdaNode.use_clauses_in_spec_of_subp_body /tmp/lal-23.0.0/ada/ast.py:1151
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Use_Clauses_In_Spec_Of_Subp_Body
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_80 with Inline_Always;
            procedure Finalizer_Scope_1815 with Inline_Always;
            procedure Finalizer_Scope_1816 with Inline_Always;
      Block_Var : Symbol_Type_Array_Access;
Block_Var_1 : Bare_Compilation_Unit;
Var_Expr : Bare_Basic_Decl;
Var_Expr_1 : Bare_Compilation_Unit;
Fld : Bare_Compilation_Unit;
Fld_1 : Symbol_Type_Array_Access;
Fld_2 : Bare_Compilation_Unit;
Fld_3 : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Result_Var : Bare_Basic_Decl;
Fld_4 : Bare_Use_Clause_Array_Access;
Scope_Result_1 : Bare_Use_Clause_Array_Access;
Result_Var_1 : Bare_Use_Clause_Array_Access;
As_Entity : Internal_Entity_Use_Clause;
Is_Null : Boolean;
If_Result : Internal_Entity_Use_Clause;
Fld_5 : Lexical_Env := Empty_Env;
Map_Result : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_80 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_80;
            procedure Finalizer_Scope_1815 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_1815;
            procedure Finalizer_Scope_1816 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_1816;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 553 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 545 '<FieldAccess for syntactic_fully_qualified_name at ast.py:1157>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1157
--# expr-start 544 '<FieldAccess for enclosing_compilation_unit at ast.py:1157>' Fld /tmp/lal-23.0.0/ada/ast.py:1157
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Self);
--# end
--# expr-done 544
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.syntactic_fully_qualified_name
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Syntactic_Fully_Qualified_Name (Node => Fld);
--# end
--# expr-done 545
Block_Var := Fld_1; Inc_Ref (Block_Var);
--# bind fqn Block_Var
--# expr-start 546 '<FieldAccess for designated_compilation_unit at ast.py:1159>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1159
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.designated_compilation_unit
Fld_2 := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Block_Var, Kind => Unit_Specification, Not_Found_Is_Error => False);
--# end
--# expr-done 546
Block_Var_1 := Fld_2; 
--# bind spec Block_Var_1
--# expr-start 552 '<env_group at ast.py:1166>' Group_Env /tmp/lal-23.0.0/ada/ast.py:1166
--# expr-start 551 '<Map at ast.py:1164>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1164
Var_Expr_1 := Block_Var_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 547 '<FieldAccess for decl at ast.py:1164>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1164
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_3 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr_1);
--# end
--# expr-done 547
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 548 '<FieldAccess for top_level_use_clauses at ast.py:1164>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1164
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_clauses
Fld_4 := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Clauses (Node => Var_Expr);
--# end
--# expr-done 548
Scope_Result_1 := Fld_4;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1815;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Bare_Use_Clause_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Use_Clause_Array_Access := Result_Var_1;
      begin
         for Item_19 of
               Collection.Items
         loop
   --# scope-start
               --# bind clause Item_19
      --# expr-start 550 '<FieldAccess for used_envs at ast.py:1165>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1165
--# expr-start 549 '<as_bare_entity at ast.py:1165>' If_Result /tmp/lal-23.0.0/ada/ast.py:1165
Is_Null := Item_19 = null; 
if Is_Null then
   If_Result := No_Entity_Use_Clause;
else
As_Entity := (Info => No_Entity_Info, Node => Item_19); 
   If_Result := As_Entity;
end if;
--# expr-done 549
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UseClause.used_envs
Fld_5 := Libadalang.Implementation.Use_Clause_P_Used_Envs (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 550
         declare
            Item_To_Append : constant Lexical_Env := Fld_5;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1816;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 551
Group_Env := Group (Map_Result, No_Metadata); 
--# expr-done 552
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 553
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_80;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_80;
               Finalizer_Scope_1815;
               Finalizer_Scope_1816;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Use_Clauses_In_Spec_Of_Subp_Body;
--# end
--# property-start AdaNode.use_clauses_in_generic_formal_part /tmp/lal-23.0.0/ada/ast.py:1169
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Use_Clauses_In_Generic_Formal_Part
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_81 with Inline_Always;
            procedure Finalizer_Scope_1818 with Inline_Always;
      Block_Var : Internal_Entity_Generic_Decl;
Var_Expr : Internal_Entity_Body_Node;
Var_Expr_1 : Internal_Entity_Generic_Decl;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Body_Node;
Fld : Internal_Entity_Generic_Decl;
Scope_Result : Internal_Entity_Generic_Decl;
Result_Var : Internal_Entity_Generic_Decl;
Fld_1 : Internal_Entity_Generic_Formal_Part;
Fld_2 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Fld_3 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_81 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_81;
            procedure Finalizer_Scope_1818 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_1818;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 560 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 555 '<Cast to Body at ast.py:1177>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1177
--# expr-start 554 '<as_bare_entity at ast.py:1177>' If_Result /tmp/lal-23.0.0/ada/ast.py:1177
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 554
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Body_Node
   then
      Cast_Result := Create_Internal_Entity_Body_Node
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Body_Node;
   end if;
--# expr-done 555
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Body_Node then
   --# scope-start
--# expr-start 556 '<FieldAccess for safe_generic_decl_part at ast.py:1177>' Fld /tmp/lal-23.0.0/ada/ast.py:1177
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.safe_generic_decl_part
Fld := Libadalang.Implementation.Body_Node_P_Safe_Generic_Decl_Part (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 556
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Generic_Decl;
end if;
Block_Var := Result_Var; 
--# bind gen_decl Block_Var
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Generic_Decl then
   --# scope-start
   --# bind gd Var_Expr_1
--# expr-start 558 '<FieldAccess for use_clauses_envs at ast.py:1179>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1179
--# expr-start 557 '<FieldAccess for formal_part at ast.py:1179>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1179
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Generic_Formal_Part (Node => Var_Expr_1.Node.Generic_Decl_F_Formal_Part, Info => Var_Expr_1.Info);
--# expr-done 557
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericFormalPart.use_clauses_envs
Fld_2 := Libadalang.Implementation.Generic_Formal_Part_P_Use_Clauses_Envs (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 558
Scope_Result_1 := Fld_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1818;
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 559 '<FieldAccess for empty_env at ast.py:1180>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1180
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.empty_env
Fld_3 := Libadalang.Implementation.Ada_Node_P_Empty_Env (Node => Self);
--# end
--# expr-done 559
   Result_Var_1 := Fld_3;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
--# expr-done 560
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_81;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_81;
               Finalizer_Scope_1818;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Use_Clauses_In_Generic_Formal_Part;
--# end
--# property-start AdaNode.nested_generic_formal_part /tmp/lal-23.0.0/ada/ast.py:1184
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Nested_Generic_Formal_Part
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_82 with Inline_Always;
            procedure Finalizer_Scope_1820 with Inline_Always;
      Block_Var : Internal_Entity_Generic_Decl;
Var_Expr : Internal_Entity_Body_Node;
Var_Expr_1 : Internal_Entity_Generic_Decl;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Body_Node;
Fld : Internal_Entity_Generic_Decl;
Scope_Result : Internal_Entity_Generic_Decl;
Result_Var : Internal_Entity_Generic_Decl;
Fld_1 : Bare_Generic_Decl;
Fld_2 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Fld_3 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_82 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_82;
            procedure Finalizer_Scope_1820 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_1820;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 567 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 562 '<Cast to Body at ast.py:1198>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1198
--# expr-start 561 '<as_bare_entity at ast.py:1198>' If_Result /tmp/lal-23.0.0/ada/ast.py:1198
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 561
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Body_Node
   then
      Cast_Result := Create_Internal_Entity_Body_Node
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Body_Node;
   end if;
--# expr-done 562
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Body_Node then
   --# scope-start
--# expr-start 563 '<FieldAccess for safe_generic_decl_part at ast.py:1198>' Fld /tmp/lal-23.0.0/ada/ast.py:1198
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.safe_generic_decl_part
Fld := Libadalang.Implementation.Body_Node_P_Safe_Generic_Decl_Part (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 563
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Generic_Decl;
end if;
Block_Var := Result_Var; 
--# bind gen_decl Block_Var
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Generic_Decl then
   --# scope-start
   --# bind gd Var_Expr_1
--# expr-start 565 '<FieldAccess for children_env at ast.py:1200>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1200
--# expr-start 564 '<FieldAccess for node at ast.py:1200>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1200
Fld_1 := Var_Expr_1.Node;
--# expr-done 564
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Fld_1);
--# expr-done 565
Scope_Result_1 := Fld_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1820;
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 566 '<FieldAccess for empty_env at ast.py:1201>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1201
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.empty_env
Fld_3 := Libadalang.Implementation.Ada_Node_P_Empty_Env (Node => Self);
--# end
--# expr-done 566
   Result_Var_1 := Fld_3;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
--# expr-done 567
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_82;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_82;
               Finalizer_Scope_1820;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Nested_Generic_Formal_Part;
--# end
--# property-start AdaNode.is_package /tmp/lal-23.0.0/ada/ast.py:1205
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Is_Package
  (Node : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 569 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 568 '<IsA PackageDecl, PackageBody, GenericPackageInstantiation, PackageRenamingDecl, GenericPackageDecl at ast.py:1209>' Is_A /tmp/lal-23.0.0/ada/ast.py:1209
Is_A := Self /= null 
and then Self.Kind in Ada_Package_Decl_Range | Ada_Package_Body_Range | Ada_Generic_Package_Instantiation_Range | Ada_Package_Renaming_Decl_Range | Ada_Generic_Package_Decl_Range; 
--# expr-done 568
Let_Result := Is_A; 
--# end
--# expr-done 569
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Is_Package;
--# end
--# property-start AdaNode.default_initial_env /tmp/lal-23.0.0/ada/ast.py:1213
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Default_Initial_Env
  (Node : Bare_Ada_Node
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_84 with Inline_Always;
            procedure Finalizer_Scope_1821 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Fld : Bare_Ada_Node;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_84 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_84;
            procedure Finalizer_Scope_1821 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1821;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 573 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 570 '<parent at ast.py:1218>' Fld /tmp/lal-23.0.0/ada/ast.py:1218
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 570
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 571 '<FieldAccess for children_env at ast.py:1218>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1218
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 571
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1821;
   Result_Var := Scope_Result;
else
   --# expr-start 572 '<FieldAccess for children_env at ast.py:1219>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1219
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Self);
--# expr-done 572
   Result_Var := Fld_2;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 573
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_84;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_84;
               Finalizer_Scope_1821;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Default_Initial_Env;
--# end
--# property-start AdaNode.top_level_decl /tmp/lal-23.0.0/ada/ast.py:1222
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Top_Level_Decl
  (Node : Bare_Ada_Node
      ; Unit : Internal_Unit
  )
   return Bare_Basic_Decl
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind unit Unit
   Property_Result : Bare_Basic_Decl;
      Var_Expr : Bare_Ada_Node;
Var_Expr_1 : Internal_Unit;
Fld : Bare_Ada_Node;
Scope_Result : Bare_Ada_Node;
Result_Var : Bare_Ada_Node;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_1 : Bare_Basic_Decl;
Scope_Result_1 : Bare_Basic_Decl;
Result_Var_1 : Bare_Basic_Decl;
Let_Result : Bare_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 577 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr_1 := Unit;
if Var_Expr_1 /= null then
   --# scope-start
--# expr-start 574 '<FieldAccess for root at ast.py:1227>' Fld /tmp/lal-23.0.0/ada/ast.py:1227
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Var_Expr_1.Ast_Root;
--# expr-done 574
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 576 '<FieldAccess for decl at ast.py:1227>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1227
--# expr-start 575 '<Cast to CompilationUnit at ast.py:1227>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1227
Cast_Expr := Var_Expr; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Cast_Expr;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 575
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Cast_Result);
--# end
--# expr-done 576
Scope_Result_1 := Fld_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Bare_Ada_Node;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 577
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Top_Level_Decl;
--# end
--# property-start AdaNode.unpack_formals /tmp/lal-23.0.0/ada/ast.py:1230
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Unpack_Formals
  (Node : Bare_Ada_Node
      ; Formal_Params : Internal_Entity_Base_Formal_Param_Decl_Array_Access
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind formal_params Formal_Params
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_86 with Inline_Always;
      Fld : Internal_Unit;
Fld_1 : Bare_Ada_Node;
Fld_2 : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_86 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_86;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 581 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 580 '<FieldAccess for unpack_formals_impl at ast.py:1234>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1234
--# expr-start 579 '<FieldAccess for root at ast.py:1234>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1234
--# expr-start 578 '<FieldAccess for unit at ast.py:1234>' Fld /tmp/lal-23.0.0/ada/ast.py:1234
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 578
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Ast_Root;
--# expr-done 579
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.unpack_formals_impl
Fld_2 := Libadalang.Implementation.Ada_Node_P_Unpack_Formals_Impl (Node => Fld_1, Formal_Params => Formal_Params);
--# end
--# expr-done 580
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 581
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_86;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_86;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Unpack_Formals;
--# end
--# property-start AdaNode.unpack_formals_impl /tmp/lal-23.0.0/ada/ast.py:1237
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Unpack_Formals_Impl
  (Node : Bare_Ada_Node
      ; Formal_Params : Internal_Entity_Base_Formal_Param_Decl_Array_Access
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind formal_params Formal_Params
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_87 with Inline_Always;
            procedure Finalizer_Scope_1822 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_Array_Access;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_87 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_87;
            procedure Finalizer_Scope_1822 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1822;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 584 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 583 '<Mapcat at ast.py:1238>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1238
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Formal_Param_Decl_Array_Access := Formal_Params;
      begin
         for Item_20 of
               Collection.Items
         loop
   --# scope-start
               --# bind spec Item_20
      --# expr-start 582 '<FieldAccess for defining_names at ast.py:1238>' Fld /tmp/lal-23.0.0/ada/ast.py:1238
      if Item_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Item_20.Node, E_Info => Item_20.Info);
--# end
--# expr-done 582
         for Item_To_Append of
               Fld.Items
         loop
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_1822;
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 583
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 584
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_87;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_87;
               Finalizer_Scope_1822;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Unpack_Formals_Impl;
--# end
--# property-start AdaNode.match_formals /tmp/lal-23.0.0/ada/ast.py:1241
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Match_Formals
  (Node : Bare_Ada_Node
      ; Formal_Params : Internal_Entity_Base_Formal_Param_Decl_Array_Access
      ; Params : Internal_Entity_Assoc_List
      ; Is_Dottable_Subp : Boolean
  )
   return Internal_Param_Match_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind formal_params Formal_Params
   --# bind params Params
   --# bind is_dottable_subp Is_Dottable_Subp
   Property_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_88 with Inline_Always;
            procedure Finalizer_Scope_1823 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Var_Expr : Internal_Entity_Assoc_List;
Idx : Integer;
Var_Expr_1 : Internal_Entity_Defining_Name;
Var_Expr_2 : Bare_Base_Id;
Var_Expr_3 : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Single_Actual_Array_Access;
Arith_Result : Integer;
If_Result : Integer;
Get_Result : Internal_Entity_Defining_Name;
New_Struct : Internal_Param_Match;
Scope_Result : Internal_Param_Match;
Result_Var : Internal_Param_Match;
Let_Result : Internal_Param_Match;
Fld_2 : Bare_Base_Id;
Fld_3 : Internal_Entity_Name;
Cast_Expr : Bare_Base_Id;
Cast_Result : Bare_Name;
Fld_4 : Boolean;
Find_Result : Internal_Entity_Defining_Name;
New_Struct_1 : Internal_Param_Match;
Scope_Result_1 : Internal_Param_Match;
Result_Var_1 : Internal_Param_Match;
Scope_Result_2 : Internal_Param_Match;
Result_Var_2 : Internal_Param_Match;
Fld_5 : Bare_Base_Id;
Is_Null : Boolean;
If_Result_1 : Internal_Param_Match;
Index_22 : Integer;
Map_Result : Internal_Param_Match_Array_Access;
Scope_Result_3 : Internal_Param_Match_Array_Access;
Result_Var_3 : Internal_Param_Match_Array_Access;
Let_Result_1 : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_88 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_88;
            procedure Finalizer_Scope_1823 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1823;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 601 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 585 '<FieldAccess for unpack_formals at ast.py:1249>' Fld /tmp/lal-23.0.0/ada/ast.py:1249
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.unpack_formals
Fld := Libadalang.Implementation.Ada_Node_P_Unpack_Formals (Node => Self, Formal_Params => Formal_Params);
--# end
--# expr-done 585
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind unpacked_formals Block_Var
Var_Expr := Params;
if Var_Expr /= No_Entity_Assoc_List then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 600 '<Map at ast.py:1251>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1251
   --# expr-start 586 '<FieldAccess for unpacked_params at ast.py:1251>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1251
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.unpacked_params
Fld_1 := Libadalang.Implementation.Assoc_List_P_Unpacked_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 586
      declare
         Map_Result_Vec : Internal_Param_Match_Vectors.Vector;
      begin
         Index_22 := 0;
      declare
         Collection : constant Internal_Single_Actual_Array_Access := Fld_1;
      begin
         for Item_21 of
               Collection.Items
         loop
   --# scope-start
               --# bind a Item_21
               --# bind i Index_22
      --# expr-start 599 '<If at ast.py:1251>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1251
--# expr-start 588 '<IsNull at ast.py:1252>' Is_Null /tmp/lal-23.0.0/ada/ast.py:1252
--# expr-start 587 '<FieldAccess for name at ast.py:1252>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1252
Fld_5 := Item_21.Name;
--# expr-done 587
Is_Null := Fld_5 = null; 
--# expr-done 588
if Is_Null then
   --# expr-start 593 '<Let at ast.py:1254>' Let_Result /tmp/lal-23.0.0/ada/ast.py:1254
--# scope-start
--# expr-start 590 '<If at ast.py:1255>' If_Result /tmp/lal-23.0.0/ada/ast.py:1255
if Is_Dottable_Subp then
   --# expr-start 589 '<Arithmetic + at ast.py:1255>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:1255
Arith_Result := (Index_22 + 1); 
--# expr-done 589
   If_Result := Arith_Result;
else
   If_Result := Index_22;
end if;
--# expr-done 590
Idx := If_Result; 
--# bind idx Idx
--# expr-start 591 '<at at ast.py:1258>' Get_Result /tmp/lal-23.0.0/ada/ast.py:1258
Get_Result := Get (Self, Block_Var, Idx, True); 
--# expr-done 591
Var_Expr_1 := Get_Result;
if Var_Expr_1 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind sp Var_Expr_1
--# expr-start 592 '<New ParamMatch at ast.py:1259>' New_Struct /tmp/lal-23.0.0/ada/ast.py:1259
New_Struct := (Actual => Item_21, Formal => Var_Expr_1, Has_Matched => True); 
--# expr-done 592
Scope_Result := New_Struct;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Param_Match;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 593
   If_Result_1 := Let_Result;
else
--# expr-start 594 '<FieldAccess for name at ast.py:1269>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1269
Fld_2 := Item_21.Name;
--# expr-done 594
Var_Expr_2 := Fld_2;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind id Var_Expr_2
--# expr-start 597 '<Find at ast.py:1270>' Find_Result /tmp/lal-23.0.0/ada/ast.py:1270
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Block_Var;
      begin
         for Item_23 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_23
      --# expr-start 596 '<FieldAccess for matches at ast.py:1270>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1270
--# expr-start 595 '<FieldAccess for name at ast.py:1270>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1270
      if Item_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Item_23.Node.Defining_Name_F_Name, Info => Item_23.Info);
--# expr-done 595
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Var_Expr_2; 
      Cast_Result := Cast_Expr;
--# property-call-start Name.matches
Fld_4 := Libadalang.Implementation.Name_P_Matches (Node => Fld_3.Node, N => Cast_Result);
--# end
--# expr-done 596
      if Fld_4 then
         Find_Result := Item_23;
      end if;
   --# end
               exit when Fld_4;
         end loop;
      end;
--# expr-done 597
Var_Expr_3 := Find_Result;
if Var_Expr_3 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind sp Var_Expr_3
--# expr-start 598 '<New ParamMatch at ast.py:1271>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:1271
New_Struct_1 := (Actual => Item_21, Formal => Var_Expr_3, Has_Matched => True); 
--# expr-done 598
Scope_Result_1 := New_Struct_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Param_Match;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Param_Match;
end if;
   If_Result_1 := Result_Var_2;
end if;
--# expr-done 599
         declare
            Item_To_Append : constant Internal_Param_Match := If_Result_1;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
               Index_22 := Index_22 + 1;
         end loop;
      end;
         Map_Result := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 600
Scope_Result_3 := Map_Result;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_1823;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Internal_Param_Match_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
Let_Result_1 := Result_Var_3; Inc_Ref (Let_Result_1);
--# end
--# expr-done 601
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_88;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_88;
               Finalizer_Scope_1823;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Match_Formals;
--# end
--# property-start AdaNode.choice_match /tmp/lal-23.0.0/ada/ast.py:1280
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Choice_Match
  (Node : Bare_Ada_Node
      ; Value : Big_Integer_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind value Value
   Property_Result : Boolean;
            procedure Finalizer_Scope_1832 with Inline_Always;
            procedure Finalizer_Scope_1833 with Inline_Always;
            procedure Finalizer_Scope_1835 with Inline_Always;
            procedure Finalizer_Scope_1838 with Inline_Always;
            procedure Finalizer_Scope_1839 with Inline_Always;
      Match_0 : Internal_Entity_Bin_Op;
Match_1 : Internal_Entity_Name;
Match_2 : Internal_Entity_Subtype_Indication;
Match_3 : Internal_Entity_Expr;
Match_4 : Internal_Entity_Others_Designator;
Match_5 : Internal_Entity;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Discrete_Range;
Edr : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
Var_Expr_2 : Internal_Discrete_Range;
Edr_1 : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
Fld : Internal_Entity_Expr;
Fld_1 : Big_Integer_Type;
Comp_Result : Boolean;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Big_Integer_Type;
Comp_Result_1 : Boolean;
If_Result : Boolean;
Fld_4 : Big_Integer_Type;
Is_Equal : Boolean;
Fld_5 : Internal_Entity_Op;
Is_A : Boolean;
If_Result_1 : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Discrete_Range;
Fld_8 : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
Fld_9 : Big_Integer_Type;
Comp_Result_2 : Boolean;
Fld_10 : Big_Integer_Type;
Comp_Result_3 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Bound_Origin : Bare_Ada_Node;
Bound_Imprecise_Fallback : Boolean;
Fld_11 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Dyn_Var_Bind_Result_1 : Boolean;
If_Result_3 : Boolean;
Scope_Result_1 : Boolean;
Fld_12 : Big_Integer_Type;
Is_Equal_1 : Boolean;
Result_Var_1 : Boolean;
Fld_13 : Internal_Discrete_Range;
Fld_14 : Internal_Eval_Discrete_Range := No_Eval_Discrete_Range;
Fld_15 : Big_Integer_Type;
Comp_Result_4 : Boolean;
Fld_16 : Big_Integer_Type;
Comp_Result_5 : Boolean;
If_Result_4 : Boolean;
Let_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Bound_Origin_1 : Bare_Ada_Node;
Bound_Imprecise_Fallback_1 : Boolean;
Fld_17 : Internal_Entity_Base_Type_Decl;
Fld_18 : Boolean;
Dyn_Var_Bind_Result_2 : Boolean;
Dyn_Var_Bind_Result_3 : Boolean;
If_Result_5 : Boolean;
Fld_19 : Big_Integer_Type;
Is_Equal_2 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Bin_Op;
Let_Result_2 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_1 : Internal_Entity_Name;
Let_Result_3 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_2 : Internal_Entity_Subtype_Indication;
Let_Result_4 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_3 : Internal_Entity_Expr;
Let_Result_5 : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_4 : Internal_Entity_Others_Designator;
Let_Result_6 : Boolean;
Scope_Result_7 : Boolean;
Cast_Result_5 : Internal_Entity;
Let_Result_7 : Boolean;
Scope_Result_8 : Boolean;
Match_Result : Boolean;
Let_Result_8 : Boolean;
            procedure Finalizer_Scope_1832 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_1832;
            procedure Finalizer_Scope_1833 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_1833;
            procedure Finalizer_Scope_1835 is
            begin
                     Dec_Ref (Fld_8);
                     Dec_Ref (Edr);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_1835;
            procedure Finalizer_Scope_1838 is
            begin
                     Dec_Ref (Fld_14);
                     Dec_Ref (Edr_1);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
            end Finalizer_Scope_1838;
            procedure Finalizer_Scope_1839 is
            begin
                     Dec_Ref (Fld_19);
            end Finalizer_Scope_1839;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 634 '<Block at ???>' Let_Result_8 None
--# scope-start
--# expr-start 633 '<Match at ast.py:1291>' Match_Result /tmp/lal-23.0.0/ada/ast.py:1291
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind bo Match_0
--# expr-start 610 '<If at ast.py:1295>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1295
--# expr-start 603 '<IsA Op.DoubleDot at ast.py:1297>' Is_A /tmp/lal-23.0.0/ada/ast.py:1297
--# expr-start 602 '<FieldAccess for op at ast.py:1297>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1297
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Op (Node => Match_0.Node.Bin_Op_F_Op, Info => Match_0.Info);
--# expr-done 602
Is_A := Fld_5.Node /= null 
and then Fld_5.Node.Kind in Ada_Op_Double_Dot_Range; 
--# expr-done 603
if Is_A then
--# expr-start 605 '<FieldAccess for eval_as_int at ast.py:1299>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1299
--# expr-start 604 '<FieldAccess for left at ast.py:1299>' Fld /tmp/lal-23.0.0/ada/ast.py:1299
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Match_0.Node.Bin_Op_F_Left, Info => Match_0.Info);
--# expr-done 604
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_1 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 605
Comp_Result := Value >= Fld_1; 
if Comp_Result then
--# expr-start 607 '<FieldAccess for eval_as_int at ast.py:1300>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1300
--# expr-start 606 '<FieldAccess for right at ast.py:1300>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1300
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Match_0.Node.Bin_Op_F_Right, Info => Match_0.Info);
--# expr-done 606
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_3 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 607
Comp_Result_1 := Value <= Fld_3; 
   If_Result := Comp_Result_1;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
else
   --# expr-start 609 '<Eq at ast.py:1302>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:1302
--# expr-start 608 '<FieldAccess for eval_as_int at ast.py:1302>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1302
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_4 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 608
Is_Equal := Equivalent (Value, Fld_4); 
--# expr-done 609
   If_Result_1 := Is_Equal;
end if;
--# expr-done 610
Let_Result_2 := If_Result_1; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
      Finalizer_Scope_1832;
            Match_Result := Scope_Result_3; 
         when Ada_Attribute_Ref .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind n Match_1
--# expr-start 611 '<FieldAccess for name_designated_type at ast.py:1307>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:1307
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_6 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 611
Var_Expr := Fld_6;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind dt Var_Expr
--# expr-start 612 '<FieldAccess for discrete_range at ast.py:1308>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:1308
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discrete_range'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discrete_Range (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 612
Var_Expr_1 := Fld_7;
if Var_Expr_1 /= No_Discrete_Range then
   --# scope-start
   --# bind dr Var_Expr_1
--# expr-start 616 '<Let at ast.py:1309>' Let_Result /tmp/lal-23.0.0/ada/ast.py:1309
--# scope-start
--# expr-start 613 '<FieldAccess for eval_discrete_range at ast.py:1310>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:1310
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.eval_discrete_range
Fld_8 := Libadalang.Implementation.Ada_Node_P_Eval_Discrete_Range (Node => Self, Dr => Var_Expr_1);
--# end
--# expr-done 613
Edr := Fld_8; Inc_Ref (Edr);
--# bind edr Edr
--# expr-start 614 '<FieldAccess for low_bound at ast.py:1311>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:1311
Fld_9 := Edr.Low_Bound;
Inc_Ref (Fld_9);
--# expr-done 614
Comp_Result_2 := Value >= Fld_9; 
if Comp_Result_2 then
--# expr-start 615 '<FieldAccess for high_bound at ast.py:1311>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:1311
Fld_10 := Edr.High_Bound;
Inc_Ref (Fld_10);
--# expr-done 615
Comp_Result_3 := Value <= Fld_10; 
   If_Result_2 := Comp_Result_3;
else
   If_Result_2 := False;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 616
Scope_Result := Let_Result;
   --# end
      Finalizer_Scope_1835;
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
if Result_Var then
   --# expr-start 619 '<bind at ast.py:1315>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:1315
Bound_Origin := Self; 
--# expr-start 618 '<bind at ast.py:1316>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:1316
Bound_Imprecise_Fallback := False; 
--# expr-start 617 '<FieldAccess for satisfies_type_predicates at ast.py:1317>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:1317
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.satisfies_type_predicates
Fld_11 := Libadalang.Implementation.Base_Type_Decl_P_Satisfies_Type_Predicates (Node => Var_Expr.Node, Value => Value, Imprecise_Fallback => Bound_Imprecise_Fallback, Origin => Bound_Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 617
Dyn_Var_Bind_Result := Fld_11; 
--# expr-done 618
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; 
--# expr-done 619
   If_Result_3 := Dyn_Var_Bind_Result_1;
else
   If_Result_3 := False;
end if;
Scope_Result_1 := If_Result_3;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 621 '<Eq at ast.py:1320>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:1320
--# expr-start 620 '<FieldAccess for eval_as_int at ast.py:1320>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:1320
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_12 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 620
Is_Equal_1 := Equivalent (Value, Fld_12); 
--# expr-done 621
   Result_Var_1 := Is_Equal_1;
end if;
Let_Result_3 := Result_Var_1; 
--# end
Scope_Result_4 := Let_Result_3;
   --# end
      Finalizer_Scope_1833;
            Match_Result := Scope_Result_4; 
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind st Match_2
--# expr-start 622 '<FieldAccess for discrete_range at ast.py:1324>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:1324
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.discrete_range
Fld_13 := Libadalang.Implementation.Subtype_Indication_P_Discrete_Range (Node => Match_2.Node, E_Info => Match_2.Info);
--# end
--# expr-done 622
Var_Expr_2 := Fld_13;
if Var_Expr_2 /= No_Discrete_Range then
   --# scope-start
   --# bind dr Var_Expr_2
--# expr-start 626 '<Let at ast.py:1325>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:1325
--# scope-start
--# expr-start 623 '<FieldAccess for eval_discrete_range at ast.py:1326>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:1326
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.eval_discrete_range
Fld_14 := Libadalang.Implementation.Ada_Node_P_Eval_Discrete_Range (Node => Self, Dr => Var_Expr_2);
--# end
--# expr-done 623
Edr_1 := Fld_14; Inc_Ref (Edr_1);
--# bind edr Edr_1
--# expr-start 624 '<FieldAccess for low_bound at ast.py:1327>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:1327
Fld_15 := Edr_1.Low_Bound;
Inc_Ref (Fld_15);
--# expr-done 624
Comp_Result_4 := Value >= Fld_15; 
if Comp_Result_4 then
--# expr-start 625 '<FieldAccess for high_bound at ast.py:1327>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:1327
Fld_16 := Edr_1.High_Bound;
Inc_Ref (Fld_16);
--# expr-done 625
Comp_Result_5 := Value <= Fld_16; 
   If_Result_4 := Comp_Result_5;
else
   If_Result_4 := False;
end if;
Let_Result_1 := If_Result_4; 
--# end
--# expr-done 626
Scope_Result_2 := Let_Result_1;
   --# end
      Finalizer_Scope_1838;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := True;
end if;
if Result_Var_2 then
   --# expr-start 630 '<bind at ast.py:1331>' Dyn_Var_Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:1331
Bound_Origin_1 := Self; 
--# expr-start 629 '<bind at ast.py:1332>' Dyn_Var_Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:1332
Bound_Imprecise_Fallback_1 := False; 
--# expr-start 628 '<FieldAccess for satisfies_type_predicates at ast.py:1333>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:1333
--# expr-start 627 '<FieldAccess for designated_type at ast.py:1333>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:1333
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_17 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Match_2.Node, Origin => Bound_Origin_1, E_Info => Match_2.Info);
--# end
--# expr-done 627
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.satisfies_type_predicates
Fld_18 := Libadalang.Implementation.Base_Type_Decl_P_Satisfies_Type_Predicates (Node => Fld_17.Node, Value => Value, Imprecise_Fallback => Bound_Imprecise_Fallback_1, Origin => Bound_Origin_1, E_Info => Fld_17.Info);
--# end
--# expr-done 628
Dyn_Var_Bind_Result_2 := Fld_18; 
--# expr-done 629
Dyn_Var_Bind_Result_3 := Dyn_Var_Bind_Result_2; 
--# expr-done 630
   If_Result_5 := Dyn_Var_Bind_Result_3;
else
   If_Result_5 := False;
end if;
Let_Result_4 := If_Result_5; 
--# end
Scope_Result_5 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_3; 
--# bind e Match_3
--# expr-start 632 '<Eq at ast.py:1338>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:1338
--# expr-start 631 '<FieldAccess for eval_as_int at ast.py:1338>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:1338
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_19 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Match_3.Node, E_Info => Match_3.Info);
--# end
--# expr-done 631
Is_Equal_2 := Equivalent (Value, Fld_19); 
--# expr-done 632
Let_Result_5 := Is_Equal_2; 
--# end
Scope_Result_6 := Let_Result_5;
   --# end
      Finalizer_Scope_1839;
            Match_Result := Scope_Result_6; 
         when Ada_Others_Designator =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Others_Designator
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_4; 
--# bind _ Match_4
Let_Result_6 := True; 
--# end
Scope_Result_7 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Abort_Absent .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Null_Component_Decl | Ada_Overriding_Not_Overriding .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_5; 
--# bind _ Match_5
Let_Result_7 := False; 
--# end
Scope_Result_8 := Let_Result_7;
   --# end
            Match_Result := Scope_Result_8; 
end case;
--# expr-done 633
Let_Result_8 := Match_Result; 
--# end
--# expr-done 634
      Property_Result := Let_Result_8;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1832;
               Finalizer_Scope_1833;
               Finalizer_Scope_1835;
               Finalizer_Scope_1838;
               Finalizer_Scope_1839;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Choice_Match;
--# end
--# property-start AdaNode.gnat_xref /tmp/lal-23.0.0/ada/ast.py:1347
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Gnat_Xref
  (Node : Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_1855 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Var_Expr_2 : Internal_Entity_Basic_Decl;
Var_Expr_3 : Internal_Entity_Basic_Decl;
Var_Expr_4 : Internal_Entity_Basic_Decl;
Var_Expr_5 : Internal_Entity_Basic_Decl;
Var_Expr_6 : Internal_Entity_Base_Type_Decl;
Var_Expr_7 : Boolean;
Var_Expr_8 : Internal_Entity_Defining_Name;
Var_Expr_9 : Internal_Entity_Base_Type_Decl;
Var_Expr_10 : Internal_Entity_Defining_Name;
Var_Expr_11 : Internal_Entity_Name;
Dbd : Internal_Entity_Basic_Decl;
Var_Expr_12 : Internal_Entity_Generic_Instantiation;
Var_Expr_13 : Internal_Entity_Defining_Name;
Var_Expr_14 : Internal_Entity_Basic_Decl;
Var_Expr_15 : Internal_Entity_Basic_Decl;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Bound_Origin : Bare_Ada_Node;
Is_A : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Fld_2 : Internal_Entity;
Is_A_1 : Boolean;
If_Result : Boolean;
Fld_3 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Defining_Name;
Is_A_2 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Fld_5 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_6 : Internal_Entity_Defining_Name;
Is_A_3 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
Fld_7 : Internal_Entity;
Is_A_4 : Boolean;
If_Result_1 : Boolean;
Fld_8 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Fld_9 : Internal_Entity_Defining_Name;
Is_A_5 : Boolean;
Scope_Result_4 : Boolean;
Result_Var_4 : Boolean;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity_Abstract_Subp_Decl;
Fld_10 : Internal_Entity_Base_Subp_Spec;
Fld_11 : Internal_Entity_Base_Type_Decl;
Fld_12 : Internal_Entity_Defining_Name;
Is_A_6 : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
Cast_Expr_2 : Internal_Entity_Basic_Decl;
Cast_Result_5 : Internal_Entity_Basic_Subp_Decl;
Fld_13 : Internal_Entity_Base_Subp_Spec;
Fld_14 : Internal_Entity_Base_Type_Decl;
Fld_15 : Boolean;
Fld_16 : Internal_Entity_Base_Type_Decl;
Fld_17 : Internal_Entity_Defining_Name;
Scope_Result_6 : Internal_Entity_Defining_Name;
Result_Var_6 : Internal_Entity_Defining_Name;
Scope_Result_7 : Internal_Entity_Defining_Name;
Fld_18 : Internal_Entity_Defining_Name;
Result_Var_7 : Internal_Entity_Defining_Name;
Scope_Result_8 : Internal_Entity_Defining_Name;
Result_Var_8 : Internal_Entity_Defining_Name;
Scope_Result_9 : Internal_Entity_Defining_Name;
Result_Var_9 : Internal_Entity_Defining_Name;
Cast_Expr_3 : Internal_Entity;
Cast_Result_6 : Internal_Entity_Name;
Fld_19 : Internal_Entity_Defining_Name;
Scope_Result_10 : Internal_Entity_Defining_Name;
Result_Var_10 : Internal_Entity_Defining_Name;
Fld_20 : Internal_Entity_Basic_Decl;
Is_A_7 : Boolean;
Cast_Expr_4 : Internal_Entity_Basic_Decl;
Cast_Result_7 : Internal_Entity_Param_Spec;
Fld_21 : Internal_Entity_Defining_Name;
Is_A_8 : Boolean;
Fld_22 : Internal_Entity_Generic_Instantiation_Array_Access;
Get_Result : Internal_Entity_Generic_Instantiation;
Cast_Expr_5 : Internal_Entity_Generic_Instantiation;
Cast_Result_8 : Internal_Entity_Basic_Decl;
Fld_23 : Internal_Entity_Defining_Name;
Scope_Result_11 : Internal_Entity_Defining_Name;
Result_Var_11 : Internal_Entity_Defining_Name;
Is_A_9 : Boolean;
Cast_Expr_6 : Internal_Entity_Basic_Decl;
Cast_Result_9 : Internal_Entity_Object_Decl;
Fld_24 : Internal_Entity_Basic_Decl;
Fld_25 : Internal_Entity_Defining_Name;
Scope_Result_12 : Internal_Entity_Defining_Name;
Result_Var_12 : Internal_Entity_Defining_Name;
Scope_Result_13 : Internal_Entity_Defining_Name;
Result_Var_13 : Internal_Entity_Defining_Name;
Is_A_10 : Boolean;
Cast_Expr_7 : Internal_Entity_Basic_Decl;
Cast_Result_10 : Internal_Entity_Base_Subp_Body;
Fld_26 : Internal_Entity_Basic_Decl;
Scope_Result_14 : Internal_Entity_Basic_Decl;
Result_Var_14 : Internal_Entity_Basic_Decl;
Fld_27 : Internal_Entity_Defining_Name;
If_Result_2 : Internal_Entity_Defining_Name;
If_Result_3 : Internal_Entity_Defining_Name;
If_Result_4 : Internal_Entity_Defining_Name;
If_Result_5 : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
Scope_Result_15 : Internal_Entity_Defining_Name;
Result_Var_15 : Internal_Entity_Defining_Name;
If_Result_6 : Internal_Entity_Defining_Name;
If_Result_7 : Internal_Entity_Defining_Name;
If_Result_8 : Internal_Entity_Defining_Name;
If_Result_9 : Internal_Entity_Defining_Name;
If_Result_10 : Internal_Entity_Defining_Name;
Dyn_Var_Bind_Result : Internal_Entity_Defining_Name;
Let_Result_1 : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_1855 is
            begin
                     Dec_Ref (Fld_22);
            end Finalizer_Scope_1855;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 690 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 636 '<FieldAccess for enclosing_defining_name at ast.py:1353>' Fld /tmp/lal-23.0.0/ada/ast.py:1353
--# expr-start 635 '<Cast to Name at ast.py:1353>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1353
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 635
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.enclosing_defining_name
Fld := Libadalang.Implementation.Name_P_Enclosing_Defining_Name (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 636
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind dn Var_Expr
--# expr-start 637 '<FieldAccess for basic_decl at ast.py:1354>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1354
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 637
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Block_Var := Result_Var; 
--# bind bd Block_Var
--# expr-start 689 '<bind at ast.py:1356>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:1356
Bound_Origin := Self; 
--# expr-start 688 '<Cond at ast.py:1356>' If_Result_10 /tmp/lal-23.0.0/ada/ast.py:1356
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_1
--# expr-start 638 '<IsA ParamSpec at ast.py:1357>' Is_A /tmp/lal-23.0.0/ada/ast.py:1357
Is_A := Var_Expr_1.Node /= null 
and then Var_Expr_1.Node.Kind in Ada_Param_Spec_Range; 
--# expr-done 638
Scope_Result_1 := Is_A;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
if Result_Var_1 then
   --# expr-start 640 '<IsA SubpDecl, ExprFunction, GenericSubpInternal, BaseTypeDecl at ast.py:1358>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:1358
--# expr-start 639 '<FieldAccess for semantic_parent at ast.py:1358>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1358
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_2 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 639
Is_A_1 := Fld_2.Node /= null 
and then Fld_2.Node.Kind in Ada_Subp_Decl_Range | Ada_Expr_Function_Range | Ada_Generic_Subp_Internal_Range | Ada_Base_Type_Decl; 
--# expr-done 640
   If_Result := Is_A_1;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 643 '<FieldAccess for defining_name at ast.py:1361>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1361
--# expr-start 642 '<Cast to BasicDecl at ast.py:1361>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1361
--# expr-start 641 '<FieldAccess for semantic_parent at ast.py:1361>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1361
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_3 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 641
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 642
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Cast_Result_1.Node, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 643
   If_Result_10 := Fld_4;
else
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_2
--# expr-start 644 '<IsA DiscriminantSpec at ast.py:1363>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:1363
Is_A_2 := Var_Expr_2.Node /= null 
and then Var_Expr_2.Node.Kind in Ada_Discriminant_Spec_Range; 
--# expr-done 644
Scope_Result_2 := Is_A_2;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
if Result_Var_2 then
   --# expr-start 647 '<FieldAccess for defining_name at ast.py:1364>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:1364
--# expr-start 646 '<Cast to BasicDecl at ast.py:1364>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1364
--# expr-start 645 '<FieldAccess for semantic_parent at ast.py:1364>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1364
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_5 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 645
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 646
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Cast_Result_2.Node, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 647
   If_Result_9 := Fld_6;
else
Var_Expr_3 := Block_Var;
if Var_Expr_3 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_3
--# expr-start 648 '<IsA ParamSpec at ast.py:1366>' Is_A_3 /tmp/lal-23.0.0/ada/ast.py:1366
Is_A_3 := Var_Expr_3.Node /= null 
and then Var_Expr_3.Node.Kind in Ada_Param_Spec_Range; 
--# expr-done 648
Scope_Result_3 := Is_A_3;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
if Result_Var_3 then
   --# expr-start 650 '<IsA AbstractSubpDecl, FormalSubpDecl, NullSubpDecl at ast.py:1367>' Is_A_4 /tmp/lal-23.0.0/ada/ast.py:1367
--# expr-start 649 '<FieldAccess for semantic_parent at ast.py:1367>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:1367
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_7 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 649
Is_A_4 := Fld_7.Node /= null 
and then Fld_7.Node.Kind in Ada_Abstract_Subp_Decl_Range | Ada_Formal_Subp_Decl | Ada_Null_Subp_Decl_Range; 
--# expr-done 650
   If_Result_1 := Is_A_4;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 653 '<FieldAccess for defining_name at ast.py:1369>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:1369
--# expr-start 652 '<Cast to BasicDecl at ast.py:1369>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:1369
--# expr-start 651 '<FieldAccess for semantic_parent at ast.py:1369>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:1369
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_8 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 651
   if Fld_8.Node = null
      or else Fld_8.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
   else
         Cast_Result_3 := No_Entity_Basic_Decl;
   end if;
--# expr-done 652
      if Cast_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Cast_Result_3.Node, E_Info => Cast_Result_3.Info);
--# end
--# expr-done 653
   If_Result_8 := Fld_9;
else
Var_Expr_4 := Block_Var;
if Var_Expr_4 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_4
--# expr-start 654 '<IsA AbstractSubpDecl at ast.py:1371>' Is_A_5 /tmp/lal-23.0.0/ada/ast.py:1371
Is_A_5 := Var_Expr_4.Node /= null 
and then Var_Expr_4.Node.Kind in Ada_Abstract_Subp_Decl_Range; 
--# expr-done 654
Scope_Result_4 := Is_A_5;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := False;
end if;
if Result_Var_4 then
   --# expr-start 658 '<FieldAccess for defining_name at ast.py:1373>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:1373
--# expr-start 657 '<FieldAccess for primitive_subp_first_type at ast.py:1373>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:1373
--# expr-start 656 '<FieldAccess for subp_decl_spec at ast.py:1372>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:1372
--# expr-start 655 '<Cast to AbstractSubpDecl at ast.py:1372>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:1372
Cast_Expr_1 := Block_Var; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Abstract_Subp_Decl_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Abstract_Subp_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_4 := No_Entity_Abstract_Subp_Decl;
   end if;
--# expr-done 655
      if Cast_Result_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Cast_Result_4.Node, E_Info => Cast_Result_4.Info);
--# end
--# expr-done 656
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_subp_first_type
Fld_11 := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Subp_First_Type (Node => Fld_10.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_10.Info);
--# end
--# expr-done 657
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_12 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Fld_11.Node, E_Info => Fld_11.Info);
--# end
--# expr-done 658
   If_Result_7 := Fld_12;
else
Var_Expr_5 := Block_Var;
if Var_Expr_5 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_5
--# expr-start 659 '<IsA BasicSubpDecl at ast.py:1375>' Is_A_6 /tmp/lal-23.0.0/ada/ast.py:1375
Is_A_6 := Var_Expr_5.Node /= null 
and then Var_Expr_5.Node.Kind in Ada_Basic_Subp_Decl; 
--# expr-done 659
Scope_Result_5 := Is_A_6;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
if Result_Var_5 then
--# expr-start 662 '<FieldAccess for primitive_subp_first_type at ast.py:1377>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:1377
--# expr-start 661 '<FieldAccess for subp_decl_spec at ast.py:1376>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:1376
--# expr-start 660 '<Cast to BasicSubpDecl at ast.py:1376>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:1376
Cast_Expr_2 := Block_Var; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Subp_Decl
   then
      Cast_Result_5 := Create_Internal_Entity_Basic_Subp_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_5 := No_Entity_Basic_Subp_Decl;
   end if;
--# expr-done 660
      if Cast_Result_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld_13 := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Cast_Result_5.Node, E_Info => Cast_Result_5.Info);
--# end
--# expr-done 661
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_subp_first_type
Fld_14 := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Subp_First_Type (Node => Fld_13.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_13.Info);
--# end
--# expr-done 662
Var_Expr_6 := Fld_14;
if Var_Expr_6 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind prim_typ Var_Expr_6
--# expr-start 663 '<FieldAccess for is_tagged_type at ast.py:1379>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:1379
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_15 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Var_Expr_6.Node, Origin => Bound_Origin, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 663
Var_Expr_7 := Fld_15;
if Var_Expr_7 /= False then
   --# scope-start
   --# bind _ Var_Expr_7
--# expr-start 664 '<FieldAccess for private_completion at ast.py:1380>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:1380
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.private_completion
Fld_16 := Libadalang.Implementation.Base_Type_Decl_P_Private_Completion (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 664
Var_Expr_9 := Fld_16;
if Var_Expr_9 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind pc Var_Expr_9
--# expr-start 665 '<FieldAccess for defining_name at ast.py:1381>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:1381
      if Var_Expr_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_17 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_9.Node, E_Info => Var_Expr_9.Info);
--# end
--# expr-done 665
Scope_Result_6 := Fld_17;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Defining_Name;
end if;
Var_Expr_8 := Result_Var_6;
if Var_Expr_8 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind e Var_Expr_8
Scope_Result_7 := Var_Expr_8;
   --# end
   Result_Var_7 := Scope_Result_7;
else
   --# expr-start 666 '<FieldAccess for defining_name at ast.py:1382>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:1382
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_18 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 666
   Result_Var_7 := Fld_18;
end if;
Scope_Result_8 := Result_Var_7;
   --# end
   Result_Var_8 := Scope_Result_8;
else
   Result_Var_8 := No_Entity_Defining_Name;
end if;
Scope_Result_9 := Result_Var_8;
   --# end
   Result_Var_9 := Scope_Result_9;
else
   Result_Var_9 := No_Entity_Defining_Name;
end if;
   If_Result_6 := Result_Var_9;
else
--# expr-start 667 '<Cast to Name at ast.py:1386>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:1386
Cast_Expr_3 := Ent; 
   if Cast_Expr_3.Node = null
      or else Cast_Expr_3.Node.Kind in Ada_Name
   then
      Cast_Result_6 := Create_Internal_Entity_Name
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
   else
         Cast_Result_6 := No_Entity_Name;
   end if;
--# expr-done 667
Var_Expr_11 := Cast_Result_6;
if Var_Expr_11 /= No_Entity_Name then
   --# scope-start
--# expr-start 668 '<FieldAccess for gnat_xref_decl at ast.py:1386>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:1386
      if Var_Expr_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.gnat_xref_decl
Fld_19 := Libadalang.Implementation.Name_P_Gnat_Xref_Decl (Node => Var_Expr_11.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_11.Info);
--# end
--# expr-done 668
Scope_Result_10 := Fld_19;
   --# end
   Result_Var_10 := Scope_Result_10;
else
   Result_Var_10 := No_Entity_Defining_Name;
end if;
Var_Expr_10 := Result_Var_10;
if Var_Expr_10 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind ret Var_Expr_10
--# expr-start 687 '<Let at ast.py:1388>' Let_Result /tmp/lal-23.0.0/ada/ast.py:1388
--# scope-start
--# expr-start 669 '<FieldAccess for basic_decl at ast.py:1388>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:1388
      if Var_Expr_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_20 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr_10.Node, E_Info => Var_Expr_10.Info);
--# end
--# expr-done 669
Dbd := Fld_20; 
--# bind dbd Dbd
--# expr-start 686 '<Cond at ast.py:1388>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:1388
--# expr-start 670 '<IsA ParamSpec at ast.py:1389>' Is_A_7 /tmp/lal-23.0.0/ada/ast.py:1389
Is_A_7 := Dbd.Node /= null 
and then Dbd.Node.Kind in Ada_Param_Spec_Range; 
--# expr-done 670
if Is_A_7 then
   --# expr-start 672 '<FieldAccess for decl_param at ast.py:1390>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:1390
--# expr-start 671 '<Cast to ParamSpec at ast.py:1390>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:1390
Cast_Expr_4 := Dbd; 
   if Cast_Expr_4.Node = null
      or else Cast_Expr_4.Node.Kind in Ada_Param_Spec_Range
   then
      Cast_Result_7 := Create_Internal_Entity_Param_Spec
        (Node => Cast_Expr_4.Node,
         Info => Cast_Expr_4.Info);
   else
         Cast_Result_7 := No_Entity_Param_Spec;
   end if;
--# expr-done 671
      if Cast_Result_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.decl_param
Fld_21 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Decl_Param (Node => Cast_Result_7.Node, Param => Var_Expr_10, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_7.Info);
--# end
--# expr-done 672
   If_Result_5 := Fld_21;
else
--# expr-start 673 '<IsA GenericSubpInternal, GenericPackageInternal at ast.py:1392>' Is_A_8 /tmp/lal-23.0.0/ada/ast.py:1392
Is_A_8 := Dbd.Node /= null 
and then Dbd.Node.Kind in Ada_Generic_Subp_Internal_Range | Ada_Generic_Package_Internal_Range; 
--# expr-done 673
if Is_A_8 then
--# expr-start 675 '<at at ast.py:1393>' Get_Result /tmp/lal-23.0.0/ada/ast.py:1393
--# expr-start 674 '<FieldAccess for generic_instantiations at ast.py:1393>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:1393
      if Dbd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.generic_instantiations
Fld_22 := Libadalang.Implementation.Ada_Node_P_Generic_Instantiations (Node => Dbd.Node, E_Info => Dbd.Info);
--# end
--# expr-done 674
Get_Result := Get (Self, Fld_22, 0, True); 
--# expr-done 675
Var_Expr_12 := Get_Result;
if Var_Expr_12 /= No_Entity_Generic_Instantiation then
   --# scope-start
   --# bind gi Var_Expr_12
--# expr-start 677 '<FieldAccess for defining_name at ast.py:1394>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:1394
--# expr-start 676 '<Cast to BasicDecl at ast.py:1394>' Cast_Result_8 /tmp/lal-23.0.0/ada/ast.py:1394
Cast_Expr_5 := Var_Expr_12; 
      Cast_Result_8 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_5.Node,
         Info => Cast_Expr_5.Info);
--# expr-done 676
      if Cast_Result_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_23 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Cast_Result_8.Node, E_Info => Cast_Result_8.Info);
--# end
--# expr-done 677
Scope_Result_11 := Fld_23;
   --# end
   Result_Var_11 := Scope_Result_11;
else
   Result_Var_11 := Var_Expr_10;
end if;
   If_Result_4 := Result_Var_11;
else
--# expr-start 678 '<IsA ObjectDecl at ast.py:1398>' Is_A_9 /tmp/lal-23.0.0/ada/ast.py:1398
Is_A_9 := Dbd.Node /= null 
and then Dbd.Node.Kind in Ada_Object_Decl_Range; 
--# expr-done 678
if Is_A_9 then
--# expr-start 680 '<FieldAccess for public_part_decl at ast.py:1399>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:1399
--# expr-start 679 '<Cast to ObjectDecl at ast.py:1399>' Cast_Result_9 /tmp/lal-23.0.0/ada/ast.py:1399
Cast_Expr_6 := Dbd; 
   if Cast_Expr_6.Node = null
      or else Cast_Expr_6.Node.Kind in Ada_Object_Decl_Range
   then
      Cast_Result_9 := Create_Internal_Entity_Object_Decl
        (Node => Cast_Expr_6.Node,
         Info => Cast_Expr_6.Info);
   else
         Cast_Result_9 := No_Entity_Object_Decl;
   end if;
--# expr-done 679
      if Cast_Result_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ObjectDecl.public_part_decl
Fld_24 := Libadalang.Implementation.Object_Decl_P_Public_Part_Decl (Node => Cast_Result_9.Node, E_Info => Cast_Result_9.Info);
--# end
--# expr-done 680
Var_Expr_14 := Fld_24;
if Var_Expr_14 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind ppd Var_Expr_14
--# expr-start 681 '<FieldAccess for defining_name at ast.py:1400>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:1400
      if Var_Expr_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_25 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_14.Node, E_Info => Var_Expr_14.Info);
--# end
--# expr-done 681
Scope_Result_12 := Fld_25;
   --# end
   Result_Var_12 := Scope_Result_12;
else
   Result_Var_12 := No_Entity_Defining_Name;
end if;
Var_Expr_13 := Result_Var_12;
if Var_Expr_13 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind e Var_Expr_13
Scope_Result_13 := Var_Expr_13;
   --# end
   Result_Var_13 := Scope_Result_13;
else
   Result_Var_13 := Var_Expr_10;
end if;
   If_Result_3 := Result_Var_13;
else
--# expr-start 682 '<IsA BaseSubpBody at ast.py:1404>' Is_A_10 /tmp/lal-23.0.0/ada/ast.py:1404
Is_A_10 := Dbd.Node /= null 
and then Dbd.Node.Kind in Ada_Base_Subp_Body; 
--# expr-done 682
if Is_A_10 then
   --# expr-start 685 '<FieldAccess for defining_name at ast.py:1406>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:1406
--# expr-start 684 '<FieldAccess for decl_part at ast.py:1406>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:1406
--# expr-start 683 '<Cast to BaseSubpBody at ast.py:1405>' Cast_Result_10 /tmp/lal-23.0.0/ada/ast.py:1405
Cast_Expr_7 := Dbd; 
   if Cast_Expr_7.Node = null
      or else Cast_Expr_7.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result_10 := Create_Internal_Entity_Base_Subp_Body
        (Node => Cast_Expr_7.Node,
         Info => Cast_Expr_7.Info);
   else
         Cast_Result_10 := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 683
      if Cast_Result_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld_26 := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Cast_Result_10.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_10.Info);
--# end
--# expr-done 684
Var_Expr_15 := Fld_26;
if Var_Expr_15 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind e Var_Expr_15
Scope_Result_14 := Var_Expr_15;
   --# end
   Result_Var_14 := Scope_Result_14;
else
   Result_Var_14 := Dbd;
end if;
      if Result_Var_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_27 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Result_Var_14.Node, E_Info => Result_Var_14.Info);
--# end
--# expr-done 685
   If_Result_2 := Fld_27;
else
   If_Result_2 := Var_Expr_10;
end if;
   If_Result_3 := If_Result_2;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
--# expr-done 686
Let_Result := If_Result_5; 
--# end
--# expr-done 687
Scope_Result_15 := Let_Result;
   --# end
      Finalizer_Scope_1855;
   Result_Var_15 := Scope_Result_15;
else
   Result_Var_15 := No_Entity_Defining_Name;
end if;
   If_Result_6 := Result_Var_15;
end if;
   If_Result_7 := If_Result_6;
end if;
   If_Result_8 := If_Result_7;
end if;
   If_Result_9 := If_Result_8;
end if;
   If_Result_10 := If_Result_9;
end if;
--# expr-done 688
Dyn_Var_Bind_Result := If_Result_10; 
--# expr-done 689
Let_Result_1 := Dyn_Var_Bind_Result; 
--# end
--# expr-done 690
      Property_Result := Let_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1855;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Gnat_Xref;
--# end
--# property-start AdaNode.env_get_real_from_node /tmp/lal-23.0.0/ada/ast.py:1414
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Env_Get_Real_From_Node
  (Node : Bare_Ada_Node
      ; From_Node : Bare_Ada_Node
  )
   return Bare_Ada_Node
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind from_node From_Node
   Property_Result : Bare_Ada_Node;
            procedure Finalizer_Scope_91 with Inline_Always;
      C : Bare_Ada_Node;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Is_Null : Boolean;
Is_A_1 : Boolean;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Base_Subp_Spec;
As_Entity : Internal_Entity_Base_Subp_Spec;
Is_Null_1 : Boolean;
If_Result : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Bare_Defining_Name;
Cast_Result_1 : Bare_Ada_Node;
If_Result_1 : Bare_Ada_Node;
If_Result_2 : Bare_Ada_Node;
Let_Result : Bare_Ada_Node;
Is_Null_2 : Boolean;
If_Result_3 : Bare_Ada_Node;
Let_Result_1 : Bare_Ada_Node;
            procedure Finalizer_Scope_91 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_91;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 704 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 703 '<If at ast.py:1421>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:1421
--# expr-start 691 '<IsNull at ast.py:1421>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:1421
Is_Null_2 := From_Node = null; 
--# expr-done 691
if Is_Null_2 then
   If_Result_3 := From_Node;
else
   --# expr-start 702 '<Let at ast.py:1421>' Let_Result /tmp/lal-23.0.0/ada/ast.py:1421
--# scope-start
--# expr-start 694 '<Find at ast.py:1422>' Find_Result /tmp/lal-23.0.0/ada/ast.py:1422
   --# expr-start 692 '<FieldAccess for parents at ast.py:1422>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:1422
      if From_Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (From_Node, True); 
--# expr-done 692
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_24 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_24
      --# expr-start 693 '<IsA GenericInstantiation, BaseSubpSpec at ast.py:1423>' Is_A /tmp/lal-23.0.0/ada/ast.py:1423
Is_A := Item_24 /= null 
and then Item_24.Kind in Ada_Generic_Instantiation | Ada_Base_Subp_Spec; 
--# expr-done 693
      if Is_A then
         Find_Result := Item_24;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 694
C := Find_Result; 
--# bind c C
--# expr-start 701 '<Cond at ast.py:1424>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:1424
--# expr-start 695 '<IsNull at ast.py:1425>' Is_Null /tmp/lal-23.0.0/ada/ast.py:1425
Is_Null := C = null; 
--# expr-done 695
if Is_Null then
   If_Result_2 := From_Node;
else
--# expr-start 696 '<IsA BaseSubpSpec at ast.py:1428>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:1428
Is_A_1 := C /= null 
and then C.Kind in Ada_Base_Subp_Spec; 
--# expr-done 696
if Is_A_1 then
--# expr-start 700 '<FieldAccess for node at ast.py:1429>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1429
--# expr-start 699 '<FieldAccess for name at ast.py:1429>' Fld /tmp/lal-23.0.0/ada/ast.py:1429
--# expr-start 698 '<as_bare_entity at ast.py:1429>' If_Result /tmp/lal-23.0.0/ada/ast.py:1429
--# expr-start 697 '<Cast to BaseSubpSpec at ast.py:1429>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1429
Cast_Expr := C; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Base_Subp_Spec
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 697
Is_Null_1 := Cast_Result = null; 
if Is_Null_1 then
   If_Result := No_Entity_Base_Subp_Spec;
else
As_Entity := (Info => No_Entity_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 698
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 699
Fld_1 := Fld.Node;
--# expr-done 700
      Cast_Result_1 := Fld_1;
   If_Result_1 := Cast_Result_1;
else
   If_Result_1 := C;
end if;
   If_Result_2 := If_Result_1;
end if;
--# expr-done 701
Let_Result := If_Result_2; 
--# end
--# expr-done 702
   If_Result_3 := Let_Result;
end if;
--# expr-done 703
Let_Result_1 := If_Result_3; 
--# end
--# expr-done 704
      Property_Result := Let_Result_1;
   --# end
      Finalizer_Scope_91;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_91;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Env_Get_Real_From_Node;
--# end
--# property-start AdaNode.entity_no_md /tmp/lal-23.0.0/ada/ast.py:1436
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Entity_No_Md
  (Node : Bare_Ada_Node
      ; N : Bare_Ada_Node
      ; Rebindings : Env_Rebindings
      ; From_Rebound : Boolean
  )
   return Internal_Entity
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind n N
   --# bind rebindings Rebindings
   --# bind from_rebound From_Rebound
   Property_Result : Internal_Entity;
      New_Struct : Internal_Entity_Info;
Is_Null : Boolean;
If_Result : Internal_Entity_Info;
New_Struct_1 : Internal_Entity;
Let_Result : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 709 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 708 '<New AdaNode.entity at ast.py:1442>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:1442
--# expr-start 707 '<If at ast.py:1444>' If_Result /tmp/lal-23.0.0/ada/ast.py:1444
--# expr-start 705 '<IsNull at ast.py:1444>' Is_Null /tmp/lal-23.0.0/ada/ast.py:1444
Is_Null := N = null; 
--# expr-done 705
if Is_Null then
   If_Result := No_Entity_Info;
else
   --# expr-start 706 '<New EntityInfo at ast.py:1444>' New_Struct /tmp/lal-23.0.0/ada/ast.py:1444
New_Struct := (From_Rebound => From_Rebound, Md => No_Metadata, Rebindings => Rebindings); 
--# expr-done 706
   If_Result := New_Struct;
end if;
--# expr-done 707
New_Struct_1 := (Info => If_Result, Node => N); 
--# expr-done 708
Let_Result := New_Struct_1; 
--# end
--# expr-done 709
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Entity_No_Md;
--# end
--# property-start AdaNode.env_mappings /tmp/lal-23.0.0/ada/ast.py:1452
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Env_Mappings
  (Node : Bare_Ada_Node
      ; Defining_Names : Bare_Defining_Name_List
      ; Value : Bare_Ada_Node
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind defining_names Defining_Names
   --# bind value Value
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_93 with Inline_Always;
            procedure Finalizer_Scope_1864 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Item_25 : Bare_Defining_Name;
Map_Result : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_93 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_93;
            procedure Finalizer_Scope_1864 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1864;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 714 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 713 '<Map at ast.py:1457>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1457
      declare
         Map_Result_Vec : Internal_Env_Assoc_Vectors.Vector;
      begin
      if Defining_Names = null then
      Map_Result := Create_Internal_Env_Assoc_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Defining_Names;
      begin
         for Untyped_Item_25 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_25 := Untyped_Item_25; 
   --# scope-start
               --# bind n Item_25
      --# expr-start 712 '<New EnvAssoc at ast.py:1458>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:1458
--# expr-start 710 '<New DesignatedEnv at ast.py:1458>' New_Struct /tmp/lal-23.0.0/ada/ast.py:1458
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 710
--# expr-start 711 '<FieldAccess for name_symbol at ast.py:1458>' Fld /tmp/lal-23.0.0/ada/ast.py:1458
      if Item_25 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Item_25);
--# end
--# expr-done 711
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Value); 
--# expr-done 712
         declare
            Item_To_Append : constant Internal_Env_Assoc := New_Struct_1;
         begin
               Inc_Ref (Item_To_Append);
            Internal_Env_Assoc_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1864;
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Env_Assoc_Array
           (Items_Count => Natural (Internal_Env_Assoc_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Env_Assoc_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Env_Assoc_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Env_Assoc_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 713
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 714
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_93;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_93;
               Finalizer_Scope_1864;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Env_Mappings;
--# end
--# property-start AdaNode.comp_bind /tmp/lal-23.0.0/ada/ast.py:1462
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Comp_Bind
  (Node : Bare_Ada_Node
      ; Left : Logic_Var
      ; Right : Logic_Var
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind left Left
   --# bind right Right
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_94 with Inline_Always;
      Bind_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_94 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_94;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 716 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 715 '<Bind at ast.py:1463>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:1463
Left.Value := No_Entity;
Entity_Vars.Reset (Left);
Right.Value := No_Entity;
Entity_Vars.Reset (Right);
Bind_Result := Solver.Create_Propagate (Left, Right, Logic_Functor_672'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:1463") else null)); 
--# expr-done 715
Let_Result := Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 716
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_94;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_94;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Comp_Bind;
--# end
--# property-start AdaNode.universal_int_bind /tmp/lal-23.0.0/ada/ast.py:1466
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Universal_Int_Bind
  (Node : Bare_Ada_Node
      ; Type_Var : Logic_Var
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind type_var Type_Var
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_95 with Inline_Always;
      Fld : Internal_Entity;
Bind_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_95 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_95;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 719 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 718 '<Bind at ast.py:1472>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:1472
Type_Var.Value := No_Entity;
Entity_Vars.Reset (Type_Var);
--# expr-start 717 '<FieldAccess for universal_int_type at ast.py:1472>' Fld /tmp/lal-23.0.0/ada/ast.py:1472
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 717
Bind_Result := Solver.Create_Assign (Type_Var, Fld, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:1472") else null)); 
--# expr-done 718
Let_Result := Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 719
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_95;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_95;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Universal_Int_Bind;
--# end
--# property-start AdaNode.universal_real_bind /tmp/lal-23.0.0/ada/ast.py:1475
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Universal_Real_Bind
  (Node : Bare_Ada_Node
      ; Type_Var : Logic_Var
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind type_var Type_Var
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_96 with Inline_Always;
      Fld : Internal_Entity;
Bind_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_96 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_96;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 722 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 721 '<Bind at ast.py:1482>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:1482
Type_Var.Value := No_Entity;
Entity_Vars.Reset (Type_Var);
--# expr-start 720 '<FieldAccess for universal_real_type at ast.py:1482>' Fld /tmp/lal-23.0.0/ada/ast.py:1482
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 720
Bind_Result := Solver.Create_Assign (Type_Var, Fld, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:1482") else null)); 
--# expr-done 721
Let_Result := Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 722
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_96;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_96;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Universal_Real_Bind;
--# end
--# property-start AdaNode.origin_node /tmp/lal-23.0.0/ada/ast.py:1485
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Origin_Node
  (Node : Bare_Ada_Node
  )
   return Bare_Ada_Node
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node;
      Fld : Boolean;
If_Result : Bare_Ada_Node;
Let_Result : Bare_Ada_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 725 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 724 '<If at ast.py:1490>' If_Result /tmp/lal-23.0.0/ada/ast.py:1490
--# expr-start 723 '<FieldAccess for in_contract at ast.py:1490>' Fld /tmp/lal-23.0.0/ada/ast.py:1490
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.in_contract
Fld := Libadalang.Implementation.Ada_Node_P_In_Contract (Node => Self);
--# end
--# expr-done 723
if Fld then
   If_Result := No_Bare_Ada_Node;
else
   If_Result := Self;
end if;
--# expr-done 724
Let_Result := If_Result; 
--# end
--# expr-done 725
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Origin_Node;
--# end
--# property-start AdaNode.env_hook /tmp/lal-23.0.0/ada/ast.py:1493
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Env_Hook
  (Node : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Match_0 : Bare_Library_Item;
Match_1 : Bare_Subunit;
Match_2 : Bare_Ada_Node;
Match_0_1 : Bare_Body_Node;
Match_1_1 : Bare_Basic_Decl;
Match_2_1 : Bare_Ada_Node;
Fld : Bare_Ada_Node;
Fld_1 : Boolean;
Fld_2 : Boolean;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Body_Node;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Bare_Basic_Decl;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_2 : Bare_Ada_Node;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
Fld_3 : Boolean;
Match_Prefix_1 : Bare_Ada_Node;
Cast_Result_3 : Bare_Library_Item;
Let_Result_3 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_4 : Bare_Subunit;
Let_Result_4 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_5 : Bare_Ada_Node;
Let_Result_5 : Boolean;
Scope_Result_5 : Boolean;
Match_Result_1 : Boolean;
Let_Result_6 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 732 '<Block at ???>' Let_Result_6 None
--# scope-start
--# expr-start 731 '<Match at ast.py:1500>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:1500
--# expr-start 726 '<parent at ast.py:1500>' Fld /tmp/lal-23.0.0/ada/ast.py:1500
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 726
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Fld; 
case Ada_Ada_Node (Match_Prefix_1.Kind) is
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix_1;
Match_0 := Cast_Result_3; 
--# bind _ Match_0
--# expr-start 729 '<Match at ast.py:1501>' Match_Result /tmp/lal-23.0.0/ada/ast.py:1501
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Expr_Function .. Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0_1 := Cast_Result; 
--# bind b Match_0_1
--# expr-start 727 '<FieldAccess for env_hook_body at ast.py:1502>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1502
      if Match_0_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.env_hook_body
Fld_1 := Libadalang.Implementation.Body_Node_P_Env_Hook_Body (Node => Match_0_1);
--# end
--# expr-done 727
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl .. Ada_Synthetic_Subp_Decl | Ada_Entry_Index_Spec .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1_1 := Cast_Result_1; 
--# bind bd Match_1_1
--# expr-start 728 '<FieldAccess for env_hook_basic_decl at ast.py:1503>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1503
      if Match_1_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.env_hook_basic_decl
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Env_Hook_Basic_Decl (Node => Match_1_1);
--# end
--# expr-done 728
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2_1 := Cast_Result_2; 
--# bind _ Match_2_1
Let_Result_2 := False; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 729
Let_Result_3 := Match_Result; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result_1 := Scope_Result_3; 
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix_1;
Match_1 := Cast_Result_4; 
--# bind su Match_1
--# expr-start 730 '<FieldAccess for env_hook_subunit at ast.py:1506>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1506
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.env_hook_subunit
Fld_3 := Libadalang.Implementation.Subunit_P_Env_Hook_Subunit (Node => Match_1);
--# end
--# expr-done 730
Let_Result_4 := Fld_3; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result_1 := Scope_Result_4; 
         when Ada_Abort_Absent .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Match_Prefix_1;
Match_2 := Cast_Result_5; 
--# bind _ Match_2
Let_Result_5 := False; 
--# end
Scope_Result_5 := Let_Result_5;
   --# end
            Match_Result_1 := Scope_Result_5; 
end case;
--# expr-done 731
Let_Result_6 := Match_Result_1; 
--# end
--# expr-done 732
      Property_Result := Let_Result_6;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Env_Hook;
--# end
--# property-start AdaNode.env_get /tmp/lal-23.0.0/ada/ast.py:1511
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Env_Get
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Symbol : Symbol_Type
      ; Lookup : Lookup_Kind
         := Recursive
      ; From_Node : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind symbol Symbol
   --# bind lookup Lookup
   --# bind from_node From_Node
   --# bind categories Categories
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_99 with Inline_Always;
      Block_Var : Bare_Ada_Node;
Block_Var_1 : Internal_Entity_Array_Access;
Block_Var_2 : Bare_Basic_Decl;
Var_Expr : Bare_Basic_Decl;
Var_Expr_1 : Bare_Defining_Name;
Var_Expr_2 : Internal_Entity_Defining_Name;
Var_Expr_3 : Internal_Entity_Basic_Decl;
Fld : Bare_Ada_Node;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Cast_Expr_1 : Bare_Ada_Node;
Cast_Result_1 : Bare_Defining_Name;
Fld_1 : Bare_Ada_Node;
Fld_2 : Bare_Ada_Node;
Cast_Result_2 : Bare_Basic_Decl;
Scope_Result_1 : Bare_Basic_Decl;
Result_Var : Bare_Basic_Decl;
Result_Var_1 : Bare_Basic_Decl;
Fld_3 : Bare_Ada_Node;
Cast_Expr_2 : Bare_Basic_Decl;
Cast_Result_3 : Bare_Ada_Node;
Is_Equal : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Array_Access;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Defining_Name;
Scope_Result_2 : Internal_Entity_Defining_Name;
Result_Var_2 : Internal_Entity_Defining_Name;
Fld_5 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
If_Result_1 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_99 is
            begin
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_99;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 748 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 733 '<FieldAccess for env_get_real_from_node at ast.py:1534>' Fld /tmp/lal-23.0.0/ada/ast.py:1534
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_get_real_from_node
Fld := Libadalang.Implementation.Ada_Node_P_Env_Get_Real_From_Node (Node => Self, From_Node => From_Node);
--# end
--# expr-done 733
Block_Var := Fld; 
--# bind real_from_node Block_Var
--# expr-start 734 '<EnvGet at ast.py:1535>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:1535
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Env, Key => Symbol, Lookup_Kind => To_Lookup_Kind_Type (Lookup), Categories => Categories, From => Block_Var)); 
--# expr-done 734
Block_Var_1 := Env_Get_Result; Inc_Ref (Block_Var_1);
--# bind results Block_Var_1
--# expr-start 735 '<Cast to BasicDecl at ast.py:1539>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1539
Cast_Expr := Block_Var; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Basic_Decl
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 735
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr
Scope_Result := Var_Expr;
   --# end
   Result_Var_1 := Scope_Result;
else
--# expr-start 736 '<Cast to DefiningName at ast.py:1540>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1540
Cast_Expr_1 := Block_Var; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Defining_Name_Range
   then
      Cast_Result_1 := Cast_Expr_1;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 736
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind name Var_Expr_1
--# expr-start 739 '<Cast to BasicDecl at ast.py:1541>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1541
--# expr-start 738 '<parent at ast.py:1541>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1541
--# expr-start 737 '<parent at ast.py:1541>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1541
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr_1.Parent; 
--# expr-done 737
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Fld_1.Parent; 
--# expr-done 738
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Fld_2;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 739
Scope_Result_1 := Cast_Result_2;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := No_Bare_Ada_Node;
end if;
   Result_Var_1 := Result_Var;
end if;
Block_Var_2 := Result_Var_1; 
--# bind enclosing_bd Block_Var_2
--# expr-start 747 '<If at ast.py:1545>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1545
--# expr-start 740 '<as_bare_entity at ast.py:1549>' If_Result /tmp/lal-23.0.0/ada/ast.py:1549
Is_Null := Block_Var_2 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Block_Var_2); 
   If_Result := As_Entity;
end if;
--# expr-done 740
Var_Expr_3 := If_Result;
if Var_Expr_3 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 741 '<FieldAccess for defining_name at ast.py:1549>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1549
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 741
Scope_Result_2 := Fld_4;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Defining_Name;
end if;
Var_Expr_2 := Result_Var_2;
if Var_Expr_2 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 742 '<FieldAccess for name_is at ast.py:1549>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1549
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_5 := Libadalang.Implementation.Name_P_Name_Is (Node => Var_Expr_2.Node, Sym => Symbol);
--# end
--# expr-done 742
Scope_Result_3 := Fld_5;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
if Result_Var_3 then
   --# expr-start 746 '<Filter at ast.py:1550>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1550
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var_1;
      begin
         for Item_26 of
               Collection.Items
         loop
   --# scope-start
               --# bind r Item_26
         --# expr-start 745 '<Not at ast.py:1550>' Not_Val /tmp/lal-23.0.0/ada/ast.py:1550
--# expr-start 744 '<Eq at ast.py:1550>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:1550
--# expr-start 743 '<FieldAccess for node at ast.py:1550>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1550
Fld_3 := Item_26.Node;
--# expr-done 743
Cast_Expr_2 := Block_Var_2; 
      Cast_Result_3 := Cast_Expr_2;
Is_Equal := Fld_3 = Cast_Result_3; 
--# expr-done 744
Not_Val := not (Is_Equal); 
--# expr-done 745
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity := Item_26;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 746
   If_Result_1 := Map_Result;
else
   If_Result_1 := Block_Var_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 747
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 748
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_99;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_99;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Env_Get;
--# end
--# property-start AdaNode.env_get_public /tmp/lal-23.0.0/ada/ast.py:1555
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Env_Get_Public
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Symbol : Symbol_Type
      ; Lookup : Lookup_Kind
         := Recursive
      ; From_Node : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind symbol Symbol
   --# bind lookup Lookup
   --# bind from_node From_Node
   --# bind categories Categories
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_100 with Inline_Always;
      Var_Expr : Internal_Entity_Package_Decl;
Fld : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Package_Decl;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Not_Val : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Map_Result : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_100 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_100;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 756 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 755 '<Filter at ast.py:1567>' Map_Result /tmp/lal-23.0.0/ada/ast.py:1567
   --# expr-start 749 '<FieldAccess for env_get at ast.py:1567>' Fld /tmp/lal-23.0.0/ada/ast.py:1567
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_get
Fld := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Env, Symbol => Symbol, Lookup => Lookup, From_Node => From_Node, Categories => Categories);
--# end
--# expr-done 749
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_27 of
               Collection.Items
         loop
   --# scope-start
               --# bind x Item_27
--# expr-start 750 '<Cast to PackageDecl at ast.py:1568>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1568
Cast_Expr := Item_27; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Package_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Package_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Package_Decl;
   end if;
--# expr-done 750
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Package_Decl then
   --# scope-start
   --# bind pkg Var_Expr
--# expr-start 754 '<Not at ast.py:1569>' Not_Val /tmp/lal-23.0.0/ada/ast.py:1569
--# expr-start 753 '<Eq at ast.py:1569>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:1569
--# expr-start 751 '<FieldAccess for name_symbol at ast.py:1569>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1569
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Var_Expr.Node);
--# end
--# expr-done 751
--# expr-start 752 '<Symbol root_types_ at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Types); 
--# expr-done 752
Is_Equal := Fld_1 = Sym; 
--# expr-done 753
Not_Val := not (Is_Equal); 
--# expr-done 754
Scope_Result := Not_Val;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
         if Result_Var then
         declare
            Item_To_Append : constant Internal_Entity := Item_27;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 755
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 756
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_100;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_100;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Env_Get_Public;
--# end
--# property-start AdaNode.synthesize_defining_name /tmp/lal-23.0.0/ada/ast.py:1576
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Synthesize_Defining_Name
  (Node : Bare_Ada_Node
      ; Sym : Symbol_Type
  )
   return Bare_Defining_Name
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   Property_Result : Bare_Defining_Name;
      New_Node : Bare_Synthetic_Identifier;
Cast_Result : Bare_Name;
New_Node_1 : Bare_Synthetic_Defining_Name;
Let_Result : Bare_Synthetic_Defining_Name;
Cast_Result_1 : Bare_Defining_Name;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Synthesize_Defining_Name,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Sym);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Bare_Defining_Name;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
--# expr-start 759 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 758 '<New SyntheticDefiningName at ast.py:1581>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:1581
--# expr-start 757 '<New SyntheticIdentifier at ast.py:1582>' New_Node /tmp/lal-23.0.0/ada/ast.py:1582
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Identifier);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Identifier,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
      New_Node.Expr_Logic_Vars :=
         System.Null_Address;
      New_Node.Synthetic_Identifier_Sym :=
         Sym;
--# expr-done 757
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Defining_Name);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Defining_Name,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Defining_Name
     (Self => New_Node_1,
      Defining_Name_F_Name => Cast_Result);
      New_Node_1.Expr_Logic_Vars :=
         System.Null_Address;
--# expr-done 758
Let_Result := New_Node_1; 
--# end
--# expr-done 759
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Bare_Defining_Name,
                        As_Bare_Defining_Name => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Synthesize_Defining_Name;
--# end
--# property-start AdaNode.create_unop_assoc /tmp/lal-23.0.0/ada/ast.py:1590
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Create_Unop_Assoc
  (Node : Bare_Ada_Node
      ; Op : Symbol_Type
      ; Rhs : Bare_Base_Type_Decl
      ; Ret : Bare_Base_Type_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind op Op
   --# bind rhs Rhs
   --# bind ret Ret
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_102 with Inline_Always;
      Sym : Symbol_Type;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
New_Node_2 : Bare_Synthetic_Type_Expr;
New_Node_3 : Bare_Synthetic_Unary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_4 : Bare_Synthetic_Subp_Decl;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Result_2 : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_102 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_102;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Create_Unop_Assoc,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Op);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Rhs);
               Mmz_K.Items (4) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Ret);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 768 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 767 '<New EnvAssoc at ast.py:1596>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:1596
--# expr-start 760 '<New DesignatedEnv at ast.py:1596>' New_Struct /tmp/lal-23.0.0/ada/ast.py:1596
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 760
--# expr-start 766 '<New SyntheticSubpDecl at ast.py:1598>' New_Node_4 /tmp/lal-23.0.0/ada/ast.py:1598
--# expr-start 765 '<New SyntheticUnarySpec at ast.py:1598>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:1598
--# expr-start 761 '<New SyntheticTypeExpr at ast.py:1604>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:1604
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_2,
      Synthetic_Type_Expr_F_Target_Type => Ret);
--# expr-done 761
--# expr-start 764 '<New SyntheticFormalParamDecl at ast.py:1600>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:1600
--# expr-start 762 '<New SyntheticTypeExpr at ast.py:1602>' New_Node /tmp/lal-23.0.0/ada/ast.py:1602
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Rhs);
--# expr-done 762
      Cast_Result := New_Node;
--# expr-start 763 '<Symbol right at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Right); 
--# expr-done 763
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym;
--# expr-done 764
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_3,
      Synthetic_Unary_Spec_F_Return_Type_Expr => New_Node_2, Synthetic_Unary_Spec_F_Right_Param => New_Node_1);
      New_Node_3.Synthetic_Unary_Spec_Subp_Symbol :=
         Op;
--# expr-done 765
      Cast_Result_1 := New_Node_3;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_4 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_4,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_4);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_4,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 766
      Cast_Result_2 := New_Node_4;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Op, Metadata => No_Metadata, Value => Cast_Result_2); 
--# expr-done 767
Let_Result := New_Struct_1; Inc_Ref (Let_Result);
--# end
--# expr-done 768
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_102;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc,
                        As_Internal_Env_Assoc => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_102;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Create_Unop_Assoc;
--# end
--# property-start AdaNode.create_binop_assoc_impl /tmp/lal-23.0.0/ada/ast.py:1609
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Create_Binop_Assoc_Impl
  (Node : Bare_Ada_Node
      ; Op : Symbol_Type
      ; Lhs : Bare_Type_Expr
      ; Rhs : Bare_Type_Expr
      ; Ret : Bare_Type_Expr
  )
   return Internal_Env_Assoc
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind op Op
   --# bind lhs Lhs
   --# bind rhs Rhs
   --# bind ret Ret
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_103 with Inline_Always;
      Sym : Symbol_Type;
New_Node : Bare_Synthetic_Formal_Param_Decl;
Sym_1 : Symbol_Type;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
New_Node_2 : Bare_Synthetic_Binary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_3 : Bare_Synthetic_Subp_Decl;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Result_1 : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_103 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_103;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Create_Binop_Assoc_Impl,
            Items    => new Mmz_Key_Array (1 ..  5))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Op);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Lhs);
               Mmz_K.Items (4) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Rhs);
               Mmz_K.Items (5) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Ret);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 777 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 776 '<New EnvAssoc at ast.py:1616>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:1616
--# expr-start 769 '<New DesignatedEnv at ast.py:1616>' New_Struct /tmp/lal-23.0.0/ada/ast.py:1616
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 769
--# expr-start 775 '<New SyntheticSubpDecl at ast.py:1618>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:1618
--# expr-start 774 '<New SyntheticBinarySpec at ast.py:1618>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:1618
--# expr-start 771 '<New SyntheticFormalParamDecl at ast.py:1620>' New_Node /tmp/lal-23.0.0/ada/ast.py:1620
--# expr-start 770 '<Symbol left at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Left); 
--# expr-done 770
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node,
      Synthetic_Formal_Param_Decl_F_Param_Type => Lhs);
      New_Node.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym;
--# expr-done 771
--# expr-start 773 '<New SyntheticFormalParamDecl at ast.py:1624>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:1624
--# expr-start 772 '<Symbol right at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Right); 
--# expr-done 772
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Rhs);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_1;
--# expr-done 773
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node_2,
      Synthetic_Binary_Spec_F_Left_Param => New_Node, Synthetic_Binary_Spec_F_Return_Type_Expr => Ret, Synthetic_Binary_Spec_F_Right_Param => New_Node_1);
      New_Node_2.Synthetic_Binary_Spec_Subp_Symbol :=
         Op;
--# expr-done 774
      Cast_Result := New_Node_2;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_3,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 775
      Cast_Result_1 := New_Node_3;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Op, Metadata => No_Metadata, Value => Cast_Result_1); 
--# expr-done 776
Let_Result := New_Struct_1; Inc_Ref (Let_Result);
--# end
--# expr-done 777
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_103;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc,
                        As_Internal_Env_Assoc => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_103;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Create_Binop_Assoc_Impl;
--# end
--# property-start AdaNode.create_binop_assoc /tmp/lal-23.0.0/ada/ast.py:1633
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Create_Binop_Assoc
  (Node : Bare_Ada_Node
      ; Op : Symbol_Type
      ; Lhs : Bare_Base_Type_Decl
      ; Rhs : Bare_Base_Type_Decl
      ; Ret : Bare_Base_Type_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind op Op
   --# bind lhs Lhs
   --# bind rhs Rhs
   --# bind ret Ret
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_104 with Inline_Always;
      New_Node : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
New_Node_2 : Bare_Synthetic_Type_Expr;
Cast_Result_2 : Bare_Type_Expr;
Fld : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_104 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_104;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Create_Binop_Assoc,
            Items    => new Mmz_Key_Array (1 ..  5))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Op);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Lhs);
               Mmz_K.Items (4) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Rhs);
               Mmz_K.Items (5) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Ret);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 782 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 781 '<FieldAccess for create_binop_assoc_impl at ast.py:1641>' Fld /tmp/lal-23.0.0/ada/ast.py:1641
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 778 '<New SyntheticTypeExpr at ast.py:1643>' New_Node /tmp/lal-23.0.0/ada/ast.py:1643
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Lhs);
--# expr-done 778
      Cast_Result := New_Node;
--# expr-start 779 '<New SyntheticTypeExpr at ast.py:1644>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:1644
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_1,
      Synthetic_Type_Expr_F_Target_Type => Rhs);
--# expr-done 779
      Cast_Result_1 := New_Node_1;
--# expr-start 780 '<New SyntheticTypeExpr at ast.py:1645>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:1645
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_2,
      Synthetic_Type_Expr_F_Target_Type => Ret);
--# expr-done 780
      Cast_Result_2 := New_Node_2;
--# property-call-start AdaNode.create_binop_assoc_impl
Fld := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_Impl (Node => Self, Op => Op, Lhs => Cast_Result, Rhs => Cast_Result_1, Ret => Cast_Result_2);
--# end
--# expr-done 781
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 782
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_104;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc,
                        As_Internal_Env_Assoc => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_104;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Create_Binop_Assoc;
--# end
--# property-start AdaNode.create_binop_assoc_l_expr /tmp/lal-23.0.0/ada/ast.py:1649
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Create_Binop_Assoc_L_Expr
  (Node : Bare_Ada_Node
      ; Op : Symbol_Type
      ; Lhs : Bare_Type_Expr
      ; Rhs : Bare_Base_Type_Decl
      ; Ret : Bare_Base_Type_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind op Op
   --# bind lhs Lhs
   --# bind rhs Rhs
   --# bind ret Ret
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_105 with Inline_Always;
      New_Node : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
Fld : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_105 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_105;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Create_Binop_Assoc_L_Expr,
            Items    => new Mmz_Key_Array (1 ..  5))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Op);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Lhs);
               Mmz_K.Items (4) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Rhs);
               Mmz_K.Items (5) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Ret);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 786 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 785 '<FieldAccess for create_binop_assoc_impl at ast.py:1656>' Fld /tmp/lal-23.0.0/ada/ast.py:1656
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 783 '<New SyntheticTypeExpr at ast.py:1659>' New_Node /tmp/lal-23.0.0/ada/ast.py:1659
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Rhs);
--# expr-done 783
      Cast_Result := New_Node;
--# expr-start 784 '<New SyntheticTypeExpr at ast.py:1660>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:1660
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_1,
      Synthetic_Type_Expr_F_Target_Type => Ret);
--# expr-done 784
      Cast_Result_1 := New_Node_1;
--# property-call-start AdaNode.create_binop_assoc_impl
Fld := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_Impl (Node => Self, Op => Op, Lhs => Lhs, Rhs => Cast_Result, Ret => Cast_Result_1);
--# end
--# expr-done 785
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 786
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_105;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc,
                        As_Internal_Env_Assoc => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_105;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Create_Binop_Assoc_L_Expr;
--# end
--# property-start AdaNode.create_binop_assoc_r_expr /tmp/lal-23.0.0/ada/ast.py:1664
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Create_Binop_Assoc_R_Expr
  (Node : Bare_Ada_Node
      ; Op : Symbol_Type
      ; Lhs : Bare_Base_Type_Decl
      ; Rhs : Bare_Type_Expr
      ; Ret : Bare_Base_Type_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind op Op
   --# bind lhs Lhs
   --# bind rhs Rhs
   --# bind ret Ret
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_106 with Inline_Always;
      New_Node : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
Fld : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_106 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_106;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Create_Binop_Assoc_R_Expr,
            Items    => new Mmz_Key_Array (1 ..  5))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Op);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Lhs);
               Mmz_K.Items (4) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Rhs);
               Mmz_K.Items (5) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Ret);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 790 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 789 '<FieldAccess for create_binop_assoc_impl at ast.py:1671>' Fld /tmp/lal-23.0.0/ada/ast.py:1671
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 787 '<New SyntheticTypeExpr at ast.py:1673>' New_Node /tmp/lal-23.0.0/ada/ast.py:1673
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Lhs);
--# expr-done 787
      Cast_Result := New_Node;
--# expr-start 788 '<New SyntheticTypeExpr at ast.py:1675>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:1675
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_1,
      Synthetic_Type_Expr_F_Target_Type => Ret);
--# expr-done 788
      Cast_Result_1 := New_Node_1;
--# property-call-start AdaNode.create_binop_assoc_impl
Fld := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_Impl (Node => Self, Op => Op, Lhs => Cast_Result, Rhs => Rhs, Ret => Cast_Result_1);
--# end
--# expr-done 789
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 790
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_106;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc,
                        As_Internal_Env_Assoc => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_106;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Create_Binop_Assoc_R_Expr;
--# end
--# property-start AdaNode.create_binop_assoc_l_r_expr /tmp/lal-23.0.0/ada/ast.py:1679
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Create_Binop_Assoc_L_R_Expr
  (Node : Bare_Ada_Node
      ; Op : Symbol_Type
      ; Lhs : Bare_Type_Expr
      ; Rhs : Bare_Type_Expr
      ; Ret : Bare_Base_Type_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind op Op
   --# bind lhs Lhs
   --# bind rhs Rhs
   --# bind ret Ret
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_107 with Inline_Always;
      New_Node : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
Fld : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_107 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_107;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ada_Node_Ada_Node_P_Create_Binop_Assoc_L_R_Expr,
            Items    => new Mmz_Key_Array (1 ..  5))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ada_Node,
                                As_Bare_Ada_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Op);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Lhs);
               Mmz_K.Items (4) := (Kind => Mmz_Bare_Type_Expr,
                                      As_Bare_Type_Expr => Rhs);
               Mmz_K.Items (5) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Ret);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 793 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 792 '<FieldAccess for create_binop_assoc_impl at ast.py:1686>' Fld /tmp/lal-23.0.0/ada/ast.py:1686
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 791 '<New SyntheticTypeExpr at ast.py:1687>' New_Node /tmp/lal-23.0.0/ada/ast.py:1687
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Ret);
--# expr-done 791
      Cast_Result := New_Node;
--# property-call-start AdaNode.create_binop_assoc_impl
Fld := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_Impl (Node => Self, Op => Op, Lhs => Lhs, Rhs => Rhs, Ret => Cast_Result);
--# end
--# expr-done 792
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 793
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_107;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc,
                        As_Internal_Env_Assoc => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_107;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Create_Binop_Assoc_L_R_Expr;
--# end
--# property-start AdaNode.custom_id_text /tmp/lal-23.0.0/ada/ast.py:192
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Custom_Id_Text
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : String_Type;
            procedure Finalizer_Scope_5 with Inline_Always;
      Str : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_5 is
            begin
                     Dec_Ref (Str);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_5;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 795 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 794 '<String at ast.py:198>' Str /tmp/lal-23.0.0/ada/ast.py:198
Str := Create_String (""); 
--# expr-done 794
Let_Result := Str; Inc_Ref (Let_Result);
--# end
--# expr-done 795
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_5;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_5;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Custom_Id_Text;
--# end
--# property-start AdaNode.complete_items /tmp/lal-23.0.0/ada/ast.py:343
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Complete_Items
  (Node : Bare_Ada_Node
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Array_Access
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_19 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Info;
Fld_3 : Internal_Metadata;
Fld_4 : Boolean;
Fld_5 : Internal_Unit;
Fld_6 : Boolean;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_7 : Integer;
New_Struct : Internal_Completion_Item;
Map_Result : Internal_Completion_Item_Array_Access;
Let_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_19 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_19;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 808 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 807 '<Map at ast.py:352>' Map_Result /tmp/lal-23.0.0/ada/ast.py:352
   --# expr-start 797 '<FieldAccess for env_get_public at ast.py:349>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:349
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 796 '<FieldAccess for children_env at ast.py:350>' Fld /tmp/lal-23.0.0/ada/ast.py:350
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Self);
--# expr-done 796
--# property-call-start AdaNode.env_get_public
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Get_Public (Node => Self, Env => Fld, Symbol => null);
--# end
--# expr-done 797
      declare
         Map_Result_Vec : Internal_Completion_Item_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_1;
      begin
         for Item_7 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_7
      --# expr-start 806 '<New CompletionItem at ast.py:353>' New_Struct /tmp/lal-23.0.0/ada/ast.py:353
--# expr-start 798 '<Cast to BasicDecl at ast.py:354>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:354
Cast_Expr := Item_7; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 798
--# expr-start 801 '<FieldAccess for dottable_subp at ast.py:355>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:355
--# expr-start 800 '<FieldAccess for md at ast.py:355>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:355
--# expr-start 799 '<FieldAccess for info at ast.py:355>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:355
Fld_2 := Item_7.Info;
--# expr-done 799
Fld_3 := Fld_2.Md;
--# expr-done 800
Fld_4 := Fld_3.Dottable_Subp;
--# expr-done 801
--# expr-start 803 '<FieldAccess for has_with_visibility at ast.py:356>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:356
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 802 '<FieldAccess for unit at ast.py:356>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:356
      if Item_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Unit (Node => Item_7.Node);
--# expr-done 802
--# property-call-start AdaNode.has_with_visibility
Fld_6 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Self, Refd_Unit => Fld_5);
--# end
--# expr-done 803
--# expr-start 805 '<FieldAccess for complete_item_weight at ast.py:357>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:357
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 804 '<Cast to BasicDecl at ast.py:357>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:357
Cast_Expr_1 := Item_7; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 804
--# property-call-start '[dispatcher]AdaNode.complete_item_weight'
Fld_7 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Complete_Item_Weight (Node => Self, Item => Cast_Result_1, Origin => Origin);
--# end
--# expr-done 805
New_Struct := (Decl => Cast_Result, Is_Dot_Call => Fld_4, Is_Visible => Fld_6, Weight => Fld_7); 
--# expr-done 806
         declare
            Item_To_Append : constant Internal_Completion_Item := New_Struct;
         begin
            Internal_Completion_Item_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Completion_Item_Array
           (Items_Count => Natural (Internal_Completion_Item_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Completion_Item_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Completion_Item_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Completion_Item_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 807
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 808
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_19;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_19;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Complete_Items;
--# end
--# property-start AdaNode.complete_item_weight /tmp/lal-23.0.0/ada/ast.py:362
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Complete_Item_Weight
  (Node : Bare_Ada_Node
      ; Item : Internal_Entity_Basic_Decl
      ; Origin : Bare_Ada_Node
  )
   return Integer
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind item Item
   --# bind origin Origin
   Property_Result : Integer;
      Let_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 809 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := 0; 
--# end
--# expr-done 809
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Complete_Item_Weight;
--# end
--# property-start AdaNode.immediate_declarative_region /tmp/lal-23.0.0/ada/ast.py:522
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Immediate_Declarative_Region
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_31 with Inline_Always;
      Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_31 is
            begin
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_31;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 810 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := Empty_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 810
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_31;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_31;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Immediate_Declarative_Region;
--# end
 function Ada_Node_P_Xref_Equation
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is (raise Property_Error
    with "Property AdaNode.xref_equation not implemented on type "
    & Kind_Name (Node));
--# property-start AdaNode.xref_stop_resolution /tmp/lal-23.0.0/ada/ast.py:646
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Xref_Stop_Resolution
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Xref_Stop_Resolution;
--# end
--# property-start AdaNode.stop_resolution_equation /tmp/lal-23.0.0/ada/ast.py:647
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Stop_Resolution_Equation
  (Node : Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_39 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_39 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_39;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:648") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_39;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_39;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Stop_Resolution_Equation;
--# end
--# property-start AdaNode.xref_initial_env /tmp/lal-23.0.0/ada/ast.py:653
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Xref_Initial_Env
  (Node : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity :=
     Internal_Entity'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_40 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_40 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_40;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 812 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 811 '<FieldAccess for children_env at ast.py:659>' Fld /tmp/lal-23.0.0/ada/ast.py:659
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 811
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 812
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_40;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_40;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Xref_Initial_Env;
--# end
--# property-start AdaNode.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:721
pragma Warnings (Off, "is not referenced");
 function Ada_Node_P_Xref_Entry_Point
  (Node : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Ada_Node := Bare_Ada_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ada_Node_P_Xref_Entry_Point;
--# end
function Ada_Node_P_Resolve_Generic_Actual
  (E : Entity
  ) return Internal_Entity
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Internal_Entity :=
      Ada_Node_P_Resolve_Generic_Actual (E.Node, E_Info);
begin
      return (Node => Result.Node, Info => Result.Info);
end;
function Ada_Node_P_Use_Clauses_In_Spec_Of_Subp_Body
  (E : Entity
  ) return Lexical_Env
is
   Result : constant Lexical_Env :=
      Ada_Node_P_Use_Clauses_In_Spec_Of_Subp_Body (E.Node);
begin
      return Result;
end;
function Ada_Node_P_Use_Clauses_In_Generic_Formal_Part
  (E : Entity
  ) return Lexical_Env
is
   Result : constant Lexical_Env :=
      Ada_Node_P_Use_Clauses_In_Generic_Formal_Part (E.Node);
begin
      return Result;
end;
function Ada_Node_P_Nested_Generic_Formal_Part
  (E : Entity
  ) return Lexical_Env
is
   Result : constant Lexical_Env :=
      Ada_Node_P_Nested_Generic_Formal_Part (E.Node);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Abort_Node
   --
--# property-start '[dispatcher]Abort.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Abort_Node_P_As_Bool
  (Node : Bare_Abort_Node
  )
   return Boolean
is
   Self : Bare_Abort_Node := Bare_Abort_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Abort_Node (Self.Kind) is
               when Ada_Abort_Absent =>
                  --# property-call-start Abort.Absent.as_bool
                  Property_Result := Abort_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Abort_Present =>
                  --# property-call-start Abort.Present.as_bool
                  Property_Result := Abort_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Abort_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Abort_Absent
   --
--# property-start Abort.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5029
pragma Warnings (Off, "is not referenced");
 function Abort_Absent_P_As_Bool
  (Node : Bare_Abort_Absent
  )
   return Boolean
is
   Self : Bare_Abort_Absent := Bare_Abort_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abort_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Abort_Present
   --
--# property-start Abort.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5029
pragma Warnings (Off, "is not referenced");
 function Abort_Present_P_As_Bool
  (Node : Bare_Abort_Present
  )
   return Boolean
is
   Self : Bare_Abort_Present := Bare_Abort_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abort_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Abstract_Node
   --
--# property-start '[dispatcher]Abstract.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Abstract_Node_P_As_Bool
  (Node : Bare_Abstract_Node
  )
   return Boolean
is
   Self : Bare_Abstract_Node := Bare_Abstract_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Abstract_Node (Self.Kind) is
               when Ada_Abstract_Absent =>
                  --# property-call-start Abstract.Absent.as_bool
                  Property_Result := Abstract_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Abstract_Present =>
                  --# property-call-start Abstract.Present.as_bool
                  Property_Result := Abstract_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Abstract_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Abstract_Absent
   --
--# property-start Abstract.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:4973
pragma Warnings (Off, "is not referenced");
 function Abstract_Absent_P_As_Bool
  (Node : Bare_Abstract_Absent
  )
   return Boolean
is
   Self : Bare_Abstract_Absent := Bare_Abstract_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abstract_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Abstract_Present
   --
--# property-start Abstract.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:4973
pragma Warnings (Off, "is not referenced");
 function Abstract_Present_P_As_Bool
  (Node : Bare_Abstract_Present
  )
   return Boolean
is
   Self : Bare_Abstract_Present := Bare_Abstract_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abstract_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Ada_List
   --
   --
   --  Primitives for Bare_Ada_Node_List
   --
   --
   --  Primitives for Bare_Abstract_State_Decl_List
   --
   --
   --  Primitives for Bare_Alternatives_List
   --
--# property-start AlternativesList.enum_type /tmp/lal-23.0.0/ada/ast.py:20827
pragma Warnings (Off, "is not referenced");
 function Alternatives_List_P_Enum_Type
  (Node : Bare_Alternatives_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Alternatives_List := Bare_Alternatives_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Alternatives_List :=
     Internal_Entity_Alternatives_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Case_Stmt;
Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity;
Cast_Result : Internal_Entity_Case_Stmt;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 819 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 816 '<Cast to CaseStmt at ast.py:20832>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20832
--# expr-start 815 '<parent at ast.py:20832>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20832
--# expr-start 814 '<parent at ast.py:20832>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20832
--# expr-start 813 '<parent at ast.py:20832>' Fld /tmp/lal-23.0.0/ada/ast.py:20832
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 813
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 814
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 815
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Case_Stmt_Range
   then
      Cast_Result := Create_Internal_Entity_Case_Stmt
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result := No_Entity_Case_Stmt;
   end if;
--# expr-done 816
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Case_Stmt then
   --# scope-start
   --# bind cs Var_Expr
--# expr-start 818 '<FieldAccess for expression_type at ast.py:20833>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20833
--# expr-start 817 '<FieldAccess for expr at ast.py:20833>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20833
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Case_Stmt_F_Expr, Info => Var_Expr.Info);
--# expr-done 817
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_4 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# end
--# expr-done 818
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 819
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Alternatives_List_P_Enum_Type;
--# end
--# property-start AlternativesList.complete_items /tmp/lal-23.0.0/ada/ast.py:20837
pragma Warnings (Off, "is not referenced");
 function Alternatives_List_P_Complete_Items
  (Node : Bare_Alternatives_List
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Array_Access
is
   Self : Bare_Alternatives_List := Bare_Alternatives_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Alternatives_List :=
     Internal_Entity_Alternatives_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_1463 with Inline_Always;
      Match_0 : Internal_Entity_Enum_Literal_Decl;
Match_1 : Internal_Entity;
Fld : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Info;
Fld_2 : Internal_Metadata;
Fld_3 : Boolean;
Fld_4 : Internal_Unit;
Fld_5 : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Entity_Type_Decl;
Cast_Result_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Integer;
Match_Prefix : Internal_Entity;
Cast_Result_3 : Internal_Entity_Enum_Literal_Decl;
Let_Result : Integer;
Scope_Result : Integer;
Cast_Result_4 : Internal_Entity;
Let_Result_1 : Integer;
Scope_Result_1 : Integer;
Match_Result : Integer;
New_Struct : Internal_Completion_Item;
Map_Result : Internal_Completion_Item_Array_Access;
Let_Result_2 : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_1463 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_1463;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 835 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 834 '<Map at ast.py:20841>' Map_Result /tmp/lal-23.0.0/ada/ast.py:20841
   --# expr-start 821 '<EnvGet at ast.py:20841>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:20841
--# expr-start 820 '<FieldAccess for children_env at ast.py:20841>' Fld /tmp/lal-23.0.0/ada/ast.py:20841
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Self);
--# expr-done 820
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld, Key => null, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 821
      declare
         Map_Result_Vec : Internal_Completion_Item_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_28 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_28
      --# expr-start 833 '<New CompletionItem at ast.py:20842>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20842
--# expr-start 822 '<Cast to BasicDecl at ast.py:20843>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20843
Cast_Expr := Item_28; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 822
--# expr-start 825 '<FieldAccess for dottable_subp at ast.py:20844>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20844
--# expr-start 824 '<FieldAccess for md at ast.py:20844>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20844
--# expr-start 823 '<FieldAccess for info at ast.py:20844>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20844
Fld_1 := Item_28.Info;
--# expr-done 823
Fld_2 := Fld_1.Md;
--# expr-done 824
Fld_3 := Fld_2.Dottable_Subp;
--# expr-done 825
--# expr-start 827 '<FieldAccess for has_with_visibility at ast.py:20845>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:20845
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 826 '<FieldAccess for unit at ast.py:20845>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20845
      if Item_28.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Unit (Node => Item_28.Node);
--# expr-done 826
--# property-call-start AdaNode.has_with_visibility
Fld_5 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Self, Refd_Unit => Fld_4);
--# end
--# expr-done 827
--# expr-start 832 '<Match at ast.py:20846>' Match_Result /tmp/lal-23.0.0/ada/ast.py:20846
      if Item_28.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_28; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Enum_Literal_Decl .. Ada_Synthetic_Char_Enum_Lit =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Enum_Literal_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_3; 
--# bind eld Match_0
--# expr-start 831 '<If at ast.py:20847>' If_Result /tmp/lal-23.0.0/ada/ast.py:20847
--# expr-start 830 '<Eq at ast.py:20848>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:20848
--# expr-start 828 '<FieldAccess for enum_type at ast.py:20848>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:20848
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AlternativesList.enum_type
Fld_6 := Libadalang.Implementation.Alternatives_List_P_Enum_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 828
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
--# expr-start 829 '<FieldAccess for enum_type at ast.py:20848>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:20848
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]EnumLiteralDecl.enum_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Enum_Literal_Decl_P_Enum_Type (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 829
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 830
if Is_Equiv then
   If_Result := 100;
else
   If_Result := 0;
end if;
--# expr-done 831
Let_Result := If_Result; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abort_Absent .. Ada_Entry_Decl | Ada_Generic_Subp_Internal .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_4; 
--# bind _ Match_1
Let_Result_1 := 0; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 832
New_Struct := (Decl => Cast_Result, Is_Dot_Call => Fld_3, Is_Visible => Fld_5, Weight => Match_Result); 
--# expr-done 833
         declare
            Item_To_Append : constant Internal_Completion_Item := New_Struct;
         begin
            Internal_Completion_Item_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Completion_Item_Array
           (Items_Count => Natural (Internal_Completion_Item_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Completion_Item_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Completion_Item_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Completion_Item_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 834
Let_Result_2 := Map_Result; Inc_Ref (Let_Result_2);
--# end
--# expr-done 835
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1463;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1463;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Alternatives_List_P_Complete_Items;
--# end
   --
   --  Primitives for Bare_Constraint_List
   --
   --
   --  Primitives for Bare_Decl_List
   --
   --
   --  Primitives for Bare_Stmt_List
   --
   --
   --  Primitives for Bare_Aspect_Assoc_List
   --
   --
   --  Primitives for Bare_Base_Assoc_List
   --
   --
   --  Primitives for Bare_Basic_Assoc_List
   --
   --
   --  Primitives for Bare_Assoc_List
   --
--# property-start AssocList.actual_for_param_at /tmp/lal-23.0.0/ada/ast.py:15103
pragma Warnings (Off, "is not referenced");
 function Assoc_List_P_Actual_For_Param_At
  (Node : Bare_Assoc_List
      ; Param : Internal_Entity_Defining_Name
      ; Pos : Integer
      ; Default_Expr : Internal_Entity_Expr
         := No_Entity_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Assoc_List := Bare_Assoc_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Assoc_List :=
     Internal_Entity_Assoc_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind param Param
   --# bind pos Pos
   --# bind default_expr Default_Expr
   Property_Result : Internal_Entity_Expr;
            procedure Finalizer_Scope_1094 with Inline_Always;
      Block_Var : Internal_Single_Actual_Array_Access;
Var_Expr : Internal_Single_Actual;
Var_Expr_1 : Bare_Base_Id;
Fld : Internal_Single_Actual_Array_Access;
Fld_1 : Bare_Base_Id;
Fld_2 : Internal_Entity_Name;
Fld_3 : Bare_Name;
Fld_4 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Find_Result : Internal_Single_Actual;
Fld_5 : Internal_Entity_Basic_Assoc;
Fld_6 : Internal_Entity_Expr;
Scope_Result_1 : Internal_Entity_Expr;
Get_Result : Internal_Single_Actual;
Fld_7 : Internal_Entity_Basic_Assoc;
Fld_8 : Internal_Entity_Expr;
Get_Result_1 : Internal_Single_Actual;
Is_Equal : Boolean;
Get_Result_2 : Internal_Single_Actual;
Fld_9 : Internal_Entity_Basic_Assoc;
Fld_10 : Bare_Ada_Node_Array_Access;
Is_Equal_1 : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Expr;
Result_Var_1 : Internal_Entity_Expr;
Let_Result : Internal_Entity_Expr;
            procedure Finalizer_Scope_1094 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_1094;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 855 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 836 '<FieldAccess for unpacked_params at ast.py:15110>' Fld /tmp/lal-23.0.0/ada/ast.py:15110
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.unpacked_params
Fld := Libadalang.Implementation.Assoc_List_P_Unpacked_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 836
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind up Block_Var
--# expr-start 841 '<Find at ast.py:15112>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15112
      Find_Result := No_Single_Actual;
      declare
         Collection : constant Internal_Single_Actual_Array_Access := Block_Var;
      begin
         for Item_29 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_29
--# expr-start 837 '<FieldAccess for name at ast.py:15114>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15114
Fld_1 := Item_29.Name;
--# expr-done 837
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 840 '<FieldAccess for matches at ast.py:15114>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15114
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 839 '<FieldAccess for node at ast.py:15114>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15114
--# expr-start 838 '<FieldAccess for name at ast.py:15114>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15114
      if Param.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Param.Node.Defining_Name_F_Name, Info => Param.Info);
--# expr-done 838
Fld_3 := Fld_2.Node;
--# expr-done 839
--# property-call-start Name.matches
Fld_4 := Libadalang.Implementation.Name_P_Matches (Node => Var_Expr_1, N => Fld_3);
--# end
--# expr-done 840
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      if Result_Var then
         Find_Result := Item_29;
      end if;
   --# end
               exit when Result_Var;
         end loop;
      end;
--# expr-done 841
Var_Expr := Find_Result;
if Var_Expr /= No_Single_Actual then
   --# scope-start
   --# bind a Var_Expr
--# expr-start 843 '<FieldAccess for expr at ast.py:15116>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15116
--# expr-start 842 '<FieldAccess for assoc at ast.py:15116>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15116
Fld_5 := Var_Expr.Assoc;
--# expr-done 842
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_6 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_5.Node, E_Info => Fld_5.Info);
--# end
--# expr-done 843
Scope_Result_1 := Fld_6;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 854 '<If at ast.py:15118>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15118
--# expr-start 845 '<IsNull at ast.py:15120>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15120
--# expr-start 844 '<at at ast.py:15120>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:15120
Get_Result_1 := Get (Self, Block_Var, Pos, True); 
--# expr-done 844
Is_Equal := Get_Result_1 = No_Single_Actual; 
--# expr-done 845
if Is_Equal then
   If_Result := True;
else
   --# expr-start 850 '<Not at ast.py:15121>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15121
--# expr-start 849 '<IsNull at ast.py:15121>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:15121
--# expr-start 848 '<FieldAccess for names at ast.py:15121>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15121
--# expr-start 847 '<FieldAccess for assoc at ast.py:15121>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15121
--# expr-start 846 '<at at ast.py:15121>' Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:15121
Get_Result_2 := Get (Self, Block_Var, Pos, True); 
--# expr-done 846
Fld_9 := Get_Result_2.Assoc;
--# expr-done 847
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.names'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Names (Node => Fld_9.Node);
--# end
--# expr-done 848
Is_Equal_1 := Equivalent (Fld_10, No_Bare_Ada_Node_Array_Type); 
--# expr-done 849
Not_Val := not (Is_Equal_1); 
--# expr-done 850
   If_Result := Not_Val;
end if;
if If_Result then
   If_Result_1 := Default_Expr;
else
   --# expr-start 853 '<FieldAccess for expr at ast.py:15127>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15127
--# expr-start 852 '<FieldAccess for assoc at ast.py:15127>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15127
--# expr-start 851 '<at at ast.py:15127>' Get_Result /tmp/lal-23.0.0/ada/ast.py:15127
Get_Result := Get (Self, Block_Var, Pos, True); 
--# expr-done 851
Fld_7 := Get_Result.Assoc;
--# expr-done 852
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_8 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 853
   If_Result_1 := Fld_8;
end if;
--# expr-done 854
   Result_Var_1 := If_Result_1;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 855
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1094;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1094;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Assoc_List_P_Actual_For_Param_At;
--# end
--# property-start AssocList.unpacked_params /tmp/lal-23.0.0/ada/ast.py:15132
pragma Warnings (Off, "is not referenced");
 function Assoc_List_P_Unpacked_Params
  (Node : Bare_Assoc_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Single_Actual_Array_Access
is
   Self : Bare_Assoc_List := Bare_Assoc_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Assoc_List :=
     Internal_Entity_Assoc_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Single_Actual_Array_Access;
            procedure Finalizer_Scope_1095 with Inline_Always;
            procedure Finalizer_Scope_1824 with Inline_Always;
      Names : Bare_Ada_Node_Array_Access;
Saved : Internal_Entity_Assoc_List;
Fld : Bare_Assoc_List;
Fld_1 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_2 : Bare_Ada_Node_Array_Access;
Cast_Expr : Bare_Identifier;
Cast_Result : Bare_Base_Id;
New_Struct : Internal_Single_Actual;
Singleton : Internal_Single_Actual_Array_Access;
Cast_Expr_1 : Bare_Ada_Node;
Cast_Result_1 : Bare_Base_Id;
New_Struct_1 : Internal_Single_Actual;
Is_A : Boolean;
Map_Result : Internal_Single_Actual_Array_Access;
Len : Integer;
Is_Equal : Boolean;
If_Result_1 : Internal_Single_Actual_Array_Access;
Let_Result : Internal_Single_Actual_Array_Access;
Item_30 : Internal_Entity_Basic_Assoc;
Bare_Item_30 : Bare_Basic_Assoc;
Map_Result_1 : Internal_Single_Actual_Array_Access;
Let_Result_1 : Internal_Single_Actual_Array_Access;
            procedure Finalizer_Scope_1095 is
            begin
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_1095;
            procedure Finalizer_Scope_1824 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Names);
                     Dec_Ref (Singleton);
                     Dec_Ref (Map_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1824;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Assoc_List_Assoc_List_P_Unpacked_Params,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Assoc_List,
                                As_Bare_Assoc_List => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Single_Actual_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 867 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 866 '<Mapcat at ast.py:15138>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:15138
Saved := Ent; 
Fld := Saved.Node;
      declare
         Map_Result_1_Vec : Internal_Single_Actual_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result_1 := Create_Internal_Single_Actual_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld;
      begin
         for Untyped_Item_30 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_30 := Untyped_Item_30; 
Is_Null := Bare_Item_30 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_1 := Saved.Info;
As_Entity := (Info => Fld_1, Node => Bare_Item_30); 
   If_Result := As_Entity;
end if;
                  Item_30 := If_Result; 
   --# scope-start
               --# bind pa Item_30
      --# expr-start 865 '<Let at ast.py:15138>' Let_Result /tmp/lal-23.0.0/ada/ast.py:15138
--# scope-start
--# expr-start 856 '<FieldAccess for names at ast.py:15138>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15138
      if Item_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.names'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Names (Node => Item_30.Node);
--# end
--# expr-done 856
Names := Fld_2; Inc_Ref (Names);
--# bind names Names
--# expr-start 864 '<If at ast.py:15138>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15138
--# expr-start 858 '<Eq at ast.py:15139>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15139
--# expr-start 857 '<length at ast.py:15139>' Len /tmp/lal-23.0.0/ada/ast.py:15139
Len := Length (Names); 
--# expr-done 857
Is_Equal := Len = 0; 
--# expr-done 858
if Is_Equal then
   --# expr-start 859 '<New SingleActual at ast.py:15140>' New_Struct /tmp/lal-23.0.0/ada/ast.py:15140
Cast_Expr := No_Bare_Ada_Node; 
      Cast_Result := Cast_Expr;
New_Struct := (Assoc => Item_30, Name => Cast_Result); 
--# expr-done 859
                Singleton := Create_Internal_Single_Actual_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
   If_Result_1 := Singleton;
else
   --# expr-start 863 '<FilterMap at ast.py:15141>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15141
      declare
         Map_Result_Vec : Internal_Single_Actual_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Names;
      begin
         for Item_31 of
               Collection.Items
         loop
   --# scope-start
               --# bind i Item_31
         --# expr-start 860 '<IsA BaseId at ast.py:15143>' Is_A /tmp/lal-23.0.0/ada/ast.py:15143
Is_A := Item_31 /= null 
and then Item_31.Kind in Ada_Base_Id; 
--# expr-done 860
         if Is_A then
      --# expr-start 862 '<New SingleActual at ast.py:15142>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:15142
--# expr-start 861 '<Cast to BaseId at ast.py:15142>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15142
Cast_Expr_1 := Item_31; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Base_Id
   then
      Cast_Result_1 := Cast_Expr_1;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 861
New_Struct_1 := (Assoc => Item_30, Name => Cast_Result_1); 
--# expr-done 862
         declare
            Item_To_Append : constant Internal_Single_Actual := New_Struct_1;
         begin
            Internal_Single_Actual_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Single_Actual_Array
           (Items_Count => Natural (Internal_Single_Actual_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Single_Actual_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Single_Actual_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Single_Actual_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 863
   If_Result_1 := Map_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 864
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 865
         for Item_To_Append of
               Let_Result.Items
         loop
            Internal_Single_Actual_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_1824;
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Internal_Single_Actual_Array
           (Items_Count => Natural (Internal_Single_Actual_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Single_Actual_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Single_Actual_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Single_Actual_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 866
Let_Result_1 := Map_Result_1; Inc_Ref (Let_Result_1);
--# end
--# expr-done 867
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1095;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Single_Actual_Array_Access,
                        As_Internal_Single_Actual_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1095;
               Finalizer_Scope_1824;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Assoc_List_P_Unpacked_Params;
--# end
--# property-start AssocList.zip_with_params /tmp/lal-23.0.0/ada/ast.py:15149
pragma Warnings (Off, "is not referenced");
 function Assoc_List_P_Zip_With_Params
  (Node : Bare_Assoc_List
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Actual_Array_Access
is
   Self : Bare_Assoc_List := Bare_Assoc_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Assoc_List :=
     Internal_Entity_Assoc_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_1096 with Inline_Always;
            procedure Finalizer_Scope_1883 with Inline_Always;
            procedure Finalizer_Scope_1884 with Inline_Always;
            procedure Finalizer_Scope_1885 with Inline_Always;
            procedure Finalizer_Scope_1886 with Inline_Always;
            procedure Finalizer_Scope_1887 with Inline_Always;
            procedure Finalizer_Scope_1888 with Inline_Always;
            procedure Finalizer_Scope_1889 with Inline_Always;
            procedure Finalizer_Scope_1890 with Inline_Always;
            procedure Finalizer_Scope_1891 with Inline_Always;
            procedure Finalizer_Scope_1894 with Inline_Always;
            procedure Finalizer_Scope_1896 with Inline_Always;
            procedure Finalizer_Scope_1898 with Inline_Always;
            procedure Finalizer_Scope_1904 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Block_Var_2 : Internal_Entity_Basic_Assoc;
Block_Var_3 : Internal_Param_Actual_Array_Access;
Block_Var_4 : Internal_Param_Actual_Array_Access;
Block_Var_5 : Internal_Param_Actual_Array_Access;
Block_Var_6 : Internal_Param_Actual_Array_Access;
Var_Expr : Internal_Entity_Name;
Var_Expr_1 : Internal_Entity;
Match_0 : Internal_Entity_Call_Expr;
Match_1 : Internal_Entity_Generic_Instantiation;
Match_2 : Internal_Entity_Composite_Constraint;
Match_3 : Internal_Entity_Base_Aggregate;
Match_4 : Internal_Entity;
Var_Expr_2 : Internal_Entity_Base_Formal_Param_Holder;
Var_Expr_3 : Internal_Entity_Generic_Decl;
Var_Expr_4 : Internal_Entity_Base_Type_Decl;
Var_Expr_5 : Internal_Entity_Base_Record_Def;
Var_Expr_6 : Internal_Entity_Expr;
Var_Expr_7 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Var_Expr_8 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Decl : Internal_Entity_Generic_Formal_Subp_Decl;
Subp : Internal_Entity_Formal_Subp_Decl;
Var_Expr_9 : Internal_Entity_Basic_Decl;
Var_Expr_10 : Internal_Entity_Generic_Formal_Subp_Decl;
Var_Expr_11 : Internal_Entity_Formal_Subp_Decl;
Var_Expr_12 : Internal_Entity_Basic_Assoc;
Bound_Imprecise_Fallback : Boolean;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Name;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Dyn_Var_Bind_Result : Boolean;
Fld_2 : Internal_Entity;
Fld_3 : Internal_Entity_Base_Formal_Param_Holder;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_5 : Internal_Entity_Name;
Fld_6 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Generic_Decl;
Fld_7 : Internal_Entity_Generic_Formal_Part;
Fld_8 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_9 : Internal_Entity_Base_Type_Decl;
Fld_10 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Cast_Expr : Bare_Assoc_List;
Cast_Result_2 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_11 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_12 : Internal_Entity_Base_Type_Decl;
Fld_13 : Internal_Entity_Base_Record_Def;
Fld_14 : Internal_Entity_Component_List;
Fld_15 : Internal_Entity_Expr;
Fld_16 : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_4 : Internal_Entity_Base_Type_Decl;
Fld_17 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_5 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_5 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Dyn_Var_Bind_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Match_Prefix : Internal_Entity;
Cast_Result_3 : Internal_Entity_Call_Expr;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_6 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Cast_Result_4 : Internal_Entity_Generic_Instantiation;
Let_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_7 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Cast_Result_5 : Internal_Entity_Composite_Constraint;
Let_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_8 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Cast_Result_6 : Internal_Entity_Base_Aggregate;
Let_Result_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_9 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Cast_Result_7 : Internal_Entity;
Let_Result_4 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_10 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Match_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_11 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_6 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Saved : Internal_Entity_Assoc_List;
Fld_18 : Bare_Assoc_List;
Fld_19 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_20 : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Quantifier_Result : Boolean;
Item_32 : Internal_Entity_Basic_Assoc;
Bare_Item_32 : Bare_Basic_Assoc;
Find_Result : Internal_Entity_Basic_Assoc;
Fld_21 : Internal_Param_Match_Array_Access;
Fld_22 : Internal_Entity_Defining_Name;
Fld_23 : Internal_Single_Actual;
Fld_24 : Internal_Entity_Basic_Assoc;
Fld_25 : Internal_Entity_Expr;
New_Struct : Internal_Param_Actual;
Map_Result : Internal_Param_Actual_Array_Access;
Scope_Result_12 : Internal_Param_Actual_Array_Access;
Result_Var_7 : Internal_Param_Actual_Array_Access;
Cast_Expr_1 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_8 : Internal_Entity_Generic_Formal_Subp_Decl;
Cast_Expr_2 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_9 : Internal_Entity_Generic_Formal_Subp_Decl;
Fld_26 : Internal_Entity_Basic_Decl;
Cast_Result_10 : Internal_Entity_Formal_Subp_Decl;
Fld_27 : Internal_Entity_Defining_Name;
Fld_28 : Internal_Entity_Expr;
Fld_29 : Internal_Entity;
Cast_Result_11 : Internal_Entity_Generic_Instantiation;
Fld_30 : Internal_Entity_Basic_Decl;
Fld_31 : Internal_Entity_Defining_Name;
Scope_Result_13 : Internal_Entity_Defining_Name;
Result_Var_8 : Internal_Entity_Defining_Name;
Cast_Result_12 : Internal_Entity_Expr;
Fld_32 : Internal_Entity_Expr;
Is_A_1 : Boolean;
If_Result_1 : Internal_Entity_Expr;
New_Struct_1 : Internal_Param_Actual;
Let_Result_5 : Internal_Param_Actual;
Cast_Expr_3 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_13 : Internal_Entity_Generic_Formal_Subp_Decl;
Fld_33 : Internal_Entity_Basic_Decl;
Cast_Result_14 : Internal_Entity_Formal_Subp_Decl;
Fld_34 : Internal_Entity_Expr;
Is_A_2 : Boolean;
Fld_35 : Internal_Entity_Defining_Name;
Fld_36 : Internal_Entity_Defining_Name;
Cast_Result_15 : Internal_Entity;
Cast_Result_16 : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result_1 : Boolean;
Not_Val : Boolean;
If_Result_2 : Boolean;
Scope_Result_14 : Boolean;
Result_Var_9 : Boolean;
Scope_Result_15 : Boolean;
Result_Var_10 : Boolean;
Map_Result_1 : Internal_Param_Actual_Array_Access;
Scope_Result_16 : Internal_Param_Actual_Array_Access;
Result_Var_11 : Internal_Param_Actual_Array_Access;
Concat_Result : Internal_Param_Actual_Array_Access;
Fld_37 : Internal_Entity_Defining_Name_Array_Access;
Fld_38 : Internal_Entity_Expr;
New_Struct_2 : Internal_Param_Actual;
Fld_39 : Internal_Entity_Defining_Name;
Cast_Result_17 : Internal_Entity;
Cast_Expr_4 : Internal_Entity_Defining_Name;
Cast_Result_18 : Internal_Entity;
Is_Equiv_1 : Boolean;
Quantifier_Result_2 : Boolean;
Not_Val_1 : Boolean;
Map_Result_2 : Internal_Param_Actual_Array_Access;
Scope_Result_17 : Internal_Param_Actual_Array_Access;
Result_Var_12 : Internal_Param_Actual_Array_Access;
Concat_Result_1 : Internal_Param_Actual_Array_Access;
Let_Result_6 : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_1096 is
            begin
                     Dec_Ref (Scope_Result_11);
                     Dec_Ref (Result_Var_6);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Scope_Result_12);
                     Dec_Ref (Result_Var_7);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Scope_Result_16);
                     Dec_Ref (Result_Var_11);
                     Dec_Ref (Block_Var_4);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Block_Var_5);
                     Dec_Ref (Scope_Result_17);
                     Dec_Ref (Result_Var_12);
                     Dec_Ref (Block_Var_6);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Let_Result_6);
            end Finalizer_Scope_1096;
            procedure Finalizer_Scope_1883 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_8);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_9);
                     Dec_Ref (Let_Result_4);
                     Dec_Ref (Scope_Result_10);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_1883;
            procedure Finalizer_Scope_1884 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_1884;
            procedure Finalizer_Scope_1885 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_1885;
            procedure Finalizer_Scope_1886 is
            begin
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
            end Finalizer_Scope_1886;
            procedure Finalizer_Scope_1887 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_1887;
            procedure Finalizer_Scope_1888 is
            begin
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
            end Finalizer_Scope_1888;
            procedure Finalizer_Scope_1889 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_1889;
            procedure Finalizer_Scope_1890 is
            begin
                     Dec_Ref (Fld_11);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Result_Var_5);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result_2);
            end Finalizer_Scope_1890;
            procedure Finalizer_Scope_1891 is
            begin
                     Dec_Ref (Fld_17);
            end Finalizer_Scope_1891;
            procedure Finalizer_Scope_1894 is
            begin
                     Dec_Ref (Fld_20);
            end Finalizer_Scope_1894;
            procedure Finalizer_Scope_1896 is
            begin
                     Dec_Ref (Var_Expr_7);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1896;
            procedure Finalizer_Scope_1898 is
            begin
                     Dec_Ref (Var_Expr_8);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_1898;
            procedure Finalizer_Scope_1904 is
            begin
                     Dec_Ref (Fld_37);
                     Dec_Ref (Map_Result_2);
            end Finalizer_Scope_1904;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 939 '<Block at ???>' Let_Result_6 None
--# scope-start
--# expr-start 871 '<bind at ast.py:15157>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:15157
Bound_Imprecise_Fallback := False; 
--# expr-start 869 '<Cast to Name at ast.py:15158>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15158
--# expr-start 868 '<parent at ast.py:15158>' Fld /tmp/lal-23.0.0/ada/ast.py:15158
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 868
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 869
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 870 '<FieldAccess for is_dot_call at ast.py:15158>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15158
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_dot_call
Fld_1 := Libadalang.Implementation.Name_P_Is_Dot_Call (Node => Var_Expr.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 870
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Dyn_Var_Bind_Result := Result_Var; 
--# expr-done 871
Block_Var := Dyn_Var_Bind_Result; 
--# bind is_dottable_subp Block_Var
--# expr-start 872 '<parent at ast.py:15161>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15161
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 872
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity then
   --# scope-start
--# expr-start 891 '<Match at ast.py:15161>' Match_Result /tmp/lal-23.0.0/ada/ast.py:15161
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr_1; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_3; 
--# bind e Match_0
--# expr-start 873 '<FieldAccess for called_subp_spec at ast.py:15162>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15162
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_3 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 873
Var_Expr_2 := Fld_3;
if Var_Expr_2 /= No_Entity_Base_Formal_Param_Holder then
   --# scope-start
--# expr-start 874 '<FieldAccess for abstract_formal_params at ast.py:15162>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15162
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 874
Scope_Result_1 := Fld_4;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1885;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
Scope_Result_6 := Let_Result;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_1884;
            Match_Result := Scope_Result_6; Inc_Ref (Match_Result);
         when Ada_Generic_Package_Instantiation .. Ada_Generic_Subp_Instantiation =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Generic_Instantiation
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_4; 
--# bind i Match_1
--# expr-start 877 '<Cast to GenericDecl at ast.py:15165>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15165
--# expr-start 876 '<FieldAccess for referenced_decl at ast.py:15165>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15165
--# expr-start 875 '<FieldAccess for generic_entity_name at ast.py:15165>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15165
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_entity_name'
Fld_5 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Entity_Name (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 875
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_6 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_5.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_5.Info);
--# end
--# expr-done 876
   if Fld_6.Node = null
      or else Fld_6.Node.Kind in Ada_Generic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Generic_Decl
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
   else
         Cast_Result_1 := No_Entity_Generic_Decl;
   end if;
--# expr-done 877
Var_Expr_3 := Cast_Result_1;
if Var_Expr_3 /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 879 '<FieldAccess for abstract_formal_params at ast.py:15166>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15166
--# expr-start 878 '<FieldAccess for formal_part at ast.py:15166>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15166
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Generic_Formal_Part (Node => Var_Expr_3.Node.Generic_Decl_F_Formal_Part, Info => Var_Expr_3.Info);
--# expr-done 878
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_8 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 879
Scope_Result_2 := Fld_8;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_1887;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_2);
Let_Result_1 := Result_Var_2; Inc_Ref (Let_Result_1);
--# end
Scope_Result_7 := Let_Result_1;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_1886;
            Match_Result := Scope_Result_7; Inc_Ref (Match_Result);
         when Ada_Composite_Constraint =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Composite_Constraint
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_5; 
--# bind c Match_2
--# expr-start 880 '<FieldAccess for subtype at ast.py:15169>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15169
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.subtype
Fld_9 := Libadalang.Implementation.Constraint_P_Subtype (Node => Match_2.Node, E_Info => Match_2.Info);
--# end
--# expr-done 880
Var_Expr_4 := Fld_9;
if Var_Expr_4 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 881 '<FieldAccess for discriminants_list at ast.py:15169>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15169
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_10 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Var_Expr_4.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 881
Scope_Result_3 := Fld_10;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_1889;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
Let_Result_2 := Result_Var_3; Inc_Ref (Let_Result_2);
--# end
Scope_Result_8 := Let_Result_2;
   Inc_Ref (Scope_Result_8);
   --# end
      Finalizer_Scope_1888;
            Match_Result := Scope_Result_8; Inc_Ref (Match_Result);
         when Ada_Aggregate .. Ada_Null_Record_Aggregate =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Base_Aggregate
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_6; 
--# bind a Match_3
--# expr-start 890 '<bind at ast.py:15171>' Dyn_Var_Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:15171
Cast_Expr := Self; 
      Cast_Result_2 := Cast_Expr;
Bound_Origin := Cast_Result_2; 
--# expr-start 889 '<bind at ast.py:15171>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15171
--# expr-start 882 '<FieldAccess for node_env at ast.py:15172>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15172
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Node_Env (Node => Self);
--# expr-done 882
Bound_Env := Fld_11; Inc_Ref (Bound_Env);
--# expr-start 884 '<FieldAccess for record_def at ast.py:15173>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15173
--# expr-start 883 '<FieldAccess for expression_type at ast.py:15173>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15173
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_12 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Match_3.Node, E_Info => Match_3.Info);
--# end
--# expr-done 883
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_13 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Fld_12.Node, Origin => Bound_Origin, E_Info => Fld_12.Info);
--# end
--# expr-done 884
Var_Expr_5 := Fld_13;
if Var_Expr_5 /= No_Entity_Base_Record_Def then
   --# scope-start
--# expr-start 888 '<FieldAccess for abstract_formal_params_for_assocs at ast.py:15173>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15173
--# expr-start 885 '<FieldAccess for components at ast.py:15174>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:15174
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Component_List (Node => Var_Expr_5.Node.Base_Record_Def_F_Components, Info => Var_Expr_5.Info);
--# expr-done 885
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 886 '<FieldAccess for ancestor_expr at ast.py:15178>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:15178
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Expr (Node => Match_3.Node.Base_Aggregate_F_Ancestor_Expr, Info => Match_3.Info);
--# expr-done 886
Var_Expr_6 := Fld_15;
if Var_Expr_6 /= No_Entity_Expr then
   --# scope-start
--# expr-start 887 '<FieldAccess for expression_type at ast.py:15178>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15178
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_16 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 887
Scope_Result_4 := Fld_16;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Base_Type_Decl;
end if;
--# property-call-start ComponentList.abstract_formal_params_for_assocs
Fld_17 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_For_Assocs (Node => Fld_14.Node, Assocs => Ent, Stop_Recurse_At => Result_Var_4, Env => Bound_Env, Origin => Bound_Origin, E_Info => Fld_14.Info);
--# end
--# expr-done 888
Scope_Result_5 := Fld_17;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_1891;
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_5);
Dyn_Var_Bind_Result_1 := Result_Var_5; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 889
Dyn_Var_Bind_Result_2 := Dyn_Var_Bind_Result_1; Inc_Ref (Dyn_Var_Bind_Result_2);
--# expr-done 890
Let_Result_3 := Dyn_Var_Bind_Result_2; Inc_Ref (Let_Result_3);
--# end
Scope_Result_9 := Let_Result_3;
   Inc_Ref (Scope_Result_9);
   --# end
      Finalizer_Scope_1890;
            Match_Result := Scope_Result_9; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Generic_Subp_Decl | Ada_Generic_Package_Renaming_Decl .. Ada_Constant_Present | Ada_Delta_Constraint .. Ada_Allocator | Ada_Bin_Op .. Ada_Attribute_Ref | Ada_Defining_Name .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_7; 
--# bind _ Match_4
Let_Result_4 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type; Inc_Ref (Let_Result_4);
--# end
Scope_Result_10 := Let_Result_4;
   Inc_Ref (Scope_Result_10);
   --# end
            Match_Result := Scope_Result_10; Inc_Ref (Match_Result);
end case;
--# expr-done 891
Scope_Result_11 := Match_Result;
   Inc_Ref (Scope_Result_11);
   --# end
      Finalizer_Scope_1883;
   Result_Var_6 := Scope_Result_11;
else
   Result_Var_6 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_6);
Block_Var_1 := Result_Var_6; Inc_Ref (Block_Var_1);
--# bind params Block_Var_1
--# expr-start 895 '<Find at ast.py:15185>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15185
Saved := Ent; 
Fld_18 := Saved.Node;
      Find_Result := No_Entity_Basic_Assoc;
      if Fld_18 = null then
      Find_Result := No_Entity_Basic_Assoc;
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_18;
      begin
         for Untyped_Item_32 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_32 := Untyped_Item_32; 
Is_Null := Bare_Item_32 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_19 := Saved.Info;
As_Entity := (Info => Fld_19, Node => Bare_Item_32); 
   If_Result := As_Entity;
end if;
                  Item_32 := If_Result; 
   --# scope-start
               --# bind assoc Item_32
      --# expr-start 894 '<AnyQuantifier at ast.py:15186>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:15186
   --# expr-start 892 '<FieldAccess for names at ast.py:15186>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:15186
      if Item_32.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.names'
Fld_20 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Names (Node => Item_32.Node);
--# end
--# expr-done 892
      Quantifier_Result := False;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Fld_20;
      begin
         for Item_33 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_33
      --# expr-start 893 '<IsA OthersDesignator at ast.py:15187>' Is_A /tmp/lal-23.0.0/ada/ast.py:15187
Is_A := Item_33 /= null 
and then Item_33.Kind in Ada_Others_Designator_Range; 
--# expr-done 893
      Quantifier_Result := Is_A;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 894
      if Quantifier_Result then
         Find_Result := Item_32;
      end if;
   --# end
      Finalizer_Scope_1894;
               exit when Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 895
Block_Var_2 := Find_Result; 
--# bind others_assoc Block_Var_2
Var_Expr_7 := Block_Var_1;
      Inc_Ref (Var_Expr_7);
if Var_Expr_7 /= No_Internal_Entity_Base_Formal_Param_Decl_Array_Type then
   --# scope-start
   --# bind _ Var_Expr_7
--# expr-start 902 '<Map at ast.py:15192>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15192
   --# expr-start 896 '<FieldAccess for match_formals at ast.py:15192>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:15192
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.match_formals
Fld_21 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Block_Var_1, Params => Ent, Is_Dottable_Subp => Block_Var);
--# end
--# expr-done 896
      declare
         Map_Result_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_21;
      begin
         for Item_34 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_34
      --# expr-start 901 '<New ParamActual at ast.py:15193>' New_Struct /tmp/lal-23.0.0/ada/ast.py:15193
--# expr-start 899 '<FieldAccess for expr at ast.py:15195>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:15195
--# expr-start 898 '<FieldAccess for assoc at ast.py:15195>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:15195
--# expr-start 897 '<FieldAccess for actual at ast.py:15195>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:15195
Fld_23 := Item_34.Actual;
--# expr-done 897
Fld_24 := Fld_23.Assoc;
--# expr-done 898
      if Fld_24.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_25 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_24.Node, E_Info => Fld_24.Info);
--# end
--# expr-done 899
--# expr-start 900 '<FieldAccess for formal at ast.py:15194>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:15194
Fld_22 := Item_34.Formal;
--# expr-done 900
New_Struct := (Actual => Fld_25, Param => Fld_22); 
--# expr-done 901
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 902
Scope_Result_12 := Map_Result;
   Inc_Ref (Scope_Result_12);
   --# end
      Finalizer_Scope_1896;
   Result_Var_7 := Scope_Result_12;
else
   Result_Var_7 := No_Internal_Param_Actual_Array_Type;
end if;
      Inc_Ref (Result_Var_7);
Block_Var_3 := Result_Var_7; Inc_Ref (Block_Var_3);
--# bind explicit_matches Block_Var_3
Var_Expr_8 := Block_Var_1;
      Inc_Ref (Var_Expr_8);
if Var_Expr_8 /= No_Internal_Entity_Base_Formal_Param_Decl_Array_Type then
   --# scope-start
   --# bind _ Var_Expr_8
--# expr-start 928 '<FilterMap at ast.py:15200>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:15200
      declare
         Map_Result_1_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Formal_Param_Decl_Array_Access := Block_Var_1;
      begin
         for Item_35 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_35
--# expr-start 903 '<Cast to GenericFormalSubpDecl at ast.py:15219>' Cast_Result_13 /tmp/lal-23.0.0/ada/ast.py:15219
Cast_Expr_3 := Item_35; 
   if Cast_Expr_3.Node = null
      or else Cast_Expr_3.Node.Kind in Ada_Generic_Formal_Subp_Decl_Range
   then
      Cast_Result_13 := Create_Internal_Entity_Generic_Formal_Subp_Decl
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
   else
         Cast_Result_13 := No_Entity_Generic_Formal_Subp_Decl;
   end if;
--# expr-done 903
Var_Expr_10 := Cast_Result_13;
if Var_Expr_10 /= No_Entity_Generic_Formal_Subp_Decl then
   --# scope-start
   --# bind fd Var_Expr_10
--# expr-start 905 '<Cast to FormalSubpDecl at ast.py:15220>' Cast_Result_14 /tmp/lal-23.0.0/ada/ast.py:15220
--# expr-start 904 '<FieldAccess for decl at ast.py:15220>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:15220
      if Var_Expr_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_33 := Create_Internal_Entity_Basic_Decl (Node => Var_Expr_10.Node.Generic_Formal_F_Decl, Info => Var_Expr_10.Info);
--# expr-done 904
   if Fld_33.Node = null
      or else Fld_33.Node.Kind in Ada_Formal_Subp_Decl
   then
      Cast_Result_14 := Create_Internal_Entity_Formal_Subp_Decl
        (Node => Fld_33.Node,
         Info => Fld_33.Info);
   else
         Cast_Result_14 := No_Entity_Formal_Subp_Decl;
   end if;
--# expr-done 905
Var_Expr_11 := Cast_Result_14;
if Var_Expr_11 /= No_Entity_Formal_Subp_Decl then
   --# scope-start
   --# bind subp Var_Expr_11
--# expr-start 907 '<IsA BoxExpr, Name at ast.py:15224>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:15224
--# expr-start 906 '<FieldAccess for default_expr at ast.py:15224>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:15224
      if Var_Expr_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_34 := Create_Internal_Entity_Expr (Node => Var_Expr_11.Node.Formal_Subp_Decl_F_Default_Expr, Info => Var_Expr_11.Info);
--# expr-done 906
Is_A_2 := Fld_34.Node /= null 
and then Fld_34.Node.Kind in Ada_Box_Expr_Range | Ada_Name; 
--# expr-done 907
if Is_A_2 then
   --# expr-start 912 '<Not at ast.py:15227>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15227
--# expr-start 911 '<AnyQuantifier at ast.py:15227>' Quantifier_Result_1 /tmp/lal-23.0.0/ada/ast.py:15227
      Quantifier_Result_1 := False;
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Block_Var_3;
      begin
         for Item_36 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_36
      --# expr-start 910 '<Eq at ast.py:15228>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:15228
--# expr-start 908 '<FieldAccess for param at ast.py:15228>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:15228
Fld_35 := Item_36.Param;
--# expr-done 908
      Cast_Result_15 := Create_Internal_Entity
        (Node => Fld_35.Node,
         Info => Fld_35.Info);
--# expr-start 909 '<FieldAccess for defining_name at ast.py:15228>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:15228
      if Var_Expr_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_36 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_11.Node, E_Info => Var_Expr_11.Info);
--# end
--# expr-done 909
      Cast_Result_16 := Create_Internal_Entity
        (Node => Fld_36.Node,
         Info => Fld_36.Info);
Is_Equiv := Equivalent (Cast_Result_15, Cast_Result_16); 
--# expr-done 910
      Quantifier_Result_1 := Is_Equiv;
   --# end
               exit when Quantifier_Result_1;
         end loop;
      end;
--# expr-done 911
Not_Val := not (Quantifier_Result_1); 
--# expr-done 912
   If_Result_2 := Not_Val;
else
   If_Result_2 := False;
end if;
Scope_Result_14 := If_Result_2;
   --# end
   Result_Var_9 := Scope_Result_14;
else
   Result_Var_9 := False;
end if;
Scope_Result_15 := Result_Var_9;
   --# end
   Result_Var_10 := Scope_Result_15;
else
   Result_Var_10 := False;
end if;
         if Result_Var_10 then
      --# expr-start 927 '<Let at ast.py:15203>' Let_Result_5 /tmp/lal-23.0.0/ada/ast.py:15203
--# scope-start
--# expr-start 913 '<Cast to GenericFormalSubpDecl at ast.py:15205>' Cast_Result_8 /tmp/lal-23.0.0/ada/ast.py:15205
Cast_Expr_1 := Item_35; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Generic_Formal_Subp_Decl_Range
   then
      Cast_Result_8 := Create_Internal_Entity_Generic_Formal_Subp_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_8 := No_Entity_Generic_Formal_Subp_Decl;
   end if;
--# expr-done 913
Decl := Cast_Result_8; 
--# bind decl Decl
--# expr-start 916 '<Cast to FormalSubpDecl at ast.py:15206>' Cast_Result_10 /tmp/lal-23.0.0/ada/ast.py:15206
--# expr-start 915 '<FieldAccess for decl at ast.py:15206>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:15206
--# expr-start 914 '<Cast to GenericFormalSubpDecl at ast.py:15206>' Cast_Result_9 /tmp/lal-23.0.0/ada/ast.py:15206
Cast_Expr_2 := Item_35; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Generic_Formal_Subp_Decl_Range
   then
      Cast_Result_9 := Create_Internal_Entity_Generic_Formal_Subp_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_9 := No_Entity_Generic_Formal_Subp_Decl;
   end if;
--# expr-done 914
      if Cast_Result_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Create_Internal_Entity_Basic_Decl (Node => Cast_Result_9.Node.Generic_Formal_F_Decl, Info => Cast_Result_9.Info);
--# expr-done 915
   if Fld_26.Node = null
      or else Fld_26.Node.Kind in Ada_Formal_Subp_Decl
   then
      Cast_Result_10 := Create_Internal_Entity_Formal_Subp_Decl
        (Node => Fld_26.Node,
         Info => Fld_26.Info);
   else
         Cast_Result_10 := No_Entity_Formal_Subp_Decl;
   end if;
--# expr-done 916
Subp := Cast_Result_10; 
--# bind subp Subp
--# expr-start 926 '<New ParamActual at ast.py:15208>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:15208
--# expr-start 924 '<If at ast.py:15210>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15210
--# expr-start 918 '<IsA Name at ast.py:15211>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:15211
--# expr-start 917 '<FieldAccess for default_expr at ast.py:15211>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:15211
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_32 := Create_Internal_Entity_Expr (Node => Subp.Node.Formal_Subp_Decl_F_Default_Expr, Info => Subp.Info);
--# expr-done 917
Is_A_1 := Fld_32.Node /= null 
and then Fld_32.Node.Kind in Ada_Name; 
--# expr-done 918
if Is_A_1 then
   --# expr-start 919 '<FieldAccess for default_expr at ast.py:15212>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:15212
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Create_Internal_Entity_Expr (Node => Subp.Node.Formal_Subp_Decl_F_Default_Expr, Info => Subp.Info);
--# expr-done 919
   If_Result_1 := Fld_28;
else
--# expr-start 922 '<FieldAccess for designated_subprogram_from at ast.py:15213>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:15213
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 921 '<Cast to GenericInstantiation at ast.py:15214>' Cast_Result_11 /tmp/lal-23.0.0/ada/ast.py:15214
--# expr-start 920 '<parent at ast.py:15214>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:15214
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 920
   if Fld_29.Node = null
      or else Fld_29.Node.Kind in Ada_Generic_Instantiation
   then
      Cast_Result_11 := Create_Internal_Entity_Generic_Instantiation
        (Node => Fld_29.Node,
         Info => Fld_29.Info);
   else
         Cast_Result_11 := No_Entity_Generic_Instantiation;
   end if;
--# expr-done 921
--# property-call-start FormalSubpDecl.designated_subprogram_from
Fld_30 := Libadalang.Implementation.Formal_Subp_Decl_P_Designated_Subprogram_From (Node => Subp.Node, Inst => Cast_Result_11, E_Info => Subp.Info);
--# end
--# expr-done 922
Var_Expr_9 := Fld_30;
if Var_Expr_9 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 923 '<FieldAccess for defining_name at ast.py:15215>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:15215
      if Var_Expr_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_31 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_9.Node, E_Info => Var_Expr_9.Info);
--# end
--# expr-done 923
Scope_Result_13 := Fld_31;
   --# end
   Result_Var_8 := Scope_Result_13;
else
   Result_Var_8 := No_Entity_Defining_Name;
end if;
      Cast_Result_12 := Create_Internal_Entity_Expr
        (Node => Result_Var_8.Node,
         Info => Result_Var_8.Info);
   If_Result_1 := Cast_Result_12;
end if;
--# expr-done 924
--# expr-start 925 '<FieldAccess for defining_name at ast.py:15209>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:15209
      if Decl.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_27 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Decl.Node, E_Info => Decl.Info);
--# end
--# expr-done 925
New_Struct_1 := (Actual => If_Result_1, Param => Fld_27); 
--# expr-done 926
Let_Result_5 := New_Struct_1; 
--# end
--# expr-done 927
         declare
            Item_To_Append : constant Internal_Param_Actual := Let_Result_5;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 928
Scope_Result_16 := Map_Result_1;
   Inc_Ref (Scope_Result_16);
   --# end
      Finalizer_Scope_1898;
   Result_Var_11 := Scope_Result_16;
else
   Result_Var_11 := No_Internal_Param_Actual_Array_Type;
end if;
      Inc_Ref (Result_Var_11);
Block_Var_4 := Result_Var_11; Inc_Ref (Block_Var_4);
--# bind default_subp_matches Block_Var_4
--# expr-start 929 '<Concat at ast.py:15235>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15235
Concat_Result := Concat (Block_Var_3, Block_Var_4); 
--# expr-done 929
Block_Var_5 := Concat_Result; Inc_Ref (Block_Var_5);
--# bind given_matches Block_Var_5
Var_Expr_12 := Block_Var_2;
if Var_Expr_12 /= No_Entity_Basic_Assoc then
   --# scope-start
   --# bind oa Var_Expr_12
--# expr-start 937 '<FilterMap at ast.py:15238>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:15238
   --# expr-start 930 '<FieldAccess for unpack_formals at ast.py:15238>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:15238
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.unpack_formals
Fld_37 := Libadalang.Implementation.Ada_Node_P_Unpack_Formals (Node => Self, Formal_Params => Block_Var_1);
--# end
--# expr-done 930
      declare
         Map_Result_2_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_37;
      begin
         for Item_37 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_37
         --# expr-start 934 '<Not at ast.py:15243>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:15243
--# expr-start 933 '<AnyQuantifier at ast.py:15243>' Quantifier_Result_2 /tmp/lal-23.0.0/ada/ast.py:15243
      Quantifier_Result_2 := False;
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Block_Var_5;
      begin
         for Item_38 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_38
      --# expr-start 932 '<Eq at ast.py:15243>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:15243
--# expr-start 931 '<FieldAccess for param at ast.py:15243>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:15243
Fld_39 := Item_38.Param;
--# expr-done 931
      Cast_Result_17 := Create_Internal_Entity
        (Node => Fld_39.Node,
         Info => Fld_39.Info);
Cast_Expr_4 := Item_37; 
      Cast_Result_18 := Create_Internal_Entity
        (Node => Cast_Expr_4.Node,
         Info => Cast_Expr_4.Info);
Is_Equiv_1 := Equivalent (Cast_Result_17, Cast_Result_18); 
--# expr-done 932
      Quantifier_Result_2 := Is_Equiv_1;
   --# end
               exit when Quantifier_Result_2;
         end loop;
      end;
--# expr-done 933
Not_Val_1 := not (Quantifier_Result_2); 
--# expr-done 934
         if Not_Val_1 then
      --# expr-start 936 '<New ParamActual at ast.py:15239>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:15239
--# expr-start 935 '<FieldAccess for expr at ast.py:15241>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:15241
      if Var_Expr_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_38 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Var_Expr_12.Node, E_Info => Var_Expr_12.Info);
--# end
--# expr-done 935
New_Struct_2 := (Actual => Fld_38, Param => Item_37); 
--# expr-done 936
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct_2;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 937
Scope_Result_17 := Map_Result_2;
   Inc_Ref (Scope_Result_17);
   --# end
      Finalizer_Scope_1904;
   Result_Var_12 := Scope_Result_17;
else
   Result_Var_12 := No_Internal_Param_Actual_Array_Type;
end if;
      Inc_Ref (Result_Var_12);
Block_Var_6 := Result_Var_12; Inc_Ref (Block_Var_6);
--# bind others_matches Block_Var_6
--# expr-start 938 '<Concat at ast.py:15247>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:15247
Concat_Result_1 := Concat (Block_Var_5, Block_Var_6); 
--# expr-done 938
Let_Result_6 := Concat_Result_1; Inc_Ref (Let_Result_6);
--# end
--# expr-done 939
      Property_Result := Let_Result_6;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1096;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1096;
               Finalizer_Scope_1883;
               Finalizer_Scope_1884;
               Finalizer_Scope_1885;
               Finalizer_Scope_1886;
               Finalizer_Scope_1887;
               Finalizer_Scope_1888;
               Finalizer_Scope_1889;
               Finalizer_Scope_1890;
               Finalizer_Scope_1891;
               Finalizer_Scope_1894;
               Finalizer_Scope_1896;
               Finalizer_Scope_1898;
               Finalizer_Scope_1904;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Assoc_List_P_Zip_With_Params;
--# end
   --
   --  Primitives for Bare_Basic_Decl_List
   --
   --
   --  Primitives for Bare_Case_Expr_Alternative_List
   --
   --
   --  Primitives for Bare_Case_Stmt_Alternative_List
   --
   --
   --  Primitives for Bare_Compilation_Unit_List
   --
   --
   --  Primitives for Bare_Concat_Operand_List
   --
   --
   --  Primitives for Bare_Contract_Case_Assoc_List
   --
   --
   --  Primitives for Bare_Defining_Name_List
   --
   --
   --  Primitives for Bare_Discriminant_Spec_List
   --
   --
   --  Primitives for Bare_Elsif_Expr_Part_List
   --
   --
   --  Primitives for Bare_Elsif_Stmt_Part_List
   --
   --
   --  Primitives for Bare_Enum_Literal_Decl_List
   --
   --
   --  Primitives for Bare_Expr_List
   --
   --
   --  Primitives for Bare_Expr_Alternatives_List
   --
   --
   --  Primitives for Bare_Identifier_List
   --
   --
   --  Primitives for Bare_Discriminant_Choice_List
   --
   --
   --  Primitives for Bare_Name_List
   --
   --
   --  Primitives for Bare_Parent_List
   --
   --
   --  Primitives for Bare_Param_Spec_List
   --
   --
   --  Primitives for Bare_Pragma_Node_List
   --
   --
   --  Primitives for Bare_Select_When_Part_List
   --
   --
   --  Primitives for Bare_Unconstrained_Array_Index_List
   --
   --
   --  Primitives for Bare_Variant_List
   --
   --
   --  Primitives for Bare_Aliased_Node
   --
--# property-start '[dispatcher]Aliased.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Aliased_Node_P_As_Bool
  (Node : Bare_Aliased_Node
  )
   return Boolean
is
   Self : Bare_Aliased_Node := Bare_Aliased_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Aliased_Node (Self.Kind) is
               when Ada_Aliased_Absent =>
                  --# property-call-start Aliased.Absent.as_bool
                  Property_Result := Aliased_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Aliased_Present =>
                  --# property-call-start Aliased.Present.as_bool
                  Property_Result := Aliased_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Aliased_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Aliased_Absent
   --
--# property-start Aliased.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:4997
pragma Warnings (Off, "is not referenced");
 function Aliased_Absent_P_As_Bool
  (Node : Bare_Aliased_Absent
  )
   return Boolean
is
   Self : Bare_Aliased_Absent := Bare_Aliased_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aliased_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Aliased_Present
   --
--# property-start Aliased.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:4997
pragma Warnings (Off, "is not referenced");
 function Aliased_Present_P_As_Bool
  (Node : Bare_Aliased_Present
  )
   return Boolean
is
   Self : Bare_Aliased_Present := Bare_Aliased_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aliased_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_All_Node
   --
--# property-start '[dispatcher]All.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_All_Node_P_As_Bool
  (Node : Bare_All_Node
  )
   return Boolean
is
   Self : Bare_All_Node := Bare_All_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_All_Node (Self.Kind) is
               when Ada_All_Absent =>
                  --# property-call-start All.Absent.as_bool
                  Property_Result := All_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_All_Present =>
                  --# property-call-start All.Present.as_bool
                  Property_Result := All_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_All_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_All_Absent
   --
--# property-start All.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5021
pragma Warnings (Off, "is not referenced");
 function All_Absent_P_As_Bool
  (Node : Bare_All_Absent
  )
   return Boolean
is
   Self : Bare_All_Absent := Bare_All_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end All_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_All_Present
   --
--# property-start All.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5021
pragma Warnings (Off, "is not referenced");
 function All_Present_P_As_Bool
  (Node : Bare_All_Present
  )
   return Boolean
is
   Self : Bare_All_Present := Bare_All_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end All_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Array_Indices
   --
--# property-start '[dispatcher]ArrayIndices.ndims' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Array_Indices_P_Ndims
  (Node : Bare_Array_Indices
  )
   return Integer
is
   Self : Bare_Array_Indices := Bare_Array_Indices (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Array_Indices (Self.Kind) is
               when Ada_Constrained_Array_Indices =>
                  --# property-call-start ConstrainedArrayIndices.ndims
                  Property_Result := Constrained_Array_Indices_P_Ndims
                    (Self
                    );
                  --# end
               when Ada_Unconstrained_Array_Indices =>
                  --# property-call-start UnconstrainedArrayIndices.ndims
                  Property_Result := Unconstrained_Array_Indices_P_Ndims
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Array_Indices_P_Ndims;
--# end
--# property-start '[dispatcher]ArrayIndices.constrain_index_expr' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Array_Indices_P_Constrain_Index_Expr
  (Node : Bare_Array_Indices
      ; Index_Expr : Internal_Entity_Expr
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Array_Indices := Bare_Array_Indices (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind index_expr Index_Expr
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Logic_Equation;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Array_Indices (Self.Kind) is
               when Ada_Constrained_Array_Indices =>
                  --# property-call-start ConstrainedArrayIndices.constrain_index_expr
                  Property_Result := Constrained_Array_Indices_P_Constrain_Index_Expr
                    (Self
                        , Index_Expr
                        , Dim
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Unconstrained_Array_Indices =>
                  --# property-call-start UnconstrainedArrayIndices.constrain_index_expr
                  Property_Result := Unconstrained_Array_Indices_P_Constrain_Index_Expr
                    (Self
                        , Index_Expr
                        , Dim
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Array_Indices_P_Constrain_Index_Expr;
--# end
--# property-start '[dispatcher]ArrayIndices.index_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Array_Indices_P_Index_Type
  (Node : Bare_Array_Indices
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Array_Indices := Bare_Array_Indices (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Array_Indices (Self.Kind) is
               when Ada_Constrained_Array_Indices =>
                  --# property-call-start ConstrainedArrayIndices.index_type
                  Property_Result := Constrained_Array_Indices_P_Index_Type
                    (Self
                        , Dim
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Unconstrained_Array_Indices =>
                  --# property-call-start UnconstrainedArrayIndices.index_type
                  Property_Result := Unconstrained_Array_Indices_P_Index_Type
                    (Self
                        , Dim
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Array_Indices_P_Index_Type;
--# end
--# property-start '[dispatcher]ArrayIndices.is_static' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Array_Indices_P_Is_Static
  (Node : Bare_Array_Indices
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Array_Indices := Bare_Array_Indices (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Array_Indices (Self.Kind) is
               when Ada_Constrained_Array_Indices =>
                  --# property-call-start ConstrainedArrayIndices.is_static
                  Property_Result := Constrained_Array_Indices_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Unconstrained_Array_Indices =>
                  --# property-call-start UnconstrainedArrayIndices.is_static
                  Property_Result := Unconstrained_Array_Indices_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Array_Indices_P_Is_Static;
--# end
   --
   --  Primitives for Bare_Constrained_Array_Indices
   --
      procedure Initialize_Fields_For_Constrained_Array_Indices
        (Self : Bare_Constrained_Array_Indices
         ; Constrained_Array_Indices_F_List : Bare_Constraint_List
        ) is
      begin
            Self.Constrained_Array_Indices_F_List := Constrained_Array_Indices_F_List;
      end Initialize_Fields_For_Constrained_Array_Indices;
   function Constrained_Array_Indices_F_List
     (Node : Bare_Constrained_Array_Indices) return Bare_Constraint_List
   is
   begin
         return Node.Constrained_Array_Indices_F_List;
   end;
--# property-start ConstrainedArrayIndices.ndims /tmp/lal-23.0.0/ada/ast.py:8328
pragma Warnings (Off, "is not referenced");
 function Constrained_Array_Indices_P_Ndims
  (Node : Bare_Constrained_Array_Indices
  )
   return Integer
is
   Self : Bare_Constrained_Array_Indices := Bare_Constrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Integer;
      Fld : Bare_Constraint_List;
Len : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 941 '<length at ast.py:8328>' Len /tmp/lal-23.0.0/ada/ast.py:8328
--# expr-start 940 '<FieldAccess for list at ast.py:8328>' Fld /tmp/lal-23.0.0/ada/ast.py:8328
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Constrained_Array_Indices_F_List;
--# expr-done 940
Len := Length (Fld); 
--# expr-done 941
      Property_Result := Len;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constrained_Array_Indices_P_Ndims;
--# end
--# property-start ConstrainedArrayIndices.constrain_index_expr /tmp/lal-23.0.0/ada/ast.py:8331
pragma Warnings (Off, "is not referenced");
 function Constrained_Array_Indices_P_Constrain_Index_Expr
  (Node : Bare_Constrained_Array_Indices
      ; Index_Expr : Internal_Entity_Expr
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Constrained_Array_Indices := Bare_Constrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Constrained_Array_Indices :=
     Internal_Entity_Constrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind index_expr Index_Expr
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_644 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_644 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_644;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 947 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 946 '<And at ast.py:8332>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8332
--# expr-start 944 '<Bind at ast.py:8333>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:8333
--# expr-start 942 '<FieldAccess for expected_type_var at ast.py:8333>' Fld /tmp/lal-23.0.0/ada/ast.py:8333
      if Index_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Index_Expr.Node);
--# expr-done 942
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 943 '<FieldAccess for index_type at ast.py:8333>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8333
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]ArrayIndices.index_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Index_Type (Node => Ent.Node, Dim => Dim, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 943
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8333") else null)); 
--# expr-done 944
--# expr-start 945 '<FieldAccess for matches_expected_type at ast.py:8334>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8334
      if Index_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_2 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Index_Expr.Node, Origin => Origin);
--# end
--# expr-done 945
And_Pred := Create_And (Bind_Result, Fld_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8332") else null)); 
--# expr-done 946
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 947
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_644;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_644;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constrained_Array_Indices_P_Constrain_Index_Expr;
--# end
--# property-start ConstrainedArrayIndices.xref_equation /tmp/lal-23.0.0/ada/ast.py:8338
pragma Warnings (Off, "is not referenced");
 function Constrained_Array_Indices_P_Xref_Equation
  (Node : Bare_Constrained_Array_Indices
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Constrained_Array_Indices := Bare_Constrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Constrained_Array_Indices :=
     Internal_Entity_Constrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_645 with Inline_Always;
            procedure Finalizer_Scope_1908 with Inline_Always;
            procedure Finalizer_Scope_1909 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Constraint_List;
Fld_1 : Bare_Constraint_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_3 : Logic_Equation;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
Fld_4 : Logic_Var;
Pred : Logic_Equation;
Fld_5 : Logic_Var;
Pred_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Var;
Pred_2 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Item_39 : Internal_Entity;
Bare_Item_39 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_645 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_645;
            procedure Finalizer_Scope_1908 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_1908;
            procedure Finalizer_Scope_1909 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Pred_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Pred_2);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_1909;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 962 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 961 '<LogicAll at ast.py:8339>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8339
--# expr-start 960 '<Map at ast.py:8339>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8339
   --# expr-start 948 '<FieldAccess for list at ast.py:8339>' Fld /tmp/lal-23.0.0/ada/ast.py:8339
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Constraint_List (Node => Ent.Node.Constrained_Array_Indices_F_List, Info => Ent.Info);
--# expr-done 948
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Constraint_List := Fld_1;
      begin
         for Untyped_Item_39 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_39 := Untyped_Item_39; 
Is_Null := Bare_Item_39 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_39); 
   If_Result := As_Entity;
end if;
                  Item_39 := If_Result; 
   --# scope-start
               --# bind index Item_39
      --# expr-start 959 '<And at ast.py:8341>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:8341
--# expr-start 949 '<FieldAccess for sub_equation at ast.py:8341>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8341
      if Item_39.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_39.Node, Env => Env, Origin => Origin, E_Info => Item_39.Info);
--# end
--# expr-done 949
--# expr-start 950 '<Cast to Expr at ast.py:8342>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8342
Cast_Expr := Item_39; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Expr;
   end if;
--# expr-done 950
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind expr Var_Expr
--# expr-start 958 '<And at ast.py:8344>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:8344
--# expr-start 955 '<And at ast.py:8344>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8344
--# expr-start 952 '<Predicate on AdaNode.is_not_null at ast.py:8344>' Pred /tmp/lal-23.0.0/ada/ast.py:8344
--# expr-start 951 '<FieldAccess for type_var at ast.py:8344>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8344
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Var_Expr.Node);
--# expr-done 951
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Pred := Solver.Create_Predicate (Fld_4, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 952
--# expr-start 954 '<Predicate on BaseTypeDecl.is_discrete_type at ast.py:8345>' Pred_1 /tmp/lal-23.0.0/ada/ast.py:8345
--# expr-start 953 '<FieldAccess for type_var at ast.py:8345>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8345
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Var_Expr.Node);
--# expr-done 953
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Pred_1 := Solver.Create_Predicate (Fld_5, Create_Base_Type_Decl_P_Is_Discrete_Type_0_Predicate (Origin)); 
--# expr-done 954
And_Pred := Create_And (Pred, Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8344") else null)); 
--# expr-done 955
--# expr-start 957 '<Predicate on BaseTypeDecl.is_not_root_int_type at ast.py:8346>' Pred_2 /tmp/lal-23.0.0/ada/ast.py:8346
--# expr-start 956 '<FieldAccess for type_var at ast.py:8346>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8346
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Var_Expr.Node);
--# expr-done 956
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
Pred_2 := Solver.Create_Predicate (Fld_6, Create_Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate); 
--# expr-done 957
And_Pred_1 := Create_And (And_Pred, Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8344") else null)); 
--# expr-done 958
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1909;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8347") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (Fld_3, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8341") else null)); 
--# expr-done 959
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_2;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1908;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 960
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8339") else null)); 
--# expr-done 961
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 962
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_645;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_645;
               Finalizer_Scope_1908;
               Finalizer_Scope_1909;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constrained_Array_Indices_P_Xref_Equation;
--# end
--# property-start ConstrainedArrayIndices.index_type /tmp/lal-23.0.0/ada/ast.py:8352
pragma Warnings (Off, "is not referenced");
 function Constrained_Array_Indices_P_Index_Type
  (Node : Bare_Constrained_Array_Indices
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Constrained_Array_Indices := Bare_Constrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Constrained_Array_Indices :=
     Internal_Entity_Constrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_646 with Inline_Always;
      Block_Var : Boolean;
Var_Expr : Internal_Entity;
Match_0 : Internal_Entity_Subtype_Indication;
Match_1 : Internal_Entity_Expr;
Match_2 : Internal_Entity;
Node_Parents : Bare_Ada_Node_Array_Access;
Fld : Boolean;
Find_Result : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Constraint_List;
Fld_3 : Bare_Constraint_List;
Fld_4 : Internal_Entity_Info;
Get_Result : Bare_Ada_Node;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Subtype_Indication;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Expr;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_646 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_646;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 973 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 967 '<FieldAccess for resolve_names at ast.py:8355>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8355
--# expr-start 966 '<as_entity at ast.py:8355>' If_Result /tmp/lal-23.0.0/ada/ast.py:8355
--# expr-start 965 '<Find at ast.py:8354>' Find_Result /tmp/lal-23.0.0/ada/ast.py:8354
   --# expr-start 963 '<FieldAccess for parents at ast.py:8354>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:8354
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 963
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_40 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_40
      --# expr-start 964 '<FieldAccess for xref_entry_point at ast.py:8355>' Fld /tmp/lal-23.0.0/ada/ast.py:8355
      if Item_40 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_entry_point'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Entry_Point (Node => Item_40);
--# end
--# expr-done 964
      if Fld then
         Find_Result := Item_40;
      end if;
   --# end
               exit when Fld;
         end loop;
      end;
--# expr-done 965
Is_Null := Find_Result = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Find_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 966
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names
Fld_1 := Libadalang.Implementation.Ada_Node_P_Resolve_Names (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 967
Block_Var := Fld_1; 
--# expr-start 968 '<FieldAccess for list at ast.py:8358>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8358
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Constraint_List (Node => Ent.Node.Constrained_Array_Indices_F_List, Info => Ent.Info);
--# expr-done 968
Fld_3 := Fld_2.Node;
Get_Result := Get (Self, Fld_3, Dim, True); 
Is_Null_1 := Get_Result = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_4 := Fld_2.Info;
As_Entity_1 := (Info => Fld_4, Node => Get_Result); 
   If_Result_1 := As_Entity_1;
end if;
Var_Expr := If_Result_1;
if Var_Expr /= No_Entity then
   --# scope-start
--# expr-start 972 '<Match at ast.py:8358>' Match_Result /tmp/lal-23.0.0/ada/ast.py:8358
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind st Match_0
--# expr-start 969 '<FieldAccess for designated_type at ast.py:8359>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8359
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 969
Let_Result := Fld_5; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind e Match_1
--# expr-start 971 '<Cast to BaseTypeDecl.entity at ast.py:8360>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8360
--# expr-start 970 '<FieldAccess for type_val at ast.py:8360>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8360
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_6 := Libadalang.Implementation.Expr_P_Type_Val (Node => Match_1.Node);
--# end
--# expr-done 970
   if Fld_6.Node = null
      or else Fld_6.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 971
Let_Result_1 := Cast_Result; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Base_Type_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 972
Scope_Result_3 := Match_Result;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result_3 := Result_Var; 
--# end
--# expr-done 973
      Property_Result := Let_Result_3;
   --# end
      Finalizer_Scope_646;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_646;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constrained_Array_Indices_P_Index_Type;
--# end
--# property-start ConstrainedArrayIndices.is_static /tmp/lal-23.0.0/ada/ast.py:8364
pragma Warnings (Off, "is not referenced");
 function Constrained_Array_Indices_P_Is_Static
  (Node : Bare_Constrained_Array_Indices
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Constrained_Array_Indices := Bare_Constrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Constrained_Array_Indices :=
     Internal_Entity_Constrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Subtype_Indication;
Match_1 : Internal_Entity_Bin_Op;
Match_2 : Internal_Entity;
Fld : Internal_Entity_Constraint_List;
Fld_1 : Bare_Constraint_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_3 : Boolean;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Boolean;
Fld_6 : Internal_Entity_Expr;
Fld_7 : Boolean;
If_Result_1 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Subtype_Indication;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Internal_Entity_Bin_Op;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_2 : Internal_Entity;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
Item_41 : Internal_Entity;
Bare_Item_41 : Bare_Ada_Node;
Quantifier_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 981 '<AllQuantifier at ast.py:8364>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:8364
   --# expr-start 974 '<FieldAccess for list at ast.py:8364>' Fld /tmp/lal-23.0.0/ada/ast.py:8364
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Constraint_List (Node => Ent.Node.Constrained_Array_Indices_F_List, Info => Ent.Info);
--# expr-done 974
Fld_1 := Fld.Node;
      Quantifier_Result := True;
      if Fld_1 = null then
      null;
      else
      declare
         Collection : constant Bare_Constraint_List := Fld_1;
      begin
         for Untyped_Item_41 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_41 := Untyped_Item_41; 
Is_Null := Bare_Item_41 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_41); 
   If_Result := As_Entity;
end if;
                  Item_41 := If_Result; 
   --# scope-start
               --# bind t Item_41
      --# expr-start 980 '<Match at ast.py:8365>' Match_Result /tmp/lal-23.0.0/ada/ast.py:8365
      if Item_41.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_41; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind st Match_0
--# expr-start 975 '<FieldAccess for is_static_subtype at ast.py:8366>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8366
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.is_static_subtype
Fld_3 := Libadalang.Implementation.Subtype_Indication_P_Is_Static_Subtype (Node => Match_0.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_0.Info);
--# end
--# expr-done 975
Let_Result := Fld_3; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind e Match_1
--# expr-start 977 '<FieldAccess for is_static_expr at ast.py:8367>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8367
--# expr-start 976 '<FieldAccess for left at ast.py:8367>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8367
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Left, Info => Match_1.Info);
--# expr-done 976
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_5 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_4.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_4.Info);
--# end
--# expr-done 977
if Fld_5 then
   --# expr-start 979 '<FieldAccess for is_static_expr at ast.py:8367>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:8367
--# expr-start 978 '<FieldAccess for right at ast.py:8367>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8367
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Right, Info => Match_1.Info);
--# expr-done 978
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_7 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_6.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_6.Info);
--# end
--# expr-done 979
   If_Result_1 := Fld_7;
else
   If_Result_1 := False;
end if;
Let_Result_1 := If_Result_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := False; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 980
      Quantifier_Result := Match_Result;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 981
      Property_Result := Quantifier_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constrained_Array_Indices_P_Is_Static;
--# end
   --
   --  Primitives for Bare_Unconstrained_Array_Indices
   --
      procedure Initialize_Fields_For_Unconstrained_Array_Indices
        (Self : Bare_Unconstrained_Array_Indices
         ; Unconstrained_Array_Indices_F_Types : Bare_Unconstrained_Array_Index_List
        ) is
      begin
            Self.Unconstrained_Array_Indices_F_Types := Unconstrained_Array_Indices_F_Types;
      end Initialize_Fields_For_Unconstrained_Array_Indices;
   function Unconstrained_Array_Indices_F_Types
     (Node : Bare_Unconstrained_Array_Indices) return Bare_Unconstrained_Array_Index_List
   is
   begin
         return Node.Unconstrained_Array_Indices_F_Types;
   end;
--# property-start UnconstrainedArrayIndices.ndims /tmp/lal-23.0.0/ada/ast.py:8298
pragma Warnings (Off, "is not referenced");
 function Unconstrained_Array_Indices_P_Ndims
  (Node : Bare_Unconstrained_Array_Indices
  )
   return Integer
is
   Self : Bare_Unconstrained_Array_Indices := Bare_Unconstrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Integer;
      Fld : Bare_Unconstrained_Array_Index_List;
Len : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 983 '<length at ast.py:8298>' Len /tmp/lal-23.0.0/ada/ast.py:8298
--# expr-start 982 '<FieldAccess for types at ast.py:8298>' Fld /tmp/lal-23.0.0/ada/ast.py:8298
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Unconstrained_Array_Indices_F_Types;
--# expr-done 982
Len := Length (Fld); 
--# expr-done 983
      Property_Result := Len;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Unconstrained_Array_Indices_P_Ndims;
--# end
--# property-start UnconstrainedArrayIndices.constrain_index_expr /tmp/lal-23.0.0/ada/ast.py:8301
pragma Warnings (Off, "is not referenced");
 function Unconstrained_Array_Indices_P_Constrain_Index_Expr
  (Node : Bare_Unconstrained_Array_Indices
      ; Index_Expr : Internal_Entity_Expr
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Unconstrained_Array_Indices := Bare_Unconstrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Unconstrained_Array_Indices :=
     Internal_Entity_Unconstrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind index_expr Index_Expr
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_639 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_639 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_639;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 989 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 988 '<And at ast.py:8302>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8302
--# expr-start 986 '<Bind at ast.py:8303>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:8303
--# expr-start 984 '<FieldAccess for expected_type_var at ast.py:8303>' Fld /tmp/lal-23.0.0/ada/ast.py:8303
      if Index_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Index_Expr.Node);
--# expr-done 984
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 985 '<FieldAccess for index_type at ast.py:8303>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8303
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]ArrayIndices.index_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Index_Type (Node => Ent.Node, Dim => Dim, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 985
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8303") else null)); 
--# expr-done 986
--# expr-start 987 '<FieldAccess for matches_expected_type at ast.py:8304>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8304
      if Index_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_2 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Index_Expr.Node, Origin => Origin);
--# end
--# expr-done 987
And_Pred := Create_And (Bind_Result, Fld_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8302") else null)); 
--# expr-done 988
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 989
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_639;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_639;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Unconstrained_Array_Indices_P_Constrain_Index_Expr;
--# end
--# property-start UnconstrainedArrayIndices.index_type /tmp/lal-23.0.0/ada/ast.py:8308
pragma Warnings (Off, "is not referenced");
 function Unconstrained_Array_Indices_P_Index_Type
  (Node : Bare_Unconstrained_Array_Indices
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Unconstrained_Array_Indices := Bare_Unconstrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Unconstrained_Array_Indices :=
     Internal_Entity_Unconstrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Unconstrained_Array_Index;
Fld : Internal_Entity_Unconstrained_Array_Index_List;
Fld_1 : Bare_Unconstrained_Array_Index_List;
Fld_2 : Internal_Entity_Info;
Get_Result : Bare_Unconstrained_Array_Index;
As_Entity : Internal_Entity_Unconstrained_Array_Index;
Is_Null : Boolean;
If_Result : Internal_Entity_Unconstrained_Array_Index;
Fld_3 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 992 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 990 '<FieldAccess for types at ast.py:8309>' Fld /tmp/lal-23.0.0/ada/ast.py:8309
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Unconstrained_Array_Index_List (Node => Ent.Node.Unconstrained_Array_Indices_F_Types, Info => Ent.Info);
--# expr-done 990
Fld_1 := Fld.Node;
Get_Result := Get (Self, Fld_1, Dim, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Unconstrained_Array_Index;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Get_Result); 
   If_Result := As_Entity;
end if;
Var_Expr := If_Result;
if Var_Expr /= No_Entity_Unconstrained_Array_Index then
   --# scope-start
--# expr-start 991 '<FieldAccess for designated_type at ast.py:8309>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8309
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UnconstrainedArrayIndex.designated_type
Fld_3 := Libadalang.Implementation.Unconstrained_Array_Index_P_Designated_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 991
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 992
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Unconstrained_Array_Indices_P_Index_Type;
--# end
--# property-start UnconstrainedArrayIndices.xref_equation /tmp/lal-23.0.0/ada/ast.py:8312
pragma Warnings (Off, "is not referenced");
 function Unconstrained_Array_Indices_P_Xref_Equation
  (Node : Bare_Unconstrained_Array_Indices
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Unconstrained_Array_Indices := Bare_Unconstrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Unconstrained_Array_Indices :=
     Internal_Entity_Unconstrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_641 with Inline_Always;
            procedure Finalizer_Scope_1920 with Inline_Always;
      Fld : Internal_Entity_Unconstrained_Array_Index_List;
Fld_1 : Bare_Unconstrained_Array_Index_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Unconstrained_Array_Index;
Is_Null : Boolean;
If_Result : Internal_Entity_Unconstrained_Array_Index;
Fld_3 : Internal_Entity_Subtype_Indication;
Fld_4 : Logic_Equation;
Item_42 : Internal_Entity_Unconstrained_Array_Index;
Bare_Item_42 : Bare_Unconstrained_Array_Index;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_641 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_641;
            procedure Finalizer_Scope_1920 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_1920;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 998 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 997 '<LogicAll at ast.py:8313>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8313
--# expr-start 996 '<Map at ast.py:8313>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8313
   --# expr-start 993 '<FieldAccess for types at ast.py:8313>' Fld /tmp/lal-23.0.0/ada/ast.py:8313
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Unconstrained_Array_Index_List (Node => Ent.Node.Unconstrained_Array_Indices_F_Types, Info => Ent.Info);
--# expr-done 993
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Unconstrained_Array_Index_List := Fld_1;
      begin
         for Untyped_Item_42 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_42 := Untyped_Item_42; 
Is_Null := Bare_Item_42 = null; 
if Is_Null then
   If_Result := No_Entity_Unconstrained_Array_Index;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_42); 
   If_Result := As_Entity;
end if;
                  Item_42 := If_Result; 
   --# scope-start
               --# bind typ Item_42
      --# expr-start 995 '<FieldAccess for sub_equation at ast.py:8314>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8314
--# expr-start 994 '<FieldAccess for subtype_indication at ast.py:8314>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8314
      if Item_42.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Subtype_Indication (Node => Item_42.Node.Unconstrained_Array_Index_F_Subtype_Indication, Info => Item_42.Info);
--# expr-done 994
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 995
         declare
            Item_To_Append : constant Logic_Equation := Fld_4;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1920;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 996
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8313") else null)); 
--# expr-done 997
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 998
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_641;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_641;
               Finalizer_Scope_1920;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Unconstrained_Array_Indices_P_Xref_Equation;
--# end
--# property-start UnconstrainedArrayIndices.is_static /tmp/lal-23.0.0/ada/ast.py:8317
pragma Warnings (Off, "is not referenced");
 function Unconstrained_Array_Indices_P_Is_Static
  (Node : Bare_Unconstrained_Array_Indices
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Unconstrained_Array_Indices := Bare_Unconstrained_Array_Indices (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Unconstrained_Array_Indices :=
     Internal_Entity_Unconstrained_Array_Indices'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Unconstrained_Array_Index_List;
Fld_1 : Bare_Unconstrained_Array_Index_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Unconstrained_Array_Index;
Is_Null : Boolean;
If_Result : Internal_Entity_Unconstrained_Array_Index;
Fld_3 : Internal_Entity_Subtype_Indication;
Fld_4 : Boolean;
Item_43 : Internal_Entity_Unconstrained_Array_Index;
Bare_Item_43 : Bare_Unconstrained_Array_Index;
Quantifier_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1002 '<AllQuantifier at ast.py:8317>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:8317
   --# expr-start 999 '<FieldAccess for types at ast.py:8317>' Fld /tmp/lal-23.0.0/ada/ast.py:8317
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Unconstrained_Array_Index_List (Node => Ent.Node.Unconstrained_Array_Indices_F_Types, Info => Ent.Info);
--# expr-done 999
Fld_1 := Fld.Node;
      Quantifier_Result := True;
      if Fld_1 = null then
      null;
      else
      declare
         Collection : constant Bare_Unconstrained_Array_Index_List := Fld_1;
      begin
         for Untyped_Item_43 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_43 := Untyped_Item_43; 
Is_Null := Bare_Item_43 = null; 
if Is_Null then
   If_Result := No_Entity_Unconstrained_Array_Index;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_43); 
   If_Result := As_Entity;
end if;
                  Item_43 := If_Result; 
   --# scope-start
               --# bind t Item_43
      --# expr-start 1001 '<FieldAccess for is_static_subtype at ast.py:8318>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8318
--# expr-start 1000 '<FieldAccess for subtype_indication at ast.py:8318>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8318
      if Item_43.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Subtype_Indication (Node => Item_43.Node.Unconstrained_Array_Index_F_Subtype_Indication, Info => Item_43.Info);
--# expr-done 1000
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.is_static_subtype
Fld_4 := Libadalang.Implementation.Subtype_Indication_P_Is_Static_Subtype (Node => Fld_3.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_3.Info);
--# end
--# expr-done 1001
      Quantifier_Result := Fld_4;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 1002
      Property_Result := Quantifier_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Unconstrained_Array_Indices_P_Is_Static;
--# end
   --
   --  Primitives for Bare_Aspect_Assoc
   --
      procedure Initialize_Fields_For_Aspect_Assoc
        (Self : Bare_Aspect_Assoc
         ; Aspect_Assoc_F_Id : Bare_Name
         ; Aspect_Assoc_F_Expr : Bare_Expr
        ) is
      begin
            Self.Aspect_Assoc_F_Id := Aspect_Assoc_F_Id;
            Self.Aspect_Assoc_F_Expr := Aspect_Assoc_F_Expr;
      end Initialize_Fields_For_Aspect_Assoc;
   function Aspect_Assoc_F_Id
     (Node : Bare_Aspect_Assoc) return Bare_Name
   is
   begin
         return Node.Aspect_Assoc_F_Id;
   end;
   function Aspect_Assoc_F_Expr
     (Node : Bare_Aspect_Assoc) return Bare_Expr
   is
   begin
         return Node.Aspect_Assoc_F_Expr;
   end;
--# property-start AspectAssoc.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:10026
pragma Warnings (Off, "is not referenced");
 function Aspect_Assoc_P_Xref_Entry_Point
  (Node : Bare_Aspect_Assoc
  )
   return Boolean
is
   Self : Bare_Aspect_Assoc := Bare_Aspect_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aspect_Assoc_P_Xref_Entry_Point;
--# end
--# property-start AspectAssoc.xref_equation /tmp/lal-23.0.0/ada/ast.py:10029
pragma Warnings (Off, "is not referenced");
 function Aspect_Assoc_P_Xref_Equation
  (Node : Bare_Aspect_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aspect_Assoc := Bare_Aspect_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aspect_Assoc :=
     Internal_Entity_Aspect_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_805 with Inline_Always;
            procedure Finalizer_Scope_1922 with Inline_Always;
            procedure Finalizer_Scope_1924 with Inline_Always;
      Block_Var : Bare_Ada_Node;
Expr_Equation_Env : Lexical_Env := Empty_Env;
Var_Expr : Bare_Type_Decl;
Var_Expr_1 : Internal_Entity_Expr;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Fld_2 : Bare_Ada_Node;
Fld_3 : Internal_Entity_Name;
Sym : Symbol_Type;
Fld_4 : Boolean;
Fld_5 : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Aggregate;
Fld_6 : Internal_Entity_Assoc_List;
Fld_7 : Internal_Single_Actual_Array_Access;
Fld_8 : Internal_Entity_Basic_Assoc;
Fld_9 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_10 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_11 : Internal_Entity_Name;
Fld_12 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal : Boolean;
Fld_13 : Internal_Entity_Name;
Fld_14 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_15 : Internal_Entity_Name;
Fld_16 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_17 : Internal_Entity_Name;
Fld_18 : Symbol_Type;
Sym_4 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_19 : Internal_Entity_Name;
Fld_20 : Symbol_Type;
Sym_5 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_3 : Boolean;
Fld_21 : Internal_Entity_Name;
Fld_22 : Symbol_Type;
Sym_6 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_4 : Boolean;
Fld_23 : Internal_Entity_Name;
Fld_24 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_5 : Boolean;
Fld_25 : Internal_Entity_Name;
Fld_26 : Symbol_Type;
Sym_8 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_6 : Boolean;
Cast_Expr : Bare_Ada_Node;
Cast_Result_2 : Bare_Type_Decl;
Fld_27 : Bare_Type_Def;
Fld_28 : Lexical_Env := Empty_Env;
Fld_29 : Lexical_Env := Empty_Env;
Fld_30 : Internal_Entity_Name;
Fld_31 : Symbol_Type;
Sym_9 : Symbol_Type;
Is_Equal_8 : Boolean;
Fld_32 : Internal_Entity_Name;
Fld_33 : Symbol_Type;
Sym_10 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_7 : Boolean;
Cast_Expr_1 : Bare_Ada_Node;
Cast_Result_3 : Bare_Type_Decl;
Fld_34 : Bare_Type_Def;
Scope_Result : Bare_Type_Def;
Result_Var : Bare_Type_Def;
Is_A : Boolean;
If_Result_8 : Boolean;
If_Result_9 : Lexical_Env := Empty_Env;
Fld_35 : Bare_Expr;
Fld_36 : Logic_Var;
Fld_37 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result : Logic_Equation;
Bound_Env : Lexical_Env := Empty_Env;
Fld_38 : Internal_Entity_Expr;
Fld_39 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_40 : Bare_Expr;
Fld_41 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
Fld_42 : Internal_Entity_Name;
Sym_11 : Symbol_Type;
Fld_43 : Boolean;
Fld_44 : Internal_Entity_Expr;
Fld_45 : Logic_Equation;
Fld_46 : Internal_Entity_Name;
Sym_12 : Symbol_Type;
Fld_47 : Boolean;
Fld_48 : Internal_Entity_Expr;
Cast_Result_5 : Internal_Entity_Name;
Fld_49 : Logic_Equation;
Fld_50 : Internal_Entity_Expr;
Cast_Result_6 : Internal_Entity_Name;
Fld_51 : Logic_Var;
Cast_Expr_2 : Bare_Ada_Node;
Cast_Result_7 : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result_10 : Internal_Entity_Base_Type_Decl;
Pred : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_52 : Internal_Entity_Name;
Sym_13 : Symbol_Type;
Fld_53 : Boolean;
Fld_54 : Internal_Entity_Name;
Sym_14 : Symbol_Type;
Fld_55 : Boolean;
If_Result_11 : Boolean;
True_Rel : Logic_Equation;
Fld_56 : Internal_Entity_Expr;
Fld_57 : Logic_Equation;
Fld_58 : Internal_Entity_Expr;
Is_A_1 : Boolean;
If_Result_12 : Logic_Equation;
Fld_59 : Internal_Entity_Name;
Sym_15 : Symbol_Type;
Fld_60 : Boolean;
True_Rel_1 : Logic_Equation;
Fld_61 : Internal_Entity_Name;
Sym_16 : Symbol_Type;
Fld_62 : Boolean;
Fld_63 : Logic_Equation;
Fld_64 : Internal_Entity_Expr;
Fld_65 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_2 : Logic_Equation;
Result_Var_1 : Logic_Equation;
True_Rel_3 : Logic_Equation;
Or_Pred : Logic_Equation;
If_Result_13 : Logic_Equation;
If_Result_14 : Logic_Equation;
If_Result_15 : Logic_Equation;
If_Result_16 : Logic_Equation;
If_Result_17 : Logic_Equation;
If_Result_18 : Logic_Equation;
If_Result_19 : Logic_Equation;
Let_Result_1 : Logic_Equation;
            procedure Finalizer_Scope_805 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Fld_28);
                     Dec_Ref (Fld_29);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Expr_Equation_Env);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_39);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_41);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Fld_45);
                     Dec_Ref (Fld_49);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Fld_57);
                     Dec_Ref (If_Result_12);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Fld_63);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_2);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (True_Rel_3);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (If_Result_13);
                     Dec_Ref (If_Result_14);
                     Dec_Ref (If_Result_15);
                     Dec_Ref (If_Result_16);
                     Dec_Ref (If_Result_17);
                     Dec_Ref (If_Result_18);
                     Dec_Ref (If_Result_19);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_805;
            procedure Finalizer_Scope_1922 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_1922;
            procedure Finalizer_Scope_1924 is
            begin
                     Dec_Ref (Fld_65);
            end Finalizer_Scope_1924;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1119 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 1005 '<parent at ast.py:10030>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10030
--# expr-start 1004 '<parent at ast.py:10030>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10030
--# expr-start 1003 '<parent at ast.py:10030>' Fld /tmp/lal-23.0.0/ada/ast.py:10030
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 1003
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 1004
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Fld_1.Parent; 
--# expr-done 1005
Block_Var := Fld_2; 
--# bind target Block_Var
--# expr-start 1118 '<Cond at ast.py:10031>' If_Result_19 /tmp/lal-23.0.0/ada/ast.py:10031
--# expr-start 1008 '<FieldAccess for name_is at ast.py:10033>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10033
--# expr-start 1006 '<FieldAccess for id at ast.py:10033>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10033
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1006
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1007 '<Symbol Iterable at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterable); 
--# expr-done 1007
--# property-call-start Name.name_is
Fld_4 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_3.Node, Sym => Sym);
--# end
--# expr-done 1008
if Fld_4 then
   --# expr-start 1018 '<LogicAll at ast.py:10034>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:10034
--# expr-start 1017 '<Map at ast.py:10034>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10034
   --# expr-start 1012 '<FieldAccess for unpacked_params at ast.py:10034>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10034
--# expr-start 1011 '<FieldAccess for assocs at ast.py:10034>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10034
--# expr-start 1010 '<Cast to Aggregate at ast.py:10034>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10034
--# expr-start 1009 '<FieldAccess for expr at ast.py:10034>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10034
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1009
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Aggregate_Range
   then
      Cast_Result := Create_Internal_Entity_Aggregate
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result := No_Entity_Aggregate;
   end if;
--# expr-done 1010
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Assoc_List (Node => Cast_Result.Node.Base_Aggregate_F_Assocs, Info => Cast_Result.Info);
--# expr-done 1011
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.unpacked_params
Fld_7 := Libadalang.Implementation.Assoc_List_P_Unpacked_Params (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 1012
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Single_Actual_Array_Access := Fld_7;
      begin
         for Item_44 of
               Collection.Items
         loop
   --# scope-start
               --# bind sa Item_44
      --# expr-start 1016 '<FieldAccess for xref_no_overloading at ast.py:10036>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10036
--# expr-start 1015 '<Cast to Name at ast.py:10037>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:10037
--# expr-start 1014 '<FieldAccess for expr at ast.py:10036>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10036
--# expr-start 1013 '<FieldAccess for assoc at ast.py:10036>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10036
Fld_8 := Item_44.Assoc;
--# expr-done 1013
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_9 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_8.Node, E_Info => Fld_8.Info);
--# end
--# expr-done 1014
   if Fld_9.Node = null
      or else Fld_9.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1015
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_10 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_1.Node, Sequential => False, Env => Env, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 1016
         declare
            Item_To_Append : constant Logic_Equation := Fld_10;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1922;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1017
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10034") else null)); 
--# expr-done 1018
   If_Result_19 := Logic_Boolean_Op;
else
--# expr-start 1022 '<Eq at ast.py:10041>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1020 '<FieldAccess for name_symbol at ast.py:10041>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1019 '<FieldAccess for id at ast.py:10041>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1019
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_12 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_11.Node);
--# end
--# expr-done 1020
--# expr-start 1021 '<Symbol Pre at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre); 
--# expr-done 1021
Is_Equal := Fld_12 = Sym_1; 
--# expr-done 1022
if Is_Equal then
   If_Result := True;
else
   --# expr-start 1026 '<Eq at ast.py:10041>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1024 '<FieldAccess for name_symbol at ast.py:10041>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1023 '<FieldAccess for id at ast.py:10041>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1023
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_14 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_13.Node);
--# end
--# expr-done 1024
--# expr-start 1025 '<Symbol Post at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post); 
--# expr-done 1025
Is_Equal_1 := Fld_14 = Sym_2; 
--# expr-done 1026
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 1030 '<Eq at ast.py:10041>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1028 '<FieldAccess for name_symbol at ast.py:10041>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1027 '<FieldAccess for id at ast.py:10041>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1027
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_16 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_15.Node);
--# end
--# expr-done 1028
--# expr-start 1029 '<Symbol Refined_Post at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Post); 
--# expr-done 1029
Is_Equal_2 := Fld_16 = Sym_3; 
--# expr-done 1030
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 1034 '<Eq at ast.py:10041>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1032 '<FieldAccess for name_symbol at ast.py:10041>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1031 '<FieldAccess for id at ast.py:10041>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1031
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_18 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_17.Node);
--# end
--# expr-done 1032
--# expr-start 1033 '<Symbol Type_Invariant at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Type_Invariant); 
--# expr-done 1033
Is_Equal_3 := Fld_18 = Sym_4; 
--# expr-done 1034
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 1038 '<Eq at ast.py:10041>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1036 '<FieldAccess for name_symbol at ast.py:10041>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1035 '<FieldAccess for id at ast.py:10041>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1035
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_20 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_19.Node);
--# end
--# expr-done 1036
--# expr-start 1037 '<Symbol Invariant at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Invariant); 
--# expr-done 1037
Is_Equal_4 := Fld_20 = Sym_5; 
--# expr-done 1038
   If_Result_3 := Is_Equal_4;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 1042 '<Eq at ast.py:10041>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1040 '<FieldAccess for name_symbol at ast.py:10041>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1039 '<FieldAccess for id at ast.py:10041>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1039
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_22 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_21.Node);
--# end
--# expr-done 1040
--# expr-start 1041 '<Symbol Predicate at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Predicate); 
--# expr-done 1041
Is_Equal_5 := Fld_22 = Sym_6; 
--# expr-done 1042
   If_Result_4 := Is_Equal_5;
end if;
if If_Result_4 then
   If_Result_5 := True;
else
   --# expr-start 1046 '<Eq at ast.py:10041>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1044 '<FieldAccess for name_symbol at ast.py:10041>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1043 '<FieldAccess for id at ast.py:10041>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1043
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_24 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_23.Node);
--# end
--# expr-done 1044
--# expr-start 1045 '<Symbol Static_Predicate at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Static_Predicate); 
--# expr-done 1045
Is_Equal_6 := Fld_24 = Sym_7; 
--# expr-done 1046
   If_Result_5 := Is_Equal_6;
end if;
if If_Result_5 then
   If_Result_6 := True;
else
   --# expr-start 1050 '<Eq at ast.py:10041>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1048 '<FieldAccess for name_symbol at ast.py:10041>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:10041
--# expr-start 1047 '<FieldAccess for id at ast.py:10041>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:10041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1047
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_26 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_25.Node);
--# end
--# expr-done 1048
--# expr-start 1049 '<Symbol Dynamic_Predicate at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Dynamic_Predicate); 
--# expr-done 1049
Is_Equal_7 := Fld_26 = Sym_8; 
--# expr-done 1050
   If_Result_6 := Is_Equal_7;
end if;
if If_Result_6 then
   --# expr-start 1078 '<Let at ast.py:10045>' Let_Result /tmp/lal-23.0.0/ada/ast.py:10045
--# scope-start
--# expr-start 1066 '<If at ast.py:10046>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:10046
--# expr-start 1054 '<Eq at ast.py:10051>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:10051
--# expr-start 1052 '<FieldAccess for name_symbol at ast.py:10051>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:10051
--# expr-start 1051 '<FieldAccess for id at ast.py:10051>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:10051
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_30 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1051
      if Fld_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_31 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_30.Node);
--# end
--# expr-done 1052
--# expr-start 1053 '<Symbol Pre at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre); 
--# expr-done 1053
Is_Equal_8 := Fld_31 = Sym_9; 
--# expr-done 1054
if Is_Equal_8 then
   If_Result_7 := True;
else
   --# expr-start 1058 '<Eq at ast.py:10051>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:10051
--# expr-start 1056 '<FieldAccess for name_symbol at ast.py:10051>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:10051
--# expr-start 1055 '<FieldAccess for id at ast.py:10051>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:10051
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_32 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1055
      if Fld_32.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_33 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_32.Node);
--# end
--# expr-done 1056
--# expr-start 1057 '<Symbol Post at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post); 
--# expr-done 1057
Is_Equal_9 := Fld_33 = Sym_10; 
--# expr-done 1058
   If_Result_7 := Is_Equal_9;
end if;
if If_Result_7 then
   --# expr-start 1061 '<IsA AccessToSubpDef at ast.py:10052>' Is_A /tmp/lal-23.0.0/ada/ast.py:10052
--# expr-start 1059 '<Cast to TypeDecl at ast.py:10052>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:10052
Cast_Expr_1 := Block_Var; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Type_Decl
   then
      Cast_Result_3 := Cast_Expr_1;
   else
         Cast_Result_3 := No_Bare_Ada_Node;
   end if;
--# expr-done 1059
Var_Expr := Cast_Result_3;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 1060 '<FieldAccess for type_def at ast.py:10052>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:10052
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_34 := Var_Expr.Type_Decl_F_Type_Def;
--# expr-done 1060
Scope_Result := Fld_34;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_A := Result_Var /= null 
and then Result_Var.Kind in Ada_Access_To_Subp_Def_Range; 
--# expr-done 1061
   If_Result_8 := Is_A;
else
   If_Result_8 := False;
end if;
if If_Result_8 then
   --# expr-start 1064 '<FieldAccess for children_env at ast.py:10053>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:10053
--# expr-start 1063 '<FieldAccess for type_def at ast.py:10053>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:10053
--# expr-start 1062 '<Cast to TypeDecl at ast.py:10053>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:10053
Cast_Expr := Block_Var; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Type_Decl
   then
      Cast_Result_2 := Cast_Expr;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 1062
      if Cast_Result_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Cast_Result_2.Type_Decl_F_Type_Def;
--# expr-done 1063
      if Fld_27 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Libadalang.Implementation.Children_Env (Node => Fld_27);
--# expr-done 1064
   If_Result_9 := Fld_28;
else
   --# expr-start 1065 '<FieldAccess for node_env at ast.py:10054>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:10054
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 1065
   If_Result_9 := Fld_29;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 1066
Expr_Equation_Env := If_Result_9; Inc_Ref (Expr_Equation_Env);
--# bind expr_equation_env Expr_Equation_Env
--# expr-start 1077 '<And at ast.py:10056>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:10056
--# expr-start 1074 '<And at ast.py:10056>' And_Pred /tmp/lal-23.0.0/ada/ast.py:10056
--# expr-start 1070 '<Bind at ast.py:10056>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:10056
--# expr-start 1068 '<FieldAccess for expected_type_var at ast.py:10056>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:10056
--# expr-start 1067 '<FieldAccess for expr at ast.py:10056>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:10056
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_35 := Self.Aspect_Assoc_F_Expr;
--# expr-done 1067
      if Fld_35 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_36 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_35);
--# expr-done 1068
Fld_36.Value := No_Entity;
Entity_Vars.Reset (Fld_36);
--# expr-start 1069 '<FieldAccess for bool_type at ast.py:10056>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:10056
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_37 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 1069
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_37.Node,
         Info => Fld_37.Info);
Bind_Result := Solver.Create_Assign (Fld_36, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10056") else null)); 
--# expr-done 1070
--# expr-start 1073 '<bind at ast.py:10057>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:10057
Bound_Env := Expr_Equation_Env; Inc_Ref (Bound_Env);
--# expr-start 1072 '<FieldAccess for sub_equation at ast.py:10058>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:10058
--# expr-start 1071 '<FieldAccess for expr at ast.py:10058>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:10058
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_38 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1071
      if Fld_38.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_39 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_38.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_38.Info);
--# end
--# expr-done 1072
Dyn_Var_Bind_Result := Fld_39; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 1073
And_Pred := Create_And (Bind_Result, Dyn_Var_Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10056") else null)); 
--# expr-done 1074
--# expr-start 1076 '<FieldAccess for matches_expected_formal_prim_type at ast.py:10059>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:10059
--# expr-start 1075 '<FieldAccess for expr at ast.py:10059>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:10059
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_40 := Self.Aspect_Assoc_F_Expr;
--# expr-done 1075
      if Fld_40 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_41 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_40, Origin => Origin);
--# end
--# expr-done 1076
And_Pred_1 := Create_And (And_Pred, Fld_41, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10056") else null)); 
--# expr-done 1077
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1078
   If_Result_18 := Let_Result;
else
--# expr-start 1081 '<FieldAccess for name_is at ast.py:10062>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:10062
--# expr-start 1079 '<FieldAccess for id at ast.py:10062>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:10062
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_42 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1079
      if Fld_42.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1080 '<Symbol Contract_Cases at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 1080
--# property-call-start Name.name_is
Fld_43 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_42.Node, Sym => Sym_11);
--# end
--# expr-done 1081
if Fld_43 then
   --# expr-start 1083 '<FieldAccess for sub_equation at ast.py:10063>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:10063
--# expr-start 1082 '<FieldAccess for expr at ast.py:10063>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:10063
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_44 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1082
      if Fld_44.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_45 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_44.Node, Env => Env, Origin => Origin, E_Info => Fld_44.Info);
--# end
--# expr-done 1083
   If_Result_17 := Fld_45;
else
--# expr-start 1086 '<FieldAccess for name_is at ast.py:10066>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:10066
--# expr-start 1084 '<FieldAccess for id at ast.py:10066>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:10066
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_46 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1084
      if Fld_46.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1085 '<Symbol Put_Image at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image); 
--# expr-done 1085
--# property-call-start Name.name_is
Fld_47 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_46.Node, Sym => Sym_12);
--# end
--# expr-done 1086
if Fld_47 then
   --# expr-start 1096 '<And at ast.py:10067>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:10067
--# expr-start 1089 '<FieldAccess for xref_no_overloading at ast.py:10067>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:10067
--# expr-start 1088 '<Cast to Name at ast.py:10067>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:10067
--# expr-start 1087 '<FieldAccess for expr at ast.py:10067>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:10067
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_48 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1087
   if Fld_48.Node = null
      or else Fld_48.Node.Kind in Ada_Name
   then
      Cast_Result_5 := Create_Internal_Entity_Name
        (Node => Fld_48.Node,
         Info => Fld_48.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1088
      if Cast_Result_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_49 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_5.Node, Sequential => False, All_Els => True, Env => Env, Origin => Origin, E_Info => Cast_Result_5.Info);
--# end
--# expr-done 1089
--# expr-start 1095 '<Predicate on BasicDecl.is_put_image_subprogram_for_type at ast.py:10069>' Pred /tmp/lal-23.0.0/ada/ast.py:10069
--# expr-start 1092 '<FieldAccess for ref_var at ast.py:10071>' Fld_51 /tmp/lal-23.0.0/ada/ast.py:10071
--# expr-start 1091 '<Cast to Name at ast.py:10071>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:10071
--# expr-start 1090 '<FieldAccess for expr at ast.py:10071>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:10071
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_50 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1090
   if Fld_50.Node = null
      or else Fld_50.Node.Kind in Ada_Name
   then
      Cast_Result_6 := Create_Internal_Entity_Name
        (Node => Fld_50.Node,
         Info => Fld_50.Info);
   else
         Cast_Result_6 := No_Entity_Name;
   end if;
--# expr-done 1091
      if Cast_Result_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_51 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Cast_Result_6.Node);
--# end
--# expr-done 1092
Fld_51.Value := No_Entity;
Entity_Vars.Reset (Fld_51);
--# expr-start 1094 '<as_entity at ast.py:10072>' If_Result_10 /tmp/lal-23.0.0/ada/ast.py:10072
--# expr-start 1093 '<Cast to BaseTypeDecl at ast.py:10072>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:10072
Cast_Expr_2 := Block_Var; 
   if Cast_Expr_2 = null
      or else Cast_Expr_2.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_7 := Cast_Expr_2;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1093
Is_Null := Cast_Result_7 = null; 
if Is_Null then
   If_Result_10 := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result_7); 
   If_Result_10 := As_Entity;
end if;
--# expr-done 1094
Pred := Solver.Create_Predicate (Fld_51, Create_Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate (If_Result_10)); 
--# expr-done 1095
And_Pred_2 := Create_And (Fld_49, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10067") else null)); 
--# expr-done 1096
   If_Result_16 := And_Pred_2;
else
--# expr-start 1099 '<FieldAccess for name_is at ast.py:10077>' Fld_53 /tmp/lal-23.0.0/ada/ast.py:10077
--# expr-start 1097 '<FieldAccess for id at ast.py:10077>' Fld_52 /tmp/lal-23.0.0/ada/ast.py:10077
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_52 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1097
      if Fld_52.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1098 '<Symbol Global at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Global); 
--# expr-done 1098
--# property-call-start Name.name_is
Fld_53 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_52.Node, Sym => Sym_13);
--# end
--# expr-done 1099
if Fld_53 then
   If_Result_11 := True;
else
   --# expr-start 1102 '<FieldAccess for name_is at ast.py:10077>' Fld_55 /tmp/lal-23.0.0/ada/ast.py:10077
--# expr-start 1100 '<FieldAccess for id at ast.py:10077>' Fld_54 /tmp/lal-23.0.0/ada/ast.py:10077
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_54 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1100
      if Fld_54.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1101 '<Symbol Refined_Global at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Global); 
--# expr-done 1101
--# property-call-start Name.name_is
Fld_55 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_54.Node, Sym => Sym_14);
--# end
--# expr-done 1102
   If_Result_11 := Fld_55;
end if;
if If_Result_11 then
   --# expr-start 1107 '<If at ast.py:10078>' If_Result_12 /tmp/lal-23.0.0/ada/ast.py:10078
--# expr-start 1104 '<IsA NullLiteral at ast.py:10079>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:10079
--# expr-start 1103 '<FieldAccess for expr at ast.py:10079>' Fld_58 /tmp/lal-23.0.0/ada/ast.py:10079
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_58 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1103
Is_A_1 := Fld_58.Node /= null 
and then Fld_58.Node.Kind in Ada_Null_Literal_Range; 
--# expr-done 1104
if Is_A_1 then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10080") else null)); 
   If_Result_12 := True_Rel;
else
   --# expr-start 1106 '<FieldAccess for sub_equation at ast.py:10081>' Fld_57 /tmp/lal-23.0.0/ada/ast.py:10081
--# expr-start 1105 '<FieldAccess for expr at ast.py:10081>' Fld_56 /tmp/lal-23.0.0/ada/ast.py:10081
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_56 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1105
      if Fld_56.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_57 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_56.Node, Env => Env, Origin => Origin, E_Info => Fld_56.Info);
--# end
--# expr-done 1106
   If_Result_12 := Fld_57;
end if;
      Inc_Ref (If_Result_12);
--# expr-done 1107
   If_Result_15 := If_Result_12;
else
--# expr-start 1110 '<FieldAccess for name_is at ast.py:10087>' Fld_60 /tmp/lal-23.0.0/ada/ast.py:10087
--# expr-start 1108 '<FieldAccess for id at ast.py:10087>' Fld_59 /tmp/lal-23.0.0/ada/ast.py:10087
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_59 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1108
      if Fld_59.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1109 '<Symbol Convention at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Convention); 
--# expr-done 1109
--# property-call-start Name.name_is
Fld_60 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_59.Node, Sym => Sym_15);
--# end
--# expr-done 1110
if Fld_60 then
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10087") else null)); 
   If_Result_14 := True_Rel_1;
else
--# expr-start 1113 '<FieldAccess for name_is at ast.py:10089>' Fld_62 /tmp/lal-23.0.0/ada/ast.py:10089
--# expr-start 1111 '<FieldAccess for id at ast.py:10089>' Fld_61 /tmp/lal-23.0.0/ada/ast.py:10089
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_61 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1111
      if Fld_61.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1112 '<Symbol Stable_Properties at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Stable_Properties); 
--# expr-done 1112
--# property-call-start Name.name_is
Fld_62 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_61.Node, Sym => Sym_16);
--# end
--# expr-done 1113
if Fld_62 then
   --# expr-start 1114 '<FieldAccess for stable_properties_assoc_equation at ast.py:10090>' Fld_63 /tmp/lal-23.0.0/ada/ast.py:10090
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AspectAssoc.stable_properties_assoc_equation
Fld_63 := Libadalang.Implementation.Aspect_Assoc_P_Stable_Properties_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1114
   If_Result_13 := Fld_63;
else
   --# expr-start 1117 '<Or at ast.py:10095>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:10095
--# expr-start 1115 '<FieldAccess for expr at ast.py:10095>' Fld_64 /tmp/lal-23.0.0/ada/ast.py:10095
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_64 := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1115
Var_Expr_1 := Fld_64;
if Var_Expr_1 /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr_1
--# expr-start 1116 '<FieldAccess for sub_equation at ast.py:10095>' Fld_65 /tmp/lal-23.0.0/ada/ast.py:10095
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_65 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr_1.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1116
Scope_Result_1 := Fld_65;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1924;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_2 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10095") else null)); 
   Result_Var_1 := True_Rel_2;
end if;
      Inc_Ref (Result_Var_1);
True_Rel_3 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10096") else null)); 
Or_Pred := Create_Or (Result_Var_1, True_Rel_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10095") else null)); 
--# expr-done 1117
   If_Result_13 := Or_Pred;
end if;
      Inc_Ref (If_Result_13);
   If_Result_14 := If_Result_13;
end if;
      Inc_Ref (If_Result_14);
   If_Result_15 := If_Result_14;
end if;
      Inc_Ref (If_Result_15);
   If_Result_16 := If_Result_15;
end if;
      Inc_Ref (If_Result_16);
   If_Result_17 := If_Result_16;
end if;
      Inc_Ref (If_Result_17);
   If_Result_18 := If_Result_17;
end if;
      Inc_Ref (If_Result_18);
   If_Result_19 := If_Result_18;
end if;
      Inc_Ref (If_Result_19);
--# expr-done 1118
Let_Result_1 := If_Result_19; Inc_Ref (Let_Result_1);
--# end
--# expr-done 1119
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_805;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_805;
               Finalizer_Scope_1922;
               Finalizer_Scope_1924;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aspect_Assoc_P_Xref_Equation;
--# end
--# property-start AspectAssoc.stable_properties_assoc_equation /tmp/lal-23.0.0/ada/ast.py:10100
pragma Warnings (Off, "is not referenced");
 function Aspect_Assoc_P_Stable_Properties_Assoc_Equation
  (Node : Bare_Aspect_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aspect_Assoc := Bare_Aspect_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aspect_Assoc :=
     Internal_Entity_Aspect_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_806 with Inline_Always;
            procedure Finalizer_Scope_1925 with Inline_Always;
            procedure Finalizer_Scope_1927 with Inline_Always;
            procedure Finalizer_Scope_1928 with Inline_Always;
            procedure Finalizer_Scope_1933 with Inline_Always;
            procedure Finalizer_Scope_1935 with Inline_Always;
      Block_Var : Internal_Entity_Identifier_Array_Access;
Match_0 : Internal_Entity_Aggregate;
Match_1 : Internal_Entity_Paren_Expr;
Match_2 : Internal_Entity_Expr;
Var_Expr : Internal_Entity_Un_Op;
Fld : Internal_Entity_Expr;
Fld_1 : Internal_Entity_Assoc_List;
Fld_2 : Bare_Assoc_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_4 : Internal_Entity_Expr;
Item_47 : Internal_Entity_Basic_Assoc;
Bare_Item_47 : Bare_Basic_Assoc;
Map_Result : Internal_Entity_Expr_Array_Access;
Fld_5 : Internal_Entity_Expr;
Singleton : Internal_Entity_Expr_Array_Access;
Singleton_1 : Internal_Entity_Expr_Array_Access;
Match_Prefix : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Aggregate;
Let_Result : Internal_Entity_Expr_Array_Access;
Scope_Result : Internal_Entity_Expr_Array_Access;
Cast_Result_1 : Internal_Entity_Paren_Expr;
Let_Result_1 : Internal_Entity_Expr_Array_Access;
Scope_Result_1 : Internal_Entity_Expr_Array_Access;
Cast_Result_2 : Internal_Entity_Expr;
Let_Result_2 : Internal_Entity_Expr_Array_Access;
Scope_Result_2 : Internal_Entity_Expr_Array_Access;
Match_Result : Internal_Entity_Expr_Array_Access;
Cast_Expr : Internal_Entity_Expr;
Cast_Result_3 : Internal_Entity_Un_Op;
Fld_6 : Internal_Entity_Expr;
Fld_7 : Internal_Entity_Op;
Is_A : Boolean;
If_Result_1 : Internal_Entity_Expr;
Scope_Result_3 : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Map_Result_1 : Internal_Entity_Expr_Array_Access;
Cast_Expr_1 : Internal_Entity_Expr;
Cast_Result_4 : Internal_Entity_Identifier;
Map_Result_2 : Internal_Entity_Identifier_Array_Access;
Fld_8 : Symbol_Type;
Fld_9 : Bare_Ada_Node;
Fld_10 : Internal_Entity_Array_Access;
Is_A_1 : Boolean;
Cast_Expr_2 : Internal_Entity;
Cast_Result_5 : Internal_Entity_Basic_Decl;
Fld_11 : Internal_Entity_Base_Subp_Spec;
Fld_12 : Boolean;
If_Result_2 : Boolean;
Map_Result_3 : Internal_Entity_Array_Access;
Fld_13 : Logic_Var;
Bind_Result : Logic_Equation;
Map_Result_4 : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Map_Result_5 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
Let_Result_3 : Logic_Equation;
            procedure Finalizer_Scope_806 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result_5);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_806;
            procedure Finalizer_Scope_1925 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1925;
            procedure Finalizer_Scope_1927 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1927;
            procedure Finalizer_Scope_1928 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_1928;
            procedure Finalizer_Scope_1933 is
            begin
                     Dec_Ref (Fld_10);
                     Dec_Ref (Map_Result_3);
                     Dec_Ref (Map_Result_4);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_1933;
            procedure Finalizer_Scope_1935 is
            begin
                     Dec_Ref (Bind_Result);
            end Finalizer_Scope_1935;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1148 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 1133 '<Map at ast.py:10120>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:10120
   --# expr-start 1131 '<Map at ast.py:10113>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:10113
   --# expr-start 1125 '<Match at ast.py:10107>' Match_Result /tmp/lal-23.0.0/ada/ast.py:10107
--# expr-start 1120 '<FieldAccess for expr at ast.py:10107>' Fld /tmp/lal-23.0.0/ada/ast.py:10107
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Aspect_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1120
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Expr (Match_Prefix.Node.Kind) is
         when Ada_Aggregate .. Ada_Bracket_Aggregate =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Aggregate
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind a Match_0
--# expr-start 1123 '<Map at ast.py:10109>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10109
   --# expr-start 1121 '<FieldAccess for assocs at ast.py:10109>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10109
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Assoc_List (Node => Match_0.Node.Base_Aggregate_F_Assocs, Info => Match_0.Info);
--# expr-done 1121
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Internal_Entity_Expr_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Expr_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_2;
      begin
         for Untyped_Item_47 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_47 := Untyped_Item_47; 
Is_Null := Bare_Item_47 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_47); 
   If_Result := As_Entity;
end if;
                  Item_47 := If_Result; 
   --# scope-start
               --# bind i Item_47
      --# expr-start 1122 '<FieldAccess for expr at ast.py:10109>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10109
      if Item_47.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_47.Node, E_Info => Item_47.Info);
--# end
--# expr-done 1122
         declare
            Item_To_Append : constant Internal_Entity_Expr := Fld_4;
         begin
            Internal_Entity_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Expr_Array
           (Items_Count => Natural (Internal_Entity_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1123
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1925;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Paren_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Paren_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind pe Match_1
--# expr-start 1124 '<FieldAccess for expr at ast.py:10111>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10111
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Match_1.Node.Paren_Expr_F_Expr, Info => Match_1.Info);
--# expr-done 1124
                Singleton := Create_Internal_Entity_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_5;
Let_Result_1 := Singleton; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1927;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Abstract_State_Decl_Expr .. Ada_Allocator | Ada_Delta_Aggregate .. Ada_Update_Attribute_Ref | Ada_Quantified_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
                Singleton_1 := Create_Internal_Entity_Expr_Array (Items_Count => 1);
                Singleton_1.Items (1) := No_Entity_Expr;
Let_Result_2 := Singleton_1; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_1928;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
end case;
--# expr-done 1125
      declare
         Map_Result_1_Vec : Internal_Entity_Expr_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Expr_Array_Access := Match_Result;
      begin
         for Item_46 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_46
--# expr-start 1126 '<Cast to UnOp at ast.py:10116>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:10116
Cast_Expr := Item_46; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Un_Op_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Un_Op
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_3 := No_Entity_Un_Op;
   end if;
--# expr-done 1126
Var_Expr := Cast_Result_3;
if Var_Expr /= No_Entity_Un_Op then
   --# scope-start
   --# bind uo Var_Expr
--# expr-start 1130 '<If at ast.py:10117>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:10117
--# expr-start 1128 '<IsA Op.Not at ast.py:10117>' Is_A /tmp/lal-23.0.0/ada/ast.py:10117
--# expr-start 1127 '<FieldAccess for op at ast.py:10117>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10117
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Op (Node => Var_Expr.Node.Un_Op_F_Op, Info => Var_Expr.Info);
--# expr-done 1127
Is_A := Fld_7.Node /= null 
and then Fld_7.Node.Kind in Ada_Op_Not_Range; 
--# expr-done 1128
if Is_A then
   --# expr-start 1129 '<FieldAccess for expr at ast.py:10117>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10117
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Un_Op_F_Expr, Info => Var_Expr.Info);
--# expr-done 1129
   If_Result_1 := Fld_6;
else
   If_Result_1 := Item_46;
end if;
--# expr-done 1130
Scope_Result_3 := If_Result_1;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := Item_46;
end if;
         declare
            Item_To_Append : constant Internal_Entity_Expr := Result_Var;
         begin
            Internal_Entity_Expr_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Expr_Array
           (Items_Count => Natural (Internal_Entity_Expr_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Expr_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Expr_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Expr_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 1131
      declare
         Map_Result_2_Vec : Internal_Entity_Identifier_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Expr_Array_Access := Map_Result_1;
      begin
         for Item_45 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_45
      --# expr-start 1132 '<Cast to Identifier at ast.py:10122>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:10122
Cast_Expr_1 := Item_45; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Identifier_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Identifier
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1132
         declare
            Item_To_Append : constant Internal_Entity_Identifier := Cast_Result_4;
         begin
            Internal_Entity_Identifier_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Identifier_Array
           (Items_Count => Natural (Internal_Entity_Identifier_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Identifier_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Identifier_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Identifier_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 1133
Block_Var := Map_Result_2; Inc_Ref (Block_Var);
--# bind identifiers Block_Var
--# expr-start 1147 '<LogicAll at ast.py:10126>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:10126
--# expr-start 1146 '<Map at ast.py:10126>' Map_Result_5 /tmp/lal-23.0.0/ada/ast.py:10126
      declare
         Map_Result_5_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Identifier_Array_Access := Block_Var;
      begin
         for Item_48 of
               Collection.Items
         loop
   --# scope-start
               --# bind i Item_48
      --# expr-start 1145 '<LogicAny at ast.py:10139>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:10139
--# expr-start 1144 '<Map at ast.py:10139>' Map_Result_4 /tmp/lal-23.0.0/ada/ast.py:10139
   --# expr-start 1141 '<Filter at ast.py:10133>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:10133
   --# expr-start 1136 '<FieldAccess for env_get at ast.py:10127>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10127
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1134 '<FieldAccess for sym at ast.py:10129>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10129
      if Item_48.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_8 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Item_48.Node);
--# end
--# expr-done 1134
--# expr-start 1135 '<FieldAccess for origin_node at ast.py:10131>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10131
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_9 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1135
--# property-call-start AdaNode.env_get
Fld_10 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Env, Symbol => Fld_8, Lookup => Recursive, From_Node => Fld_9, Categories => (Inherited_Primitives => True, Nocat => True));
--# end
--# expr-done 1136
      declare
         Map_Result_3_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_10;
      begin
         for Item_50 of
               Collection.Items
         loop
   --# scope-start
               --# bind f Item_50
--# expr-start 1137 '<IsA SubpDecl, ExprFunction at ast.py:10135>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:10135
Is_A_1 := Item_50.Node /= null 
and then Item_50.Node.Kind in Ada_Subp_Decl_Range | Ada_Expr_Function_Range; 
--# expr-done 1137
if Is_A_1 then
   --# expr-start 1140 '<FieldAccess for denotes_the_property_function at ast.py:10136>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10136
      if Item_48.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1139 '<FieldAccess for subp_spec_or_null at ast.py:10137>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10137
--# expr-start 1138 '<Cast to BasicDecl at ast.py:10137>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:10137
Cast_Expr_2 := Item_50; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_5 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_5 := No_Entity_Basic_Decl;
   end if;
--# expr-done 1138
      if Cast_Result_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result_5.Node, E_Info => Cast_Result_5.Info);
--# end
--# expr-done 1139
--# property-call-start BaseId.denotes_the_property_function
Fld_12 := Libadalang.Implementation.Base_Id_P_Denotes_The_Property_Function (Node => Item_48.Node, Subp_Spec => Fld_11, E_Info => Item_48.Info);
--# end
--# expr-done 1140
   If_Result_2 := Fld_12;
else
   If_Result_2 := False;
end if;
         if If_Result_2 then
         declare
            Item_To_Append : constant Internal_Entity := Item_50;
         begin
            Internal_Entity_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_3 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_3_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 1141
      declare
         Map_Result_4_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result_3;
      begin
         for Item_49 of
               Collection.Items
         loop
   --# scope-start
               --# bind f Item_49
      --# expr-start 1143 '<Bind at ast.py:10140>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:10140
--# expr-start 1142 '<FieldAccess for ref_var at ast.py:10140>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10140
      if Item_48.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_13 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Item_48.Node);
--# end
--# expr-done 1142
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
Bind_Result := Solver.Create_Assign (Fld_13, Item_49, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10140") else null)); 
--# expr-done 1143
         declare
            Item_To_Append : constant Logic_Equation := Bind_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_4_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1935;
         end loop;
      end;
         Map_Result_4 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_4_Vec)));
         for I in Map_Result_4.Items'Range loop
            Map_Result_4.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_4_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_4.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_4_Vec);
      end;
--# expr-done 1144
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result_4.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10139") else null)); 
--# expr-done 1145
         declare
            Item_To_Append : constant Logic_Equation := Logic_Boolean_Op;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_5_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_1933;
         end loop;
      end;
         Map_Result_5 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_5_Vec)));
         for I in Map_Result_5.Items'Range loop
            Map_Result_5.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_5_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_5.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_5_Vec);
      end;
--# expr-done 1146
Logic_Boolean_Op_1 := Solver.Create_All (Relation_Array (Map_Result_5.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10126") else null)); 
--# expr-done 1147
Let_Result_3 := Logic_Boolean_Op_1; Inc_Ref (Let_Result_3);
--# end
--# expr-done 1148
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_806;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_806;
               Finalizer_Scope_1925;
               Finalizer_Scope_1927;
               Finalizer_Scope_1928;
               Finalizer_Scope_1933;
               Finalizer_Scope_1935;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aspect_Assoc_P_Stable_Properties_Assoc_Equation;
--# end
--# property-start AspectAssoc.aspect_name /tmp/lal-23.0.0/ada/ast.py:10145
pragma Warnings (Off, "is not referenced");
 function Aspect_Assoc_P_Aspect_Name
  (Node : Bare_Aspect_Assoc
      ; N : Internal_Entity_Name
  )
   return String_Type
is
   Self : Bare_Aspect_Assoc := Bare_Aspect_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind n N
   Property_Result : String_Type;
            procedure Finalizer_Scope_807 with Inline_Always;
            procedure Finalizer_Scope_1936 with Inline_Always;
            procedure Finalizer_Scope_1937 with Inline_Always;
      Match_0 : Internal_Entity_Base_Id;
Match_1 : Internal_Entity_Attribute_Ref;
Match_2 : Internal_Entity_Name;
Fld : Symbol_Type;
Fld_1 : String_Type;
Fld_2 : Internal_Entity_Name;
Fld_3 : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Fld_4 : Internal_Entity_Identifier;
Fld_5 : Symbol_Type;
Fld_6 : String_Type;
Concat_Result_1 : String_Type;
Match_Prefix : Internal_Entity_Name;
Cast_Result : Internal_Entity_Base_Id;
Let_Result : String_Type;
Scope_Result : String_Type;
Cast_Result_1 : Internal_Entity_Attribute_Ref;
Let_Result_1 : String_Type;
Scope_Result_1 : String_Type;
Cast_Result_2 : Internal_Entity_Name;
Let_Result_2 : String_Type;
Scope_Result_2 : String_Type;
Match_Result : String_Type;
Let_Result_3 : String_Type;
            procedure Finalizer_Scope_807 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_807;
            procedure Finalizer_Scope_1936 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1936;
            procedure Finalizer_Scope_1937 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Concat_Result_1);
            end Finalizer_Scope_1937;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1160 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 1159 '<Match at ast.py:10152>' Match_Result /tmp/lal-23.0.0/ada/ast.py:10152
      if N.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := N; 
case Ada_Name (Match_Prefix.Node.Kind) is
         when Ada_Char_Literal .. Ada_String_Literal =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Base_Id
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind bid Match_0
--# expr-start 1150 '<FieldAccess for image at ast.py:10153>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10153
--# expr-start 1149 '<FieldAccess for sym at ast.py:10153>' Fld /tmp/lal-23.0.0/ada/ast.py:10153
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Match_0.Node);
--# end
--# expr-done 1149
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Image (Self => Fld);
--# expr-done 1150
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1936;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind ar Match_1
--# expr-start 1158 '<Concat at ast.py:10156>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:10156
--# expr-start 1154 '<Concat at ast.py:10155>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:10155
--# expr-start 1152 '<FieldAccess for aspect_name at ast.py:10154>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10154
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1151 '<FieldAccess for prefix at ast.py:10154>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10154
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Match_1.Node.Attribute_Ref_F_Prefix, Info => Match_1.Info);
--# expr-done 1151
--# property-call-start AspectAssoc.aspect_name
Fld_3 := Libadalang.Implementation.Aspect_Assoc_P_Aspect_Name (Node => Self, N => Fld_2);
--# end
--# expr-done 1152
--# expr-start 1153 '<String at ast.py:10155>' Str /tmp/lal-23.0.0/ada/ast.py:10155
Str := Create_String ("'"); 
--# expr-done 1153
Concat_Result := Concat_String (Fld_3, Str); 
--# expr-done 1154
--# expr-start 1157 '<FieldAccess for image at ast.py:10156>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10156
--# expr-start 1156 '<FieldAccess for sym at ast.py:10156>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10156
--# expr-start 1155 '<FieldAccess for attribute at ast.py:10156>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10156
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Match_1.Node.Attribute_Ref_F_Attribute, Info => Match_1.Info);
--# expr-done 1155
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_5 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_4.Node);
--# end
--# expr-done 1156
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Image (Self => Fld_5);
--# expr-done 1157
Concat_Result_1 := Concat_String (Concat_Result, Fld_6); 
--# expr-done 1158
Let_Result_1 := Concat_Result_1; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1937;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Call_Expr .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error with "aspect_name called on an invalid aspect name"; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
end case;
--# expr-done 1159
Let_Result_3 := Match_Result; Inc_Ref (Let_Result_3);
--# end
--# expr-done 1160
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_807;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_807;
               Finalizer_Scope_1936;
               Finalizer_Scope_1937;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aspect_Assoc_P_Aspect_Name;
--# end
--# property-start AspectAssoc.is_ghost_code /tmp/lal-23.0.0/ada/ast.py:10164
pragma Warnings (Off, "is not referenced");
 function Aspect_Assoc_P_Is_Ghost_Code
  (Node : Bare_Aspect_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Aspect_Assoc := Bare_Aspect_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aspect_Assoc :=
     Internal_Entity_Aspect_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Name;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_4 : Internal_Entity_Name;
Fld_5 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1173 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1164 '<Eq at ast.py:10168>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:10168
--# expr-start 1162 '<FieldAccess for name_symbol at ast.py:10168>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10168
--# expr-start 1161 '<FieldAccess for id at ast.py:10168>' Fld /tmp/lal-23.0.0/ada/ast.py:10168
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1161
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 1162
--# expr-start 1163 '<Symbol Pre at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre); 
--# expr-done 1163
Is_Equal := Fld_1 = Sym; 
--# expr-done 1164
if Is_Equal then
   If_Result := True;
else
   --# expr-start 1168 '<Eq at ast.py:10168>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:10168
--# expr-start 1166 '<FieldAccess for name_symbol at ast.py:10168>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10168
--# expr-start 1165 '<FieldAccess for id at ast.py:10168>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10168
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1165
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_2.Node);
--# end
--# expr-done 1166
--# expr-start 1167 '<Symbol Post at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post); 
--# expr-done 1167
Is_Equal_1 := Fld_3 = Sym_1; 
--# expr-done 1168
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 1172 '<Eq at ast.py:10168>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:10168
--# expr-start 1170 '<FieldAccess for name_symbol at ast.py:10168>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10168
--# expr-start 1169 '<FieldAccess for id at ast.py:10168>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10168
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Ent.Node.Aspect_Assoc_F_Id, Info => Ent.Info);
--# expr-done 1169
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_4.Node);
--# end
--# expr-done 1170
--# expr-start 1171 '<Symbol Contract_Cases at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 1171
Is_Equal_2 := Fld_5 = Sym_2; 
--# expr-done 1172
   If_Result_1 := Is_Equal_2;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 1173
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aspect_Assoc_P_Is_Ghost_Code;
--# end
   --
   --  Primitives for Bare_Aspect_Clause
   --
--# property-start AspectClause.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:9820
pragma Warnings (Off, "is not referenced");
 function Aspect_Clause_P_Xref_Entry_Point
  (Node : Bare_Aspect_Clause
  )
   return Boolean
is
   Self : Bare_Aspect_Clause := Bare_Aspect_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aspect_Clause_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_At_Clause
   --
      procedure Initialize_Fields_For_At_Clause
        (Self : Bare_At_Clause
         ; At_Clause_F_Name : Bare_Base_Id
         ; At_Clause_F_Expr : Bare_Expr
        ) is
      begin
            Self.At_Clause_F_Name := At_Clause_F_Name;
            Self.At_Clause_F_Expr := At_Clause_F_Expr;
      end Initialize_Fields_For_At_Clause;
   function At_Clause_F_Name
     (Node : Bare_At_Clause) return Bare_Base_Id
   is
   begin
         return Node.At_Clause_F_Name;
   end;
   function At_Clause_F_Expr
     (Node : Bare_At_Clause) return Bare_Expr
   is
   begin
         return Node.At_Clause_F_Expr;
   end;
--# property-start AtClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:9953
pragma Warnings (Off, "is not referenced");
 function At_Clause_P_Xref_Equation
  (Node : Bare_At_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_At_Clause := Bare_At_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_At_Clause :=
     Internal_Entity_At_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_793 with Inline_Always;
      Fld : Internal_Entity_Base_Id;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_793 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_793;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1179 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1178 '<And at ast.py:9954>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9954
--# expr-start 1175 '<FieldAccess for sub_equation at ast.py:9954>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9954
--# expr-start 1174 '<FieldAccess for name at ast.py:9954>' Fld /tmp/lal-23.0.0/ada/ast.py:9954
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Base_Id (Node => Ent.Node.At_Clause_F_Name, Info => Ent.Info);
--# expr-done 1174
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 1175
--# expr-start 1177 '<FieldAccess for sub_equation at ast.py:9954>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9954
--# expr-start 1176 '<FieldAccess for expr at ast.py:9954>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9954
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.At_Clause_F_Expr, Info => Ent.Info);
--# expr-done 1176
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 1177
And_Pred := Create_And (Fld_1, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9954") else null)); 
--# expr-done 1178
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 1179
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_793;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_793;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end At_Clause_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Attribute_Def_Clause
   --
      procedure Initialize_Fields_For_Attribute_Def_Clause
        (Self : Bare_Attribute_Def_Clause
         ; Attribute_Def_Clause_F_Attribute_Expr : Bare_Name
         ; Attribute_Def_Clause_F_Expr : Bare_Expr
        ) is
      begin
            Self.Attribute_Def_Clause_F_Attribute_Expr := Attribute_Def_Clause_F_Attribute_Expr;
            Self.Attribute_Def_Clause_F_Expr := Attribute_Def_Clause_F_Expr;
      end Initialize_Fields_For_Attribute_Def_Clause;
   function Attribute_Def_Clause_F_Attribute_Expr
     (Node : Bare_Attribute_Def_Clause) return Bare_Name
   is
   begin
         return Node.Attribute_Def_Clause_F_Attribute_Expr;
   end;
   function Attribute_Def_Clause_F_Expr
     (Node : Bare_Attribute_Def_Clause) return Bare_Expr
   is
   begin
         return Node.Attribute_Def_Clause_F_Expr;
   end;
--# property-start AttributeDefClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:9865
pragma Warnings (Off, "is not referenced");
 function Attribute_Def_Clause_P_Xref_Equation
  (Node : Bare_Attribute_Def_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Def_Clause := Bare_Attribute_Def_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Def_Clause :=
     Internal_Entity_Attribute_Def_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_789 with Inline_Always;
            procedure Finalizer_Scope_1939 with Inline_Always;
      Block_Var : Internal_Entity_Attribute_Ref;
Block_Var_1 : Symbol_Type;
Var_Expr : Internal_Entity_Attribute_Ref;
Fld : Internal_Entity_Name;
Cast_Result : Internal_Entity_Attribute_Ref;
Fld_1 : Internal_Entity_Identifier;
Fld_2 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_3 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_4 : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity_Name;
Fld_6 : Logic_Var;
Fld_7 : Internal_Entity_Name;
Fld_8 : Internal_Entity_Base_Type_Decl;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
Pred : Logic_Equation;
And_Pred : Logic_Equation;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
Fld_9 : Internal_Entity_Expr;
Cast_Result_3 : Internal_Entity_Name;
Fld_10 : Logic_Equation;
Fld_11 : Internal_Entity_Expr;
Cast_Result_4 : Internal_Entity_Name;
Fld_12 : Logic_Var;
Fld_13 : Internal_Entity_Name;
Fld_14 : Internal_Entity_Base_Type_Decl;
Pred_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_15 : Internal_Entity_Expr;
Fld_16 : Logic_Equation;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
Fld_17 : Bare_Expr;
Fld_18 : Logic_Var;
Sym_7 : Symbol_Type;
Fld_19 : Internal_Entity;
Bind_Result : Logic_Equation;
True_Rel : Logic_Equation;
If_Result_3 : Logic_Equation;
And_Pred_2 : Logic_Equation;
If_Result_4 : Logic_Equation;
If_Result_5 : Logic_Equation;
Fld_20 : Internal_Entity_Name;
Fld_21 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_789 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Pred_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_789;
            procedure Finalizer_Scope_1939 is
            begin
                     Dec_Ref (Fld_21);
            end Finalizer_Scope_1939;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1231 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1181 '<Cast to AttributeRef at ast.py:9866>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9866
--# expr-start 1180 '<FieldAccess for attribute_expr at ast.py:9866>' Fld /tmp/lal-23.0.0/ada/ast.py:9866
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Def_Clause_F_Attribute_Expr, Info => Ent.Info);
--# expr-done 1180
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result := Create_Internal_Entity_Attribute_Ref
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1181
Block_Var := Cast_Result; 
--# bind attr Block_Var
--# expr-start 1183 '<FieldAccess for name_symbol at ast.py:9867>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9867
--# expr-start 1182 '<FieldAccess for attribute at ast.py:9867>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9867
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Identifier (Node => Block_Var.Node.Attribute_Ref_F_Attribute, Info => Block_Var.Info);
--# expr-done 1182
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_1.Node);
--# end
--# expr-done 1183
Block_Var_1 := Fld_2; 
--# bind rel_name Block_Var_1
--# expr-start 1230 '<And at ast.py:9869>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:9869
--# expr-start 1227 '<Cond at ast.py:9869>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:9869
--# expr-start 1185 '<Eq at ast.py:9870>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9870
--# expr-start 1184 '<Symbol Read at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Read); 
--# expr-done 1184
Is_Equal := Block_Var_1 = Sym; 
--# expr-done 1185
if Is_Equal then
   If_Result := True;
else
   --# expr-start 1187 '<Eq at ast.py:9870>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9870
--# expr-start 1186 '<Symbol Write at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Write); 
--# expr-done 1186
Is_Equal_1 := Block_Var_1 = Sym_1; 
--# expr-done 1187
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 1189 '<Eq at ast.py:9870>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:9870
--# expr-start 1188 '<Symbol Input at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Input); 
--# expr-done 1188
Is_Equal_2 := Block_Var_1 = Sym_2; 
--# expr-done 1189
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 1191 '<Eq at ast.py:9870>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:9870
--# expr-start 1190 '<Symbol Output at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Output); 
--# expr-done 1190
Is_Equal_3 := Block_Var_1 = Sym_3; 
--# expr-done 1191
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   --# expr-start 1203 '<And at ast.py:9871>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9871
--# expr-start 1194 '<FieldAccess for xref_no_overloading at ast.py:9871>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9871
--# expr-start 1193 '<Cast to Name at ast.py:9871>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9871
--# expr-start 1192 '<FieldAccess for expr at ast.py:9871>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9871
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Attribute_Def_Clause_F_Expr, Info => Ent.Info);
--# expr-done 1192
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1193
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_4 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_1.Node, Env => Env, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 1194
--# expr-start 1202 '<Predicate on BasicDecl.is_stream_subprogram_for_type at ast.py:9872>' Pred /tmp/lal-23.0.0/ada/ast.py:9872
--# expr-start 1197 '<FieldAccess for ref_var at ast.py:9874>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9874
--# expr-start 1196 '<Cast to Name at ast.py:9874>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:9874
--# expr-start 1195 '<FieldAccess for expr at ast.py:9874>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9874
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Attribute_Def_Clause_F_Expr, Info => Ent.Info);
--# expr-done 1195
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Name
   then
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_2 := No_Entity_Name;
   end if;
--# expr-done 1196
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Cast_Result_2.Node);
--# end
--# expr-done 1197
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 1199 '<FieldAccess for name_designated_type at ast.py:9875>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9875
--# expr-start 1198 '<FieldAccess for prefix at ast.py:9875>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9875
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Block_Var.Node.Attribute_Ref_F_Prefix, Info => Block_Var.Info);
--# expr-done 1198
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_8 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 1199
--# expr-start 1201 '<Eq at ast.py:9876>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:9876
--# expr-start 1200 '<Symbol Input at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Input); 
--# expr-done 1200
Is_Equal_4 := Block_Var_1 = Sym_4; 
--# expr-done 1201
Pred := Solver.Create_Predicate (Fld_6, Create_Basic_Decl_P_Is_Stream_Subprogram_For_Type_0_Predicate (Fld_8, Is_Equal_4)); 
--# expr-done 1202
And_Pred := Create_And (Fld_4, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9871") else null)); 
--# expr-done 1203
   If_Result_5 := And_Pred;
else
--# expr-start 1205 '<Eq at ast.py:9879>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:9879
--# expr-start 1204 '<Symbol Put_Image at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image); 
--# expr-done 1204
Is_Equal_5 := Block_Var_1 = Sym_5; 
--# expr-done 1205
if Is_Equal_5 then
   --# expr-start 1215 '<And at ast.py:9880>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:9880
--# expr-start 1208 '<FieldAccess for xref_no_overloading at ast.py:9880>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9880
--# expr-start 1207 '<Cast to Name at ast.py:9880>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:9880
--# expr-start 1206 '<FieldAccess for expr at ast.py:9880>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9880
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Expr (Node => Ent.Node.Attribute_Def_Clause_F_Expr, Info => Ent.Info);
--# expr-done 1206
   if Fld_9.Node = null
      or else Fld_9.Node.Kind in Ada_Name
   then
      Cast_Result_3 := Create_Internal_Entity_Name
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1207
      if Cast_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_10 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_3.Node, All_Els => True, Env => Env, Origin => Origin, E_Info => Cast_Result_3.Info);
--# end
--# expr-done 1208
--# expr-start 1214 '<Predicate on BasicDecl.is_put_image_subprogram_for_type at ast.py:9881>' Pred_1 /tmp/lal-23.0.0/ada/ast.py:9881
--# expr-start 1211 '<FieldAccess for ref_var at ast.py:9883>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9883
--# expr-start 1210 '<Cast to Name at ast.py:9883>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:9883
--# expr-start 1209 '<FieldAccess for expr at ast.py:9883>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9883
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Expr (Node => Ent.Node.Attribute_Def_Clause_F_Expr, Info => Ent.Info);
--# expr-done 1209
   if Fld_11.Node = null
      or else Fld_11.Node.Kind in Ada_Name
   then
      Cast_Result_4 := Create_Internal_Entity_Name
        (Node => Fld_11.Node,
         Info => Fld_11.Info);
   else
         Cast_Result_4 := No_Entity_Name;
   end if;
--# expr-done 1210
      if Cast_Result_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_12 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Cast_Result_4.Node);
--# end
--# expr-done 1211
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
--# expr-start 1213 '<FieldAccess for name_designated_type at ast.py:9884>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:9884
--# expr-start 1212 '<FieldAccess for prefix at ast.py:9884>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9884
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Name (Node => Block_Var.Node.Attribute_Ref_F_Prefix, Info => Block_Var.Info);
--# expr-done 1212
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_14 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_13.Node, E_Info => Fld_13.Info);
--# end
--# expr-done 1213
Pred_1 := Solver.Create_Predicate (Fld_12, Create_Basic_Decl_P_Is_Put_Image_Subprogram_For_Type_0_Predicate (Fld_14)); 
--# expr-done 1214
And_Pred_1 := Create_And (Fld_10, Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9880") else null)); 
--# expr-done 1215
   If_Result_4 := And_Pred_1;
else
   --# expr-start 1226 '<And at ast.py:9887>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:9887
--# expr-start 1217 '<FieldAccess for sub_equation at ast.py:9887>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:9887
--# expr-start 1216 '<FieldAccess for expr at ast.py:9887>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:9887
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Expr (Node => Ent.Node.Attribute_Def_Clause_F_Expr, Info => Ent.Info);
--# expr-done 1216
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_16 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_15.Node, Env => Env, Origin => Origin, E_Info => Fld_15.Info);
--# end
--# expr-done 1217
--# expr-start 1225 '<Cond at ast.py:9887>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:9887
--# expr-start 1219 '<Eq at ast.py:9888>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:9888
--# expr-start 1218 '<Symbol External_Tag at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_External_Tag); 
--# expr-done 1218
Is_Equal_6 := Block_Var_1 = Sym_6; 
--# expr-done 1219
if Is_Equal_6 then
   --# expr-start 1224 '<Bind at ast.py:9889>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:9889
--# expr-start 1221 '<FieldAccess for expected_type_var at ast.py:9889>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:9889
--# expr-start 1220 '<FieldAccess for expr at ast.py:9889>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:9889
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Self.Attribute_Def_Clause_F_Expr;
--# expr-done 1220
      if Fld_17 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_17);
--# expr-done 1221
Fld_18.Value := No_Entity;
Entity_Vars.Reset (Fld_18);
--# expr-start 1223 '<FieldAccess for std_entity at ast.py:9889>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:9889
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1222 '<Symbol String at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 1222
--# property-call-start AdaNode.std_entity
Fld_19 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_7);
--# end
--# expr-done 1223
Bind_Result := Solver.Create_Assign (Fld_18, Fld_19, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9889") else null)); 
--# expr-done 1224
   If_Result_3 := Bind_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9891") else null)); 
   If_Result_3 := True_Rel;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 1225
And_Pred_2 := Create_And (Fld_16, If_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9887") else null)); 
--# expr-done 1226
   If_Result_4 := And_Pred_2;
end if;
      Inc_Ref (If_Result_4);
   If_Result_5 := If_Result_4;
end if;
      Inc_Ref (If_Result_5);
--# expr-done 1227
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Attribute_Ref then
   --# scope-start
   --# bind ar Var_Expr
--# expr-start 1229 '<FieldAccess for sub_equation at ast.py:9894>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:9894
--# expr-start 1228 '<FieldAccess for prefix at ast.py:9894>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:9894
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Attribute_Ref_F_Prefix, Info => Var_Expr.Info);
--# expr-done 1228
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_21 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_20.Node, Env => Env, Origin => Origin, E_Info => Fld_20.Info);
--# end
--# expr-done 1229
Scope_Result := Fld_21;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1939;
   Result_Var := Scope_Result;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9894") else null)); 
   Result_Var := True_Rel_1;
end if;
      Inc_Ref (Result_Var);
And_Pred_3 := Create_And (If_Result_5, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9869") else null)); 
--# expr-done 1230
Let_Result := And_Pred_3; Inc_Ref (Let_Result);
--# end
--# expr-done 1231
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_789;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_789;
               Finalizer_Scope_1939;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Def_Clause_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Enum_Rep_Clause
   --
      procedure Initialize_Fields_For_Enum_Rep_Clause
        (Self : Bare_Enum_Rep_Clause
         ; Enum_Rep_Clause_F_Type_Name : Bare_Name
         ; Enum_Rep_Clause_F_Aggregate : Bare_Base_Aggregate
        ) is
      begin
            Self.Enum_Rep_Clause_F_Type_Name := Enum_Rep_Clause_F_Type_Name;
            Self.Enum_Rep_Clause_F_Aggregate := Enum_Rep_Clause_F_Aggregate;
      end Initialize_Fields_For_Enum_Rep_Clause;
   function Enum_Rep_Clause_F_Type_Name
     (Node : Bare_Enum_Rep_Clause) return Bare_Name
   is
   begin
         return Node.Enum_Rep_Clause_F_Type_Name;
   end;
   function Enum_Rep_Clause_F_Aggregate
     (Node : Bare_Enum_Rep_Clause) return Bare_Base_Aggregate
   is
   begin
         return Node.Enum_Rep_Clause_F_Aggregate;
   end;
--# property-start EnumRepClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:9831
pragma Warnings (Off, "is not referenced");
 function Enum_Rep_Clause_P_Xref_Equation
  (Node : Bare_Enum_Rep_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Enum_Rep_Clause := Bare_Enum_Rep_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Rep_Clause :=
     Internal_Entity_Enum_Rep_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_787 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_787 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_787;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1234 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1233 '<FieldAccess for xref_no_overloading at ast.py:9833>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9833
--# expr-start 1232 '<FieldAccess for type_name at ast.py:9833>' Fld /tmp/lal-23.0.0/ada/ast.py:9833
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Enum_Rep_Clause_F_Type_Name, Info => Ent.Info);
--# expr-done 1232
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 1233
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1234
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_787;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_787;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Rep_Clause_P_Xref_Equation;
--# end
--# property-start EnumRepClause.params /tmp/lal-23.0.0/ada/ast.py:9836
pragma Warnings (Off, "is not referenced");
 function Enum_Rep_Clause_P_Params
  (Node : Bare_Enum_Rep_Clause
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Actual_Array_Access
is
   Self : Bare_Enum_Rep_Clause := Bare_Enum_Rep_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Rep_Clause :=
     Internal_Entity_Enum_Rep_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_788 with Inline_Always;
      Block_Var : Internal_Entity_Enum_Literal_Decl_List;
Block_Var_1 : Internal_Entity_Assoc_List;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Type_Decl;
Fld_3 : Internal_Entity_Type_Def;
Cast_Result_2 : Internal_Entity_Enum_Type_Def;
Fld_4 : Internal_Entity_Enum_Literal_Decl_List;
Fld_5 : Internal_Entity_Base_Aggregate;
Fld_6 : Internal_Entity_Assoc_List;
Saved : Internal_Entity_Enum_Literal_Decl_List;
Fld_7 : Bare_Enum_Literal_Decl_List;
Fld_8 : Internal_Entity_Info;
As_Entity : Internal_Entity_Enum_Literal_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Enum_Literal_Decl;
Fld_9 : Internal_Entity_Defining_Name;
Fld_10 : Internal_Entity_Defining_Name;
Fld_11 : Internal_Entity_Expr;
New_Struct : Internal_Param_Actual;
Item_51 : Internal_Entity_Enum_Literal_Decl;
Bare_Item_51 : Bare_Enum_Literal_Decl;
Index_52 : Integer;
Map_Result : Internal_Param_Actual_Array_Access;
Let_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_788 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_788;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1250 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1242 '<FieldAccess for enum_literals at ast.py:9844>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9844
--# expr-start 1241 '<Cast to EnumTypeDef at ast.py:9843>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:9843
--# expr-start 1240 '<FieldAccess for type_def at ast.py:9843>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9843
--# expr-start 1239 '<Cast to TypeDecl at ast.py:9843>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9843
--# expr-start 1238 '<FieldAccess for root_type at ast.py:9843>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9843
--# expr-start 1237 '<Cast to BaseTypeDecl at ast.py:9842>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9842
--# expr-start 1236 '<FieldAccess for referenced_decl at ast.py:9842>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9842
--# expr-start 1235 '<FieldAccess for type_name at ast.py:9842>' Fld /tmp/lal-23.0.0/ada/ast.py:9842
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Enum_Rep_Clause_F_Type_Name, Info => Ent.Info);
--# expr-done 1235
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_1 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld.Node, Imprecise_Fallback => False, E_Info => Fld.Info);
--# end
--# expr-done 1236
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 1237
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.root_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Root_Type (Node => Cast_Result.Node, Origin => No_Bare_Ada_Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 1238
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Type_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result_1 := No_Entity_Type_Decl;
   end if;
--# expr-done 1239
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Type_Def (Node => Cast_Result_1.Node.Type_Decl_F_Type_Def, Info => Cast_Result_1.Info);
--# expr-done 1240
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Enum_Type_Def_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Enum_Type_Def
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result_2 := No_Entity_Enum_Type_Def;
   end if;
--# expr-done 1241
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Enum_Literal_Decl_List (Node => Cast_Result_2.Node.Enum_Type_Def_F_Enum_Literals, Info => Cast_Result_2.Info);
--# expr-done 1242
Block_Var := Fld_4; 
--# bind el Block_Var
--# expr-start 1244 '<FieldAccess for assocs at ast.py:9846>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9846
--# expr-start 1243 '<FieldAccess for aggregate at ast.py:9846>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9846
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Base_Aggregate (Node => Ent.Node.Enum_Rep_Clause_F_Aggregate, Info => Ent.Info);
--# expr-done 1243
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Assoc_List (Node => Fld_5.Node.Base_Aggregate_F_Assocs, Info => Fld_5.Info);
--# expr-done 1244
Block_Var_1 := Fld_6; 
--# bind ra Block_Var_1
--# expr-start 1249 '<Map at ast.py:9848>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9848
Saved := Block_Var; 
Fld_7 := Saved.Node;
      declare
         Map_Result_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      if Fld_7 = null then
      Map_Result := Create_Internal_Param_Actual_Array (0);
      else
         Index_52 := 0;
      declare
         Collection : constant Bare_Enum_Literal_Decl_List := Fld_7;
      begin
         for Untyped_Item_51 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_51 := Untyped_Item_51; 
Is_Null := Bare_Item_51 = null; 
if Is_Null then
   If_Result := No_Entity_Enum_Literal_Decl;
else
Fld_8 := Saved.Info;
As_Entity := (Info => Fld_8, Node => Bare_Item_51); 
   If_Result := As_Entity;
end if;
                  Item_51 := If_Result; 
   --# scope-start
               --# bind l Item_51
               --# bind i Index_52
      --# expr-start 1248 '<New ParamActual at ast.py:9849>' New_Struct /tmp/lal-23.0.0/ada/ast.py:9849
--# expr-start 1246 '<FieldAccess for actual_for_param_at at ast.py:9851>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9851
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1245 '<FieldAccess for name at ast.py:9851>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9851
      if Item_51.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Defining_Name (Node => Item_51.Node.Enum_Literal_Decl_F_Name, Info => Item_51.Info);
--# expr-done 1245
--# property-call-start AssocList.actual_for_param_at
Fld_11 := Libadalang.Implementation.Assoc_List_P_Actual_For_Param_At (Node => Block_Var_1.Node, Param => Fld_10, Pos => Index_52, E_Info => Block_Var_1.Info);
--# end
--# expr-done 1246
--# expr-start 1247 '<FieldAccess for name at ast.py:9850>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9850
      if Item_51.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Defining_Name (Node => Item_51.Node.Enum_Literal_Decl_F_Name, Info => Item_51.Info);
--# expr-done 1247
New_Struct := (Actual => Fld_11, Param => Fld_9); 
--# expr-done 1248
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
               Index_52 := Index_52 + 1;
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1249
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 1250
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_788;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_788;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Rep_Clause_P_Params;
--# end
   --
   --  Primitives for Bare_Record_Rep_Clause
   --
      procedure Initialize_Fields_For_Record_Rep_Clause
        (Self : Bare_Record_Rep_Clause
         ; Record_Rep_Clause_F_Name : Bare_Name
         ; Record_Rep_Clause_F_At_Expr : Bare_Expr
         ; Record_Rep_Clause_F_Components : Bare_Ada_Node_List
        ) is
      begin
            Self.Record_Rep_Clause_F_Name := Record_Rep_Clause_F_Name;
            Self.Record_Rep_Clause_F_At_Expr := Record_Rep_Clause_F_At_Expr;
            Self.Record_Rep_Clause_F_Components := Record_Rep_Clause_F_Components;
      end Initialize_Fields_For_Record_Rep_Clause;
   function Record_Rep_Clause_F_Name
     (Node : Bare_Record_Rep_Clause) return Bare_Name
   is
   begin
         return Node.Record_Rep_Clause_F_Name;
   end;
   function Record_Rep_Clause_F_At_Expr
     (Node : Bare_Record_Rep_Clause) return Bare_Expr
   is
   begin
         return Node.Record_Rep_Clause_F_At_Expr;
   end;
   function Record_Rep_Clause_F_Components
     (Node : Bare_Record_Rep_Clause) return Bare_Ada_Node_List
   is
   begin
         return Node.Record_Rep_Clause_F_Components;
   end;
--# property-start RecordRepClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:9935
pragma Warnings (Off, "is not referenced");
 function Record_Rep_Clause_P_Xref_Equation
  (Node : Bare_Record_Rep_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Record_Rep_Clause := Bare_Record_Rep_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Record_Rep_Clause :=
     Internal_Entity_Record_Rep_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_792 with Inline_Always;
            procedure Finalizer_Scope_1941 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_792 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_792;
            procedure Finalizer_Scope_1941 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_1941;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1256 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1255 '<And at ast.py:9936>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9936
--# expr-start 1252 '<FieldAccess for xref_no_overloading at ast.py:9937>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9937
--# expr-start 1251 '<FieldAccess for name at ast.py:9937>' Fld /tmp/lal-23.0.0/ada/ast.py:9937
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Record_Rep_Clause_F_Name, Info => Ent.Info);
--# expr-done 1251
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 1252
--# expr-start 1253 '<FieldAccess for at_expr at ast.py:9938>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9938
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Record_Rep_Clause_F_At_Expr, Info => Ent.Info);
--# expr-done 1253
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 1254 '<FieldAccess for sub_equation at ast.py:9939>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9939
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1254
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1941;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9940") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9936") else null)); 
--# expr-done 1255
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 1256
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_792;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_792;
               Finalizer_Scope_1941;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Record_Rep_Clause_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Aspect_Spec
   --
      procedure Initialize_Fields_For_Aspect_Spec
        (Self : Bare_Aspect_Spec
         ; Aspect_Spec_F_Aspect_Assocs : Bare_Aspect_Assoc_List
        ) is
      begin
            Self.Aspect_Spec_F_Aspect_Assocs := Aspect_Spec_F_Aspect_Assocs;
      end Initialize_Fields_For_Aspect_Spec;
   function Aspect_Spec_F_Aspect_Assocs
     (Node : Bare_Aspect_Spec) return Bare_Aspect_Assoc_List
   is
   begin
         return Node.Aspect_Spec_F_Aspect_Assocs;
   end;
   --
   --  Primitives for Bare_Base_Assoc
   --
--# property-start '[dispatcher]BaseAssoc.assoc_expr' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Assoc_P_Assoc_Expr
  (Node : Bare_Base_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Base_Assoc := Bare_Base_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Assoc (Self.Kind) is
               when Ada_Contract_Case_Assoc =>
                  --# property-call-start ContractCaseAssoc.assoc_expr
                  Property_Result := Contract_Case_Assoc_P_Assoc_Expr
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Pragma_Argument_Assoc =>
                  --# property-call-start PragmaArgumentAssoc.assoc_expr
                  Property_Result := Pragma_Argument_Assoc_P_Assoc_Expr
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Assoc_P_Assoc_Expr;
--# end
   --
   --  Primitives for Bare_Contract_Case_Assoc
   --
      procedure Initialize_Fields_For_Contract_Case_Assoc
        (Self : Bare_Contract_Case_Assoc
         ; Contract_Case_Assoc_F_Guard : Bare_Ada_Node
         ; Contract_Case_Assoc_F_Consequence : Bare_Expr
        ) is
      begin
            Self.Contract_Case_Assoc_F_Guard := Contract_Case_Assoc_F_Guard;
            Self.Contract_Case_Assoc_F_Consequence := Contract_Case_Assoc_F_Consequence;
      end Initialize_Fields_For_Contract_Case_Assoc;
   function Contract_Case_Assoc_F_Guard
     (Node : Bare_Contract_Case_Assoc) return Bare_Ada_Node
   is
   begin
         return Node.Contract_Case_Assoc_F_Guard;
   end;
   function Contract_Case_Assoc_F_Consequence
     (Node : Bare_Contract_Case_Assoc) return Bare_Expr
   is
   begin
         return Node.Contract_Case_Assoc_F_Consequence;
   end;
--# property-start ContractCaseAssoc.assoc_expr /tmp/lal-23.0.0/ada/ast.py:12102
pragma Warnings (Off, "is not referenced");
 function Contract_Case_Assoc_P_Assoc_Expr
  (Node : Bare_Contract_Case_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Contract_Case_Assoc := Bare_Contract_Case_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Contract_Case_Assoc :=
     Internal_Entity_Contract_Case_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Fld : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1257 '<FieldAccess for consequence at ast.py:12102>' Fld /tmp/lal-23.0.0/ada/ast.py:12102
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Contract_Case_Assoc_F_Consequence, Info => Ent.Info);
--# expr-done 1257
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Contract_Case_Assoc_P_Assoc_Expr;
--# end
   --
   --  Primitives for Bare_Pragma_Argument_Assoc
   --
      procedure Initialize_Fields_For_Pragma_Argument_Assoc
        (Self : Bare_Pragma_Argument_Assoc
         ; Pragma_Argument_Assoc_F_Name : Bare_Name
         ; Pragma_Argument_Assoc_F_Expr : Bare_Expr
        ) is
      begin
            Self.Pragma_Argument_Assoc_F_Name := Pragma_Argument_Assoc_F_Name;
            Self.Pragma_Argument_Assoc_F_Expr := Pragma_Argument_Assoc_F_Expr;
      end Initialize_Fields_For_Pragma_Argument_Assoc;
   function Pragma_Argument_Assoc_F_Name
     (Node : Bare_Pragma_Argument_Assoc) return Bare_Name
   is
   begin
         return Node.Pragma_Argument_Assoc_F_Name;
   end;
   function Pragma_Argument_Assoc_F_Expr
     (Node : Bare_Pragma_Argument_Assoc) return Bare_Expr
   is
   begin
         return Node.Pragma_Argument_Assoc_F_Expr;
   end;
--# property-start PragmaArgumentAssoc.assoc_expr /tmp/lal-23.0.0/ada/ast.py:9812
pragma Warnings (Off, "is not referenced");
 function Pragma_Argument_Assoc_P_Assoc_Expr
  (Node : Bare_Pragma_Argument_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Pragma_Argument_Assoc := Bare_Pragma_Argument_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Argument_Assoc :=
     Internal_Entity_Pragma_Argument_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Fld : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1258 '<FieldAccess for expr at ast.py:9812>' Fld /tmp/lal-23.0.0/ada/ast.py:9812
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Pragma_Argument_Assoc_F_Expr, Info => Ent.Info);
--# expr-done 1258
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Argument_Assoc_P_Assoc_Expr;
--# end
   --
   --  Primitives for Bare_Base_Formal_Param_Holder
   --
--# property-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params
  (Node : Bare_Base_Formal_Param_Holder
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Formal_Param_Holder (Self.Kind) is
               when Ada_Entry_Spec .. Ada_Subp_Spec =>
                  --# property-call-start BaseSubpSpec.abstract_formal_params
                  Property_Result := Base_Subp_Spec_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Binary_Spec =>
                  --# property-call-start SyntheticBinarySpec.abstract_formal_params
                  Property_Result := Synthetic_Binary_Spec_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Unary_Spec =>
                  --# property-call-start SyntheticUnarySpec.abstract_formal_params
                  Property_Result := Synthetic_Unary_Spec_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Component_List =>
                  --# property-call-start ComponentList.abstract_formal_params
                  Property_Result := Component_List_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Unknown_Discriminant_Part =>
                  --# property-call-start DiscriminantPart.abstract_formal_params
                  Property_Result := Discriminant_Part_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Known_Discriminant_Part =>
                  --# property-call-start KnownDiscriminantPart.abstract_formal_params
                  Property_Result := Known_Discriminant_Part_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Completion_Formal_Params =>
                  --# property-call-start EntryCompletionFormalParams.abstract_formal_params
                  Property_Result := Entry_Completion_Formal_Params_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Formal_Part =>
                  --# property-call-start GenericFormalPart.abstract_formal_params
                  Property_Result := Generic_Formal_Part_P_Abstract_Formal_Params
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params;
--# end
--# property-start BaseFormalParamHolder.unpacked_formal_params /tmp/lal-23.0.0/ada/ast.py:4097
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Unpacked_Formal_Params
  (Node : Bare_Base_Formal_Param_Holder
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_259 with Inline_Always;
      Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_259 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_259;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1260 '<FieldAccess for unpack_formals at ast.py:4098>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4098
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1259 '<FieldAccess for abstract_formal_params at ast.py:4098>' Fld /tmp/lal-23.0.0/ada/ast.py:4098
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1259
--# property-call-start AdaNode.unpack_formals
Fld_1 := Libadalang.Implementation.Ada_Node_P_Unpack_Formals (Node => Self, Formal_Params => Fld);
--# end
--# expr-done 1260
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_259;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_259;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Unpacked_Formal_Params;
--# end
--# property-start BaseFormalParamHolder.formal_params /tmp/lal-23.0.0/ada/ast.py:4105
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Formal_Params
  (Node : Bare_Base_Formal_Param_Holder
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_260 with Inline_Always;
            procedure Finalizer_Scope_1942 with Inline_Always;
            procedure Finalizer_Scope_1944 with Inline_Always;
      Match_0 : Internal_Entity_Component_List;
Match_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_53 : Internal_Entity;
Bare_Item_53 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_3 : Internal_Entity_Defining_Name_Array_Access;
Fld_4 : Internal_Entity_Defining_Name_Array_Access;
Match_Prefix : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result_1 : Internal_Entity_Component_List;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Cast_Result_2 : Internal_Entity_Base_Formal_Param_Holder;
Let_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Scope_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Match_Result : Internal_Entity_Defining_Name_Array_Access;
Let_Result_2 : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_260 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_260;
            procedure Finalizer_Scope_1942 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_1942;
            procedure Finalizer_Scope_1944 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_1944;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1268 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 1267 '<Match at ast.py:4111>' Match_Result /tmp/lal-23.0.0/ada/ast.py:4111
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Base_Formal_Param_Holder (Match_Prefix.Node.Kind) is
         when Ada_Component_List =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Component_List
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind r Match_0
--# expr-start 1265 '<FieldAccess for unpack_formals at ast.py:4113>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4113
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1264 '<FilterMap at ast.py:4113>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4113
   --# expr-start 1261 '<FieldAccess for components at ast.py:4113>' Fld /tmp/lal-23.0.0/ada/ast.py:4113
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Match_0.Node.Component_List_F_Components, Info => Match_0.Info);
--# expr-done 1261
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_53 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_53 := Untyped_Item_53; 
Is_Null := Bare_Item_53 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_53); 
   If_Result := As_Entity;
end if;
                  Item_53 := If_Result; 
   --# scope-start
               --# bind e Item_53
         --# expr-start 1262 '<IsA BaseFormalParamDecl at ???>' Is_A None
Is_A := Item_53.Node /= null 
and then Item_53.Node.Kind in Ada_Base_Formal_Param_Decl; 
--# expr-done 1262
         if Is_A then
      --# expr-start 1263 '<Cast to BaseFormalParamDecl at ???>' Cast_Result None
Cast_Expr := Item_53; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Formal_Param_Decl;
   end if;
--# expr-done 1263
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1264
--# property-call-start AdaNode.unpack_formals
Fld_3 := Libadalang.Implementation.Ada_Node_P_Unpack_Formals (Node => Self, Formal_Params => Map_Result);
--# end
--# expr-done 1265
Let_Result := Fld_3; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1942;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Entry_Spec .. Ada_Synthetic_Unary_Spec | Ada_Known_Discriminant_Part .. Ada_Generic_Formal_Part =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind _ Match_1
--# expr-start 1266 '<FieldAccess for unpacked_formal_params at ast.py:4114>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4114
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1266
Let_Result_1 := Fld_4; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1944;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
end case;
--# expr-done 1267
Let_Result_2 := Match_Result; Inc_Ref (Let_Result_2);
--# end
--# expr-done 1268
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_260;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_260;
               Finalizer_Scope_1942;
               Finalizer_Scope_1944;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Formal_Params;
--# end
--# property-start BaseFormalParamHolder.match_param_list /tmp/lal-23.0.0/ada/ast.py:4118
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Match_Param_List
  (Node : Bare_Base_Formal_Param_Holder
      ; Params : Internal_Entity_Assoc_List
      ; Is_Dottable_Subp : Boolean
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Match_Array_Access
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind params Params
   --# bind is_dottable_subp Is_Dottable_Subp
   --# bind env Env
   Property_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_261 with Inline_Always;
      Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_1 : Internal_Param_Match_Array_Access;
Let_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_261 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_261;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1271 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1270 '<FieldAccess for match_formals at ast.py:4120>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4120
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1269 '<FieldAccess for abstract_formal_params at ast.py:4121>' Fld /tmp/lal-23.0.0/ada/ast.py:4121
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1269
--# property-call-start AdaNode.match_formals
Fld_1 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Fld, Params => Params, Is_Dottable_Subp => Is_Dottable_Subp);
--# end
--# expr-done 1270
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1271
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_261;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_261;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Match_Param_List;
--# end
--# property-start BaseFormalParamHolder.nb_min_params /tmp/lal-23.0.0/ada/ast.py:4124
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Nb_Min_Params
  (Node : Bare_Base_Formal_Param_Holder
  )
   return Integer
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Integer;
            procedure Finalizer_Scope_262 with Inline_Always;
      As_Entity : Internal_Entity_Base_Formal_Param_Holder;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Formal_Param_Holder;
Fld : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_2 : Boolean;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
Len : Integer;
            procedure Finalizer_Scope_262 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_262;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1277 '<length at ast.py:4127>' Len /tmp/lal-23.0.0/ada/ast.py:4127
--# expr-start 1276 '<Filter at ast.py:4125>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4125
   --# expr-start 1273 '<FieldAccess for unpacked_formal_params at ast.py:4125>' Fld /tmp/lal-23.0.0/ada/ast.py:4125
--# expr-start 1272 '<as_bare_entity at ast.py:4125>' If_Result /tmp/lal-23.0.0/ada/ast.py:4125
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Base_Formal_Param_Holder;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 1272
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 1273
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld;
      begin
         for Item_54 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_54
         --# expr-start 1275 '<FieldAccess for is_mandatory at ast.py:4126>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4126
--# expr-start 1274 '<FieldAccess for formal_decl at ast.py:4126>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4126
      if Item_54.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Item_54.Node, E_Info => Item_54.Info);
--# end
--# expr-done 1274
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamDecl.is_mandatory'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Decl_P_Is_Mandatory (Node => Fld_1.Node);
--# end
--# expr-done 1275
         if Fld_2 then
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Item_54;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1276
Len := Length (Map_Result); 
--# expr-done 1277
      Property_Result := Len;
   --# end
      Finalizer_Scope_262;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_262;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Nb_Min_Params;
--# end
--# property-start BaseFormalParamHolder.nb_max_params /tmp/lal-23.0.0/ada/ast.py:4134
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Nb_Max_Params
  (Node : Bare_Base_Formal_Param_Holder
  )
   return Integer
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Integer;
            procedure Finalizer_Scope_263 with Inline_Always;
      As_Entity : Internal_Entity_Base_Formal_Param_Holder;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Formal_Param_Holder;
Fld : Internal_Entity_Defining_Name_Array_Access;
Len : Integer;
            procedure Finalizer_Scope_263 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_263;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1280 '<length at ast.py:4135>' Len /tmp/lal-23.0.0/ada/ast.py:4135
--# expr-start 1279 '<FieldAccess for unpacked_formal_params at ast.py:4135>' Fld /tmp/lal-23.0.0/ada/ast.py:4135
--# expr-start 1278 '<as_bare_entity at ast.py:4135>' If_Result /tmp/lal-23.0.0/ada/ast.py:4135
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Base_Formal_Param_Holder;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 1278
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 1279
Len := Length (Fld); 
--# expr-done 1280
      Property_Result := Len;
   --# end
      Finalizer_Scope_263;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_263;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Nb_Max_Params;
--# end
--# property-start BaseFormalParamHolder.paramless /tmp/lal-23.0.0/ada/ast.py:4143
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Paramless
  (Node : Bare_Base_Formal_Param_Holder
      ; Dottable_Subp : Boolean
      ; Can_Be : Boolean
         := True
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind dottable_subp Dottable_Subp
   --# bind can_be Can_Be
   Property_Result : Boolean;
      Block_Var : Integer;
Fld : Integer;
Fld_1 : Integer;
If_Result : Integer;
Is_Equal : Boolean;
If_Result_1 : Boolean;
Is_Equal_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1286 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1283 '<If at ast.py:4149>' If_Result /tmp/lal-23.0.0/ada/ast.py:4149
if Can_Be then
   --# expr-start 1281 '<FieldAccess for nb_min_params at ast.py:4149>' Fld /tmp/lal-23.0.0/ada/ast.py:4149
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_min_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Min_Params (Node => Self);
--# end
--# expr-done 1281
   If_Result := Fld;
else
   --# expr-start 1282 '<FieldAccess for nb_max_params at ast.py:4149>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4149
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_max_params
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Max_Params (Node => Self);
--# end
--# expr-done 1282
   If_Result := Fld_1;
end if;
--# expr-done 1283
Block_Var := If_Result; 
--# bind nb_params Block_Var
if Dottable_Subp then
   --# expr-start 1284 '<Eq at ast.py:4151>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:4151
Is_Equal := Block_Var = 1; 
--# expr-done 1284
   If_Result_1 := Is_Equal;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 1285 '<Eq at ast.py:4152>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:4152
Is_Equal_1 := Block_Var = 0; 
--# expr-done 1285
   If_Result_2 := Is_Equal_1;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 1286
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Paramless;
--# end
--# property-start BaseFormalParamHolder.is_matching_param_list /tmp/lal-23.0.0/ada/ast.py:4156
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Is_Matching_Param_List
  (Node : Bare_Base_Formal_Param_Holder
      ; Params : Internal_Entity_Assoc_List
      ; Is_Dottable_Subp : Boolean
      ; Env : Lexical_Env
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind params Params
   --# bind is_dottable_subp Is_Dottable_Subp
   --# bind env Env
   Property_Result : Boolean;
            procedure Finalizer_Scope_265 with Inline_Always;
      Block_Var : Internal_Entity_Base_Formal_Param_Holder;
Block_Var_1 : Internal_Param_Match_Array_Access;
Block_Var_2 : Integer;
Block_Var_3 : Integer;
As_Entity : Internal_Entity_Base_Formal_Param_Holder;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Formal_Param_Holder;
Fld : Internal_Param_Match_Array_Access;
Fld_1 : Integer;
Arith_Result : Integer;
Fld_2 : Integer;
If_Result_1 : Integer;
Fld_3 : Integer;
Arith_Result_1 : Integer;
Fld_4 : Integer;
If_Result_2 : Integer;
Fld_5 : Bare_Assoc_List;
Len : Integer;
Comp_Result : Boolean;
Fld_6 : Boolean;
Quantifier_Result : Boolean;
If_Result_3 : Boolean;
Fld_7 : Internal_Entity_Defining_Name;
Fld_8 : Internal_Entity_Base_Formal_Param_Decl;
Fld_9 : Boolean;
Map_Result : Internal_Param_Match_Array_Access;
Len_1 : Integer;
Is_Equal : Boolean;
If_Result_4 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_265 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_265;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1306 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1287 '<as_bare_entity at ast.py:4162>' If_Result /tmp/lal-23.0.0/ada/ast.py:4162
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Base_Formal_Param_Holder;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 1287
Block_Var := If_Result; 
--# bind bare Block_Var
--# expr-start 1288 '<FieldAccess for match_param_list at ast.py:4163>' Fld /tmp/lal-23.0.0/ada/ast.py:4163
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.match_param_list
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Param_List (Node => Block_Var.Node, Params => Params, Is_Dottable_Subp => Is_Dottable_Subp, Env => Env, E_Info => Block_Var.Info);
--# end
--# expr-done 1288
Block_Var_1 := Fld; Inc_Ref (Block_Var_1);
--# bind match_list Block_Var_1
--# expr-start 1292 '<If at ast.py:4165>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:4165
if Is_Dottable_Subp then
   --# expr-start 1290 '<Arithmetic - at ast.py:4165>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:4165
--# expr-start 1289 '<FieldAccess for nb_max_params at ast.py:4165>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4165
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_max_params
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Max_Params (Node => Block_Var.Node);
--# end
--# expr-done 1289
Arith_Result := (Fld_1 - 1); 
--# expr-done 1290
   If_Result_1 := Arith_Result;
else
   --# expr-start 1291 '<FieldAccess for nb_max_params at ast.py:4165>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4165
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_max_params
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Max_Params (Node => Block_Var.Node);
--# end
--# expr-done 1291
   If_Result_1 := Fld_2;
end if;
--# expr-done 1292
Block_Var_2 := If_Result_1; 
--# bind nb_max_params Block_Var_2
--# expr-start 1296 '<If at ast.py:4168>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:4168
if Is_Dottable_Subp then
   --# expr-start 1294 '<Arithmetic - at ast.py:4168>' Arith_Result_1 /tmp/lal-23.0.0/ada/ast.py:4168
--# expr-start 1293 '<FieldAccess for nb_min_params at ast.py:4168>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4168
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_min_params
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Min_Params (Node => Block_Var.Node);
--# end
--# expr-done 1293
Arith_Result_1 := (Fld_3 - 1); 
--# expr-done 1294
   If_Result_2 := Arith_Result_1;
else
   --# expr-start 1295 '<FieldAccess for nb_min_params at ast.py:4168>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4168
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_min_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Min_Params (Node => Block_Var.Node);
--# end
--# expr-done 1295
   If_Result_2 := Fld_4;
end if;
--# expr-done 1296
Block_Var_3 := If_Result_2; 
--# bind nb_min_params Block_Var_3
--# expr-start 1297 '<length at ast.py:4172>' Len /tmp/lal-23.0.0/ada/ast.py:4172
Fld_5 := Params.Node; 
Len := Length (Fld_5); 
--# expr-done 1297
Comp_Result := Len <= Block_Var_2; 
if Comp_Result then
   --# expr-start 1299 '<AllQuantifier at ast.py:4173>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:4173
      Quantifier_Result := True;
      declare
         Collection : constant Internal_Param_Match_Array_Access := Block_Var_1;
      begin
         for Item_55 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_55
      --# expr-start 1298 '<FieldAccess for has_matched at ast.py:4173>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4173
Fld_6 := Item_55.Has_Matched;
--# expr-done 1298
      Quantifier_Result := Fld_6;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
--# expr-done 1299
   If_Result_3 := Quantifier_Result;
else
   If_Result_3 := False;
end if;
if If_Result_3 then
   --# expr-start 1305 '<Eq at ast.py:4174>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:4174
--# expr-start 1304 '<length at ast.py:4176>' Len_1 /tmp/lal-23.0.0/ada/ast.py:4176
--# expr-start 1303 '<Filter at ast.py:4174>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4174
      declare
         Map_Result_Vec : Internal_Param_Match_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Block_Var_1;
      begin
         for Item_56 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_56
         --# expr-start 1302 '<FieldAccess for is_mandatory at ast.py:4175>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4175
--# expr-start 1301 '<FieldAccess for formal_decl at ast.py:4175>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4175
--# expr-start 1300 '<FieldAccess for formal at ast.py:4175>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4175
Fld_7 := Item_56.Formal;
--# expr-done 1300
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_8 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 1301
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamDecl.is_mandatory'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Decl_P_Is_Mandatory (Node => Fld_8.Node);
--# end
--# expr-done 1302
         if Fld_9 then
         declare
            Item_To_Append : constant Internal_Param_Match := Item_56;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1303
Len_1 := Length (Map_Result); 
--# expr-done 1304
Is_Equal := Len_1 = Block_Var_3; 
--# expr-done 1305
   If_Result_4 := Is_Equal;
else
   If_Result_4 := False;
end if;
Let_Result := If_Result_4; 
--# end
--# expr-done 1306
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_265;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_265;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Is_Matching_Param_List;
--# end
--# property-start BaseFormalParamHolder.param_types /tmp/lal-23.0.0/ada/ast.py:4181
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Param_Types
  (Node : Bare_Base_Formal_Param_Holder
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_266 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_2 : Internal_Entity_Type_Expr;
Fld_3 : Internal_Entity_Base_Type_Decl;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_266 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_266;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1312 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1311 '<Map at ast.py:4185>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4185
   --# expr-start 1307 '<FieldAccess for unpacked_formal_params at ast.py:4185>' Fld /tmp/lal-23.0.0/ada/ast.py:4185
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1307
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld;
      begin
         for Item_57 of
               Collection.Items
         loop
   --# scope-start
               --# bind fp Item_57
      --# expr-start 1310 '<FieldAccess for real_designated_type at ast.py:4187>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4187
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1309 '<FieldAccess for type_expression at ast.py:4187>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4187
--# expr-start 1308 '<FieldAccess for formal_decl at ast.py:4187>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4187
      if Item_57.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Item_57.Node, E_Info => Item_57.Info);
--# end
--# expr-done 1308
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 1309
--# property-call-start BaseFormalParamHolder.real_designated_type
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Real_Designated_Type (Node => Ent.Node, Typ => Fld_2, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1310
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Fld_3;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1311
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 1312
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_266;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_266;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Param_Types;
--# end
--# property-start BaseFormalParamHolder.param_modes /tmp/lal-23.0.0/ada/ast.py:4191
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Param_Modes
  (Node : Bare_Base_Formal_Param_Holder
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Mode_Array_Access
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Mode_Array_Access;
            procedure Finalizer_Scope_267 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result : Internal_Entity_Param_Spec;
Fld_2 : Internal_Entity_Mode;
Map_Result : Internal_Entity_Mode_Array_Access;
Let_Result : Internal_Entity_Mode_Array_Access;
            procedure Finalizer_Scope_267 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_267;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1318 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1317 '<Map at ast.py:4195>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4195
   --# expr-start 1313 '<FieldAccess for unpacked_formal_params at ast.py:4195>' Fld /tmp/lal-23.0.0/ada/ast.py:4195
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1313
      declare
         Map_Result_Vec : Internal_Entity_Mode_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld;
      begin
         for Item_58 of
               Collection.Items
         loop
   --# scope-start
               --# bind fp Item_58
      --# expr-start 1316 '<FieldAccess for mode at ast.py:4196>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4196
--# expr-start 1315 '<Cast to ParamSpec at ast.py:4196>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4196
--# expr-start 1314 '<FieldAccess for formal_decl at ast.py:4196>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4196
      if Item_58.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Item_58.Node, E_Info => Item_58.Info);
--# end
--# expr-done 1314
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Param_Spec_Range
   then
      Cast_Result := Create_Internal_Entity_Param_Spec
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Param_Spec;
   end if;
--# expr-done 1315
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Mode (Node => Cast_Result.Node.Param_Spec_F_Mode, Info => Cast_Result.Info);
--# expr-done 1316
         declare
            Item_To_Append : constant Internal_Entity_Mode := Fld_2;
         begin
            Internal_Entity_Mode_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Mode_Array
           (Items_Count => Natural (Internal_Entity_Mode_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Mode_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Mode_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Mode_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1317
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 1318
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_267;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_267;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Param_Modes;
--# end
--# property-start BaseFormalParamHolder.real_type /tmp/lal-23.0.0/ada/ast.py:4201
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Real_Type
  (Node : Bare_Base_Formal_Param_Holder
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Bare_Ada_Node;
Var_Expr_3 : Internal_Entity_Anonymous_Type_Decl;
Var_Expr_4 : Internal_Entity_Base_Type_Decl;
Var_Expr_5 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Info;
Fld_1 : Internal_Metadata;
Fld_2 : Bare_Ada_Node;
Fld_3 : Internal_Entity_Info;
Fld_4 : Env_Rebindings;
Fld_5 : Internal_Entity_Info;
Fld_6 : Boolean;
Fld_7 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_8 : Bare_Base_Type_Decl;
Is_Null : Boolean;
Fld_9 : Internal_Entity_Base_Type_Decl;
Fld_10 : Bare_Base_Type_Decl;
Scope_Result : Bare_Base_Type_Decl;
Result_Var : Bare_Base_Type_Decl;
Fld_11 : Internal_Entity_Base_Type_Decl;
Fld_12 : Bare_Base_Type_Decl;
Scope_Result_1 : Bare_Base_Type_Decl;
Result_Var_1 : Bare_Base_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Is_Equal : Boolean;
Fld_13 : Internal_Entity_Info;
Fld_14 : Internal_Metadata;
Fld_15 : Bare_Ada_Node;
Scope_Result_2 : Bare_Ada_Node;
Fld_16 : Bare_Base_Type_Decl;
Cast_Result_2 : Bare_Ada_Node;
Result_Var_2 : Bare_Ada_Node;
Fld_17 : Internal_Entity_Info;
Fld_18 : Env_Rebindings;
Fld_19 : Internal_Entity_Info;
Fld_20 : Boolean;
Fld_21 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity_Anonymous_Type_Decl;
Fld_22 : Internal_Entity_Type_Def;
Is_A : Boolean;
Not_Val : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
Fld_23 : Internal_Entity_Base_Type_Decl;
Fld_24 : Internal_Entity_Base_Type_Decl;
Fld_25 : Internal_Entity_Base_Type_Decl;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_5 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_6 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_4 : Internal_Entity_Base_Type_Decl;
Scope_Result_5 : Internal_Entity_Base_Type_Decl;
Result_Var_5 : Internal_Entity_Base_Type_Decl;
If_Result_1 : Internal_Entity_Base_Type_Decl;
If_Result_2 : Internal_Entity_Base_Type_Decl;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1355 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1327 '<Cast to BaseTypeDecl at ast.py:4212>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4212
--# expr-start 1326 '<FieldAccess for entity_no_md at ast.py:4208>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4208
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1321 '<FieldAccess for primitive at ast.py:4209>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4209
--# expr-start 1320 '<FieldAccess for md at ast.py:4209>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4209
--# expr-start 1319 '<FieldAccess for info at ast.py:4209>' Fld /tmp/lal-23.0.0/ada/ast.py:4209
Fld := Ent.Info;
--# expr-done 1319
Fld_1 := Fld.Md;
--# expr-done 1320
Fld_2 := Fld_1.Primitive;
--# expr-done 1321
--# expr-start 1323 '<FieldAccess for rebindings at ast.py:4210>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4210
--# expr-start 1322 '<FieldAccess for info at ast.py:4210>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4210
Fld_3 := Ent.Info;
--# expr-done 1322
Fld_4 := Fld_3.Rebindings;
--# expr-done 1323
--# expr-start 1325 '<FieldAccess for from_rebound at ast.py:4211>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4211
--# expr-start 1324 '<FieldAccess for info at ast.py:4211>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4211
Fld_5 := Ent.Info;
--# expr-done 1324
Fld_6 := Fld_5.From_Rebound;
--# expr-done 1325
--# property-call-start AdaNode.entity_no_md
Fld_7 := Libadalang.Implementation.Ada_Node_P_Entity_No_Md (Node => Ent.Node, N => Fld_2, Rebindings => Fld_4, From_Rebound => Fld_6);
--# end
--# expr-done 1326
   if Fld_7.Node = null
      or else Fld_7.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 1327
Block_Var := Cast_Result; 
--# bind prim_type Block_Var
--# expr-start 1354 '<Cond at ast.py:4214>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:4214
--# expr-start 1329 '<IsNull at ast.py:4215>' Is_Null /tmp/lal-23.0.0/ada/ast.py:4215
--# expr-start 1328 '<FieldAccess for node at ast.py:4215>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4215
Fld_8 := Block_Var.Node;
--# expr-done 1328
Is_Null := Fld_8 = null; 
--# expr-done 1329
if Is_Null then
   If_Result_3 := Typ;
else
--# expr-start 1334 '<Eq at ast.py:4218>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:4218
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1331 '<FieldAccess for node at ast.py:4218>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4218
--# expr-start 1330 '<FieldAccess for canonical_type at ast.py:4218>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4218
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1330
Fld_10 := Fld_9.Node;
--# expr-done 1331
Scope_Result := Fld_10;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
      Cast_Result_1 := Result_Var;
Var_Expr_1 := Typ;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1333 '<FieldAccess for node at ast.py:4218>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4218
--# expr-start 1332 '<FieldAccess for canonical_type at ast.py:4218>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4218
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_11 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1332
Fld_12 := Fld_11.Node;
--# expr-done 1333
Scope_Result_1 := Fld_12;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Bare_Ada_Node;
end if;
Is_Equal := Cast_Result_1 = Result_Var_1; 
--# expr-done 1334
if Is_Equal then
   --# expr-start 1344 '<Cast to BaseTypeDecl at ast.py:4223>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:4223
--# expr-start 1343 '<FieldAccess for entity_no_md at ast.py:4219>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:4219
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1337 '<FieldAccess for primitive_real_type at ast.py:4220>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:4220
--# expr-start 1336 '<FieldAccess for md at ast.py:4220>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:4220
--# expr-start 1335 '<FieldAccess for info at ast.py:4220>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:4220
Fld_13 := Ent.Info;
--# expr-done 1335
Fld_14 := Fld_13.Md;
--# expr-done 1336
Fld_15 := Fld_14.Primitive_Real_Type;
--# expr-done 1337
Var_Expr_2 := Fld_15;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_2 := Var_Expr_2;
   --# end
   Result_Var_2 := Scope_Result_2;
else
--# expr-start 1338 '<FieldAccess for node at ast.py:4220>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:4220
Fld_16 := Typ.Node;
--# expr-done 1338
      Cast_Result_2 := Fld_16;
   Result_Var_2 := Cast_Result_2;
end if;
--# expr-start 1340 '<FieldAccess for rebindings at ast.py:4221>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:4221
--# expr-start 1339 '<FieldAccess for info at ast.py:4221>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:4221
Fld_17 := Ent.Info;
--# expr-done 1339
Fld_18 := Fld_17.Rebindings;
--# expr-done 1340
--# expr-start 1342 '<FieldAccess for from_rebound at ast.py:4222>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:4222
--# expr-start 1341 '<FieldAccess for info at ast.py:4222>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:4222
Fld_19 := Ent.Info;
--# expr-done 1341
Fld_20 := Fld_19.From_Rebound;
--# expr-done 1342
--# property-call-start AdaNode.entity_no_md
Fld_21 := Libadalang.Implementation.Ada_Node_P_Entity_No_Md (Node => Ent.Node, N => Result_Var_2, Rebindings => Fld_18, From_Rebound => Fld_20);
--# end
--# expr-done 1343
   if Fld_21.Node = null
      or else Fld_21.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_21.Node,
         Info => Fld_21.Info);
   else
         Cast_Result_3 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 1344
   If_Result_2 := Cast_Result_3;
else
--# expr-start 1345 '<Cast to AnonymousTypeDecl at ast.py:4228>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:4228
Cast_Expr := Typ; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Anonymous_Type_Decl_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Anonymous_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_4 := No_Entity_Anonymous_Type_Decl;
   end if;
--# expr-done 1345
Var_Expr_3 := Cast_Result_4;
if Var_Expr_3 /= No_Entity_Anonymous_Type_Decl then
   --# scope-start
   --# bind td Var_Expr_3
--# expr-start 1348 '<Not at ast.py:4229>' Not_Val /tmp/lal-23.0.0/ada/ast.py:4229
--# expr-start 1347 '<IsA AccessToSubpDef at ast.py:4229>' Is_A /tmp/lal-23.0.0/ada/ast.py:4229
--# expr-start 1346 '<FieldAccess for type_def at ast.py:4229>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:4229
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Create_Internal_Entity_Type_Def (Node => Var_Expr_3.Node.Type_Decl_F_Type_Def, Info => Var_Expr_3.Info);
--# expr-done 1346
Is_A := Fld_22.Node /= null 
and then Fld_22.Node.Kind in Ada_Access_To_Subp_Def_Range; 
--# expr-done 1347
Not_Val := not (Is_A); 
--# expr-done 1348
Scope_Result_3 := Not_Val;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
if Result_Var_3 then
--# expr-start 1349 '<FieldAccess for accessed_type at ast.py:4231>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:4231
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_23 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Typ.Node, Origin => Origin, E_Info => Typ.Info);
--# end
--# expr-done 1349
Var_Expr_4 := Fld_23;
if Var_Expr_4 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind at Var_Expr_4
--# expr-start 1350 '<FieldAccess for real_type at ast.py:4232>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:4232
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.real_type
Fld_24 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Real_Type (Node => Ent.Node, Typ => Var_Expr_4, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1350
Var_Expr_5 := Fld_24;
if Var_Expr_5 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind rat Var_Expr_5
--# expr-start 1353 '<If at ast.py:4233>' If_Result /tmp/lal-23.0.0/ada/ast.py:4233
--# expr-start 1351 '<Eq at ast.py:4234>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:4234
Cast_Expr_1 := Var_Expr_4; 
      Cast_Result_5 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Cast_Expr_2 := Var_Expr_5; 
      Cast_Result_6 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv := Equivalent (Cast_Result_5, Cast_Result_6); 
--# expr-done 1351
if Is_Equiv then
   If_Result := Typ;
else
   --# expr-start 1352 '<FieldAccess for anonymous_access_type at ast.py:4236>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:4236
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.anonymous_access_type
Fld_25 := Libadalang.Implementation.Base_Type_Decl_P_Anonymous_Access_Type (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 1352
   If_Result := Fld_25;
end if;
--# expr-done 1353
Scope_Result_4 := If_Result;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Base_Type_Decl;
end if;
Scope_Result_5 := Result_Var_4;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := No_Entity_Base_Type_Decl;
end if;
   If_Result_1 := Result_Var_5;
else
   If_Result_1 := Typ;
end if;
   If_Result_2 := If_Result_1;
end if;
   If_Result_3 := If_Result_2;
end if;
--# expr-done 1354
Let_Result := If_Result_3; 
--# end
--# expr-done 1355
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Real_Type;
--# end
--# property-start BaseFormalParamHolder.real_designated_type /tmp/lal-23.0.0/ada/ast.py:4246
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Real_Designated_Type
  (Node : Bare_Base_Formal_Param_Holder
      ; Typ : Internal_Entity_Type_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Block_Var : Internal_Metadata;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Rt : Internal_Entity_Base_Type_Decl;
Base_Rebindings : Env_Rebindings;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Info;
Fld_1 : Internal_Metadata;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity;
Scope_Result : Internal_Entity;
Result_Var : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Bare_Ada_Node;
Cast_Result_1 : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_6 : Bare_Ada_Node;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_7 : Env_Rebindings;
Scope_Result_1 : Env_Rebindings;
Result_Var_1 : Env_Rebindings;
Fld_8 : Bare_Type_Expr;
Fld_9 : Internal_Entity_Info;
Fld_10 : Env_Rebindings;
Rebinding : Env_Rebindings;
Fld_11 : Internal_Entity_Info;
Fld_12 : Boolean;
New_Struct : Internal_Entity_Info;
New_Struct_1 : Internal_Entity_Type_Expr;
Fld_13 : Internal_Entity_Base_Type_Decl;
Is_Equal : Boolean;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Is_Equiv : Boolean;
If_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Fld_14 : Boolean;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1384 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 1357 '<FieldAccess for md at ast.py:4307>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4307
--# expr-start 1356 '<FieldAccess for info at ast.py:4307>' Fld /tmp/lal-23.0.0/ada/ast.py:4307
Fld := Ent.Info;
--# expr-done 1356
Fld_1 := Fld.Md;
--# expr-done 1357
Block_Var := Fld_1; 
--# bind md Block_Var
--# expr-start 1360 '<Cast to BaseTypeDecl at ast.py:4309>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4309
--# expr-start 1358 '<FieldAccess for designated_type at ast.py:4309>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4309
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Typ.Node, Origin => Origin, E_Info => Typ.Info);
--# end
--# expr-done 1358
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1359 '<FieldAccess for without_md at ast.py:4309>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4309
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.without_md
Fld_3 := Libadalang.Implementation.Ada_Node_P_Without_Md (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1359
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 1360
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 1383 '<If at ast.py:4310>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:4310
--# expr-start 1361 '<FieldAccess for dottable_subp at ast.py:4319>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:4319
Fld_14 := Block_Var.Dottable_Subp;
--# expr-done 1361
if Fld_14 then
   If_Result_3 := Var_Expr;
else
   --# expr-start 1382 '<Let at ast.py:4321>' Let_Result /tmp/lal-23.0.0/ada/ast.py:4321
--# scope-start
--# expr-start 1362 '<FieldAccess for real_type at ast.py:4323>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4323
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.real_type
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Real_Type (Node => Ent.Node, Typ => Var_Expr, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1362
Rt := Fld_4; 
--# bind rt Rt
--# expr-start 1365 '<as_bare_entity at ast.py:4325>' If_Result /tmp/lal-23.0.0/ada/ast.py:4325
--# expr-start 1364 '<Cast to BaseTypeDecl at ast.py:4324>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:4324
--# expr-start 1363 '<FieldAccess for primitive_real_type at ast.py:4324>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4324
Fld_5 := Block_Var.Primitive_Real_Type;
--# expr-done 1363
   if Fld_5 = null
      or else Fld_5.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Fld_5;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 1364
Is_Null := Cast_Result_1 = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Cast_Result_1); 
   If_Result := As_Entity;
end if;
--# expr-done 1365
Var_Expr_2 := If_Result;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1368 '<FieldAccess for find_base_type_rebindings at ast.py:4325>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4325
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1367 '<Cast to BaseTypeDecl at ast.py:4326>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:4326
--# expr-start 1366 '<FieldAccess for primitive at ast.py:4326>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4326
Fld_6 := Block_Var.Primitive;
--# expr-done 1366
   if Fld_6 = null
      or else Fld_6.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_2 := Fld_6;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 1367
--# property-call-start BaseTypeDecl.find_base_type_rebindings
Fld_7 := Libadalang.Implementation.Base_Type_Decl_P_Find_Base_Type_Rebindings (Node => Var_Expr_2.Node, Target => Cast_Result_2, Origin => Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 1368
Scope_Result_1 := Fld_7;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := null;
end if;
Base_Rebindings := Result_Var_1; 
--# bind base_rebindings Base_Rebindings
--# expr-start 1381 '<If at ast.py:4327>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:4327
--# expr-start 1369 '<Eq at ast.py:4328>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:4328
Cast_Expr := Var_Expr; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Rt; 
      Cast_Result_4 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_3, Cast_Result_4); 
--# expr-done 1369
if Is_Equiv then
   --# expr-start 1380 '<If at ast.py:4329>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:4329
--# expr-start 1370 '<IsNull at ast.py:4330>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:4330
Is_Equal := Base_Rebindings = null; 
--# expr-done 1370
if Is_Equal then
   If_Result_1 := Var_Expr;
else
   --# expr-start 1379 '<FieldAccess for designated_type at ???>' Fld_13 None
--# expr-start 1378 '<New TypeExpr.entity at ???>' New_Struct_1 None
--# expr-start 1376 '<New EntityInfo at ast.py:4334>' New_Struct /tmp/lal-23.0.0/ada/ast.py:4334
--# expr-start 1372 '<FieldAccess for from_rebound at ast.py:4338>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4338
--# expr-start 1371 '<FieldAccess for info at ast.py:4338>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4338
Fld_11 := Typ.Info;
--# expr-done 1371
Fld_12 := Fld_11.From_Rebound;
--# expr-done 1372
--# expr-start 1375 '<concat_rebindings at ast.py:4337>' Rebinding /tmp/lal-23.0.0/ada/ast.py:4337
--# expr-start 1374 '<FieldAccess for rebindings at ast.py:4336>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4336
--# expr-start 1373 '<FieldAccess for info at ast.py:4336>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4336
Fld_9 := Typ.Info;
--# expr-done 1373
Fld_10 := Fld_9.Rebindings;
--# expr-done 1374
Rebinding := AST_Envs.Combine (Fld_10, Base_Rebindings); 
--# expr-done 1375
New_Struct := (From_Rebound => Fld_12, Md => No_Metadata, Rebindings => Rebinding); 
--# expr-done 1376
--# expr-start 1377 '<FieldAccess for node at ast.py:4333>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4333
Fld_8 := Typ.Node;
--# expr-done 1377
New_Struct_1 := (Info => New_Struct, Node => Fld_8); 
--# expr-done 1378
      if New_Struct_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_13 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => New_Struct_1.Node, Origin => Origin, E_Info => New_Struct_1.Info);
--# end
--# expr-done 1379
   If_Result_1 := Fld_13;
end if;
--# expr-done 1380
   If_Result_2 := If_Result_1;
else
   If_Result_2 := Rt;
end if;
--# expr-done 1381
Let_Result := If_Result_2; 
--# end
--# expr-done 1382
   If_Result_3 := Let_Result;
end if;
--# expr-done 1383
Scope_Result_2 := If_Result_3;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Base_Type_Decl;
end if;
Let_Result_1 := Result_Var_2; 
--# end
--# expr-done 1384
      Property_Result := Let_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Real_Designated_Type;
--# end
--# property-start BaseFormalParamHolder.call_argument_equation /tmp/lal-23.0.0/ada/ast.py:4349
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Call_Argument_Equation
  (Node : Bare_Base_Formal_Param_Holder
      ; Param : Internal_Entity_Base_Formal_Param_Decl
      ; Arg : Internal_Entity_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind param Param
   --# bind arg Arg
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_270 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Type_Expr;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_270 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_270;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1391 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1386 '<FieldAccess for real_designated_type at ast.py:4357>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4357
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1385 '<FieldAccess for type_expression at ast.py:4357>' Fld /tmp/lal-23.0.0/ada/ast.py:4357
      if Param.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Param.Node, E_Info => Param.Info);
--# end
--# expr-done 1385
--# property-call-start BaseFormalParamHolder.real_designated_type
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Real_Designated_Type (Node => Ent.Node, Typ => Fld, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1386
Block_Var := Fld_1; 
--# bind param_type Block_Var
--# expr-start 1390 '<And at ast.py:4358>' And_Pred /tmp/lal-23.0.0/ada/ast.py:4358
--# expr-start 1388 '<Bind at ast.py:4359>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:4359
--# expr-start 1387 '<FieldAccess for expected_type_var at ast.py:4359>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4359
      if Arg.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Arg.Node);
--# expr-done 1387
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_2, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4359") else null)); 
--# expr-done 1388
--# expr-start 1389 '<FieldAccess for matches_expected_formal_type at ast.py:4360>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4360
      if Arg.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_3 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Arg.Node, Origin => Origin);
--# end
--# expr-done 1389
And_Pred := Create_And (Bind_Result, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4358") else null)); 
--# expr-done 1390
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 1391
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_270;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_270;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Call_Argument_Equation;
--# end
--# property-start BaseFormalParamHolder.match_formal_params /tmp/lal-23.0.0/ada/ast.py:4364
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Match_Formal_Params
  (Node : Bare_Base_Formal_Param_Holder
      ; Other : Internal_Entity_Base_Formal_Param_Holder
      ; Match_Names : Boolean
         := True
      ; Ignore_First_Param : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind match_names Match_Names
   --# bind ignore_first_param Ignore_First_Param
   Property_Result : Boolean;
            procedure Finalizer_Scope_271 with Inline_Always;
            procedure Finalizer_Scope_1959 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Block_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Block_Var_2 : Internal_Entity_Base_Type_Decl_Array_Access;
Block_Var_3 : Internal_Entity_Base_Type_Decl_Array_Access;
Var_Expr : Internal_Entity_Defining_Name_Array_Access;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Defining_Name_Array_Access;
Index_60 : Integer;
Is_Equal : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
If_Result : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Fld_2 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_3 : Internal_Entity_Base_Type_Decl_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_4 : Bare_Base_Formal_Param_Holder;
Fld_5 : Bare_Ada_Node;
Bound_Origin_1 : Bare_Ada_Node;
Fld_6 : Internal_Entity_Base_Type_Decl_Array_Access;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Len : Integer;
Len_1 : Integer;
Is_Equal_1 : Boolean;
Fld_7 : Bare_Ada_Node;
Bound_Origin_2 : Bare_Ada_Node;
Not_Val_1 : Boolean;
Fld_8 : Internal_Entity_Name;
Get_Result : Internal_Entity_Defining_Name;
Fld_9 : Internal_Entity_Name;
Fld_10 : Bare_Name;
Fld_11 : Boolean;
If_Result_1 : Boolean;
Get_Result_1 : Internal_Entity_Base_Type_Decl;
Get_Result_2 : Internal_Entity_Base_Type_Decl;
Fld_12 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_2 : Boolean;
Index_62 : Integer;
Quantifier_Result : Boolean;
Dyn_Var_Bind_Result_2 : Boolean;
If_Result_3 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_271 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Block_Var_3);
            end Finalizer_Scope_271;
            procedure Finalizer_Scope_1959 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Map_Result);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_1959;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1420 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1392 '<FieldAccess for unpacked_formal_params at ast.py:4372>' Fld /tmp/lal-23.0.0/ada/ast.py:4372
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1392
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Defining_Name_Array_Type then
   --# scope-start
   --# bind params Var_Expr
--# expr-start 1396 '<If at ast.py:4373>' If_Result /tmp/lal-23.0.0/ada/ast.py:4373
if Ignore_First_Param then
   --# expr-start 1395 '<Filter at ast.py:4375>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4375
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
         Index_60 := 0;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Var_Expr;
      begin
         for Item_59 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_59
               --# bind i Index_60
         --# expr-start 1394 '<Not at ast.py:4375>' Not_Val /tmp/lal-23.0.0/ada/ast.py:4375
--# expr-start 1393 '<Eq at ast.py:4375>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:4375
Is_Equal := Index_60 = 0; 
--# expr-done 1393
Not_Val := not (Is_Equal); 
--# expr-done 1394
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Item_59;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
               Index_60 := Index_60 + 1;
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1395
   If_Result := Map_Result;
else
   If_Result := Var_Expr;
end if;
      Inc_Ref (If_Result);
--# expr-done 1396
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1959;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
Block_Var := Result_Var; Inc_Ref (Block_Var);
--# bind self_params Block_Var
--# expr-start 1397 '<FieldAccess for unpacked_formal_params at ast.py:4379>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4379
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Other.Node, E_Info => Other.Info);
--# end
--# expr-done 1397
Block_Var_1 := Fld_1; Inc_Ref (Block_Var_1);
--# bind other_params Block_Var_1
--# expr-start 1400 '<bind at ast.py:4381>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:4381
--# expr-start 1398 '<FieldAccess for origin_node at ast.py:4381>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4381
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_2 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1398
Bound_Origin := Fld_2; 
--# expr-start 1399 '<FieldAccess for param_types at ast.py:4381>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4381
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.param_types
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Param_Types (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 1399
Dyn_Var_Bind_Result := Fld_3; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 1400
Block_Var_2 := Dyn_Var_Bind_Result; Inc_Ref (Block_Var_2);
--# bind self_types Block_Var_2
--# expr-start 1404 '<bind at ast.py:4382>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:4382
--# expr-start 1402 '<FieldAccess for origin_node at ast.py:4382>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4382
--# expr-start 1401 '<FieldAccess for node at ast.py:4382>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4382
Fld_4 := Other.Node;
--# expr-done 1401
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_5 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Fld_4);
--# end
--# expr-done 1402
Bound_Origin_1 := Fld_5; 
--# expr-start 1403 '<FieldAccess for param_types at ast.py:4383>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4383
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.param_types
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Param_Types (Node => Other.Node, Origin => Bound_Origin_1, E_Info => Other.Info);
--# end
--# expr-done 1403
Dyn_Var_Bind_Result_1 := Fld_6; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 1404
Block_Var_3 := Dyn_Var_Bind_Result_1; Inc_Ref (Block_Var_3);
--# bind other_types Block_Var_3
--# expr-start 1407 '<Eq at ast.py:4385>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:4385
--# expr-start 1405 '<length at ast.py:4385>' Len /tmp/lal-23.0.0/ada/ast.py:4385
Len := Length (Block_Var); 
--# expr-done 1405
--# expr-start 1406 '<length at ast.py:4385>' Len_1 /tmp/lal-23.0.0/ada/ast.py:4385
Len_1 := Length (Block_Var_1); 
--# expr-done 1406
Is_Equal_1 := Len = Len_1; 
--# expr-done 1407
if Is_Equal_1 then
   --# expr-start 1419 '<bind at ast.py:4386>' Dyn_Var_Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:4386
--# expr-start 1408 '<FieldAccess for origin_node at ast.py:4386>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4386
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_7 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1408
Bound_Origin_2 := Fld_7; 
--# expr-start 1418 '<AllQuantifier at ast.py:4386>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:4386
      Quantifier_Result := True;
         Index_62 := 0;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Block_Var;
      begin
         for Item_61 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_61
               --# bind i Index_62
--# expr-start 1409 '<Not at ast.py:4388>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:4388
Not_Val_1 := not (Match_Names); 
--# expr-done 1409
if Not_Val_1 then
   If_Result_1 := True;
else
   --# expr-start 1414 '<FieldAccess for matches at ast.py:4389>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4389
--# expr-start 1410 '<FieldAccess for name at ast.py:4389>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4389
      if Item_61.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Name (Node => Item_61.Node.Defining_Name_F_Name, Info => Item_61.Info);
--# expr-done 1410
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1413 '<FieldAccess for node at ast.py:4389>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4389
--# expr-start 1412 '<FieldAccess for name at ast.py:4389>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4389
--# expr-start 1411 '<at at ast.py:4389>' Get_Result /tmp/lal-23.0.0/ada/ast.py:4389
Get_Result := Get (Self, Block_Var_1, Index_62, True); 
--# expr-done 1411
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Name (Node => Get_Result.Node.Defining_Name_F_Name, Info => Get_Result.Info);
--# expr-done 1412
Fld_10 := Fld_9.Node;
--# expr-done 1413
--# property-call-start Name.matches
Fld_11 := Libadalang.Implementation.Name_P_Matches (Node => Fld_8.Node, N => Fld_10);
--# end
--# expr-done 1414
   If_Result_1 := Fld_11;
end if;
if If_Result_1 then
--# expr-start 1415 '<at at ast.py:4390>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:4390
Get_Result_1 := Get (Self, Block_Var_2, Index_62, True); 
--# expr-done 1415
Var_Expr_1 := Get_Result_1;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1417 '<FieldAccess for matching_type at ast.py:4390>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4390
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1416 '<at at ast.py:4390>' Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:4390
Get_Result_2 := Get (Self, Block_Var_3, Index_62, True); 
--# expr-done 1416
--# property-call-start BaseTypeDecl.matching_type
Fld_12 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Var_Expr_1.Node, Expected_Type => Get_Result_2, Origin => Bound_Origin_2, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1417
Scope_Result_1 := Fld_12;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_2 := Result_Var_1;
else
   If_Result_2 := False;
end if;
      Quantifier_Result := If_Result_2;
   --# end
               exit when not Quantifier_Result;
               Index_62 := Index_62 + 1;
         end loop;
      end;
--# expr-done 1418
Dyn_Var_Bind_Result_2 := Quantifier_Result; 
--# expr-done 1419
   If_Result_3 := Dyn_Var_Bind_Result_2;
else
   If_Result_3 := False;
end if;
Let_Result := If_Result_3; 
--# end
--# expr-done 1420
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_271;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_271;
               Finalizer_Scope_1959;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Match_Formal_Params;
--# end
--# property-start '[dispatcher]BaseFormalParamHolder.match_other' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Formal_Param_Holder_P_Match_Other
  (Node : Bare_Base_Formal_Param_Holder
      ; Other : Internal_Entity_Base_Formal_Param_Holder
      ; Match_Names : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind match_names Match_Names
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Formal_Param_Holder (Self.Kind) is
               when Ada_Component_List .. Ada_Generic_Formal_Part =>
                  --# property-call-start BaseFormalParamHolder.match_other
                  Property_Result := Base_Formal_Param_Holder_P_Match_Other
                    (Self
                        , Other
                        , Match_Names
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Spec .. Ada_Synthetic_Unary_Spec =>
                  --# property-call-start BaseSubpSpec.match_other
                  Property_Result := Base_Subp_Spec_P_Match_Other
                    (Self
                        , Other
                        , Match_Names
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Formal_Param_Holder_P_Match_Other;
--# end
--# property-start BaseFormalParamHolder.match_other /tmp/lal-23.0.0/ada/ast.py:4395
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Holder_P_Match_Other
  (Node : Bare_Base_Formal_Param_Holder
      ; Other : Internal_Entity_Base_Formal_Param_Holder
      ; Match_Names : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Holder := Bare_Base_Formal_Param_Holder (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Holder :=
     Internal_Entity_Base_Formal_Param_Holder'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind match_names Match_Names
   Property_Result : Boolean;
      Fld : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1422 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1421 '<FieldAccess for match_formal_params at ast.py:4403>' Fld /tmp/lal-23.0.0/ada/ast.py:4403
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.match_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Formal_Params (Node => Ent.Node, Other => Other, Match_Names => Match_Names, E_Info => Ent.Info);
--# end
--# expr-done 1421
Let_Result := Fld; 
--# end
--# expr-done 1422
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Holder_P_Match_Other;
--# end
   --
   --  Primitives for Bare_Base_Subp_Spec
   --
--# property-start '[dispatcher]BaseSubpSpec.name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Subp_Spec_P_Name
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Subp_Spec (Self.Kind) is
               when Ada_Entry_Spec =>
                  --# property-call-start EntrySpec.name
                  Property_Result := Entry_Spec_P_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Subp_Spec =>
                  --# property-call-start EnumSubpSpec.name
                  Property_Result := Enum_Subp_Spec_P_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Spec =>
                  --# property-call-start SubpSpec.name
                  Property_Result := Subp_Spec_P_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Binary_Spec =>
                  --# property-call-start SyntheticBinarySpec.name
                  Property_Result := Synthetic_Binary_Spec_P_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Unary_Spec =>
                  --# property-call-start SyntheticUnarySpec.name
                  Property_Result := Synthetic_Unary_Spec_P_Name
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Subp_Spec_P_Name;
--# end
--# property-start '[dispatcher]BaseSubpSpec.returns' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Subp_Spec_P_Returns
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Subp_Spec (Self.Kind) is
               when Ada_Entry_Spec =>
                  --# property-call-start EntrySpec.returns
                  Property_Result := Entry_Spec_P_Returns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Subp_Spec =>
                  --# property-call-start EnumSubpSpec.returns
                  Property_Result := Enum_Subp_Spec_P_Returns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Spec =>
                  --# property-call-start SubpSpec.returns
                  Property_Result := Subp_Spec_P_Returns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Binary_Spec =>
                  --# property-call-start SyntheticBinarySpec.returns
                  Property_Result := Synthetic_Binary_Spec_P_Returns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Unary_Spec =>
                  --# property-call-start SyntheticUnarySpec.returns
                  Property_Result := Synthetic_Unary_Spec_P_Returns
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Subp_Spec_P_Returns;
--# end
--# property-start '[dispatcher]BaseSubpSpec.params' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Subp_Spec_P_Params
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Param_Spec_Array_Access
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Param_Spec_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Subp_Spec (Self.Kind) is
               when Ada_Synthetic_Binary_Spec .. Ada_Synthetic_Unary_Spec =>
                  --# property-call-start BaseSubpSpec.params
                  Property_Result := Base_Subp_Spec_P_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Spec =>
                  --# property-call-start EntrySpec.params
                  Property_Result := Entry_Spec_P_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Subp_Spec =>
                  --# property-call-start EnumSubpSpec.params
                  Property_Result := Enum_Subp_Spec_P_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Spec =>
                  --# property-call-start SubpSpec.params
                  Property_Result := Subp_Spec_P_Params
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Subp_Spec_P_Params;
--# end
--# property-start BaseSubpSpec.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:17074
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Abstract_Formal_Params
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1221 with Inline_Always;
      Fld : Internal_Entity_Param_Spec_Array_Access;
Cast_Expr : Internal_Entity_Param_Spec;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1221 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1221;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1425 '<Map at ast.py:17075>' Map_Result /tmp/lal-23.0.0/ada/ast.py:17075
   --# expr-start 1423 '<FieldAccess for params at ast.py:17075>' Fld /tmp/lal-23.0.0/ada/ast.py:17075
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.params'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1423
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Param_Spec_Array_Access := Fld;
      begin
         for Item_63 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_63
      --# expr-start 1424 '<Cast to BaseFormalParamDecl at ast.py:17075>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17075
Cast_Expr := Item_63; 
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-done 1424
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1425
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1221;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1221;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Abstract_Formal_Params;
--# end
--# property-start BaseSubpSpec.match_return_type /tmp/lal-23.0.0/ada/ast.py:17079
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Match_Return_Type
  (Node : Bare_Base_Subp_Spec
      ; Other : Internal_Entity_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Subp_Spec;
Fld_3 : Bare_Ada_Node;
Bound_Origin_1 : Bare_Ada_Node;
Fld_4 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Type_Expr;
Is_Null : Boolean;
Fld_6 : Internal_Entity_Type_Expr;
Is_Null_1 : Boolean;
If_Result : Boolean;
Fld_7 : Internal_Entity_Type_Expr;
Is_Null_2 : Boolean;
Not_Val : Boolean;
Fld_8 : Internal_Entity_Type_Expr;
Is_Null_3 : Boolean;
Not_Val_1 : Boolean;
If_Result_1 : Boolean;
Fld_9 : Bare_Ada_Node;
Bound_Origin_2 : Bare_Ada_Node;
Fld_10 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Dyn_Var_Bind_Result_2 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1446 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1428 '<bind at ast.py:17085>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:17085
--# expr-start 1426 '<FieldAccess for origin_node at ast.py:17085>' Fld /tmp/lal-23.0.0/ada/ast.py:17085
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1426
Bound_Origin := Fld; 
--# expr-start 1427 '<FieldAccess for return_type at ast.py:17085>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17085
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 1427
Dyn_Var_Bind_Result := Fld_1; 
--# expr-done 1428
Block_Var := Dyn_Var_Bind_Result; 
--# bind self_ret Block_Var
--# expr-start 1432 '<bind at ast.py:17086>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:17086
--# expr-start 1430 '<FieldAccess for origin_node at ast.py:17086>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17086
--# expr-start 1429 '<FieldAccess for node at ast.py:17086>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17086
Fld_2 := Other.Node;
--# expr-done 1429
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_3 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Fld_2);
--# end
--# expr-done 1430
Bound_Origin_1 := Fld_3; 
--# expr-start 1431 '<FieldAccess for return_type at ast.py:17086>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17086
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_4 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Other.Node, Origin => Bound_Origin_1, E_Info => Other.Info);
--# end
--# expr-done 1431
Dyn_Var_Bind_Result_1 := Fld_4; 
--# expr-done 1432
Block_Var_1 := Dyn_Var_Bind_Result_1; 
--# bind other_ret Block_Var_1
--# expr-start 1434 '<IsNull at ast.py:17088>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17088
--# expr-start 1433 '<FieldAccess for returns at ast.py:17088>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17088
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1433
Is_Null := Fld_5.Node = null; 
--# expr-done 1434
if Is_Null then
   --# expr-start 1436 '<IsNull at ast.py:17088>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:17088
--# expr-start 1435 '<FieldAccess for returns at ast.py:17088>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17088
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Other.Node, E_Info => Other.Info);
--# end
--# expr-done 1435
Is_Null_1 := Fld_6.Node = null; 
--# expr-done 1436
   If_Result := Is_Null_1;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_3 := True;
else
--# expr-start 1439 '<Not at ast.py:17090>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17090
--# expr-start 1438 '<IsNull at ast.py:17090>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:17090
--# expr-start 1437 '<FieldAccess for returns at ast.py:17090>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17090
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1437
Is_Null_2 := Fld_7.Node = null; 
--# expr-done 1438
Not_Val := not (Is_Null_2); 
--# expr-done 1439
if Not_Val then
   --# expr-start 1442 '<Not at ast.py:17090>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:17090
--# expr-start 1441 '<IsNull at ast.py:17090>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:17090
--# expr-start 1440 '<FieldAccess for returns at ast.py:17090>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17090
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_8 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Other.Node, E_Info => Other.Info);
--# end
--# expr-done 1440
Is_Null_3 := Fld_8.Node = null; 
--# expr-done 1441
Not_Val_1 := not (Is_Null_3); 
--# expr-done 1442
   If_Result_1 := Not_Val_1;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 1445 '<bind at ast.py:17091>' Dyn_Var_Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:17091
--# expr-start 1443 '<FieldAccess for origin_node at ast.py:17091>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:17091
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_9 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1443
Bound_Origin_2 := Fld_9; 
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1444 '<FieldAccess for matching_type at ast.py:17092>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:17092
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_10 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Var_Expr.Node, Expected_Type => Block_Var_1, Origin => Bound_Origin_2, E_Info => Var_Expr.Info);
--# end
--# expr-done 1444
Scope_Result := Fld_10;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Dyn_Var_Bind_Result_2 := Result_Var; 
--# expr-done 1445
   If_Result_2 := Dyn_Var_Bind_Result_2;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
Let_Result := If_Result_3; 
--# end
--# expr-done 1446
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Match_Return_Type;
--# end
--# property-start BaseSubpSpec.match_signature /tmp/lal-23.0.0/ada/ast.py:17097
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Match_Signature
  (Node : Bare_Base_Subp_Spec
      ; Other : Internal_Entity_Base_Subp_Spec
      ; Match_Name : Boolean
      ; Use_Entity_Info : Boolean
         := True
      ; Ignore_First_Param : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind match_name Match_Name
   --# bind use_entity_info Use_Entity_Info
   --# bind ignore_first_param Ignore_First_Param
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Subp_Spec;
As_Entity : Internal_Entity_Base_Subp_Spec;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Subp_Spec;
If_Result_1 : Internal_Entity_Base_Subp_Spec;
Not_Val : Boolean;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Bare_Defining_Name;
Fld_2 : Internal_Entity_Defining_Name;
Fld_3 : Bare_Defining_Name;
Cast_Result : Bare_Name;
Fld_4 : Boolean;
If_Result_2 : Boolean;
Fld_5 : Boolean;
If_Result_3 : Boolean;
Cast_Expr : Internal_Entity_Base_Subp_Spec;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_6 : Boolean;
If_Result_4 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1457 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1448 '<If at ast.py:17120>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:17120
if Use_Entity_Info then
   If_Result_1 := Ent;
else
   --# expr-start 1447 '<as_bare_entity at ast.py:17120>' If_Result /tmp/lal-23.0.0/ada/ast.py:17120
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Base_Subp_Spec;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 1447
   If_Result_1 := If_Result;
end if;
--# expr-done 1448
Block_Var := If_Result_1; 
--# bind ent Block_Var
--# expr-start 1449 '<Not at ast.py:17123>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17123
Not_Val := not (Match_Name); 
--# expr-done 1449
if Not_Val then
   If_Result_2 := True;
else
   --# expr-start 1454 '<FieldAccess for matches at ast.py:17123>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17123
--# expr-start 1451 '<FieldAccess for node at ast.py:17123>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17123
--# expr-start 1450 '<FieldAccess for name at ast.py:17123>' Fld /tmp/lal-23.0.0/ada/ast.py:17123
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 1450
Fld_1 := Fld.Node;
--# expr-done 1451
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1453 '<FieldAccess for node at ast.py:17123>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17123
--# expr-start 1452 '<FieldAccess for name at ast.py:17123>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17123
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Other.Node, E_Info => Other.Info);
--# end
--# expr-done 1452
Fld_3 := Fld_2.Node;
--# expr-done 1453
      Cast_Result := Fld_3;
--# property-call-start Name.matches
Fld_4 := Libadalang.Implementation.Name_P_Matches (Node => Fld_1, N => Cast_Result);
--# end
--# expr-done 1454
   If_Result_2 := Fld_4;
end if;
if If_Result_2 then
   --# expr-start 1455 '<FieldAccess for match_return_type at ast.py:17124>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17124
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.match_return_type
Fld_5 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Return_Type (Node => Block_Var.Node, Other => Other, E_Info => Block_Var.Info);
--# end
--# expr-done 1455
   If_Result_3 := Fld_5;
else
   If_Result_3 := False;
end if;
if If_Result_3 then
   --# expr-start 1456 '<FieldAccess for match_formal_params at ast.py:17125>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17125
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Other; 
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# property-call-start BaseFormalParamHolder.match_formal_params
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Formal_Params (Node => Block_Var.Node, Other => Cast_Result_1, Match_Names => Match_Name, Ignore_First_Param => Ignore_First_Param, E_Info => Block_Var.Info);
--# end
--# expr-done 1456
   If_Result_4 := Fld_6;
else
   If_Result_4 := False;
end if;
Let_Result := If_Result_4; 
--# end
--# expr-done 1457
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Match_Signature;
--# end
--# property-start BaseSubpSpec.match_other /tmp/lal-23.0.0/ada/ast.py:17129
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Match_Other
  (Node : Bare_Base_Subp_Spec
      ; Other : Internal_Entity_Base_Formal_Param_Holder
      ; Match_Names : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind match_names Match_Names
   Property_Result : Boolean;
      Cast_Expr : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result : Internal_Entity_Base_Subp_Spec;
Fld : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1460 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1459 '<FieldAccess for match_signature at ast.py:17131>' Fld /tmp/lal-23.0.0/ada/ast.py:17131
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1458 '<Cast to BaseSubpSpec at ast.py:17132>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17132
Cast_Expr := Other; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Subp_Spec
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1458
--# property-call-start BaseSubpSpec.match_signature
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Ent.Node, Other => Cast_Result, Match_Name => Match_Names, E_Info => Ent.Info);
--# end
--# expr-done 1459
Let_Result := Fld; 
--# end
--# expr-done 1460
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Match_Other;
--# end
--# property-start BaseSubpSpec.defining_env /tmp/lal-23.0.0/ada/ast.py:17137
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Defining_Env
  (Node : Bare_Base_Subp_Spec
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1225 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Type_Expr;
Is_Null : Boolean;
If_Result : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1225 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1225;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1466 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1465 '<If at ast.py:17141>' If_Result /tmp/lal-23.0.0/ada/ast.py:17141
--# expr-start 1462 '<IsNull at ast.py:17141>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17141
--# expr-start 1461 '<FieldAccess for returns at ast.py:17141>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17141
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1461
Is_Null := Fld_2.Node = null; 
--# expr-done 1462
if Is_Null then
   If_Result := Empty_Env;
else
   --# expr-start 1464 '<FieldAccess for defining_env at ast.py:17142>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17142
--# expr-start 1463 '<FieldAccess for return_type at ast.py:17142>' Fld /tmp/lal-23.0.0/ada/ast.py:17142
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1463
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Fld.Info);
--# end
--# expr-done 1464
   If_Result := Fld_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 1465
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 1466
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1225;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1225;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Defining_Env;
--# end
--# property-start BaseSubpSpec.potential_dottable_type /tmp/lal-23.0.0/ada/ast.py:17145
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Potential_Dottable_Type
  (Node : Bare_Base_Subp_Spec
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1226 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Formal_Param_Decl;
Var_Expr_1 : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Get_Result : Internal_Entity_Base_Formal_Param_Decl;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1226 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1226;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1471 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1468 '<at at ast.py:17150>' Get_Result /tmp/lal-23.0.0/ada/ast.py:17150
--# expr-start 1467 '<FieldAccess for abstract_formal_params at ast.py:17150>' Fld /tmp/lal-23.0.0/ada/ast.py:17150
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1467
Get_Result := Get (Self, Fld, 0, True); 
--# expr-done 1468
Var_Expr := Get_Result;
if Var_Expr /= No_Entity_Base_Formal_Param_Decl then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 1469 '<FieldAccess for type_expression at ast.py:17151>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17151
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1469
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity_Type_Expr then
   --# scope-start
--# expr-start 1470 '<FieldAccess for element_type at ast.py:17151>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17151
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.element_type
Fld_2 := Libadalang.Implementation.Type_Expr_P_Element_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1470
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 1471
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1226;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1226;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Potential_Dottable_Type;
--# end
--# property-start BaseSubpSpec.get_candidate_type_for_primitive /tmp/lal-23.0.0/ada/ast.py:17155
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Get_Candidate_Type_For_Primitive
  (Node : Bare_Base_Subp_Spec
      ; Type_Expr : Internal_Entity_Type_Expr
      ; Canonicalize : Boolean
         := True
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind type_expr Type_Expr
   --# bind canonicalize Canonicalize
   Property_Result : Internal_Entity_Base_Type_Decl;
      Block_Var : Bare_Declarative_Part;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Block_Var_3 : Internal_Entity_Base_Type_Decl;
Block_Var_4 : Bare_Declarative_Part;
Match_0 : Internal_Entity_Anonymous_Type;
Match_1 : Internal_Entity_Type_Expr;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Boolean;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Var_Expr_3 : Internal_Entity_Incomplete_Type_Decl;
Var_Expr_4 : Internal_Entity_Base_Type_Decl;
Var_Expr_5 : Bare_Declarative_Part;
Var_Expr_6 : Bare_Declarative_Part;
Var_Expr_7 : Internal_Entity_Type_Decl;
Var_Expr_8 : Internal_Entity_Base_Type_Decl;
Var_Expr_9 : Bare_Declarative_Part;
Var_Expr_10 : Bare_Base_Package_Decl;
Var_Expr_11 : Bare_Declarative_Part;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Fld_2 : Bare_Ada_Node;
Cast_Result : Bare_Declarative_Part;
Fld_3 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
Not_Val : Boolean;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Type_Expr;
Cast_Result_1 : Internal_Entity_Anonymous_Type;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Type_Expr;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Fld_7 : Bare_Ada_Node;
Bound_Origin_1 : Bare_Ada_Node;
Fld_8 : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Type_Decl;
If_Result : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity_Incomplete_Type_Decl;
Fld_9 : Internal_Entity_Base_Type_Decl;
Scope_Result_5 : Internal_Entity_Base_Type_Decl;
Result_Var_3 : Internal_Entity_Base_Type_Decl;
Fld_10 : Bare_Base_Type_Decl;
Fld_11 : Bare_Ada_Node;
Fld_12 : Bare_Ada_Node;
Cast_Result_4 : Bare_Declarative_Part;
Scope_Result_6 : Bare_Declarative_Part;
Result_Var_4 : Bare_Declarative_Part;
Fld_13 : Bare_Ada_Node;
Scope_Result_7 : Bare_Ada_Node;
Result_Var_5 : Bare_Ada_Node;
Is_A : Boolean;
Fld_14 : Bare_Ada_Node;
Scope_Result_8 : Bare_Ada_Node;
Result_Var_6 : Bare_Ada_Node;
Is_A_1 : Boolean;
If_Result_1 : Boolean;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_5 : Internal_Entity_Type_Decl;
Fld_15 : Boolean;
Scope_Result_9 : Boolean;
Result_Var_7 : Boolean;
If_Result_2 : Boolean;
Fld_16 : Boolean;
Scope_Result_10 : Boolean;
Result_Var_8 : Boolean;
Not_Val_1 : Boolean;
If_Result_3 : Boolean;
Cast_Expr_2 : Bare_Declarative_Part;
Cast_Result_6 : Bare_Declarative_Part;
Is_Equal : Boolean;
Fld_17 : Bare_Ada_Node;
Scope_Result_11 : Bare_Ada_Node;
Result_Var_9 : Bare_Ada_Node;
Cast_Result_7 : Bare_Base_Package_Decl;
Fld_18 : Bare_Public_Part;
Scope_Result_12 : Bare_Public_Part;
Result_Var_10 : Bare_Public_Part;
Cast_Result_8 : Bare_Declarative_Part;
Is_Equal_1 : Boolean;
If_Result_4 : Boolean;
Scope_Result_13 : Boolean;
Result_Var_11 : Boolean;
If_Result_5 : Boolean;
If_Result_6 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1507 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 1475 '<Cast to DeclarativePart at ast.py:17166>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17166
--# expr-start 1474 '<parent at ast.py:17166>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17166
--# expr-start 1473 '<parent at ast.py:17166>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17166
--# expr-start 1472 '<parent at ast.py:17166>' Fld /tmp/lal-23.0.0/ada/ast.py:17166
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 1472
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 1473
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Fld_1.Parent; 
--# expr-done 1474
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Declarative_Part_Range
   then
      Cast_Result := Fld_2;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 1475
Block_Var := Cast_Result; 
--# bind decl_scope Block_Var
--# expr-start 1482 '<bind at ast.py:17168>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:17168
--# expr-start 1476 '<FieldAccess for origin_node at ast.py:17168>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17168
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_3 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1476
Bound_Origin := Fld_3; 
--# expr-start 1481 '<Match at ast.py:17168>' Match_Result /tmp/lal-23.0.0/ada/ast.py:17168
      if Type_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Type_Expr; 
case Ada_Type_Expr (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Anonymous_Type
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind at Match_0
--# expr-start 1477 '<FieldAccess for element_type at ast.py:17169>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17169
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.element_type
Fld_4 := Libadalang.Implementation.Type_Expr_P_Element_Type (Node => Match_0.Node, Origin => Bound_Origin, E_Info => Match_0.Info);
--# end
--# expr-done 1477
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind et Var_Expr
--# expr-start 1479 '<Not at ast.py:17172>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17172
--# expr-start 1478 '<FieldAccess for is_classwide at ast.py:17172>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17172
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1478
Not_Val := not (Fld_5); 
--# expr-done 1479
Var_Expr_1 := Not_Val;
if Var_Expr_1 /= False then
   --# scope-start
   --# bind _ Var_Expr_1
Scope_Result := Var_Expr;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Enum_Lit_Synth_Type_Expr .. Ada_Synthetic_Type_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind other Match_1
--# expr-start 1480 '<FieldAccess for designated_type at ast.py:17176>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17176
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Match_1.Node, Origin => Bound_Origin, E_Info => Match_1.Info);
--# end
--# expr-done 1480
Let_Result_1 := Fld_6; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 1481
Dyn_Var_Bind_Result := Match_Result; 
--# expr-done 1482
Block_Var_1 := Dyn_Var_Bind_Result; 
--# bind typ Block_Var_1
--# expr-start 1486 '<If at ast.py:17180>' If_Result /tmp/lal-23.0.0/ada/ast.py:17180
if Canonicalize then
   --# expr-start 1485 '<bind at ast.py:17182>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:17182
--# expr-start 1483 '<FieldAccess for origin_node at ast.py:17182>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17182
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_7 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 1483
Bound_Origin_1 := Fld_7; 
Var_Expr_2 := Block_Var_1;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1484 '<FieldAccess for canonical_type at ast.py:17182>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17182
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_8 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Var_Expr_2.Node, Origin => Bound_Origin_1, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 1484
Scope_Result_4 := Fld_8;
   --# end
   Result_Var_2 := Scope_Result_4;
else
   Result_Var_2 := No_Entity_Base_Type_Decl;
end if;
Dyn_Var_Bind_Result_1 := Result_Var_2; 
--# expr-done 1485
   If_Result := Dyn_Var_Bind_Result_1;
else
   If_Result := Block_Var_1;
end if;
--# expr-done 1486
Block_Var_2 := If_Result; 
--# bind canon_type Block_Var_2
--# expr-start 1487 '<Cast to IncompleteTypeDecl at ast.py:17186>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:17186
Cast_Expr := Block_Var_2; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Incomplete_Type_Decl_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Incomplete_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_3 := No_Entity_Incomplete_Type_Decl;
   end if;
--# expr-done 1487
Var_Expr_3 := Cast_Result_3;
if Var_Expr_3 /= No_Entity_Incomplete_Type_Decl then
   --# scope-start
   --# bind i Var_Expr_3
--# expr-start 1488 '<FieldAccess for next_part at ast.py:17187>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:17187
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.next_part
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Next_Part (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 1488
Scope_Result_5 := Fld_9;
   --# end
   Result_Var_3 := Scope_Result_5;
else
   Result_Var_3 := Block_Var_2;
end if;
Block_Var_3 := Result_Var_3; 
--# bind final_type Block_Var_3
Var_Expr_4 := Block_Var_3;
if Var_Expr_4 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr_4
--# expr-start 1492 '<Cast to DeclarativePart at ast.py:17192>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:17192
--# expr-start 1491 '<parent at ast.py:17192>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:17192
--# expr-start 1490 '<parent at ast.py:17192>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:17192
--# expr-start 1489 '<FieldAccess for node at ast.py:17192>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:17192
Fld_10 := Var_Expr_4.Node;
--# expr-done 1489
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Fld_10.Parent; 
--# expr-done 1490
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Fld_11.Parent; 
--# expr-done 1491
   if Fld_12 = null
      or else Fld_12.Kind in Ada_Declarative_Part_Range
   then
      Cast_Result_4 := Fld_12;
   else
         Cast_Result_4 := No_Bare_Ada_Node;
   end if;
--# expr-done 1492
Scope_Result_6 := Cast_Result_4;
   --# end
   Result_Var_4 := Scope_Result_6;
else
   Result_Var_4 := No_Bare_Ada_Node;
end if;
Block_Var_4 := Result_Var_4; 
--# bind type_scope Block_Var_4
--# expr-start 1506 '<If at ast.py:17195>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:17195
--# expr-start 1494 '<IsA BasePackageDecl at ast.py:17201>' Is_A /tmp/lal-23.0.0/ada/ast.py:17201
Var_Expr_5 := Block_Var_4;
if Var_Expr_5 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 1493 '<parent at ast.py:17201>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:17201
      if Var_Expr_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Var_Expr_5.Parent; 
--# expr-done 1493
Scope_Result_7 := Fld_13;
   --# end
   Result_Var_5 := Scope_Result_7;
else
   Result_Var_5 := No_Bare_Ada_Node;
end if;
Is_A := Result_Var_5 /= null 
and then Result_Var_5.Kind in Ada_Base_Package_Decl; 
--# expr-done 1494
if Is_A then
   --# expr-start 1496 '<IsA BasePackageDecl at ast.py:17202>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:17202
Var_Expr_6 := Block_Var;
if Var_Expr_6 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 1495 '<parent at ast.py:17202>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:17202
      if Var_Expr_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Var_Expr_6.Parent; 
--# expr-done 1495
Scope_Result_8 := Fld_14;
   --# end
   Result_Var_6 := Scope_Result_8;
else
   Result_Var_6 := No_Bare_Ada_Node;
end if;
Is_A_1 := Result_Var_6 /= null 
and then Result_Var_6.Kind in Ada_Base_Package_Decl; 
--# expr-done 1496
   If_Result_1 := Is_A_1;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
--# expr-start 1497 '<Cast to TypeDecl at ast.py:17217>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:17217
Cast_Expr_1 := Block_Var_3; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Type_Decl
   then
      Cast_Result_5 := Create_Internal_Entity_Type_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_5 := No_Entity_Type_Decl;
   end if;
--# expr-done 1497
Var_Expr_7 := Cast_Result_5;
if Var_Expr_7 /= No_Entity_Type_Decl then
   --# scope-start
--# expr-start 1498 '<FieldAccess for is_derived_tagged_type at ast.py:17217>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:17217
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.is_derived_tagged_type
Fld_15 := Libadalang.Implementation.Type_Decl_P_Is_Derived_Tagged_Type (Node => Var_Expr_7.Node, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 1498
Scope_Result_9 := Fld_15;
   --# end
   Result_Var_7 := Scope_Result_9;
else
   Result_Var_7 := False;
end if;
   If_Result_2 := Result_Var_7;
end if;
if If_Result_2 then
   --# expr-start 1500 '<Not at ast.py:17221>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:17221
Var_Expr_8 := Block_Var_3;
if Var_Expr_8 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1499 '<FieldAccess for is_classwide at ast.py:17221>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:17221
      if Var_Expr_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_16 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Var_Expr_8.Node, E_Info => Var_Expr_8.Info);
--# end
--# expr-done 1499
Scope_Result_10 := Fld_16;
   --# end
   Result_Var_8 := Scope_Result_10;
else
   Result_Var_8 := False;
end if;
Not_Val_1 := not (Result_Var_8); 
--# expr-done 1500
   If_Result_3 := Not_Val_1;
else
   If_Result_3 := False;
end if;
if If_Result_3 then
Var_Expr_9 := Block_Var_4;
if Var_Expr_9 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind ds Var_Expr_9
--# expr-start 1501 '<Eq at ast.py:17226>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:17226
Cast_Expr_2 := Block_Var; 
      Cast_Result_6 := Cast_Expr_2;
Is_Equal := Cast_Result_6 = Var_Expr_9; 
--# expr-done 1501
if Is_Equal then
   If_Result_4 := True;
else
   --# expr-start 1505 '<Eq at ast.py:17226>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:17226
--# expr-start 1503 '<Cast to BasePackageDecl at ast.py:17228>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:17228
Var_Expr_11 := Block_Var;
if Var_Expr_11 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 1502 '<parent at ast.py:17228>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:17228
      if Var_Expr_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Var_Expr_11.Parent; 
--# expr-done 1502
Scope_Result_11 := Fld_17;
   --# end
   Result_Var_9 := Scope_Result_11;
else
   Result_Var_9 := No_Bare_Ada_Node;
end if;
   if Result_Var_9 = null
      or else Result_Var_9.Kind in Ada_Base_Package_Decl
   then
      Cast_Result_7 := Result_Var_9;
   else
         Cast_Result_7 := No_Bare_Ada_Node;
   end if;
--# expr-done 1503
Var_Expr_10 := Cast_Result_7;
if Var_Expr_10 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 1504 '<FieldAccess for public_part at ast.py:17228>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:17228
      if Var_Expr_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Var_Expr_10.Base_Package_Decl_F_Public_Part;
--# expr-done 1504
Scope_Result_12 := Fld_18;
   --# end
   Result_Var_10 := Scope_Result_12;
else
   Result_Var_10 := No_Bare_Ada_Node;
end if;
      Cast_Result_8 := Result_Var_10;
Is_Equal_1 := Var_Expr_9 = Cast_Result_8; 
--# expr-done 1505
   If_Result_4 := Is_Equal_1;
end if;
Scope_Result_13 := If_Result_4;
   --# end
   Result_Var_11 := Scope_Result_13;
else
   Result_Var_11 := False;
end if;
   If_Result_5 := Result_Var_11;
else
   If_Result_5 := False;
end if;
if If_Result_5 then
   If_Result_6 := Block_Var_3;
else
   If_Result_6 := No_Entity_Base_Type_Decl;
end if;
--# expr-done 1506
Let_Result_2 := If_Result_6; 
--# end
--# expr-done 1507
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Get_Candidate_Type_For_Primitive;
--# end
--# property-start BaseSubpSpec.candidate_primitive_subp_types /tmp/lal-23.0.0/ada/ast.py:17236
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Candidate_Primitive_Subp_Types
  (Node : Bare_Base_Subp_Spec
      ; Canonicalize : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind canonicalize Canonicalize
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_1228 with Inline_Always;
            procedure Finalizer_Scope_1983 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Block_Var_1 : Internal_Entity_Type_Expr_Array_Access;
Var_Expr : Internal_Entity_Type_Expr;
Var_Expr_1 : Internal_Entity_Incomplete_Type_Decl;
Fld : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_2 : Internal_Entity_Type_Expr;
Map_Result : Internal_Entity_Type_Expr_Array_Access;
Fld_3 : Internal_Entity_Type_Expr;
Singleton : Internal_Entity_Type_Expr_Array_Access;
Scope_Result : Internal_Entity_Type_Expr_Array_Access;
Result_Var : Internal_Entity_Type_Expr_Array_Access;
Concat_Result : Internal_Entity_Type_Expr_Array_Access;
Fld_4 : Internal_Entity_Base_Type_Decl;
Map_Result_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Is_Null : Boolean;
Not_Val : Boolean;
Map_Result_2 : Internal_Entity_Base_Type_Decl_Array_Access;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Incomplete_Type_Decl;
Fld_5 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Map_Result_3 : Internal_Entity_Base_Type_Decl_Array_Access;
Unique_Array : Internal_Entity_Base_Type_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_1228 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Map_Result_3);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1228;
            procedure Finalizer_Scope_1983 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1983;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Subp_Spec_Base_Subp_Spec_P_Candidate_Primitive_Subp_Types,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Subp_Spec,
                                As_Bare_Base_Subp_Spec => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Canonicalize);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 1523 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1508 '<FieldAccess for unpacked_formal_params at ast.py:17245>' Fld /tmp/lal-23.0.0/ada/ast.py:17245
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1508
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind params Block_Var
--# expr-start 1513 '<Concat at ast.py:17246>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:17246
--# expr-start 1511 '<Map at ast.py:17246>' Map_Result /tmp/lal-23.0.0/ada/ast.py:17246
      declare
         Map_Result_Vec : Internal_Entity_Type_Expr_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Block_Var;
      begin
         for Item_64 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_64
      --# expr-start 1510 '<FieldAccess for type_expression at ast.py:17246>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17246
--# expr-start 1509 '<FieldAccess for formal_decl at ast.py:17246>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17246
      if Item_64.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Item_64.Node, E_Info => Item_64.Info);
--# end
--# expr-done 1509
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 1510
         declare
            Item_To_Append : constant Internal_Entity_Type_Expr := Fld_2;
         begin
            Internal_Entity_Type_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Type_Expr_Array
           (Items_Count => Natural (Internal_Entity_Type_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Type_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Type_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Type_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1511
--# expr-start 1512 '<FieldAccess for returns at ast.py:17247>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17247
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1512
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Type_Expr then
   --# scope-start
                Singleton := Create_Internal_Entity_Type_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1983;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Type_Expr_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result := Concat (Map_Result, Result_Var); 
--# expr-done 1513
Block_Var_1 := Concat_Result; Inc_Ref (Block_Var_1);
--# bind types Block_Var_1
--# expr-start 1522 '<unique at ast.py:17261>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:17261
--# expr-start 1521 '<Map at ast.py:17256>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:17256
   --# expr-start 1518 '<Filter at ast.py:17254>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:17254
   --# expr-start 1515 '<Map at ast.py:17250>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:17250
      declare
         Map_Result_1_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Type_Expr_Array_Access := Block_Var_1;
      begin
         for Item_67 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_67
      --# expr-start 1514 '<FieldAccess for get_candidate_type_for_primitive at ast.py:17251>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17251
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.get_candidate_type_for_primitive
Fld_4 := Libadalang.Implementation.Base_Subp_Spec_P_Get_Candidate_Type_For_Primitive (Node => Ent.Node, Type_Expr => Item_67, Canonicalize => Canonicalize);
--# end
--# expr-done 1514
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Fld_4;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 1515
      declare
         Map_Result_2_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Map_Result_1;
      begin
         for Item_66 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_66
         --# expr-start 1517 '<Not at ast.py:17255>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17255
--# expr-start 1516 '<IsNull at ast.py:17255>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17255
Is_Null := Item_66.Node = null; 
--# expr-done 1516
Not_Val := not (Is_Null); 
--# expr-done 1517
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Item_66;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 1518
      declare
         Map_Result_3_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Map_Result_2;
      begin
         for Item_65 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_65
--# expr-start 1519 '<Cast to IncompleteTypeDecl at ast.py:17257>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17257
Cast_Expr := Item_65; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Incomplete_Type_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Incomplete_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Incomplete_Type_Decl;
   end if;
--# expr-done 1519
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Incomplete_Type_Decl then
   --# scope-start
   --# bind i Var_Expr_1
--# expr-start 1520 '<FieldAccess for next_part at ast.py:17258>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17258
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.next_part
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Next_Part (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1520
Scope_Result_1 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Item_65;
end if;
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Result_Var_1;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_3 := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_3_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 1521
Unique_Array := Make_Unique (Map_Result_3); 
--# expr-done 1522
Let_Result := Unique_Array; Inc_Ref (Let_Result);
--# end
--# expr-done 1523
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1228;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl_Array_Access,
                        As_Internal_Entity_Base_Type_Decl_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1228;
               Finalizer_Scope_1983;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Candidate_Primitive_Subp_Types;
--# end
--# property-start BaseSubpSpec.candidate_primitive_subp_first_type /tmp/lal-23.0.0/ada/ast.py:17264
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Candidate_Primitive_Subp_First_Type
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1229 with Inline_Always;
            procedure Finalizer_Scope_1988 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl_Array_Access;
Fld : Internal_Entity_Base_Type_Decl_Array_Access;
Get_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1229 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1229;
            procedure Finalizer_Scope_1988 is
            begin
                     Dec_Ref (Var_Expr);
            end Finalizer_Scope_1988;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1526 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1524 '<FieldAccess for candidate_primitive_subp_types at ast.py:17269>' Fld /tmp/lal-23.0.0/ada/ast.py:17269
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_types
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Types (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1524
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Base_Type_Decl_Array_Type then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 1525 '<at at ast.py:17269>' Get_Result /tmp/lal-23.0.0/ada/ast.py:17269
Get_Result := Get (Self, Var_Expr, 0, True); 
--# expr-done 1525
Scope_Result := Get_Result;
   --# end
      Finalizer_Scope_1988;
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 1526
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1229;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1229;
               Finalizer_Scope_1988;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Candidate_Primitive_Subp_First_Type;
--# end
--# property-start BaseSubpSpec.candidate_primitive_subp_tagged_type /tmp/lal-23.0.0/ada/ast.py:17272
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type
  (Node : Bare_Base_Subp_Spec
      ; Canonicalize : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind canonicalize Canonicalize
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1230 with Inline_Always;
      Cast_Expr : Bare_Base_Subp_Spec;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
Find_Result : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1230 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1230;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Subp_Spec_Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Subp_Spec,
                                As_Bare_Base_Subp_Spec => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Canonicalize);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 1532 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1531 '<bind at ast.py:17278>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:17278
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 1530 '<Find at ast.py:17279>' Find_Result /tmp/lal-23.0.0/ada/ast.py:17279
   --# expr-start 1527 '<FieldAccess for candidate_primitive_subp_types at ast.py:17279>' Fld /tmp/lal-23.0.0/ada/ast.py:17279
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_types
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Types (Node => Ent.Node, Canonicalize => Canonicalize, E_Info => Ent.Info);
--# end
--# expr-done 1527
      Find_Result := No_Entity_Base_Type_Decl;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld;
      begin
         for Item_68 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_68
      --# expr-start 1529 '<FieldAccess for is_tagged_type at ast.py:17280>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17280
--# expr-start 1528 '<FieldAccess for full_view at ast.py:17280>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17280
      if Item_68.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Item_68.Node, E_Info => Item_68.Info);
--# end
--# expr-done 1528
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Fld_1.Node, Origin => Bound_Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 1529
      if Fld_2 then
         Find_Result := Item_68;
      end if;
   --# end
               exit when Fld_2;
         end loop;
      end;
--# expr-done 1530
Dyn_Var_Bind_Result := Find_Result; 
--# expr-done 1531
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 1532
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1230;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1230;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type;
--# end
--# property-start BaseSubpSpec.decl_spec /tmp/lal-23.0.0/ada/ast.py:17286
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Decl_Spec
  (Node : Bare_Base_Subp_Spec
      ; Follow_Generic : Boolean
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind follow_generic Follow_Generic
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Var_Expr_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Base_Subp_Spec;
Not_Val : Boolean;
Is_A : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Base_Subp_Spec;
Scope_Result_2 : Internal_Entity_Base_Subp_Spec;
Result_Var_2 : Internal_Entity_Base_Subp_Spec;
Let_Result : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1540 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1533 '<FieldAccess for name at ast.py:17298>' Fld /tmp/lal-23.0.0/ada/ast.py:17298
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1533
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 1534 '<FieldAccess for basic_decl at ast.py:17298>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17298
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1534
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Block_Var := Result_Var; 
--# bind bd Block_Var
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 1535 '<FieldAccess for canonical_part at ast.py:17299>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17299
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Var_Expr_2.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 1535
Scope_Result_1 := Fld_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
Var_Expr_1 := Result_Var_1;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind dp Var_Expr_1
--# expr-start 1539 '<If at ast.py:17300>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:17300
--# expr-start 1536 '<Not at ast.py:17301>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17301
Not_Val := not (Follow_Generic); 
--# expr-done 1536
if Not_Val then
   --# expr-start 1537 '<IsA GenericSubpInternal at ast.py:17301>' Is_A /tmp/lal-23.0.0/ada/ast.py:17301
Is_A := Var_Expr_1.Node /= null 
and then Var_Expr_1.Node.Kind in Ada_Generic_Subp_Internal_Range; 
--# expr-done 1537
   If_Result := Is_A;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_1 := No_Entity_Base_Subp_Spec;
else
   --# expr-start 1538 '<FieldAccess for subp_spec_or_null at ast.py:17303>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17303
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr_1.Node, Follow_Generic => Follow_Generic, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1538
   If_Result_1 := Fld_3;
end if;
--# expr-done 1539
Scope_Result_2 := If_Result_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Ent;
end if;
Let_Result := Result_Var_2; 
--# end
--# expr-done 1540
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Decl_Spec;
--# end
--# property-start BaseSubpSpec.primitive_decl_spec /tmp/lal-23.0.0/ada/ast.py:17310
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Primitive_Decl_Spec
  (Node : Bare_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Fld : Internal_Entity_Base_Subp_Spec;
Let_Result : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1542 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1541 '<FieldAccess for decl_spec at ast.py:17316>' Fld /tmp/lal-23.0.0/ada/ast.py:17316
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.decl_spec
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Decl_Spec (Node => Ent.Node, Follow_Generic => False, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 1541
Let_Result := Fld; 
--# end
--# expr-done 1542
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Primitive_Decl_Spec;
--# end
--# property-start BaseSubpSpec.as_primitive_subp_type /tmp/lal-23.0.0/ada/ast.py:17319
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_As_Primitive_Subp_Type
  (Node : Bare_Base_Subp_Spec
      ; Typ : Internal_Entity_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1993 with Inline_Always;
            procedure Finalizer_Scope_1994 with Inline_Always;
      Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Boolean;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Fld_2 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Fld_3 : Bare_Ada_Node;
Fld_4 : Internal_Entity_Basic_Decl;
Fld_5 : Bare_Basic_Decl;
Cast_Result : Bare_Ada_Node;
Is_Equal : Boolean;
Quantifier_Result : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1993 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_1993;
            procedure Finalizer_Scope_1994 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1994;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1553 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1543 '<FieldAccess for name at ast.py:17328>' Fld /tmp/lal-23.0.0/ada/ast.py:17328
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1543
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind name Var_Expr
--# expr-start 1551 '<AnyQuantifier at ast.py:17332>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:17332
   --# expr-start 1546 '<EnvGet at ast.py:17332>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:17332
Var_Expr_2 := Typ;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1544 '<FieldAccess for primitives_env at ast.py:17332>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17332
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 1544
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1994;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 1545 '<FieldAccess for name_symbol at ast.py:17332>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17332
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Var_Expr.Node);
--# end
--# expr-done 1545
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Result_Var, Key => Fld_2, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 1546
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_69 of
               Collection.Items
         loop
   --# scope-start
               --# bind b Item_69
      --# expr-start 1550 '<Eq at ast.py:17333>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:17333
--# expr-start 1547 '<FieldAccess for node at ast.py:17333>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17333
Fld_3 := Item_69.Node;
--# expr-done 1547
--# expr-start 1549 '<FieldAccess for node at ast.py:17333>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17333
--# expr-start 1548 '<FieldAccess for basic_decl at ast.py:17333>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17333
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_4 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1548
Fld_5 := Fld_4.Node;
--# expr-done 1549
      Cast_Result := Fld_5;
Is_Equal := Fld_3 = Cast_Result; 
--# expr-done 1550
      Quantifier_Result := Is_Equal;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 1551
Var_Expr_1 := Quantifier_Result;
if Var_Expr_1 /= False then
   --# scope-start
   --# bind _ Var_Expr_1
--# expr-start 1552 '<FieldAccess for real_type at ast.py:17338>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17338
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.real_type
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Real_Type (Node => Ent.Node, Typ => Typ, Origin => No_Bare_Ada_Node, E_Info => Ent.Info);
--# end
--# expr-done 1552
Scope_Result_1 := Fld_6;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
      Finalizer_Scope_1993;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var_2; 
--# end
--# expr-done 1553
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1993;
               Finalizer_Scope_1994;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_As_Primitive_Subp_Type;
--# end
--# property-start BaseSubpSpec.primitive_subp_types /tmp/lal-23.0.0/ada/ast.py:17344
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Primitive_Subp_Types
  (Node : Bare_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_1234 with Inline_Always;
            procedure Finalizer_Scope_1997 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_2 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Type_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_1234 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1234;
            procedure Finalizer_Scope_1997 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1997;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1560 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1554 '<FieldAccess for primitive_decl_spec at ast.py:17348>' Fld /tmp/lal-23.0.0/ada/ast.py:17348
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_decl_spec
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Decl_Spec (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 1554
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr
--# expr-start 1559 '<Filter at ast.py:17349>' Map_Result /tmp/lal-23.0.0/ada/ast.py:17349
   --# expr-start 1555 '<FieldAccess for candidate_primitive_subp_types at ast.py:17349>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17349
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_types
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Types (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1555
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_1;
      begin
         for Item_70 of
               Collection.Items
         loop
   --# scope-start
               --# bind c Item_70
         --# expr-start 1558 '<Not at ast.py:17350>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17350
--# expr-start 1557 '<IsNull at ast.py:17350>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17350
--# expr-start 1556 '<FieldAccess for as_primitive_subp_type at ast.py:17350>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17350
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.as_primitive_subp_type
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_As_Primitive_Subp_Type (Node => Var_Expr.Node, Typ => Item_70, E_Info => Var_Expr.Info);
--# end
--# expr-done 1556
Is_Null := Fld_2.Node = null; 
--# expr-done 1557
Not_Val := not (Is_Null); 
--# expr-done 1558
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Item_70;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1559
Scope_Result := Map_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1997;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 1560
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1234;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1234;
               Finalizer_Scope_1997;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Primitive_Subp_Types;
--# end
--# property-start BaseSubpSpec.primitive_subp_first_type /tmp/lal-23.0.0/ada/ast.py:17356
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Primitive_Subp_First_Type
  (Node : Bare_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1564 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1561 '<FieldAccess for primitive_decl_spec at ast.py:17360>' Fld /tmp/lal-23.0.0/ada/ast.py:17360
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_decl_spec
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Decl_Spec (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 1561
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr
--# expr-start 1563 '<FieldAccess for as_primitive_subp_type at ast.py:17361>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17361
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1562 '<FieldAccess for candidate_primitive_subp_first_type at ast.py:17362>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17362
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_first_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_First_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1562
--# property-call-start BaseSubpSpec.as_primitive_subp_type
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_As_Primitive_Subp_Type (Node => Var_Expr.Node, Typ => Fld_1, E_Info => Var_Expr.Info);
--# end
--# expr-done 1563
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 1564
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Primitive_Subp_First_Type;
--# end
--# property-start BaseSubpSpec.primitive_subp_tagged_type /tmp/lal-23.0.0/ada/ast.py:17368
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Primitive_Subp_Tagged_Type
  (Node : Bare_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1568 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1565 '<FieldAccess for primitive_decl_spec at ast.py:17373>' Fld /tmp/lal-23.0.0/ada/ast.py:17373
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_decl_spec
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Decl_Spec (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 1565
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr
--# expr-start 1567 '<FieldAccess for as_primitive_subp_type at ast.py:17374>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17374
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1566 '<FieldAccess for candidate_primitive_subp_tagged_type at ast.py:17375>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17375
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_tagged_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1566
--# property-call-start BaseSubpSpec.as_primitive_subp_type
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_As_Primitive_Subp_Type (Node => Var_Expr.Node, Typ => Fld_1, E_Info => Var_Expr.Info);
--# end
--# expr-done 1567
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 1568
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Primitive_Subp_Tagged_Type;
--# end
--# property-start BaseSubpSpec.has_controlling_result /tmp/lal-23.0.0/ada/ast.py:17381
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Has_Controlling_Result
  (Node : Bare_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1574 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1569 '<FieldAccess for candidate_primitive_subp_tagged_type at ast.py:17387>' Fld /tmp/lal-23.0.0/ada/ast.py:17387
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_tagged_type
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1569
Block_Var := Fld; 
--# bind typ Block_Var
--# expr-start 1571 '<Not at ast.py:17388>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17388
--# expr-start 1570 '<IsNull at ast.py:17388>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17388
Is_Null := Block_Var.Node = null; 
--# expr-done 1570
Not_Val := not (Is_Null); 
--# expr-done 1571
if Not_Val then
   --# expr-start 1573 '<Eq at ast.py:17388>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:17388
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 1572 '<FieldAccess for return_type at ast.py:17388>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17388
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Ent.Node, Origin => No_Bare_Ada_Node, E_Info => Ent.Info);
--# end
--# expr-done 1572
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 1573
   If_Result := Is_Equiv;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 1574
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Has_Controlling_Result;
--# end
--# property-start BaseSubpSpec.dottable_subp_of /tmp/lal-23.0.0/ada/ast.py:17391
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Dottable_Subp_Of
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Internal_Entity_Base_Type_Decl;
Is_A : Boolean;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Classwide_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_6 : Integer;
Comp_Result : Boolean;
If_Result_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Subp_Spec_Base_Subp_Spec_P_Dottable_Subp_Of,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Subp_Spec,
                                As_Bare_Base_Subp_Spec => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 1587 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1586 '<bind at ast.py:17396>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:17396
--# expr-start 1576 '<FieldAccess for origin_node at ast.py:17396>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17396
--# expr-start 1575 '<FieldAccess for name at ast.py:17396>' Fld /tmp/lal-23.0.0/ada/ast.py:17396
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1575
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Fld.Node);
--# end
--# expr-done 1576
Bound_Origin := Fld_1; 
--# expr-start 1585 '<If at ast.py:17396>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:17396
--# expr-start 1577 '<FieldAccess for nb_max_params at ast.py:17397>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17397
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_max_params
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Max_Params (Node => Ent.Node);
--# end
--# expr-done 1577
Comp_Result := Fld_6 > 0; 
if Comp_Result then
--# expr-start 1578 '<FieldAccess for potential_dottable_type at ast.py:17398>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17398
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.potential_dottable_type
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_Potential_Dottable_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 1578
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 1584 '<Cond at ast.py:17398>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:17398
--# expr-start 1579 '<IsA ClasswideTypeDecl at ast.py:17399>' Is_A /tmp/lal-23.0.0/ada/ast.py:17399
Is_A := Var_Expr.Node /= null 
and then Var_Expr.Node.Kind in Ada_Classwide_Type_Decl_Range; 
--# expr-done 1579
if Is_A then
   --# expr-start 1581 '<FieldAccess for typedecl at ast.py:17400>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17400
--# expr-start 1580 '<Cast to ClasswideTypeDecl at ast.py:17400>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17400
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Classwide_Type_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Classwide_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Classwide_Type_Decl;
   end if;
--# expr-done 1580
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld_3 := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 1581
   If_Result_1 := Fld_3;
else
--# expr-start 1583 '<FieldAccess for is_tagged_type at ast.py:17407>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17407
--# expr-start 1582 '<FieldAccess for full_view at ast.py:17407>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17407
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1582
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Fld_4.Node, Origin => Bound_Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 1583
if Fld_5 then
   If_Result := Var_Expr;
else
   If_Result := No_Entity_Base_Type_Decl;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 1584
Scope_Result := If_Result_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
   If_Result_2 := Result_Var;
else
   If_Result_2 := No_Entity_Base_Type_Decl;
end if;
--# expr-done 1585
Dyn_Var_Bind_Result := If_Result_2; 
--# expr-done 1586
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 1587
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Dottable_Subp_Of;
--# end
--# property-start BaseSubpSpec.return_type /tmp/lal-23.0.0/ada/ast.py:17417
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Return_Type
  (Node : Bare_Base_Subp_Spec
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Type_Expr;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1590 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1588 '<FieldAccess for returns at ast.py:17422>' Fld /tmp/lal-23.0.0/ada/ast.py:17422
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1588
Var_Expr := Fld;
if Var_Expr /= No_Entity_Type_Expr then
   --# scope-start
   --# bind rt Var_Expr
--# expr-start 1589 '<FieldAccess for real_designated_type at ast.py:17423>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17423
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.real_designated_type
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Real_Designated_Type (Node => Ent.Node, Typ => Var_Expr, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1589
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 1590
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Return_Type;
--# end
--# property-start BaseSubpSpec.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:17426
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Xref_Entry_Point
  (Node : Bare_Base_Subp_Spec
  )
   return Boolean
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Xref_Entry_Point;
--# end
--# property-start BaseSubpSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:17427
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Spec_P_Xref_Equation
  (Node : Bare_Base_Subp_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Base_Subp_Spec := Bare_Base_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Spec :=
     Internal_Entity_Base_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1241 with Inline_Always;
            procedure Finalizer_Scope_2003 with Inline_Always;
      Var_Expr : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Type_Expr;
Fld_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
            procedure Finalizer_Scope_1241 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1241;
            procedure Finalizer_Scope_2003 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2003;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 1591 '<FieldAccess for returns at ast.py:17427>' Fld /tmp/lal-23.0.0/ada/ast.py:17427
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1591
Var_Expr := Fld;
if Var_Expr /= No_Entity_Type_Expr then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 1592 '<FieldAccess for sub_equation at ast.py:17427>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17427
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1592
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2003;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17428") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1241;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1241;
               Finalizer_Scope_2003;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Spec_P_Xref_Equation;
--# end
 function Base_Subp_Spec_P_Params
  (Node : Bare_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Param_Spec_Array_Access
is (raise Property_Error
    with "Property BaseSubpSpec.params not implemented on type "
    & Kind_Name (Node));
   --
   --  Primitives for Bare_Entry_Spec
   --
      procedure Initialize_Fields_For_Entry_Spec
        (Self : Bare_Entry_Spec
         ; Entry_Spec_F_Entry_Name : Bare_Defining_Name
         ; Entry_Spec_F_Family_Type : Bare_Ada_Node
         ; Entry_Spec_F_Entry_Params : Bare_Params
        ) is
      begin
            Self.Entry_Spec_F_Entry_Name := Entry_Spec_F_Entry_Name;
            Self.Entry_Spec_F_Family_Type := Entry_Spec_F_Family_Type;
            Self.Entry_Spec_F_Entry_Params := Entry_Spec_F_Entry_Params;
      end Initialize_Fields_For_Entry_Spec;
   function Entry_Spec_F_Entry_Name
     (Node : Bare_Entry_Spec) return Bare_Defining_Name
   is
   begin
         return Node.Entry_Spec_F_Entry_Name;
   end;
   function Entry_Spec_F_Family_Type
     (Node : Bare_Entry_Spec) return Bare_Ada_Node
   is
   begin
         return Node.Entry_Spec_F_Family_Type;
   end;
   function Entry_Spec_F_Entry_Params
     (Node : Bare_Entry_Spec) return Bare_Params
   is
   begin
         return Node.Entry_Spec_F_Entry_Params;
   end;
--# property-start EntrySpec.name /tmp/lal-23.0.0/ada/ast.py:17694
pragma Warnings (Off, "is not referenced");
 function Entry_Spec_P_Name
  (Node : Bare_Entry_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Entry_Spec := Bare_Entry_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Spec :=
     Internal_Entity_Entry_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1593 '<FieldAccess for entry_name at ast.py:17694>' Fld /tmp/lal-23.0.0/ada/ast.py:17694
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Entry_Spec_F_Entry_Name, Info => Ent.Info);
--# expr-done 1593
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Spec_P_Name;
--# end
--# property-start EntrySpec.params /tmp/lal-23.0.0/ada/ast.py:17695
pragma Warnings (Off, "is not referenced");
 function Entry_Spec_P_Params
  (Node : Bare_Entry_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Param_Spec_Array_Access
is
   Self : Bare_Entry_Spec := Bare_Entry_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Spec :=
     Internal_Entity_Entry_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Param_Spec_Array_Access;
            procedure Finalizer_Scope_1272 with Inline_Always;
            procedure Finalizer_Scope_2004 with Inline_Always;
      Var_Expr : Internal_Entity_Params;
Fld : Internal_Entity_Params;
Fld_1 : Internal_Entity_Param_Spec_List;
Fld_2 : Bare_Param_Spec_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Param_Spec;
Is_Null : Boolean;
If_Result : Internal_Entity_Param_Spec;
Item_71 : Internal_Entity_Param_Spec;
Bare_Item_71 : Bare_Param_Spec;
Map_Result : Internal_Entity_Param_Spec_Array_Access;
Scope_Result : Internal_Entity_Param_Spec_Array_Access;
Result_Var : Internal_Entity_Param_Spec_Array_Access;
            procedure Finalizer_Scope_1272 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1272;
            procedure Finalizer_Scope_2004 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2004;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 1594 '<FieldAccess for entry_params at ast.py:17696>' Fld /tmp/lal-23.0.0/ada/ast.py:17696
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Params (Node => Ent.Node.Entry_Spec_F_Entry_Params, Info => Ent.Info);
--# expr-done 1594
Var_Expr := Fld;
if Var_Expr /= No_Entity_Params then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 1596 '<Map at ast.py:17697>' Map_Result /tmp/lal-23.0.0/ada/ast.py:17697
   --# expr-start 1595 '<FieldAccess for params at ast.py:17697>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17697
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Param_Spec_List (Node => Var_Expr.Node.Params_F_Params, Info => Var_Expr.Info);
--# expr-done 1595
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Internal_Entity_Param_Spec_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Param_Spec_Array (0);
      else
      declare
         Collection : constant Bare_Param_Spec_List := Fld_2;
      begin
         for Untyped_Item_71 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_71 := Untyped_Item_71; 
Is_Null := Bare_Item_71 = null; 
if Is_Null then
   If_Result := No_Entity_Param_Spec;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_71); 
   If_Result := As_Entity;
end if;
                  Item_71 := If_Result; 
   --# scope-start
               --# bind p Item_71
         declare
            Item_To_Append : constant Internal_Entity_Param_Spec := Item_71;
         begin
            Internal_Entity_Param_Spec_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Param_Spec_Array
           (Items_Count => Natural (Internal_Entity_Param_Spec_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Param_Spec_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Param_Spec_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Param_Spec_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1596
Scope_Result := Map_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2004;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Param_Spec_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1272;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1272;
               Finalizer_Scope_2004;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Spec_P_Params;
--# end
--# property-start EntrySpec.returns /tmp/lal-23.0.0/ada/ast.py:17701
pragma Warnings (Off, "is not referenced");
 function Entry_Spec_P_Returns
  (Node : Bare_Entry_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Entry_Spec := Bare_Entry_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Type_Expr;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Spec_P_Returns;
--# end
--# property-start EntrySpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:17703
pragma Warnings (Off, "is not referenced");
 function Entry_Spec_P_Xref_Equation
  (Node : Bare_Entry_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Entry_Spec := Bare_Entry_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Spec :=
     Internal_Entity_Entry_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1274 with Inline_Always;
            procedure Finalizer_Scope_2006 with Inline_Always;
      Var_Expr : Internal_Entity;
Fld : Internal_Entity;
Fld_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
            procedure Finalizer_Scope_1274 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1274;
            procedure Finalizer_Scope_2006 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2006;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 1597 '<FieldAccess for family_type at ast.py:17703>' Fld /tmp/lal-23.0.0/ada/ast.py:17703
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Entry_Spec_F_Family_Type, Info => Ent.Info);
--# expr-done 1597
Var_Expr := Fld;
if Var_Expr /= No_Entity then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 1598 '<FieldAccess for sub_equation at ast.py:17704>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17704
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1598
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2006;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17705") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1274;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1274;
               Finalizer_Scope_2006;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Spec_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Enum_Subp_Spec
   --
--# property-start EnumSubpSpec.enum_decl /tmp/lal-23.0.0/ada/ast.py:17439
pragma Warnings (Off, "is not referenced");
 function Enum_Subp_Spec_P_Enum_Decl
  (Node : Bare_Enum_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Enum_Literal_Decl
is
   Self : Bare_Enum_Subp_Spec := Bare_Enum_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Enum_Literal_Decl;
      Fld : Bare_Ada_Node;
Cast_Result : Bare_Enum_Literal_Decl;
As_Entity : Internal_Entity_Enum_Literal_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Enum_Literal_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1601 '<as_entity at ast.py:17439>' If_Result /tmp/lal-23.0.0/ada/ast.py:17439
--# expr-start 1600 '<Cast to EnumLiteralDecl at ast.py:17439>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17439
--# expr-start 1599 '<parent at ast.py:17439>' Fld /tmp/lal-23.0.0/ada/ast.py:17439
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 1599
   if Fld = null
      or else Fld.Kind in Ada_Enum_Literal_Decl_Range
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 1600
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Enum_Literal_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 1601
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Subp_Spec_P_Enum_Decl;
--# end
--# property-start EnumSubpSpec.name /tmp/lal-23.0.0/ada/ast.py:17441
pragma Warnings (Off, "is not referenced");
 function Enum_Subp_Spec_P_Name
  (Node : Bare_Enum_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Enum_Subp_Spec := Bare_Enum_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Subp_Spec :=
     Internal_Entity_Enum_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Enum_Literal_Decl;
Fld_1 : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1603 '<FieldAccess for enum_decl_name at ast.py:17441>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17441
--# expr-start 1602 '<FieldAccess for enum_decl at ast.py:17441>' Fld /tmp/lal-23.0.0/ada/ast.py:17441
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EnumSubpSpec.enum_decl
Fld := Libadalang.Implementation.Enum_Subp_Spec_P_Enum_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1602
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]EnumLiteralDecl.enum_decl_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Enum_Literal_Decl_P_Enum_Decl_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 1603
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Subp_Spec_P_Name;
--# end
--# property-start EnumSubpSpec.returns /tmp/lal-23.0.0/ada/ast.py:17442
pragma Warnings (Off, "is not referenced");
 function Enum_Subp_Spec_P_Returns
  (Node : Bare_Enum_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Enum_Subp_Spec := Bare_Enum_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Subp_Spec :=
     Internal_Entity_Enum_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Enum_Literal_Decl;
Fld_1 : Internal_Entity_Enum_Lit_Synth_Type_Expr;
Cast_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 1605 '<FieldAccess for synth_type_expr at ast.py:17442>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17442
--# expr-start 1604 '<FieldAccess for enum_decl at ast.py:17442>' Fld /tmp/lal-23.0.0/ada/ast.py:17442
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EnumSubpSpec.enum_decl
Fld := Libadalang.Implementation.Enum_Subp_Spec_P_Enum_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1604
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EnumLiteralDecl.synth_type_expr
Fld_1 := Libadalang.Implementation.Enum_Literal_Decl_P_Synth_Type_Expr (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 1605
      Cast_Result := Create_Internal_Entity_Type_Expr
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Subp_Spec_P_Returns;
--# end
--# property-start EnumSubpSpec.params /tmp/lal-23.0.0/ada/ast.py:17443
pragma Warnings (Off, "is not referenced");
 function Enum_Subp_Spec_P_Params
  (Node : Bare_Enum_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Param_Spec_Array_Access
is
   Self : Bare_Enum_Subp_Spec := Bare_Enum_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Param_Spec_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Param_Spec_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Subp_Spec_P_Params;
--# end
   --
   --  Primitives for Bare_Subp_Spec
   --
      procedure Initialize_Fields_For_Subp_Spec
        (Self : Bare_Subp_Spec
         ; Subp_Spec_F_Subp_Kind : Bare_Subp_Kind
         ; Subp_Spec_F_Subp_Name : Bare_Defining_Name
         ; Subp_Spec_F_Subp_Params : Bare_Params
         ; Subp_Spec_F_Subp_Returns : Bare_Type_Expr
        ) is
      begin
            Self.Subp_Spec_F_Subp_Kind := Subp_Spec_F_Subp_Kind;
            Self.Subp_Spec_F_Subp_Name := Subp_Spec_F_Subp_Name;
            Self.Subp_Spec_F_Subp_Params := Subp_Spec_F_Subp_Params;
            Self.Subp_Spec_F_Subp_Returns := Subp_Spec_F_Subp_Returns;
      end Initialize_Fields_For_Subp_Spec;
   function Subp_Spec_F_Subp_Kind
     (Node : Bare_Subp_Spec) return Bare_Subp_Kind
   is
   begin
         return Node.Subp_Spec_F_Subp_Kind;
   end;
   function Subp_Spec_F_Subp_Name
     (Node : Bare_Subp_Spec) return Bare_Defining_Name
   is
   begin
         return Node.Subp_Spec_F_Subp_Name;
   end;
   function Subp_Spec_F_Subp_Params
     (Node : Bare_Subp_Spec) return Bare_Params
   is
   begin
         return Node.Subp_Spec_F_Subp_Params;
   end;
   function Subp_Spec_F_Subp_Returns
     (Node : Bare_Subp_Spec) return Bare_Type_Expr
   is
   begin
         return Node.Subp_Spec_F_Subp_Returns;
   end;
--# property-start SubpSpec.name /tmp/lal-23.0.0/ada/ast.py:17597
pragma Warnings (Off, "is not referenced");
 function Subp_Spec_P_Name
  (Node : Bare_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Subp_Spec := Bare_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Spec :=
     Internal_Entity_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1606 '<FieldAccess for subp_name at ast.py:17597>' Fld /tmp/lal-23.0.0/ada/ast.py:17597
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Subp_Spec_F_Subp_Name, Info => Ent.Info);
--# expr-done 1606
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Spec_P_Name;
--# end
--# property-start SubpSpec.params /tmp/lal-23.0.0/ada/ast.py:17598
pragma Warnings (Off, "is not referenced");
 function Subp_Spec_P_Params
  (Node : Bare_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Param_Spec_Array_Access
is
   Self : Bare_Subp_Spec := Bare_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Spec :=
     Internal_Entity_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Param_Spec_Array_Access;
            procedure Finalizer_Scope_1262 with Inline_Always;
      Var_Expr : Internal_Entity_Params;
Fld : Internal_Entity_Params;
Fld_1 : Internal_Entity_Param_Spec_List;
Scope_Result : Internal_Entity_Param_Spec_List;
Result_Var : Internal_Entity_Param_Spec_List;
Fld_2 : Bare_Param_Spec_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Param_Spec;
Is_Null : Boolean;
If_Result : Internal_Entity_Param_Spec;
Item_72 : Internal_Entity_Param_Spec;
Bare_Item_72 : Bare_Param_Spec;
Map_Result : Internal_Entity_Param_Spec_Array_Access;
            procedure Finalizer_Scope_1262 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1262;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1609 '<Map at ast.py:17598>' Map_Result /tmp/lal-23.0.0/ada/ast.py:17598
--# expr-start 1607 '<FieldAccess for subp_params at ast.py:17598>' Fld /tmp/lal-23.0.0/ada/ast.py:17598
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Params (Node => Ent.Node.Subp_Spec_F_Subp_Params, Info => Ent.Info);
--# expr-done 1607
Var_Expr := Fld;
if Var_Expr /= No_Entity_Params then
   --# scope-start
--# expr-start 1608 '<FieldAccess for params at ast.py:17598>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17598
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Param_Spec_List (Node => Var_Expr.Node.Params_F_Params, Info => Var_Expr.Info);
--# expr-done 1608
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Param_Spec_List;
end if;
Fld_2 := Result_Var.Node;
      declare
         Map_Result_Vec : Internal_Entity_Param_Spec_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Param_Spec_Array (0);
      else
      declare
         Collection : constant Bare_Param_Spec_List := Fld_2;
      begin
         for Untyped_Item_72 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_72 := Untyped_Item_72; 
Is_Null := Bare_Item_72 = null; 
if Is_Null then
   If_Result := No_Entity_Param_Spec;
else
Fld_3 := Result_Var.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_72); 
   If_Result := As_Entity;
end if;
                  Item_72 := If_Result; 
   --# scope-start
               --# bind p Item_72
         declare
            Item_To_Append : constant Internal_Entity_Param_Spec := Item_72;
         begin
            Internal_Entity_Param_Spec_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Param_Spec_Array
           (Items_Count => Natural (Internal_Entity_Param_Spec_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Param_Spec_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Param_Spec_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Param_Spec_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1609
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1262;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1262;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Spec_P_Params;
--# end
--# property-start SubpSpec.returns /tmp/lal-23.0.0/ada/ast.py:17600
pragma Warnings (Off, "is not referenced");
 function Subp_Spec_P_Returns
  (Node : Bare_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Subp_Spec := Bare_Subp_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Spec :=
     Internal_Entity_Subp_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1610 '<FieldAccess for subp_returns at ast.py:17600>' Fld /tmp/lal-23.0.0/ada/ast.py:17600
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Subp_Spec_F_Subp_Returns, Info => Ent.Info);
--# expr-done 1610
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Spec_P_Returns;
--# end
   --
   --  Primitives for Bare_Synthetic_Binary_Spec
   --
      procedure Initialize_Fields_For_Synthetic_Binary_Spec
        (Self : Bare_Synthetic_Binary_Spec
         ; Synthetic_Binary_Spec_F_Left_Param : Bare_Synthetic_Formal_Param_Decl
         ; Synthetic_Binary_Spec_F_Right_Param : Bare_Synthetic_Formal_Param_Decl
         ; Synthetic_Binary_Spec_F_Return_Type_Expr : Bare_Type_Expr
        ) is
      begin
            Self.Synthetic_Binary_Spec_F_Left_Param := Synthetic_Binary_Spec_F_Left_Param;
            Self.Synthetic_Binary_Spec_F_Right_Param := Synthetic_Binary_Spec_F_Right_Param;
            Self.Synthetic_Binary_Spec_F_Return_Type_Expr := Synthetic_Binary_Spec_F_Return_Type_Expr;
      Self.Synthetic_Binary_Spec_Subp_Symbol := null;
      end Initialize_Fields_For_Synthetic_Binary_Spec;
   function Synthetic_Binary_Spec_F_Left_Param
     (Node : Bare_Synthetic_Binary_Spec) return Bare_Synthetic_Formal_Param_Decl
   is
   begin
         return Node.Synthetic_Binary_Spec_F_Left_Param;
   end;
   function Synthetic_Binary_Spec_F_Right_Param
     (Node : Bare_Synthetic_Binary_Spec) return Bare_Synthetic_Formal_Param_Decl
   is
   begin
         return Node.Synthetic_Binary_Spec_F_Right_Param;
   end;
   function Synthetic_Binary_Spec_F_Return_Type_Expr
     (Node : Bare_Synthetic_Binary_Spec) return Bare_Type_Expr
   is
   begin
         return Node.Synthetic_Binary_Spec_F_Return_Type_Expr;
   end;
--# property-start SyntheticBinarySpec.name /tmp/lal-23.0.0/ada/ast.py:17555
pragma Warnings (Off, "is not referenced");
 function Synthetic_Binary_Spec_P_Name
  (Node : Bare_Synthetic_Binary_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Synthetic_Binary_Spec := Bare_Synthetic_Binary_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Symbol_Type;
Fld_1 : Bare_Defining_Name;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1613 '<as_entity at ast.py:17555>' If_Result /tmp/lal-23.0.0/ada/ast.py:17555
--# expr-start 1612 '<FieldAccess for synthesize_defining_name at ast.py:17555>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17555
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1611 '<FieldAccess for subp_symbol at ast.py:17555>' Fld /tmp/lal-23.0.0/ada/ast.py:17555
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Synthetic_Binary_Spec_Subp_Symbol;
--# expr-done 1611
--# property-call-start AdaNode.synthesize_defining_name
Fld_1 := Libadalang.Implementation.Ada_Node_P_Synthesize_Defining_Name (Node => Self, Sym => Fld);
--# end
--# expr-done 1612
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 1613
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Binary_Spec_P_Name;
--# end
--# property-start SyntheticBinarySpec.returns /tmp/lal-23.0.0/ada/ast.py:17556
pragma Warnings (Off, "is not referenced");
 function Synthetic_Binary_Spec_P_Returns
  (Node : Bare_Synthetic_Binary_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Synthetic_Binary_Spec := Bare_Synthetic_Binary_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Binary_Spec :=
     Internal_Entity_Synthetic_Binary_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1614 '<FieldAccess for return_type_expr at ast.py:17556>' Fld /tmp/lal-23.0.0/ada/ast.py:17556
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Synthetic_Binary_Spec_F_Return_Type_Expr, Info => Ent.Info);
--# expr-done 1614
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Binary_Spec_P_Returns;
--# end
--# property-start SyntheticBinarySpec.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:17559
pragma Warnings (Off, "is not referenced");
 function Synthetic_Binary_Spec_P_Abstract_Formal_Params
  (Node : Bare_Synthetic_Binary_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Synthetic_Binary_Spec := Bare_Synthetic_Binary_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Binary_Spec :=
     Internal_Entity_Synthetic_Binary_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1257 with Inline_Always;
      Fld : Internal_Entity_Synthetic_Formal_Param_Decl;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Fld_1 : Internal_Entity_Synthetic_Formal_Param_Decl;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Decl;
Array_Lit : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1257 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1257;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1620 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1619 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 1616 '<Cast to BaseFormalParamDecl at ast.py:17561>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17561
--# expr-start 1615 '<FieldAccess for left_param at ast.py:17561>' Fld /tmp/lal-23.0.0/ada/ast.py:17561
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Synthetic_Formal_Param_Decl (Node => Ent.Node.Synthetic_Binary_Spec_F_Left_Param, Info => Ent.Info);
--# expr-done 1615
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
--# expr-done 1616
--# expr-start 1618 '<Cast to BaseFormalParamDecl at ast.py:17562>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:17562
--# expr-start 1617 '<FieldAccess for right_param at ast.py:17562>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Synthetic_Formal_Param_Decl (Node => Ent.Node.Synthetic_Binary_Spec_F_Right_Param, Info => Ent.Info);
--# expr-done 1617
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
--# expr-done 1618
Array_Lit := Create_Internal_Entity_Base_Formal_Param_Decl_Array (Internal_Internal_Entity_Base_Formal_Param_Decl_Array'(1 => Cast_Result, 2 => Cast_Result_1)); 
--# expr-done 1619
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 1620
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1257;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1257;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Binary_Spec_P_Abstract_Formal_Params;
--# end
   --
   --  Primitives for Bare_Synthetic_Unary_Spec
   --
      procedure Initialize_Fields_For_Synthetic_Unary_Spec
        (Self : Bare_Synthetic_Unary_Spec
         ; Synthetic_Unary_Spec_F_Right_Param : Bare_Synthetic_Formal_Param_Decl
         ; Synthetic_Unary_Spec_F_Return_Type_Expr : Bare_Synthetic_Type_Expr
        ) is
      begin
            Self.Synthetic_Unary_Spec_F_Right_Param := Synthetic_Unary_Spec_F_Right_Param;
            Self.Synthetic_Unary_Spec_F_Return_Type_Expr := Synthetic_Unary_Spec_F_Return_Type_Expr;
      Self.Synthetic_Unary_Spec_Subp_Symbol := null;
      end Initialize_Fields_For_Synthetic_Unary_Spec;
   function Synthetic_Unary_Spec_F_Right_Param
     (Node : Bare_Synthetic_Unary_Spec) return Bare_Synthetic_Formal_Param_Decl
   is
   begin
         return Node.Synthetic_Unary_Spec_F_Right_Param;
   end;
   function Synthetic_Unary_Spec_F_Return_Type_Expr
     (Node : Bare_Synthetic_Unary_Spec) return Bare_Synthetic_Type_Expr
   is
   begin
         return Node.Synthetic_Unary_Spec_F_Return_Type_Expr;
   end;
--# property-start SyntheticUnarySpec.name /tmp/lal-23.0.0/ada/ast.py:17537
pragma Warnings (Off, "is not referenced");
 function Synthetic_Unary_Spec_P_Name
  (Node : Bare_Synthetic_Unary_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Synthetic_Unary_Spec := Bare_Synthetic_Unary_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Symbol_Type;
Fld_1 : Bare_Defining_Name;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1623 '<as_entity at ast.py:17537>' If_Result /tmp/lal-23.0.0/ada/ast.py:17537
--# expr-start 1622 '<FieldAccess for synthesize_defining_name at ast.py:17537>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17537
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1621 '<FieldAccess for subp_symbol at ast.py:17537>' Fld /tmp/lal-23.0.0/ada/ast.py:17537
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Synthetic_Unary_Spec_Subp_Symbol;
--# expr-done 1621
--# property-call-start AdaNode.synthesize_defining_name
Fld_1 := Libadalang.Implementation.Ada_Node_P_Synthesize_Defining_Name (Node => Self, Sym => Fld);
--# end
--# expr-done 1622
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 1623
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Unary_Spec_P_Name;
--# end
--# property-start SyntheticUnarySpec.returns /tmp/lal-23.0.0/ada/ast.py:17538
pragma Warnings (Off, "is not referenced");
 function Synthetic_Unary_Spec_P_Returns
  (Node : Bare_Synthetic_Unary_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Synthetic_Unary_Spec := Bare_Synthetic_Unary_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Unary_Spec :=
     Internal_Entity_Synthetic_Unary_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Synthetic_Type_Expr;
Cast_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 1624 '<FieldAccess for return_type_expr at ast.py:17538>' Fld /tmp/lal-23.0.0/ada/ast.py:17538
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Synthetic_Type_Expr (Node => Ent.Node.Synthetic_Unary_Spec_F_Return_Type_Expr, Info => Ent.Info);
--# expr-done 1624
      Cast_Result := Create_Internal_Entity_Type_Expr
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Unary_Spec_P_Returns;
--# end
--# property-start SyntheticUnarySpec.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:17541
pragma Warnings (Off, "is not referenced");
 function Synthetic_Unary_Spec_P_Abstract_Formal_Params
  (Node : Bare_Synthetic_Unary_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Synthetic_Unary_Spec := Bare_Synthetic_Unary_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Unary_Spec :=
     Internal_Entity_Synthetic_Unary_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1254 with Inline_Always;
      Fld : Internal_Entity_Synthetic_Formal_Param_Decl;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Array_Lit : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1254 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1254;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1628 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1627 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 1626 '<Cast to BaseFormalParamDecl at ast.py:17542>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17542
--# expr-start 1625 '<FieldAccess for right_param at ast.py:17542>' Fld /tmp/lal-23.0.0/ada/ast.py:17542
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Synthetic_Formal_Param_Decl (Node => Ent.Node.Synthetic_Unary_Spec_F_Right_Param, Info => Ent.Info);
--# expr-done 1625
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
--# expr-done 1626
Array_Lit := Create_Internal_Entity_Base_Formal_Param_Decl_Array (Internal_Internal_Entity_Base_Formal_Param_Decl_Array'(1 => Cast_Result)); 
--# expr-done 1627
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 1628
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1254;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1254;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Unary_Spec_P_Abstract_Formal_Params;
--# end
   --
   --  Primitives for Bare_Component_List
   --
      procedure Initialize_Fields_For_Component_List
        (Self : Bare_Component_List
         ; Component_List_F_Components : Bare_Ada_Node_List
         ; Component_List_F_Variant_Part : Bare_Variant_Part
        ) is
      begin
            Self.Component_List_F_Components := Component_List_F_Components;
            Self.Component_List_F_Variant_Part := Component_List_F_Variant_Part;
      end Initialize_Fields_For_Component_List;
   function Component_List_F_Components
     (Node : Bare_Component_List) return Bare_Ada_Node_List
   is
   begin
         return Node.Component_List_F_Components;
   end;
   function Component_List_F_Variant_Part
     (Node : Bare_Component_List) return Bare_Variant_Part
   is
   begin
         return Node.Component_List_F_Variant_Part;
   end;
--# property-start ComponentList.type_def /tmp/lal-23.0.0/ada/ast.py:4810
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Type_Def
  (Node : Bare_Component_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Def
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Def;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Type_Def;
As_Entity : Internal_Entity_Type_Def;
Is_Null : Boolean;
If_Result : Internal_Entity_Type_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1632 '<as_entity at ast.py:4810>' If_Result /tmp/lal-23.0.0/ada/ast.py:4810
--# expr-start 1631 '<Cast to TypeDef at ast.py:4810>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4810
--# expr-start 1630 '<parent at ast.py:4810>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4810
--# expr-start 1629 '<parent at ast.py:4810>' Fld /tmp/lal-23.0.0/ada/ast.py:4810
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 1629
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 1630
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Type_Def
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 1631
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Type_Def;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 1632
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Type_Def;
--# end
--# property-start ComponentList.type_decl /tmp/lal-23.0.0/ada/ast.py:4811
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Type_Decl
  (Node : Bare_Component_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Decl;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1635 '<Cast to TypeDecl at ast.py:4811>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4811
--# expr-start 1634 '<parent at ast.py:4811>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4811
--# expr-start 1633 '<FieldAccess for type_def at ast.py:4811>' Fld /tmp/lal-23.0.0/ada/ast.py:4811
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_def
Fld := Libadalang.Implementation.Component_List_P_Type_Def (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1633
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 1634
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Type_Decl;
   end if;
--# expr-done 1635
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Type_Decl;
--# end
--# property-start ComponentList.parent_component_list /tmp/lal-23.0.0/ada/ast.py:4813
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Parent_Component_List
  (Node : Bare_Component_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Component_List
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Component_List;
      Var_Expr : Internal_Entity_Base_Record_Def;
Var_Expr_1 : Internal_Entity_Derived_Type_Def;
Cast_Expr : Bare_Component_List;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Type_Def;
Cast_Result_1 : Internal_Entity_Derived_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Record_Def;
Scope_Result : Internal_Entity_Base_Record_Def;
Result_Var : Internal_Entity_Base_Record_Def;
Fld_3 : Internal_Entity_Component_List;
Scope_Result_1 : Internal_Entity_Component_List;
Result_Var_1 : Internal_Entity_Component_List;
Dyn_Var_Bind_Result : Internal_Entity_Component_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1641 '<bind at ast.py:4813>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:4813
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 1637 '<Cast to DerivedTypeDef at ast.py:4815>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:4815
--# expr-start 1636 '<FieldAccess for type_def at ast.py:4815>' Fld /tmp/lal-23.0.0/ada/ast.py:4815
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_def
Fld := Libadalang.Implementation.Component_List_P_Type_Def (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1636
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Derived_Type_Def_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Derived_Type_Def
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result_1 := No_Entity_Derived_Type_Def;
   end if;
--# expr-done 1637
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Derived_Type_Def then
   --# scope-start
--# expr-start 1639 '<FieldAccess for record_def at ast.py:4815>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4815
--# expr-start 1638 '<FieldAccess for base_type at ast.py:4815>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4815
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1638
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Fld_1.Node, Origin => Bound_Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 1639
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Record_Def;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Base_Record_Def then
   --# scope-start
--# expr-start 1640 '<FieldAccess for comps at ast.py:4815>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4815
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseRecordDef.comps
Fld_3 := Libadalang.Implementation.Base_Record_Def_P_Comps (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1640
Scope_Result_1 := Fld_3;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Component_List;
end if;
Dyn_Var_Bind_Result := Result_Var_1; 
--# expr-done 1641
      Property_Result := Dyn_Var_Bind_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Parent_Component_List;
--# end
--# property-start ComponentList.abstract_formal_params_for_assocs /tmp/lal-23.0.0/ada/ast.py:4820
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Abstract_Formal_Params_For_Assocs
  (Node : Bare_Component_List
      ; Assocs : Internal_Entity_Assoc_List
      ; Stop_Recurse_At : Internal_Entity_Base_Type_Decl
         := No_Entity_Base_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind assocs Assocs
   --# bind stop_recurse_at Stop_Recurse_At
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_315 with Inline_Always;
      Block_Var : Internal_Entity_Type_Decl;
Block_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Block_Var_2 : Internal_Param_Match_Array_Access;
Fld : Internal_Entity_Type_Decl;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_2 : Internal_Param_Match_Array_Access;
Fld_3 : Internal_Entity_Defining_Name;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_4 : Internal_Entity_Defining_Name;
Fld_5 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Expr : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Find_Result : Internal_Entity_Base_Formal_Param_Decl;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Map_Result : Internal_Param_Match_Array_Access;
Fld_6 : Internal_Entity_Base_Record_Def;
Fld_7 : Internal_Entity_Component_List;
Fld_8 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_315 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_315;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1658 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1642 '<FieldAccess for type_decl at ast.py:4825>' Fld /tmp/lal-23.0.0/ada/ast.py:4825
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_decl
Fld := Libadalang.Implementation.Component_List_P_Type_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1642
Block_Var := Fld; 
--# bind td Block_Var
--# expr-start 1643 '<FieldAccess for discriminants_list at ast.py:4826>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4826
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 1643
Block_Var_1 := Fld_1; Inc_Ref (Block_Var_1);
--# bind discriminants Block_Var_1
--# expr-start 1654 '<Filter at ast.py:4831>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4831
   --# expr-start 1644 '<FieldAccess for match_formals at ast.py:4829>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4829
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.match_formals
Fld_2 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Block_Var_1, Params => Assocs, Is_Dottable_Subp => False);
--# end
--# expr-done 1644
      declare
         Map_Result_Vec : Internal_Param_Match_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_2;
      begin
         for Item_73 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_73
--# expr-start 1647 '<Not at ast.py:4833>' Not_Val /tmp/lal-23.0.0/ada/ast.py:4833
--# expr-start 1646 '<IsNull at ast.py:4833>' Is_Null /tmp/lal-23.0.0/ada/ast.py:4833
--# expr-start 1645 '<FieldAccess for formal at ast.py:4833>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4833
Fld_3 := Item_73.Formal;
--# expr-done 1645
Is_Null := Fld_3.Node = null; 
--# expr-done 1646
Not_Val := not (Is_Null); 
--# expr-done 1647
if Not_Val then
   --# expr-start 1653 '<Not at ast.py:4834>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:4834
--# expr-start 1652 '<IsNull at ast.py:4835>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:4835
--# expr-start 1651 '<Find at ast.py:4834>' Find_Result /tmp/lal-23.0.0/ada/ast.py:4834
      Find_Result := No_Entity_Base_Formal_Param_Decl;
      declare
         Collection : constant Internal_Entity_Base_Formal_Param_Decl_Array_Access := Block_Var_1;
      begin
         for Item_74 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_74
      --# expr-start 1650 '<Eq at ast.py:4835>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:4835
Cast_Expr := Item_74; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 1649 '<FieldAccess for formal_decl at ast.py:4835>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4835
--# expr-start 1648 '<FieldAccess for formal at ast.py:4835>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4835
Fld_4 := Item_73.Formal;
--# expr-done 1648
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_5 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 1649
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 1650
      if Is_Equiv then
         Find_Result := Item_74;
      end if;
   --# end
               exit when Is_Equiv;
         end loop;
      end;
--# expr-done 1651
Is_Null_1 := Find_Result.Node = null; 
--# expr-done 1652
Not_Val_1 := not (Is_Null_1); 
--# expr-done 1653
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
         if If_Result then
         declare
            Item_To_Append : constant Internal_Param_Match := Item_73;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1654
Block_Var_2 := Map_Result; Inc_Ref (Block_Var_2);
--# bind discriminants_matches Block_Var_2
--# expr-start 1657 '<FieldAccess for abstract_formal_params_impl at ast.py:4843>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4843
--# expr-start 1656 '<FieldAccess for comps at ast.py:4843>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4843
--# expr-start 1655 '<FieldAccess for record_def at ast.py:4843>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4843
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 1655
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseRecordDef.comps
Fld_7 := Libadalang.Implementation.Base_Record_Def_P_Comps (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 1656
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.abstract_formal_params_impl
Fld_8 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_Impl (Node => Fld_7.Node, Discriminants => Block_Var_2, Stop_Recurse_At => Stop_Recurse_At, E_Info => Fld_7.Info);
--# end
--# expr-done 1657
Let_Result := Fld_8; Inc_Ref (Let_Result);
--# end
--# expr-done 1658
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_315;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_315;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Abstract_Formal_Params_For_Assocs;
--# end
--# property-start ComponentList.abstract_formal_params_for_delta_assocs /tmp/lal-23.0.0/ada/ast.py:4849
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Abstract_Formal_Params_For_Delta_Assocs
  (Node : Bare_Component_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_316 with Inline_Always;
            procedure Finalizer_Scope_2014 with Inline_Always;
            procedure Finalizer_Scope_2016 with Inline_Always;
      Block_Var : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Block_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Block_Var_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Var_Expr : Internal_Entity_Variant_Part;
Var_Expr_1 : Internal_Entity_Component_List;
Fld : Internal_Entity_Variant_Part;
Fld_1 : Internal_Entity_Variant_List;
Scope_Result : Internal_Entity_Variant_List;
Result_Var : Internal_Entity_Variant_List;
Fld_2 : Bare_Variant_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Variant;
Is_Null : Boolean;
If_Result : Internal_Entity_Variant;
Fld_4 : Internal_Entity_Component_List;
Fld_5 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Item_75 : Internal_Entity_Variant;
Bare_Item_75 : Bare_Variant;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_6 : Internal_Entity_Ada_Node_List;
Fld_7 : Bare_Ada_Node_List;
Fld_8 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_76 : Internal_Entity;
Bare_Item_76 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_9 : Internal_Entity_Component_List;
Fld_10 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_316 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_316;
            procedure Finalizer_Scope_2014 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2014;
            procedure Finalizer_Scope_2016 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_2016;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1672 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1663 '<Mapcat at ast.py:4856>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4856
--# expr-start 1659 '<FieldAccess for variant_part at ast.py:4856>' Fld /tmp/lal-23.0.0/ada/ast.py:4856
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Variant_Part (Node => Ent.Node.Component_List_F_Variant_Part, Info => Ent.Info);
--# expr-done 1659
Var_Expr := Fld;
if Var_Expr /= No_Entity_Variant_Part then
   --# scope-start
--# expr-start 1660 '<FieldAccess for variant at ast.py:4856>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4856
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Variant_List (Node => Var_Expr.Node.Variant_Part_F_Variant, Info => Var_Expr.Info);
--# expr-done 1660
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Variant_List;
end if;
Fld_2 := Result_Var.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Variant_List := Fld_2;
      begin
         for Untyped_Item_75 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_75 := Untyped_Item_75; 
Is_Null := Bare_Item_75 = null; 
if Is_Null then
   If_Result := No_Entity_Variant;
else
Fld_3 := Result_Var.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_75); 
   If_Result := As_Entity;
end if;
                  Item_75 := If_Result; 
   --# scope-start
               --# bind v Item_75
      --# expr-start 1662 '<FieldAccess for abstract_formal_params_for_delta_assocs at ast.py:4857>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4857
--# expr-start 1661 '<FieldAccess for components at ast.py:4857>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4857
      if Item_75.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Component_List (Node => Item_75.Node.Variant_F_Components, Info => Item_75.Info);
--# expr-done 1661
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.abstract_formal_params_for_delta_assocs
Fld_5 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_For_Delta_Assocs (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 1662
         for Item_To_Append of
               Fld_5.Items
         loop
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2014;
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1663
Block_Var := Map_Result; Inc_Ref (Block_Var);
--# bind variant_part_components Block_Var
--# expr-start 1667 '<FilterMap at ast.py:4859>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:4859
   --# expr-start 1664 '<FieldAccess for components at ast.py:4859>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4859
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Ada_Node_List (Node => Ent.Node.Component_List_F_Components, Info => Ent.Info);
--# expr-done 1664
Fld_7 := Fld_6.Node;
      declare
         Map_Result_1_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_7 = null then
      Map_Result_1 := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_7;
      begin
         for Untyped_Item_76 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_76 := Untyped_Item_76; 
Is_Null_1 := Bare_Item_76 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_8 := Fld_6.Info;
As_Entity_1 := (Info => Fld_8, Node => Bare_Item_76); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_76 := If_Result_1; 
   --# scope-start
               --# bind e Item_76
         --# expr-start 1665 '<IsA BaseFormalParamDecl at ???>' Is_A None
Is_A := Item_76.Node /= null 
and then Item_76.Node.Kind in Ada_Base_Formal_Param_Decl; 
--# expr-done 1665
         if Is_A then
      --# expr-start 1666 '<Cast to BaseFormalParamDecl at ???>' Cast_Result None
Cast_Expr := Item_76; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Formal_Param_Decl;
   end if;
--# expr-done 1666
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 1667
Block_Var_1 := Map_Result_1; Inc_Ref (Block_Var_1);
--# bind self_components Block_Var_1
--# expr-start 1668 '<FieldAccess for parent_component_list at ast.py:4860>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4860
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.parent_component_list
Fld_9 := Libadalang.Implementation.Component_List_P_Parent_Component_List (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1668
Var_Expr_1 := Fld_9;
if Var_Expr_1 /= No_Entity_Component_List then
   --# scope-start
--# expr-start 1669 '<FieldAccess for abstract_formal_params_for_delta_assocs at ast.py:4861>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4861
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.abstract_formal_params_for_delta_assocs
Fld_10 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_For_Delta_Assocs (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1669
Scope_Result_1 := Fld_10;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2016;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Block_Var_2 := Result_Var_1; Inc_Ref (Block_Var_2);
--# bind parent_components Block_Var_2
--# expr-start 1671 '<Concat at ast.py:4863>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:4863
--# expr-start 1670 '<Concat at ast.py:4862>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:4862
Concat_Result := Concat (Block_Var, Block_Var_1); 
--# expr-done 1670
Concat_Result_1 := Concat (Concat_Result, Block_Var_2); 
--# expr-done 1671
Let_Result := Concat_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1672
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_316;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_316;
               Finalizer_Scope_2014;
               Finalizer_Scope_2016;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Abstract_Formal_Params_For_Delta_Assocs;
--# end
--# property-start ComponentList.abstract_formal_params_impl /tmp/lal-23.0.0/ada/ast.py:4866
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Abstract_Formal_Params_Impl
  (Node : Bare_Component_List
      ; Discriminants : Internal_Param_Match_Array_Access
      ; Include_Discriminants : Boolean
         := True
      ; Recurse : Boolean
         := True
      ; Stop_Recurse_At : Internal_Entity_Base_Type_Decl
         := No_Entity_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind discriminants Discriminants
   --# bind include_discriminants Include_Discriminants
   --# bind recurse Recurse
   --# bind stop_recurse_at Stop_Recurse_At
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_317 with Inline_Always;
            procedure Finalizer_Scope_2018 with Inline_Always;
            procedure Finalizer_Scope_2019 with Inline_Always;
            procedure Finalizer_Scope_2021 with Inline_Always;
      Block_Var : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Block_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Var_Expr : Internal_Entity_Variant_Part;
Var_Expr_1 : Internal_Entity_Component_List;
Var_Expr_2 : Internal_Entity_Composite_Constraint;
Var_Expr_3 : Internal_Entity_Type_Decl;
Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_77 : Internal_Entity;
Bare_Item_77 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_3 : Internal_Entity_Variant_Part;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_5 : Internal_Entity_Component_List;
Fld_6 : Internal_Entity_Type_Decl;
Fld_7 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_8 : Internal_Entity_Type_Def;
Cast_Result_1 : Internal_Entity_Derived_Type_Def;
Fld_9 : Internal_Entity_Subtype_Indication;
Fld_10 : Internal_Entity_Constraint;
Cast_Result_2 : Internal_Entity_Composite_Constraint;
Fld_11 : Internal_Entity_Assoc_List;
Scope_Result_1 : Internal_Entity_Assoc_List;
Result_Var_1 : Internal_Entity_Assoc_List;
Fld_12 : Internal_Param_Match_Array_Access;
Fld_13 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_14 : Internal_Entity_Type_Decl;
Fld_15 : Boolean;
If_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
If_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_16 : Internal_Entity_Type_Decl;
Fld_17 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
If_Result_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_317 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Concat_Result_2);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_317;
            procedure Finalizer_Scope_2018 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2018;
            procedure Finalizer_Scope_2019 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (If_Result_1);
            end Finalizer_Scope_2019;
            procedure Finalizer_Scope_2021 is
            begin
                     Dec_Ref (Fld_17);
            end Finalizer_Scope_2021;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1700 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1679 '<Concat at ast.py:4875>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:4875
--# expr-start 1676 '<FilterMap at ast.py:4875>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4875
   --# expr-start 1673 '<FieldAccess for components at ast.py:4875>' Fld /tmp/lal-23.0.0/ada/ast.py:4875
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Ent.Node.Component_List_F_Components, Info => Ent.Info);
--# expr-done 1673
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_77 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_77 := Untyped_Item_77; 
Is_Null := Bare_Item_77 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_77); 
   If_Result := As_Entity;
end if;
                  Item_77 := If_Result; 
   --# scope-start
               --# bind e Item_77
         --# expr-start 1674 '<IsA BaseFormalParamDecl at ???>' Is_A None
Is_A := Item_77.Node /= null 
and then Item_77.Node.Kind in Ada_Base_Formal_Param_Decl; 
--# expr-done 1674
         if Is_A then
      --# expr-start 1675 '<Cast to BaseFormalParamDecl at ???>' Cast_Result None
Cast_Expr := Item_77; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Formal_Param_Decl;
   end if;
--# expr-done 1675
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1676
--# expr-start 1677 '<FieldAccess for variant_part at ast.py:4876>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Variant_Part (Node => Ent.Node.Component_List_F_Variant_Part, Info => Ent.Info);
--# expr-done 1677
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Variant_Part then
   --# scope-start
--# expr-start 1678 '<FieldAccess for get_components at ast.py:4876>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4876
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start VariantPart.get_components
Fld_4 := Libadalang.Implementation.Variant_Part_P_Get_Components (Node => Var_Expr.Node, Discriminants => Discriminants, E_Info => Var_Expr.Info);
--# end
--# expr-done 1678
Scope_Result := Fld_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2018;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result := Concat (Map_Result, Result_Var); 
--# expr-done 1679
Block_Var := Concat_Result; Inc_Ref (Block_Var);
--# bind self_comps Block_Var
--# expr-start 1695 '<If at ast.py:4883>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:4883
if Recurse then
--# expr-start 1680 '<FieldAccess for parent_component_list at ast.py:4885>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4885
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.parent_component_list
Fld_5 := Libadalang.Implementation.Component_List_P_Parent_Component_List (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1680
Var_Expr_1 := Fld_5;
if Var_Expr_1 /= No_Entity_Component_List then
   --# scope-start
   --# bind pcl Var_Expr_1
--# expr-start 1694 '<If at ast.py:4886>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:4886
--# expr-start 1682 '<FieldAccess for matching_type at ast.py:4887>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:4887
--# expr-start 1681 '<FieldAccess for type_decl at ast.py:4887>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:4887
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_decl
Fld_14 := Libadalang.Implementation.Component_List_P_Type_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1681
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_15 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Fld_14.Node, Expected_Type => Stop_Recurse_At, Origin => No_Bare_Ada_Node, E_Info => Fld_14.Info);
--# end
--# expr-done 1682
if Fld_15 then
   If_Result_1 := Block_Var;
else
   --# expr-start 1693 '<Concat at ast.py:4898>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:4898
--# expr-start 1692 '<FieldAccess for abstract_formal_params_impl at ast.py:4889>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:4889
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1691 '<FieldAccess for match_formals at ast.py:4890>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4890
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1684 '<FieldAccess for discriminants_list at ast.py:4891>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4891
--# expr-start 1683 '<FieldAccess for type_decl at ast.py:4891>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4891
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_decl
Fld_6 := Libadalang.Implementation.Component_List_P_Type_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1683
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Fld_6.Node, Origin => No_Bare_Ada_Node, E_Info => Fld_6.Info);
--# end
--# expr-done 1684
--# expr-start 1689 '<Cast to CompositeConstraint at ast.py:4894>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:4894
--# expr-start 1688 '<FieldAccess for constraint at ast.py:4893>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4893
--# expr-start 1687 '<FieldAccess for subtype_indication at ast.py:4893>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4893
--# expr-start 1686 '<Cast to DerivedTypeDef at ast.py:4892>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:4892
--# expr-start 1685 '<FieldAccess for type_def at ast.py:4892>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4892
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_def
Fld_8 := Libadalang.Implementation.Component_List_P_Type_Def (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1685
   if Fld_8.Node = null
      or else Fld_8.Node.Kind in Ada_Derived_Type_Def_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Derived_Type_Def
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
   else
         Cast_Result_1 := No_Entity_Derived_Type_Def;
   end if;
--# expr-done 1686
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Subtype_Indication (Node => Cast_Result_1.Node.Derived_Type_Def_F_Subtype_Indication, Info => Cast_Result_1.Info);
--# expr-done 1687
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Constraint (Node => Fld_9.Node.Subtype_Indication_F_Constraint, Info => Fld_9.Info);
--# expr-done 1688
   if Fld_10.Node = null
      or else Fld_10.Node.Kind in Ada_Composite_Constraint_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Composite_Constraint
        (Node => Fld_10.Node,
         Info => Fld_10.Info);
   else
         Cast_Result_2 := No_Entity_Composite_Constraint;
   end if;
--# expr-done 1689
Var_Expr_2 := Cast_Result_2;
if Var_Expr_2 /= No_Entity_Composite_Constraint then
   --# scope-start
--# expr-start 1690 '<FieldAccess for constraints at ast.py:4894>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4894
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Assoc_List (Node => Var_Expr_2.Node.Composite_Constraint_F_Constraints, Info => Var_Expr_2.Info);
--# expr-done 1690
Scope_Result_1 := Fld_11;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Assoc_List;
end if;
--# property-call-start AdaNode.match_formals
Fld_12 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Var_Expr_1.Node, Formal_Params => Fld_7, Params => Result_Var_1, Is_Dottable_Subp => False);
--# end
--# expr-done 1691
--# property-call-start ComponentList.abstract_formal_params_impl
Fld_13 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_Impl (Node => Var_Expr_1.Node, Discriminants => Fld_12, Include_Discriminants => False, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1692
Concat_Result_1 := Concat (Fld_13, Block_Var); 
--# expr-done 1693
   If_Result_1 := Concat_Result_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 1694
Scope_Result_2 := If_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2019;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Block_Var;
end if;
      Inc_Ref (Result_Var_2);
   If_Result_2 := Result_Var_2;
else
   If_Result_2 := Block_Var;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 1695
Block_Var_1 := If_Result_2; Inc_Ref (Block_Var_1);
--# bind ret Block_Var_1
--# expr-start 1699 '<If at ast.py:4905>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:4905
if Include_Discriminants then
   --# expr-start 1698 '<Concat at ast.py:4907>' Concat_Result_2 /tmp/lal-23.0.0/ada/ast.py:4907
--# expr-start 1696 '<FieldAccess for type_decl at ast.py:4907>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:4907
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_decl
Fld_16 := Libadalang.Implementation.Component_List_P_Type_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1696
Var_Expr_3 := Fld_16;
if Var_Expr_3 /= No_Entity_Type_Decl then
   --# scope-start
--# expr-start 1697 '<FieldAccess for discriminants_list at ast.py:4907>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:4907
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_17 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Var_Expr_3.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 1697
Scope_Result_3 := Fld_17;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2021;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
Concat_Result_2 := Concat (Result_Var_3, Block_Var_1); 
--# expr-done 1698
   If_Result_3 := Concat_Result_2;
else
   If_Result_3 := Block_Var_1;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 1699
Let_Result := If_Result_3; Inc_Ref (Let_Result);
--# end
--# expr-done 1700
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_317;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_317;
               Finalizer_Scope_2018;
               Finalizer_Scope_2019;
               Finalizer_Scope_2021;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Abstract_Formal_Params_Impl;
--# end
--# property-start ComponentList.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:4912
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Abstract_Formal_Params
  (Node : Bare_Component_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_318 with Inline_Always;
      Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_318 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_318;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1702 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1701 '<FieldAccess for abstract_formal_params_impl at ast.py:4913>' Fld /tmp/lal-23.0.0/ada/ast.py:4913
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.abstract_formal_params_impl
Fld := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_Impl (Node => Ent.Node, Discriminants => No_Internal_Param_Match_Array_Type, E_Info => Ent.Info);
--# end
--# expr-done 1701
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 1702
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_318;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_318;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Abstract_Formal_Params;
--# end
--# property-start ComponentList.shapes /tmp/lal-23.0.0/ada/ast.py:4916
pragma Warnings (Off, "is not referenced");
 function Component_List_P_Shapes
  (Node : Bare_Component_List
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Shape_Array_Access
is
   Self : Bare_Component_List := Bare_Component_List (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_List :=
     Internal_Entity_Component_List'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Shape_Array_Access;
            procedure Finalizer_Scope_319 with Inline_Always;
            procedure Finalizer_Scope_2023 with Inline_Always;
            procedure Finalizer_Scope_2024 with Inline_Always;
            procedure Finalizer_Scope_2025 with Inline_Always;
      Block_Var : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Var_Expr : Internal_Entity_Variant_Part;
Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_78 : Internal_Entity;
Bare_Item_78 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_3 : Internal_Entity_Variant_Part;
Fld_4 : Internal_Entity_Variant_List;
Fld_5 : Bare_Variant_List;
Fld_6 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Variant;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Variant;
Fld_7 : Internal_Entity_Component_List;
Fld_8 : Internal_Shape_Array_Access;
Fld_9 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_10 : Internal_Entity_Identifier;
Fld_11 : Internal_Entity_Alternatives_List;
New_Struct : Internal_Discriminant_Values;
Singleton : Internal_Discriminant_Values_Array_Access;
Fld_12 : Internal_Discriminant_Values_Array_Access;
Concat_Result_1 : Internal_Discriminant_Values_Array_Access;
New_Struct_1 : Internal_Shape := No_Shape;
Map_Result_1 : Internal_Shape_Array_Access;
Item_79 : Internal_Entity_Variant;
Bare_Item_79 : Bare_Variant;
Map_Result_2 : Internal_Shape_Array_Access;
Scope_Result : Internal_Shape_Array_Access;
New_Struct_2 : Internal_Shape := No_Shape;
Singleton_1 : Internal_Shape_Array_Access;
Result_Var : Internal_Shape_Array_Access;
Let_Result : Internal_Shape_Array_Access;
            procedure Finalizer_Scope_319 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_2);
                     Dec_Ref (Singleton_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_319;
            procedure Finalizer_Scope_2023 is
            begin
                     Dec_Ref (Map_Result_2);
            end Finalizer_Scope_2023;
            procedure Finalizer_Scope_2024 is
            begin
                     Dec_Ref (Fld_8);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_2024;
            procedure Finalizer_Scope_2025 is
            begin
                     Dec_Ref (Fld_9);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Singleton);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_2025;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1722 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1706 '<FilterMap at ast.py:4920>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4920
   --# expr-start 1703 '<FieldAccess for components at ast.py:4920>' Fld /tmp/lal-23.0.0/ada/ast.py:4920
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Ent.Node.Component_List_F_Components, Info => Ent.Info);
--# expr-done 1703
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_78 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_78 := Untyped_Item_78; 
Is_Null := Bare_Item_78 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_78); 
   If_Result := As_Entity;
end if;
                  Item_78 := If_Result; 
   --# scope-start
               --# bind e Item_78
         --# expr-start 1704 '<IsA BaseFormalParamDecl at ???>' Is_A None
Is_A := Item_78.Node /= null 
and then Item_78.Node.Kind in Ada_Base_Formal_Param_Decl; 
--# expr-done 1704
         if Is_A then
      --# expr-start 1705 '<Cast to BaseFormalParamDecl at ???>' Cast_Result None
Cast_Expr := Item_78; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Formal_Param_Decl;
   end if;
--# expr-done 1705
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1706
Block_Var := Map_Result; Inc_Ref (Block_Var);
--# bind self_comps Block_Var
--# expr-start 1707 '<FieldAccess for variant_part at ast.py:4921>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4921
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Variant_Part (Node => Ent.Node.Component_List_F_Variant_Part, Info => Ent.Info);
--# expr-done 1707
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Variant_Part then
   --# scope-start
   --# bind vpart Var_Expr
--# expr-start 1720 '<Mapcat at ast.py:4922>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:4922
   --# expr-start 1708 '<FieldAccess for variant at ast.py:4922>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4922
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Variant_List (Node => Var_Expr.Node.Variant_Part_F_Variant, Info => Var_Expr.Info);
--# expr-done 1708
Fld_5 := Fld_4.Node;
      declare
         Map_Result_2_Vec : Internal_Shape_Vectors.Vector;
      begin
      if Fld_5 = null then
      Map_Result_2 := Create_Internal_Shape_Array (0);
      else
      declare
         Collection : constant Bare_Variant_List := Fld_5;
      begin
         for Untyped_Item_79 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_79 := Untyped_Item_79; 
Is_Null_1 := Bare_Item_79 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Variant;
else
Fld_6 := Fld_4.Info;
As_Entity_1 := (Info => Fld_6, Node => Bare_Item_79); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_79 := If_Result_1; 
   --# scope-start
               --# bind v Item_79
      --# expr-start 1719 '<Map at ast.py:4923>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:4923
   --# expr-start 1710 '<FieldAccess for shapes at ast.py:4923>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4923
--# expr-start 1709 '<FieldAccess for components at ast.py:4923>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4923
      if Item_79.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Component_List (Node => Item_79.Node.Variant_F_Components, Info => Item_79.Info);
--# expr-done 1709
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.shapes
Fld_8 := Libadalang.Implementation.Component_List_P_Shapes (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 1710
      declare
         Map_Result_1_Vec : Internal_Shape_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Shape_Array_Access := Fld_8;
      begin
         for Item_80 of
               Collection.Items
         loop
   --# scope-start
               --# bind s Item_80
      --# expr-start 1718 '<New Shape at ast.py:4924>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:4924
--# expr-start 1712 '<Concat at ast.py:4925>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:4925
--# expr-start 1711 '<FieldAccess for components at ast.py:4925>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4925
Fld_9 := Item_80.Components;
Inc_Ref (Fld_9);
--# expr-done 1711
Concat_Result := Concat (Block_Var, Fld_9); 
--# expr-done 1712
--# expr-start 1717 '<Concat at ast.py:4929>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:4929
--# expr-start 1715 '<New DiscriminantValues at ast.py:4926>' New_Struct /tmp/lal-23.0.0/ada/ast.py:4926
--# expr-start 1713 '<FieldAccess for discr_name at ast.py:4927>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4927
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Identifier (Node => Var_Expr.Node.Variant_Part_F_Discr_Name, Info => Var_Expr.Info);
--# expr-done 1713
--# expr-start 1714 '<FieldAccess for choices at ast.py:4928>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4928
      if Item_79.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Alternatives_List (Node => Item_79.Node.Variant_F_Choices, Info => Item_79.Info);
--# expr-done 1714
New_Struct := (Discriminant => Fld_10, Values => Fld_11); 
--# expr-done 1715
                Singleton := Create_Internal_Discriminant_Values_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
--# expr-start 1716 '<FieldAccess for discriminants_values at ast.py:4929>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4929
Fld_12 := Item_80.Discriminants_Values;
Inc_Ref (Fld_12);
--# expr-done 1716
Concat_Result_1 := Concat (Singleton, Fld_12); 
--# expr-done 1717
Inc_Ref (Concat_Result);
Inc_Ref (Concat_Result_1);
New_Struct_1 := (Components => Concat_Result, Discriminants_Values => Concat_Result_1); 
--# expr-done 1718
         declare
            Item_To_Append : constant Internal_Shape := New_Struct_1;
         begin
               Inc_Ref (Item_To_Append);
            Internal_Shape_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2025;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Shape_Array
           (Items_Count => Natural (Internal_Shape_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Shape_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Shape_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Shape_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 1719
         for Item_To_Append of
               Map_Result_1.Items
         loop
               Inc_Ref (Item_To_Append);
            Internal_Shape_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2024;
         end loop;
      end;
      end if;
         Map_Result_2 := Create_Internal_Shape_Array
           (Items_Count => Natural (Internal_Shape_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Shape_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Shape_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Shape_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 1720
Scope_Result := Map_Result_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2023;
   Result_Var := Scope_Result;
else
   --# expr-start 1721 '<New Shape at ast.py:4933>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:4933
Inc_Ref (Block_Var);
Inc_Ref (No_Internal_Discriminant_Values_Array_Type);
New_Struct_2 := (Components => Block_Var, Discriminants_Values => No_Internal_Discriminant_Values_Array_Type); 
--# expr-done 1721
                Singleton_1 := Create_Internal_Shape_Array (Items_Count => 1);
                Singleton_1.Items (1) := New_Struct_2;
                Inc_Ref (Singleton_1.Items (1));
   Result_Var := Singleton_1;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 1722
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_319;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_319;
               Finalizer_Scope_2023;
               Finalizer_Scope_2024;
               Finalizer_Scope_2025;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_List_P_Shapes;
--# end
   --
   --  Primitives for Bare_Discriminant_Part
   --
--# property-start DiscriminantPart.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:4413
pragma Warnings (Off, "is not referenced");
 function Discriminant_Part_P_Abstract_Formal_Params
  (Node : Bare_Discriminant_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Discriminant_Part := Bare_Discriminant_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_273 with Inline_Always;
      Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_273 is
            begin
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_273;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1723 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type; Inc_Ref (Let_Result);
--# end
--# expr-done 1723
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_273;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_273;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Part_P_Abstract_Formal_Params;
--# end
   --
   --  Primitives for Bare_Known_Discriminant_Part
   --
      procedure Initialize_Fields_For_Known_Discriminant_Part
        (Self : Bare_Known_Discriminant_Part
         ; Known_Discriminant_Part_F_Discr_Specs : Bare_Discriminant_Spec_List
        ) is
      begin
            Self.Known_Discriminant_Part_F_Discr_Specs := Known_Discriminant_Part_F_Discr_Specs;
      end Initialize_Fields_For_Known_Discriminant_Part;
   function Known_Discriminant_Part_F_Discr_Specs
     (Node : Bare_Known_Discriminant_Part) return Bare_Discriminant_Spec_List
   is
   begin
         return Node.Known_Discriminant_Part_F_Discr_Specs;
   end;
--# property-start KnownDiscriminantPart.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:4425
pragma Warnings (Off, "is not referenced");
 function Known_Discriminant_Part_P_Abstract_Formal_Params
  (Node : Bare_Known_Discriminant_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Known_Discriminant_Part := Bare_Known_Discriminant_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_274 with Inline_Always;
      Fld : Bare_Discriminant_Spec_List;
Cast_Expr : Bare_Discriminant_Spec;
Cast_Result : Bare_Base_Formal_Param_Decl;
As_Entity : Internal_Entity_Base_Formal_Param_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_81 : Bare_Discriminant_Spec;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_274 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_274;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1728 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1727 '<Map at ast.py:4426>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4426
   --# expr-start 1724 '<FieldAccess for discr_specs at ast.py:4426>' Fld /tmp/lal-23.0.0/ada/ast.py:4426
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Known_Discriminant_Part_F_Discr_Specs;
--# expr-done 1724
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Discriminant_Spec_List := Fld;
      begin
         for Untyped_Item_81 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_81 := Untyped_Item_81; 
   --# scope-start
               --# bind e Item_81
      --# expr-start 1726 '<as_entity at ast.py:4427>' If_Result /tmp/lal-23.0.0/ada/ast.py:4427
--# expr-start 1725 '<Cast to BaseFormalParamDecl at ast.py:4427>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4427
Cast_Expr := Item_81; 
      Cast_Result := Cast_Expr;
--# expr-done 1725
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Base_Formal_Param_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 1726
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := If_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1727
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 1728
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_274;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_274;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Known_Discriminant_Part_P_Abstract_Formal_Params;
--# end
   --
   --  Primitives for Bare_Unknown_Discriminant_Part
   --
   --
   --  Primitives for Bare_Entry_Completion_Formal_Params
   --
      procedure Initialize_Fields_For_Entry_Completion_Formal_Params
        (Self : Bare_Entry_Completion_Formal_Params
         ; Entry_Completion_Formal_Params_F_Params : Bare_Params
        ) is
      begin
            Self.Entry_Completion_Formal_Params_F_Params := Entry_Completion_Formal_Params_F_Params;
      end Initialize_Fields_For_Entry_Completion_Formal_Params;
   function Entry_Completion_Formal_Params_F_Params
     (Node : Bare_Entry_Completion_Formal_Params) return Bare_Params
   is
   begin
         return Node.Entry_Completion_Formal_Params_F_Params;
   end;
--# property-start EntryCompletionFormalParams.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:20167
pragma Warnings (Off, "is not referenced");
 function Entry_Completion_Formal_Params_P_Abstract_Formal_Params
  (Node : Bare_Entry_Completion_Formal_Params
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Entry_Completion_Formal_Params := Bare_Entry_Completion_Formal_Params (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Completion_Formal_Params :=
     Internal_Entity_Entry_Completion_Formal_Params'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1419 with Inline_Always;
      Var_Expr : Internal_Entity_Params;
Fld : Internal_Entity_Params;
Fld_1 : Internal_Entity_Param_Spec_List;
Scope_Result : Internal_Entity_Param_Spec_List;
Result_Var : Internal_Entity_Param_Spec_List;
Fld_2 : Bare_Param_Spec_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Param_Spec;
Is_Null : Boolean;
If_Result : Internal_Entity_Param_Spec;
Cast_Expr : Internal_Entity_Param_Spec;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_82 : Internal_Entity_Param_Spec;
Bare_Item_82 : Bare_Param_Spec;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1419 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1419;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1732 '<Map at ast.py:20168>' Map_Result /tmp/lal-23.0.0/ada/ast.py:20168
--# expr-start 1729 '<FieldAccess for params at ast.py:20168>' Fld /tmp/lal-23.0.0/ada/ast.py:20168
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Params (Node => Ent.Node.Entry_Completion_Formal_Params_F_Params, Info => Ent.Info);
--# expr-done 1729
Var_Expr := Fld;
if Var_Expr /= No_Entity_Params then
   --# scope-start
--# expr-start 1730 '<FieldAccess for params at ast.py:20168>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20168
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Param_Spec_List (Node => Var_Expr.Node.Params_F_Params, Info => Var_Expr.Info);
--# expr-done 1730
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Param_Spec_List;
end if;
Fld_2 := Result_Var.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Param_Spec_List := Fld_2;
      begin
         for Untyped_Item_82 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_82 := Untyped_Item_82; 
Is_Null := Bare_Item_82 = null; 
if Is_Null then
   If_Result := No_Entity_Param_Spec;
else
Fld_3 := Result_Var.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_82); 
   If_Result := As_Entity;
end if;
                  Item_82 := If_Result; 
   --# scope-start
               --# bind p Item_82
      --# expr-start 1731 '<Cast to BaseFormalParamDecl at ast.py:20168>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20168
Cast_Expr := Item_82; 
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-done 1731
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1732
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1419;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1419;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Completion_Formal_Params_P_Abstract_Formal_Params;
--# end
   --
   --  Primitives for Bare_Generic_Formal_Part
   --
      procedure Initialize_Fields_For_Generic_Formal_Part
        (Self : Bare_Generic_Formal_Part
         ; Generic_Formal_Part_F_Decls : Bare_Ada_Node_List
        ) is
      begin
            Self.Generic_Formal_Part_F_Decls := Generic_Formal_Part_F_Decls;
      end Initialize_Fields_For_Generic_Formal_Part;
   function Generic_Formal_Part_F_Decls
     (Node : Bare_Generic_Formal_Part) return Bare_Ada_Node_List
   is
   begin
         return Node.Generic_Formal_Part_F_Decls;
   end;
--# property-start GenericFormalPart.abstract_formal_params /tmp/lal-23.0.0/ada/ast.py:11311
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_Part_P_Abstract_Formal_Params
  (Node : Bare_Generic_Formal_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Generic_Formal_Part := Bare_Generic_Formal_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Formal_Part :=
     Internal_Entity_Generic_Formal_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_892 with Inline_Always;
      Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Item_83 : Internal_Entity;
Bare_Item_83 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_892 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_892;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1736 '<FilterMap at ast.py:11311>' Map_Result /tmp/lal-23.0.0/ada/ast.py:11311
   --# expr-start 1733 '<FieldAccess for decls at ast.py:11311>' Fld /tmp/lal-23.0.0/ada/ast.py:11311
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Ent.Node.Generic_Formal_Part_F_Decls, Info => Ent.Info);
--# expr-done 1733
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Formal_Param_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_83 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_83 := Untyped_Item_83; 
Is_Null := Bare_Item_83 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_83); 
   If_Result := As_Entity;
end if;
                  Item_83 := If_Result; 
   --# scope-start
               --# bind e Item_83
         --# expr-start 1734 '<IsA BaseFormalParamDecl at ???>' Is_A None
Is_A := Item_83.Node /= null 
and then Item_83.Node.Kind in Ada_Base_Formal_Param_Decl; 
--# expr-done 1734
         if Is_A then
      --# expr-start 1735 '<Cast to BaseFormalParamDecl at ???>' Cast_Result None
Cast_Expr := Item_83; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Formal_Param_Decl;
   end if;
--# expr-done 1735
         declare
            Item_To_Append : constant Internal_Entity_Base_Formal_Param_Decl := Cast_Result;
         begin
            Internal_Entity_Base_Formal_Param_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Formal_Param_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Formal_Param_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Formal_Param_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Formal_Param_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Formal_Param_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1736
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_892;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_892;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_Part_P_Abstract_Formal_Params;
--# end
--# property-start GenericFormalPart.use_clauses_envs /tmp/lal-23.0.0/ada/ast.py:11314
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_Part_P_Use_Clauses_Envs
  (Node : Bare_Generic_Formal_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Generic_Formal_Part := Bare_Generic_Formal_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Formal_Part :=
     Internal_Entity_Generic_Formal_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_893 with Inline_Always;
            procedure Finalizer_Scope_2030 with Inline_Always;
      Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Use_Clause;
Fld_3 : Lexical_Env := Empty_Env;
Item_84 : Internal_Entity;
Bare_Item_84 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_893 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_893;
            procedure Finalizer_Scope_2030 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2030;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1743 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1742 '<env_group at ast.py:11322>' Group_Env /tmp/lal-23.0.0/ada/ast.py:11322
--# expr-start 1741 '<FilterMap at ast.py:11319>' Map_Result /tmp/lal-23.0.0/ada/ast.py:11319
   --# expr-start 1737 '<FieldAccess for decls at ast.py:11319>' Fld /tmp/lal-23.0.0/ada/ast.py:11319
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Ent.Node.Generic_Formal_Part_F_Decls, Info => Ent.Info);
--# expr-done 1737
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Lexical_Env_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_84 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_84 := Untyped_Item_84; 
Is_Null := Bare_Item_84 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_84); 
   If_Result := As_Entity;
end if;
                  Item_84 := If_Result; 
   --# scope-start
               --# bind u Item_84
         --# expr-start 1738 '<IsA UseClause at ast.py:11321>' Is_A /tmp/lal-23.0.0/ada/ast.py:11321
Is_A := Item_84.Node /= null 
and then Item_84.Node.Kind in Ada_Use_Clause; 
--# expr-done 1738
         if Is_A then
      --# expr-start 1740 '<FieldAccess for used_envs at ast.py:11320>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11320
--# expr-start 1739 '<Cast to UseClause at ast.py:11320>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11320
Cast_Expr := Item_84; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Use_Clause
   then
      Cast_Result := Create_Internal_Entity_Use_Clause
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Use_Clause;
   end if;
--# expr-done 1739
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UseClause.used_envs
Fld_3 := Libadalang.Implementation.Use_Clause_P_Used_Envs (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 1740
         declare
            Item_To_Append : constant Lexical_Env := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
      Finalizer_Scope_2030;
         end loop;
      end;
      end if;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1741
Group_Env := Group (Map_Result, No_Metadata); 
--# expr-done 1742
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 1743
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_893;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_893;
               Finalizer_Scope_2030;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_Part_P_Use_Clauses_Envs;
--# end
   --
   --  Primitives for Bare_Base_Record_Def
   --
      procedure Initialize_Fields_For_Base_Record_Def
        (Self : Bare_Base_Record_Def
         ; Base_Record_Def_F_Components : Bare_Component_List
        ) is
      begin
            Self.Base_Record_Def_F_Components := Base_Record_Def_F_Components;
      end Initialize_Fields_For_Base_Record_Def;
   function Base_Record_Def_F_Components
     (Node : Bare_Base_Record_Def) return Bare_Component_List
   is
   begin
         return Node.Base_Record_Def_F_Components;
   end;
--# property-start BaseRecordDef.comps /tmp/lal-23.0.0/ada/ast.py:4948
pragma Warnings (Off, "is not referenced");
 function Base_Record_Def_P_Comps
  (Node : Bare_Base_Record_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Component_List
is
   Self : Bare_Base_Record_Def := Bare_Base_Record_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Record_Def :=
     Internal_Entity_Base_Record_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Component_List;
      Fld : Internal_Entity_Component_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1744 '<FieldAccess for components at ast.py:4948>' Fld /tmp/lal-23.0.0/ada/ast.py:4948
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Component_List (Node => Ent.Node.Base_Record_Def_F_Components, Info => Ent.Info);
--# expr-done 1744
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Record_Def_P_Comps;
--# end
   --
   --  Primitives for Bare_Null_Record_Def
   --
      procedure Initialize_Fields_For_Null_Record_Def
        (Self : Bare_Null_Record_Def
         ; Base_Record_Def_F_Components : Bare_Component_List
        ) is
      begin
            Initialize_Fields_For_Base_Record_Def
              (Self, Base_Record_Def_F_Components);
      end Initialize_Fields_For_Null_Record_Def;
   --
   --  Primitives for Bare_Record_Def
   --
      procedure Initialize_Fields_For_Record_Def
        (Self : Bare_Record_Def
         ; Base_Record_Def_F_Components : Bare_Component_List
        ) is
      begin
            Initialize_Fields_For_Base_Record_Def
              (Self, Base_Record_Def_F_Components);
      end Initialize_Fields_For_Record_Def;
   --
   --  Primitives for Bare_Basic_Assoc
   --
--# property-start '[dispatcher]BasicAssoc.expr' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Assoc_P_Expr
  (Node : Bare_Basic_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Basic_Assoc := Bare_Basic_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Assoc (Self.Kind) is
               when Ada_Aggregate_Assoc .. Ada_Multi_Dim_Array_Assoc =>
                  --# property-call-start AggregateAssoc.expr
                  Property_Result := Aggregate_Assoc_P_Expr
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Composite_Constraint_Assoc =>
                  --# property-call-start CompositeConstraintAssoc.expr
                  Property_Result := Composite_Constraint_Assoc_P_Expr
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Iterated_Assoc =>
                  --# property-call-start IteratedAssoc.expr
                  Property_Result := Iterated_Assoc_P_Expr
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Param_Assoc =>
                  --# property-call-start ParamAssoc.expr
                  Property_Result := Param_Assoc_P_Expr
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Assoc_P_Expr;
--# end
--# property-start '[dispatcher]BasicAssoc.names' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Assoc_P_Names
  (Node : Bare_Basic_Assoc
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Basic_Assoc := Bare_Basic_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Assoc (Self.Kind) is
               when Ada_Aggregate_Assoc .. Ada_Multi_Dim_Array_Assoc =>
                  --# property-call-start AggregateAssoc.names
                  Property_Result := Aggregate_Assoc_P_Names
                    (Self
                    );
                  --# end
               when Ada_Composite_Constraint_Assoc =>
                  --# property-call-start CompositeConstraintAssoc.names
                  Property_Result := Composite_Constraint_Assoc_P_Names
                    (Self
                    );
                  --# end
               when Ada_Iterated_Assoc =>
                  --# property-call-start IteratedAssoc.names
                  Property_Result := Iterated_Assoc_P_Names
                    (Self
                    );
                  --# end
               when Ada_Param_Assoc =>
                  --# property-call-start ParamAssoc.names
                  Property_Result := Param_Assoc_P_Names
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Assoc_P_Names;
--# end
--# property-start BasicAssoc.get_params /tmp/lal-23.0.0/ada/ast.py:8060
pragma Warnings (Off, "is not referenced");
 function Basic_Assoc_P_Get_Params
  (Node : Bare_Basic_Assoc
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Basic_Assoc := Bare_Basic_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Assoc :=
     Internal_Entity_Basic_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_604 with Inline_Always;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Assoc_List;
Fld_1 : Internal_Param_Actual_Array_Access;
Fld_2 : Internal_Entity_Defining_Name;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_604 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_604;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1753 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1752 '<FilterMap at ast.py:8065>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8065
   --# expr-start 1747 '<FieldAccess for zip_with_params at ast.py:8065>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8065
--# expr-start 1746 '<Cast to AssocList at ast.py:8065>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8065
--# expr-start 1745 '<parent at ast.py:8065>' Fld /tmp/lal-23.0.0/ada/ast.py:8065
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 1745
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Assoc_List_Range
   then
      Cast_Result := Create_Internal_Entity_Assoc_List
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1746
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.zip_with_params
Fld_1 := Libadalang.Implementation.Assoc_List_P_Zip_With_Params (Node => Cast_Result.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result.Info);
--# end
--# expr-done 1747
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Fld_1;
      begin
         for Item_85 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_85
         --# expr-start 1750 '<Eq at ast.py:8067>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:8067
--# expr-start 1748 '<FieldAccess for actual at ast.py:8067>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8067
Fld_3 := Item_85.Actual;
--# expr-done 1748
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
--# expr-start 1749 '<FieldAccess for expr at ast.py:8067>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8067
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1749
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 1750
         if Is_Equiv then
      --# expr-start 1751 '<FieldAccess for param at ast.py:8066>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8066
Fld_2 := Item_85.Param;
--# expr-done 1751
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Fld_2;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1752
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 1753
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_604;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_604;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Assoc_P_Get_Params;
--# end
   --
   --  Primitives for Bare_Aggregate_Assoc
   --
      procedure Initialize_Fields_For_Aggregate_Assoc
        (Self : Bare_Aggregate_Assoc
         ; Aggregate_Assoc_F_Designators : Bare_Alternatives_List
         ; Aggregate_Assoc_F_R_Expr : Bare_Expr
        ) is
      begin
            Self.Aggregate_Assoc_F_Designators := Aggregate_Assoc_F_Designators;
            Self.Aggregate_Assoc_F_R_Expr := Aggregate_Assoc_F_R_Expr;
      end Initialize_Fields_For_Aggregate_Assoc;
   function Aggregate_Assoc_F_Designators
     (Node : Bare_Aggregate_Assoc) return Bare_Alternatives_List
   is
   begin
         return Node.Aggregate_Assoc_F_Designators;
   end;
   function Aggregate_Assoc_F_R_Expr
     (Node : Bare_Aggregate_Assoc) return Bare_Expr
   is
   begin
         return Node.Aggregate_Assoc_F_R_Expr;
   end;
--# property-start AggregateAssoc.expr /tmp/lal-23.0.0/ada/ast.py:14742
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Expr
  (Node : Bare_Aggregate_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Fld : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1754 '<FieldAccess for r_expr at ast.py:14742>' Fld /tmp/lal-23.0.0/ada/ast.py:14742
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Aggregate_Assoc_F_R_Expr, Info => Ent.Info);
--# expr-done 1754
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Expr;
--# end
--# property-start AggregateAssoc.names /tmp/lal-23.0.0/ada/ast.py:14743
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Names
  (Node : Bare_Aggregate_Assoc
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1077 with Inline_Always;
      Fld : Bare_Alternatives_List;
Item_86 : Bare_Ada_Node;
Map_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1077 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1077;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1756 '<Map at ast.py:14743>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14743
   --# expr-start 1755 '<FieldAccess for designators at ast.py:14743>' Fld /tmp/lal-23.0.0/ada/ast.py:14743
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Aggregate_Assoc_F_Designators;
--# expr-done 1755
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld;
      begin
         for Untyped_Item_86 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_86 := Untyped_Item_86; 
   --# scope-start
               --# bind d Item_86
         declare
            Item_To_Append : constant Bare_Ada_Node := Item_86;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1756
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1077;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1077;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Names;
--# end
--# property-start AggregateAssoc.xref_stop_resolution /tmp/lal-23.0.0/ada/ast.py:14745
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Xref_Stop_Resolution
  (Node : Bare_Aggregate_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Xref_Stop_Resolution;
--# end
--# property-start AggregateAssoc.base_aggregate /tmp/lal-23.0.0/ada/ast.py:14747
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Base_Aggregate
  (Node : Bare_Aggregate_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Aggregate
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Aggregate;
      Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Aggregate;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1759 '<Cast to BaseAggregate at ast.py:14748>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14748
--# expr-start 1758 '<parent at ast.py:14748>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14748
--# expr-start 1757 '<parent at ast.py:14748>' Fld /tmp/lal-23.0.0/ada/ast.py:14748
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 1757
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 1758
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Aggregate
   then
      Cast_Result := Create_Internal_Entity_Base_Aggregate
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1759
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Base_Aggregate;
--# end
--# property-start AggregateAssoc.xref_equation /tmp/lal-23.0.0/ada/ast.py:14752
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Xref_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1080 with Inline_Always;
      Block_Var : Internal_Entity_Base_Aggregate;
Block_Var_1 : Internal_Multidim_Aggregate_Info;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Block_Var_3 : Internal_Entity_Array_Type_Def;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Aggregate;
Fld_1 : Internal_Multidim_Aggregate_Info;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Aggregate;
Fld_4 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Is_Equal : Boolean;
Not_Val : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Result_Var : Internal_Entity_Array_Type_Def;
Sym : Symbol_Type;
Fld_6 : Boolean;
Sym_1 : Symbol_Type;
Fld_7 : Boolean;
If_Result_1 : Boolean;
Fld_8 : Logic_Equation;
Sym_2 : Symbol_Type;
Fld_9 : Boolean;
Sym_3 : Symbol_Type;
Fld_10 : Boolean;
If_Result_2 : Boolean;
Fld_11 : Logic_Equation;
Sym_4 : Symbol_Type;
Fld_12 : Boolean;
Fld_13 : Logic_Equation;
Sym_5 : Symbol_Type;
Fld_14 : Boolean;
Fld_15 : Logic_Equation;
Sym_6 : Symbol_Type;
Fld_16 : Boolean;
Fld_17 : Logic_Equation;
Fld_18 : Internal_Entity;
Is_A : Boolean;
True_Rel : Logic_Equation;
Is_Null : Boolean;
Fld_19 : Logic_Equation;
Fld_20 : Logic_Equation;
If_Result_3 : Logic_Equation;
If_Result_4 : Logic_Equation;
If_Result_5 : Logic_Equation;
If_Result_6 : Logic_Equation;
If_Result_7 : Logic_Equation;
If_Result_8 : Logic_Equation;
If_Result_9 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1080 is
            begin
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_17);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (If_Result_8);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1080;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1795 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1760 '<FieldAccess for base_aggregate at ast.py:14753>' Fld /tmp/lal-23.0.0/ada/ast.py:14753
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.base_aggregate
Fld := Libadalang.Implementation.Aggregate_Assoc_P_Base_Aggregate (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1760
Block_Var := Fld; 
--# bind agg Block_Var
--# expr-start 1761 '<FieldAccess for multidim_root_aggregate at ast.py:14755>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14755
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.multidim_root_aggregate
Fld_1 := Libadalang.Implementation.Base_Aggregate_P_Multidim_Root_Aggregate (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 1761
Block_Var_1 := Fld_1; 
--# bind mra Block_Var_1
--# expr-start 1768 '<If at ast.py:14760>' If_Result /tmp/lal-23.0.0/ada/ast.py:14760
--# expr-start 1763 '<Not at ast.py:14761>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14761
--# expr-start 1762 '<IsNull at ast.py:14761>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14761
Is_Equal := Block_Var_1 = No_Multidim_Aggregate_Info; 
--# expr-done 1762
Not_Val := not (Is_Equal); 
--# expr-done 1763
if Not_Val then
   --# expr-start 1764 '<FieldAccess for typ at ast.py:14762>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14762
Fld_2 := Block_Var_1.Typ;
--# expr-done 1764
   If_Result := Fld_2;
else
   --# expr-start 1767 '<Cast to BaseTypeDecl at ast.py:14763>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14763
--# expr-start 1766 '<FieldAccess for type_val at ast.py:14763>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14763
--# expr-start 1765 '<FieldAccess for base_aggregate at ast.py:14763>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14763
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.base_aggregate
Fld_3 := Libadalang.Implementation.Aggregate_Assoc_P_Base_Aggregate (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1765
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_4 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld_3.Node);
--# end
--# expr-done 1766
   if Fld_4.Node = null
      or else Fld_4.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 1767
   If_Result := Cast_Result;
end if;
--# expr-done 1768
Block_Var_2 := If_Result; 
--# bind td Block_Var_2
Var_Expr := Block_Var_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1769 '<FieldAccess for array_def at ast.py:14766>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14766
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1769
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Array_Type_Def;
end if;
Block_Var_3 := Result_Var; 
--# bind atd Block_Var_3
--# expr-start 1794 '<Cond at ast.py:14768>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:14768
--# expr-start 1771 '<FieldAccess for in_aspect at ast.py:14769>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14769
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1770 '<Symbol Global at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Global); 
--# expr-done 1770
--# property-call-start AdaNode.in_aspect
Fld_6 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym);
--# end
--# expr-done 1771
if Fld_6 then
   If_Result_1 := True;
else
   --# expr-start 1773 '<FieldAccess for in_aspect at ast.py:14769>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14769
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1772 '<Symbol Refined_Global at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Global); 
--# expr-done 1772
--# property-call-start AdaNode.in_aspect
Fld_7 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym_1);
--# end
--# expr-done 1773
   If_Result_1 := Fld_7;
end if;
if If_Result_1 then
   --# expr-start 1774 '<FieldAccess for globals_assoc_equation at ast.py:14770>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14770
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.globals_assoc_equation
Fld_8 := Libadalang.Implementation.Aggregate_Assoc_P_Globals_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1774
   If_Result_9 := Fld_8;
else
--# expr-start 1776 '<FieldAccess for in_aspect at ast.py:14772>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14772
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1775 '<Symbol Depends at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Depends); 
--# expr-done 1775
--# property-call-start AdaNode.in_aspect
Fld_9 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym_2);
--# end
--# expr-done 1776
if Fld_9 then
   If_Result_2 := True;
else
   --# expr-start 1778 '<FieldAccess for in_aspect at ast.py:14772>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14772
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1777 '<Symbol Refined_Depends at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Depends); 
--# expr-done 1777
--# property-call-start AdaNode.in_aspect
Fld_10 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym_3);
--# end
--# expr-done 1778
   If_Result_2 := Fld_10;
end if;
if If_Result_2 then
   --# expr-start 1779 '<FieldAccess for depends_assoc_equation at ast.py:14773>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14773
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.depends_assoc_equation
Fld_11 := Libadalang.Implementation.Aggregate_Assoc_P_Depends_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1779
   If_Result_8 := Fld_11;
else
--# expr-start 1781 '<FieldAccess for in_aspect at ast.py:14775>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14775
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1780 '<Symbol Test_Case at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Test_Case); 
--# expr-done 1780
--# property-call-start AdaNode.in_aspect
Fld_12 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym_4);
--# end
--# expr-done 1781
if Fld_12 then
   --# expr-start 1782 '<FieldAccess for test_case_assoc_equation at ast.py:14776>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14776
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.test_case_assoc_equation
Fld_13 := Libadalang.Implementation.Aggregate_Assoc_P_Test_Case_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1782
   If_Result_7 := Fld_13;
else
--# expr-start 1784 '<FieldAccess for in_aspect at ast.py:14778>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14778
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1783 '<Symbol Refined_State at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_State); 
--# expr-done 1783
--# property-call-start AdaNode.in_aspect
Fld_14 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym_5);
--# end
--# expr-done 1784
if Fld_14 then
   --# expr-start 1785 '<FieldAccess for exprs_assoc_equation at ast.py:14781>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14781
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.exprs_assoc_equation
Fld_15 := Libadalang.Implementation.Aggregate_Assoc_P_Exprs_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1785
   If_Result_6 := Fld_15;
else
--# expr-start 1787 '<FieldAccess for in_aspect at ast.py:14783>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14783
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1786 '<Symbol Contract_Cases at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 1786
--# property-call-start AdaNode.in_aspect
Fld_16 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Block_Var.Node, Name => Sym_6);
--# end
--# expr-done 1787
if Fld_16 then
   --# expr-start 1788 '<FieldAccess for contract_cases_assoc_equation at ast.py:14784>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14784
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.contract_cases_assoc_equation
Fld_17 := Libadalang.Implementation.Aggregate_Assoc_P_Contract_Cases_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1788
   If_Result_5 := Fld_17;
else
--# expr-start 1790 '<IsA AspectClause, AspectAssoc, PragmaArgumentAssoc at ast.py:14786>' Is_A /tmp/lal-23.0.0/ada/ast.py:14786
--# expr-start 1789 '<parent at ast.py:14786>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14786
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Libadalang.Implementation.Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 1789
Is_A := Fld_18.Node /= null 
and then Fld_18.Node.Kind in Ada_Aspect_Clause | Ada_Aspect_Assoc_Range | Ada_Pragma_Argument_Assoc_Range; 
--# expr-done 1790
if Is_A then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14787") else null)); 
   If_Result_4 := True_Rel;
else
--# expr-start 1791 '<IsNull at ast.py:14789>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14789
Is_Null := Block_Var_3.Node = null; 
--# expr-done 1791
if Is_Null then
   --# expr-start 1792 '<FieldAccess for record_assoc_equation at ast.py:14790>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14790
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.record_assoc_equation
Fld_19 := Libadalang.Implementation.Aggregate_Assoc_P_Record_Assoc_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1792
   If_Result_3 := Fld_19;
else
   --# expr-start 1793 '<FieldAccess for array_assoc_equation at ast.py:14791>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:14791
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.array_assoc_equation
Fld_20 := Libadalang.Implementation.Aggregate_Assoc_P_Array_Assoc_Equation (Node => Ent.Node, Atd => Block_Var_3, Mra => Block_Var_1, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 1793
   If_Result_3 := Fld_20;
end if;
      Inc_Ref (If_Result_3);
   If_Result_4 := If_Result_3;
end if;
      Inc_Ref (If_Result_4);
   If_Result_5 := If_Result_4;
end if;
      Inc_Ref (If_Result_5);
   If_Result_6 := If_Result_5;
end if;
      Inc_Ref (If_Result_6);
   If_Result_7 := If_Result_6;
end if;
      Inc_Ref (If_Result_7);
   If_Result_8 := If_Result_7;
end if;
      Inc_Ref (If_Result_8);
   If_Result_9 := If_Result_8;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 1794
Let_Result := If_Result_9; Inc_Ref (Let_Result);
--# end
--# expr-done 1795
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1080;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1080;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Xref_Equation;
--# end
--# property-start AggregateAssoc.record_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14795
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Record_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1081 with Inline_Always;
            procedure Finalizer_Scope_2037 with Inline_Always;
            procedure Finalizer_Scope_2038 with Inline_Always;
            procedure Finalizer_Scope_2039 with Inline_Always;
      Block_Var : Internal_Entity_Base_Aggregate;
Block_Var_1 : Internal_Param_Match_Array_Access;
Block_Var_2 : Internal_Param_Match_Array_Access;
Block_Var_3 : Boolean;
Var_Expr : Bare_Base_Id;
Var_Expr_1 : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Base_Aggregate;
Fld_1 : Internal_Param_Match_Array_Access;
Fld_2 : Internal_Single_Actual;
Fld_3 : Internal_Entity_Basic_Assoc;
Cast_Result : Internal_Entity;
Cast_Expr : Internal_Entity_Aggregate_Assoc;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Map_Result : Internal_Param_Match_Array_Access;
Fld_4 : Internal_Param_Match_Array_Access;
Fld_5 : Internal_Single_Actual;
Fld_6 : Internal_Entity_Basic_Assoc;
Cast_Result_2 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Aggregate_Assoc;
Cast_Result_3 : Internal_Entity;
Is_Equiv_1 : Boolean;
Map_Result_1 : Internal_Param_Match_Array_Access;
Is_Equal : Boolean;
Not_Val : Boolean;
If_Result : Internal_Param_Match_Array_Access;
Fld_7 : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Quantifier_Result : Boolean;
Fld_8 : Internal_Single_Actual;
Fld_9 : Internal_Entity_Basic_Assoc;
Fld_10 : Internal_Entity_Expr;
Fld_11 : Logic_Var;
Fld_12 : Internal_Entity_Defining_Name;
Fld_13 : Internal_Entity_Base_Formal_Param_Decl;
Fld_14 : Internal_Entity_Type_Expr;
Fld_15 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_16 : Internal_Single_Actual;
Fld_17 : Internal_Entity_Basic_Assoc;
Fld_18 : Internal_Entity_Expr;
Fld_19 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_20 : Internal_Single_Actual;
Fld_21 : Internal_Entity_Basic_Assoc;
Fld_22 : Internal_Entity_Expr;
Fld_23 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_24 : Internal_Single_Actual;
Fld_25 : Bare_Base_Id;
Fld_26 : Logic_Var;
Fld_27 : Internal_Entity_Defining_Name;
Fld_28 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_5 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Map_Result_2 : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_29 : Internal_Entity_Defining_Name;
Fld_30 : Internal_Entity_Expr;
Fld_31 : Logic_Var;
Fld_32 : Internal_Entity_Base_Formal_Param_Decl;
Fld_33 : Internal_Entity_Type_Expr;
Fld_34 : Internal_Entity_Base_Type_Decl;
Cast_Result_6 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Fld_35 : Internal_Entity_Expr;
Fld_36 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_37 : Internal_Entity_Expr;
Fld_38 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
Not_Val_1 : Boolean;
If_Result_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1081 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1081;
            procedure Finalizer_Scope_2037 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_19);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_23);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_2037;
            procedure Finalizer_Scope_2038 is
            begin
                     Dec_Ref (Bind_Result_1);
            end Finalizer_Scope_2038;
            procedure Finalizer_Scope_2039 is
            begin
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Fld_36);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_38);
                     Dec_Ref (And_Pred_4);
            end Finalizer_Scope_2039;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1856 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1796 '<FieldAccess for base_aggregate at ast.py:14800>' Fld /tmp/lal-23.0.0/ada/ast.py:14800
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.base_aggregate
Fld := Libadalang.Implementation.Aggregate_Assoc_P_Base_Aggregate (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1796
Block_Var := Fld; 
--# bind agg Block_Var
--# expr-start 1801 '<Filter at ast.py:14803>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14803
   --# expr-start 1797 '<FieldAccess for matched_discriminants at ast.py:14803>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14803
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.matched_discriminants
Fld_1 := Libadalang.Implementation.Base_Aggregate_P_Matched_Discriminants (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 1797
      declare
         Map_Result_Vec : Internal_Param_Match_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_1;
      begin
         for Item_87 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_87
         --# expr-start 1800 '<Eq at ast.py:14804>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:14804
--# expr-start 1799 '<FieldAccess for assoc at ast.py:14804>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14804
--# expr-start 1798 '<FieldAccess for actual at ast.py:14804>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14804
Fld_2 := Item_87.Actual;
--# expr-done 1798
Fld_3 := Fld_2.Assoc;
--# expr-done 1799
      Cast_Result := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Cast_Expr := Ent; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 1800
         if Is_Equiv then
         declare
            Item_To_Append : constant Internal_Param_Match := Item_87;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1801
Block_Var_1 := Map_Result; Inc_Ref (Block_Var_1);
--# bind discr_matches Block_Var_1
--# expr-start 1809 '<If at ast.py:14816>' If_Result /tmp/lal-23.0.0/ada/ast.py:14816
--# expr-start 1803 '<Not at ast.py:14817>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14817
--# expr-start 1802 '<IsNull at ast.py:14817>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14817
Is_Equal := Equivalent (Block_Var_1, No_Internal_Param_Match_Array_Type); 
--# expr-done 1802
Not_Val := not (Is_Equal); 
--# expr-done 1803
if Not_Val then
   If_Result := Block_Var_1;
else
   --# expr-start 1808 '<Filter at ast.py:14821>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:14821
   --# expr-start 1804 '<FieldAccess for matched_components at ast.py:14821>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14821
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.matched_components
Fld_4 := Libadalang.Implementation.Base_Aggregate_P_Matched_Components (Node => Block_Var.Node, Origin => Origin, Env => Env, E_Info => Block_Var.Info);
--# end
--# expr-done 1804
      declare
         Map_Result_1_Vec : Internal_Param_Match_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_4;
      begin
         for Item_88 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_88
         --# expr-start 1807 '<Eq at ast.py:14822>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:14822
--# expr-start 1806 '<FieldAccess for assoc at ast.py:14822>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14822
--# expr-start 1805 '<FieldAccess for actual at ast.py:14822>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14822
Fld_5 := Item_88.Actual;
--# expr-done 1805
Fld_6 := Fld_5.Assoc;
--# expr-done 1806
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv_1 := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 1807
         if Is_Equiv_1 then
         declare
            Item_To_Append : constant Internal_Param_Match := Item_88;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 1808
   If_Result := Map_Result_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 1809
Block_Var_2 := If_Result; Inc_Ref (Block_Var_2);
--# bind matches Block_Var_2
--# expr-start 1812 '<AnyQuantifier at ast.py:14827>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:14827
   --# expr-start 1810 '<FieldAccess for names at ast.py:14827>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14827
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.names'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Names (Node => Ent.Node);
--# end
--# expr-done 1810
      Quantifier_Result := False;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Fld_7;
      begin
         for Item_89 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_89
      --# expr-start 1811 '<IsA OthersDesignator at ast.py:14828>' Is_A /tmp/lal-23.0.0/ada/ast.py:14828
Is_A := Item_89 /= null 
and then Item_89.Kind in Ada_Others_Designator_Range; 
--# expr-done 1811
      Quantifier_Result := Is_A;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 1812
Block_Var_3 := Quantifier_Result; 
--# bind is_others_assoc Block_Var_3
--# expr-start 1855 '<If at ast.py:14831>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14831
--# expr-start 1813 '<Not at ast.py:14832>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:14832
Not_Val_1 := not (Block_Var_3); 
--# expr-done 1813
if Not_Val_1 then
   --# expr-start 1841 '<LogicAll at ast.py:14834>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14834
--# expr-start 1840 '<Map at ast.py:14834>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:14834
      declare
         Map_Result_2_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Block_Var_2;
      begin
         for Item_90 of
               Collection.Items
         loop
   --# scope-start
               --# bind match Item_90
      --# expr-start 1839 '<And at ast.py:14834>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14834
--# expr-start 1832 '<And at ast.py:14834>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14834
--# expr-start 1827 '<And at ast.py:14834>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14834
--# expr-start 1822 '<Bind at ast.py:14835>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14835
--# expr-start 1817 '<FieldAccess for expected_type_var at ast.py:14836>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14836
--# expr-start 1816 '<FieldAccess for expr at ast.py:14836>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14836
--# expr-start 1815 '<FieldAccess for assoc at ast.py:14836>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14836
--# expr-start 1814 '<FieldAccess for actual at ast.py:14836>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14836
Fld_8 := Item_90.Actual;
--# expr-done 1814
Fld_9 := Fld_8.Assoc;
--# expr-done 1815
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_9.Node, E_Info => Fld_9.Info);
--# end
--# expr-done 1816
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_10.Node);
--# expr-done 1817
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
--# expr-start 1821 '<FieldAccess for designated_type at ast.py:14837>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14837
--# expr-start 1820 '<FieldAccess for type_expression at ast.py:14837>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14837
--# expr-start 1819 '<FieldAccess for formal_decl at ast.py:14837>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14837
--# expr-start 1818 '<FieldAccess for formal at ast.py:14837>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14837
Fld_12 := Item_90.Formal;
--# expr-done 1818
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_13 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_12.Node, E_Info => Fld_12.Info);
--# end
--# expr-done 1819
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_14 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_13.Node, E_Info => Fld_13.Info);
--# end
--# expr-done 1820
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_15 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_14.Node, Origin => Origin, E_Info => Fld_14.Info);
--# end
--# expr-done 1821
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
Bind_Result := Solver.Create_Assign (Fld_11, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14835") else null)); 
--# expr-done 1822
--# expr-start 1826 '<FieldAccess for sub_equation at ast.py:14839>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14839
--# expr-start 1825 '<FieldAccess for expr at ast.py:14839>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14839
--# expr-start 1824 '<FieldAccess for assoc at ast.py:14839>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14839
--# expr-start 1823 '<FieldAccess for actual at ast.py:14839>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14839
Fld_16 := Item_90.Actual;
--# expr-done 1823
Fld_17 := Fld_16.Assoc;
--# expr-done 1824
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_18 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_17.Node, E_Info => Fld_17.Info);
--# end
--# expr-done 1825
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_19 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_18.Node, Env => Env, Origin => Origin, E_Info => Fld_18.Info);
--# end
--# expr-done 1826
And_Pred := Create_And (Bind_Result, Fld_19, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14834") else null)); 
--# expr-done 1827
--# expr-start 1831 '<FieldAccess for matches_expected_type at ast.py:14840>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:14840
--# expr-start 1830 '<FieldAccess for expr at ast.py:14840>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:14840
--# expr-start 1829 '<FieldAccess for assoc at ast.py:14840>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:14840
--# expr-start 1828 '<FieldAccess for actual at ast.py:14840>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:14840
Fld_20 := Item_90.Actual;
--# expr-done 1828
Fld_21 := Fld_20.Assoc;
--# expr-done 1829
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_22 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_21.Node, E_Info => Fld_21.Info);
--# end
--# expr-done 1830
      if Fld_22.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_23 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_22.Node, Origin => Origin);
--# end
--# expr-done 1831
And_Pred_1 := Create_And (And_Pred, Fld_23, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14834") else null)); 
--# expr-done 1832
--# expr-start 1834 '<FieldAccess for name at ast.py:14841>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:14841
--# expr-start 1833 '<FieldAccess for actual at ast.py:14841>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:14841
Fld_24 := Item_90.Actual;
--# expr-done 1833
Fld_25 := Fld_24.Name;
--# expr-done 1834
Var_Expr := Fld_25;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind n Var_Expr
--# expr-start 1838 '<Bind at ast.py:14842>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14842
--# expr-start 1835 '<FieldAccess for ref_var at ast.py:14842>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:14842
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_26 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Var_Expr);
--# end
--# expr-done 1835
Fld_26.Value := No_Entity;
Entity_Vars.Reset (Fld_26);
--# expr-start 1837 '<FieldAccess for formal_decl at ast.py:14842>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:14842
--# expr-start 1836 '<FieldAccess for formal at ast.py:14842>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:14842
Fld_27 := Item_90.Formal;
--# expr-done 1836
      if Fld_27.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_28 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_27.Node, E_Info => Fld_27.Info);
--# end
--# expr-done 1837
      Cast_Result_5 := Create_Internal_Entity
        (Node => Fld_28.Node,
         Info => Fld_28.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_26, Cast_Result_5, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14842") else null)); 
--# expr-done 1838
Scope_Result := Bind_Result_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2038;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14843") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (And_Pred_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14834") else null)); 
--# expr-done 1839
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_2;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2037;
         end loop;
      end;
         Map_Result_2 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_2_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 1840
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result_2.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14834") else null)); 
--# expr-done 1841
   If_Result_1 := Logic_Boolean_Op;
else
--# expr-start 1842 '<FieldAccess for first_unmatched_formal at ast.py:14851>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:14851
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.first_unmatched_formal
Fld_29 := Libadalang.Implementation.Base_Aggregate_P_First_Unmatched_Formal (Node => Block_Var.Node, Origin => Origin, Env => Env, E_Info => Block_Var.Info);
--# end
--# expr-done 1842
Var_Expr_1 := Fld_29;
if Var_Expr_1 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind unmatched_formal Var_Expr_1
--# expr-start 1854 '<And at ast.py:14853>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:14853
--# expr-start 1851 '<And at ast.py:14853>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:14853
--# expr-start 1848 '<Bind at ast.py:14853>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:14853
--# expr-start 1844 '<FieldAccess for expected_type_var at ast.py:14854>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:14854
--# expr-start 1843 '<FieldAccess for expr at ast.py:14854>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:14854
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_30 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1843
      if Fld_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_30.Node);
--# expr-done 1844
Fld_31.Value := No_Entity;
Entity_Vars.Reset (Fld_31);
--# expr-start 1847 '<FieldAccess for designated_type at ast.py:14856>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:14856
--# expr-start 1846 '<FieldAccess for type_expression at ast.py:14856>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:14856
--# expr-start 1845 '<FieldAccess for formal_decl at ast.py:14855>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:14855
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_32 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 1845
      if Fld_32.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_33 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_32.Node, E_Info => Fld_32.Info);
--# end
--# expr-done 1846
      if Fld_33.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_34 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_33.Node, Origin => Origin, E_Info => Fld_33.Info);
--# end
--# expr-done 1847
      Cast_Result_6 := Create_Internal_Entity
        (Node => Fld_34.Node,
         Info => Fld_34.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_31, Cast_Result_6, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14853") else null)); 
--# expr-done 1848
--# expr-start 1850 '<FieldAccess for sub_equation at ast.py:14858>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:14858
--# expr-start 1849 '<FieldAccess for expr at ast.py:14858>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:14858
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_35 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1849
      if Fld_35.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_36 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_35.Node, Env => Env, Origin => Origin, E_Info => Fld_35.Info);
--# end
--# expr-done 1850
And_Pred_3 := Create_And (Bind_Result_2, Fld_36, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14853") else null)); 
--# expr-done 1851
--# expr-start 1853 '<FieldAccess for matches_expected_type at ast.py:14859>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:14859
--# expr-start 1852 '<FieldAccess for expr at ast.py:14859>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:14859
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_37 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1852
      if Fld_37.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_38 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_37.Node, Origin => Origin);
--# end
--# expr-done 1853
And_Pred_4 := Create_And (And_Pred_3, Fld_38, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14853") else null)); 
--# expr-done 1854
Scope_Result_1 := And_Pred_4;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2039;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14860") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
   If_Result_1 := Result_Var_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 1855
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1856
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1081;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1081;
               Finalizer_Scope_2037;
               Finalizer_Scope_2038;
               Finalizer_Scope_2039;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Record_Assoc_Equation;
--# end
--# property-start AggregateAssoc.array_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14865
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Array_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Atd : Internal_Entity_Array_Type_Def
      ; Mra : Internal_Multidim_Aggregate_Info
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind atd Atd
   --# bind mra Mra
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1082 with Inline_Always;
            procedure Finalizer_Scope_2040 with Inline_Always;
            procedure Finalizer_Scope_2041 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Var_Expr_1 : Internal_Entity_Expr;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
True_Rel : Logic_Equation;
Is_Equal : Boolean;
Fld_7 : Integer;
Fld_8 : Integer;
Arith_Result : Integer;
Is_Equal_1 : Boolean;
If_Result : Boolean;
If_Result_1 : Logic_Equation;
Fld_9 : Internal_Entity_Alternatives_List;
Fld_10 : Bare_Alternatives_List;
Fld_11 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result_2 : Internal_Entity;
Fld_12 : Logic_Equation;
Cast_Expr : Internal_Entity;
Cast_Result_1 : Internal_Entity_Name;
Fld_13 : Logic_Equation;
Cast_Expr_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Expr;
Fld_14 : Logic_Var;
Fld_15 : Integer;
Fld_16 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_17 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var : Logic_Equation;
Cast_Expr_2 : Internal_Entity;
Cast_Result_4 : Internal_Entity_Name;
Fld_18 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Is_Null_1 : Boolean;
Not_Val : Boolean;
If_Result_3 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Item_91 : Internal_Entity;
Bare_Item_91 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_4 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1082 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1082;
            procedure Finalizer_Scope_2040 is
            begin
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_2040;
            procedure Finalizer_Scope_2041 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_17);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_2041;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1893 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1892 '<And at ast.py:14871>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:14871
--# expr-start 1872 '<If at ast.py:14872>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14872
--# expr-start 1857 '<IsNull at ast.py:14875>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14875
Is_Equal := Mra = No_Multidim_Aggregate_Info; 
--# expr-done 1857
if Is_Equal then
   If_Result := True;
else
   --# expr-start 1861 '<Eq at ast.py:14875>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:14875
--# expr-start 1858 '<FieldAccess for rank at ast.py:14875>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14875
Fld_7 := Mra.Rank;
--# expr-done 1858
--# expr-start 1860 '<Arithmetic - at ast.py:14875>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:14875
--# expr-start 1859 '<FieldAccess for array_ndims at ast.py:14875>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14875
      if Atd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_8 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Atd.Node, Origin => Origin, E_Info => Atd.Info);
--# end
--# expr-done 1859
Arith_Result := (Fld_8 - 1); 
--# expr-done 1860
Is_Equal_1 := Fld_7 = Arith_Result; 
--# expr-done 1861
   If_Result := Is_Equal_1;
end if;
if If_Result then
   --# expr-start 1871 '<And at ast.py:14878>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14878
--# expr-start 1868 '<And at ast.py:14878>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14878
--# expr-start 1865 '<Bind at ast.py:14878>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14878
--# expr-start 1863 '<FieldAccess for expected_type_var at ast.py:14878>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14878
--# expr-start 1862 '<FieldAccess for expr at ast.py:14878>' Fld /tmp/lal-23.0.0/ada/ast.py:14878
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1862
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld.Node);
--# expr-done 1863
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 1864 '<FieldAccess for comp_type at ast.py:14878>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14878
      if Atd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ArrayTypeDef.comp_type
Fld_2 := Libadalang.Implementation.Array_Type_Def_P_Comp_Type (Node => Atd.Node, Origin => Origin, E_Info => Atd.Info);
--# end
--# expr-done 1864
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14878") else null)); 
--# expr-done 1865
--# expr-start 1867 '<FieldAccess for sub_equation at ast.py:14879>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14879
--# expr-start 1866 '<FieldAccess for expr at ast.py:14879>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14879
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1866
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 1867
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14878") else null)); 
--# expr-done 1868
--# expr-start 1870 '<FieldAccess for matches_expected_type at ast.py:14880>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14880
--# expr-start 1869 '<FieldAccess for expr at ast.py:14880>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14880
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_5 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1869
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 1870
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14878") else null)); 
--# expr-done 1871
   If_Result_1 := And_Pred_1;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14884") else null)); 
   If_Result_1 := True_Rel;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 1872
--# expr-start 1891 '<LogicAll at ast.py:14887>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14887
--# expr-start 1890 '<Map at ast.py:14887>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14887
   --# expr-start 1873 '<FieldAccess for designators at ast.py:14887>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14887
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Alternatives_List (Node => Ent.Node.Aggregate_Assoc_F_Designators, Info => Ent.Info);
--# expr-done 1873
Fld_10 := Fld_9.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_10 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_10;
      begin
         for Untyped_Item_91 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_91 := Untyped_Item_91; 
Is_Null := Bare_Item_91 = null; 
if Is_Null then
   If_Result_2 := No_Entity;
else
Fld_11 := Fld_9.Info;
As_Entity := (Info => Fld_11, Node => Bare_Item_91); 
   If_Result_2 := As_Entity;
end if;
                  Item_91 := If_Result_2; 
   --# scope-start
               --# bind n Item_91
      --# expr-start 1889 '<And at ast.py:14888>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:14888
--# expr-start 1874 '<FieldAccess for sub_equation at ast.py:14888>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14888
      if Item_91.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_12 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_91.Node, Env => Env, Origin => Origin, E_Info => Item_91.Info);
--# end
--# expr-done 1874
--# expr-start 1888 '<If at ast.py:14888>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:14888
--# expr-start 1878 '<Not at ast.py:14889>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14889
--# expr-start 1877 '<IsNull at ast.py:14889>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:14889
--# expr-start 1875 '<Cast to Name at ast.py:14889>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:14889
Cast_Expr_2 := Item_91; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Name
   then
      Cast_Result_4 := Create_Internal_Entity_Name
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_4 := No_Entity_Name;
   end if;
--# expr-done 1875
Var_Expr := Cast_Result_4;
if Var_Expr /= No_Entity_Name then
   --# scope-start
--# expr-start 1876 '<FieldAccess for name_designated_type at ast.py:14889>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14889
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_18 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 1876
Scope_Result_1 := Fld_18;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Is_Null_1 := Result_Var_1.Node = null; 
--# expr-done 1877
Not_Val := not (Is_Null_1); 
--# expr-done 1878
if Not_Val then
   --# expr-start 1880 '<FieldAccess for xref_no_overloading at ast.py:14891>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14891
--# expr-start 1879 '<Cast to Name at ast.py:14891>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:14891
Cast_Expr := Item_91; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 1879
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_13 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_1.Node, Env => Env, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 1880
   If_Result_3 := Fld_13;
else
--# expr-start 1881 '<Cast to Expr at ast.py:14893>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:14893
Cast_Expr_1 := Item_91; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Expr
   then
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Expr;
   end if;
--# expr-done 1881
Var_Expr_1 := Cast_Result_2;
if Var_Expr_1 /= No_Entity_Expr then
   --# scope-start
   --# bind n Var_Expr_1
--# expr-start 1887 '<And at ast.py:14895>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14895
--# expr-start 1885 '<Bind at ast.py:14895>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14895
--# expr-start 1882 '<FieldAccess for expected_type_var at ast.py:14895>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14895
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr_1.Node);
--# expr-done 1882
Fld_14.Value := No_Entity;
Entity_Vars.Reset (Fld_14);
--# expr-start 1884 '<FieldAccess for index_type at ast.py:14895>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14895
      if Atd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1883 '<FieldAccess for rank at ast.py:14895>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14895
Fld_15 := Mra.Rank;
--# expr-done 1883
--# property-call-start ArrayTypeDef.index_type
Fld_16 := Libadalang.Implementation.Array_Type_Def_P_Index_Type (Node => Atd.Node, Dim => Fld_15, Origin => Origin, E_Info => Atd.Info);
--# end
--# expr-done 1884
      Cast_Result_3 := Create_Internal_Entity
        (Node => Fld_16.Node,
         Info => Fld_16.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_14, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14895") else null)); 
--# expr-done 1885
--# expr-start 1886 '<FieldAccess for matches_expected_type at ast.py:14896>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14896
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_17 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Var_Expr_1.Node, Origin => Origin);
--# end
--# expr-done 1886
And_Pred_2 := Create_And (Bind_Result_1, Fld_17, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14895") else null)); 
--# expr-done 1887
Scope_Result := And_Pred_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2041;
   Result_Var := Scope_Result;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14897") else null)); 
   Result_Var := True_Rel_1;
end if;
      Inc_Ref (Result_Var);
   If_Result_3 := Result_Var;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 1888
And_Pred_3 := Create_And (Fld_12, If_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14888") else null)); 
--# expr-done 1889
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2040;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1890
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14887") else null)); 
--# expr-done 1891
And_Pred_4 := Create_And (If_Result_1, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14871") else null)); 
--# expr-done 1892
Let_Result := And_Pred_4; Inc_Ref (Let_Result);
--# end
--# expr-done 1893
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1082;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1082;
               Finalizer_Scope_2040;
               Finalizer_Scope_2041;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Array_Assoc_Equation;
--# end
--# property-start AggregateAssoc.globals_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14904
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Globals_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1083 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1083 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1083;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1896 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1895 '<FieldAccess for sub_equation at ast.py:14912>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14912
--# expr-start 1894 '<FieldAccess for expr at ast.py:14912>' Fld /tmp/lal-23.0.0/ada/ast.py:14912
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1894
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 1895
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1896
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1083;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1083;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Globals_Assoc_Equation;
--# end
--# property-start AggregateAssoc.depends_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14915
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Depends_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1084 with Inline_Always;
            procedure Finalizer_Scope_2043 with Inline_Always;
      Var_Expr : Internal_Entity_Identifier;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Ada_Node_Array_Access;
Get_Result : Bare_Ada_Node;
Cast_Result : Bare_Identifier;
As_Entity : Internal_Entity_Identifier;
Is_Null : Boolean;
If_Result : Internal_Entity_Identifier;
Fld_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1084 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1084;
            procedure Finalizer_Scope_2043 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2043;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1905 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1904 '<And at ast.py:14920>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14920
--# expr-start 1898 '<FieldAccess for sub_equation at ast.py:14925>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14925
--# expr-start 1897 '<FieldAccess for expr at ast.py:14925>' Fld /tmp/lal-23.0.0/ada/ast.py:14925
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1897
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 1898
--# expr-start 1902 '<as_entity at ast.py:14933>' If_Result /tmp/lal-23.0.0/ada/ast.py:14933
--# expr-start 1901 '<Cast to Identifier at ast.py:14933>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14933
--# expr-start 1900 '<at at ast.py:14933>' Get_Result /tmp/lal-23.0.0/ada/ast.py:14933
--# expr-start 1899 '<FieldAccess for names at ast.py:14933>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14933
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.names'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Names (Node => Ent.Node);
--# end
--# expr-done 1899
Get_Result := Get (Self, Fld_2, 0, True); 
--# expr-done 1900
   if Get_Result = null
      or else Get_Result.Kind in Ada_Identifier_Range
   then
      Cast_Result := Get_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 1901
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Identifier;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 1902
Var_Expr := If_Result;
if Var_Expr /= No_Entity_Identifier then
   --# scope-start
   --# bind n Var_Expr
--# expr-start 1903 '<FieldAccess for sub_equation at ast.py:14934>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14934
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1903
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2043;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14934") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14920") else null)); 
--# expr-done 1904
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 1905
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1084;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1084;
               Finalizer_Scope_2043;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Depends_Assoc_Equation;
--# end
--# property-start AggregateAssoc.test_case_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14939
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Test_Case_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1085 with Inline_Always;
      Var_Expr : Bare_Base_Id;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
True_Rel : Logic_Equation;
Fld_2 : Bare_Ada_Node_Array_Access;
Get_Result : Bare_Ada_Node;
Cast_Result : Bare_Base_Id;
Fld_3 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_4 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1085 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Fld_2);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1085;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1918 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1917 '<If at ast.py:14944>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14944
--# expr-start 1908 '<Cast to BaseId at ast.py:14947>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14947
--# expr-start 1907 '<at at ast.py:14947>' Get_Result /tmp/lal-23.0.0/ada/ast.py:14947
--# expr-start 1906 '<FieldAccess for names at ast.py:14947>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14947
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.names'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Names (Node => Ent.Node);
--# end
--# expr-done 1906
Get_Result := Get (Self, Fld_2, 0, True); 
--# expr-done 1907
   if Get_Result = null
      or else Get_Result.Kind in Ada_Base_Id
   then
      Cast_Result := Get_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 1908
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind name Var_Expr
--# expr-start 1911 '<Eq at ast.py:14948>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14948
--# expr-start 1909 '<FieldAccess for name_symbol at ast.py:14948>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14948
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Var_Expr);
--# end
--# expr-done 1909
--# expr-start 1910 '<Symbol Requires at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Requires); 
--# expr-done 1910
Is_Equal := Fld_3 = Sym; 
--# expr-done 1911
if Is_Equal then
   If_Result := True;
else
   --# expr-start 1914 '<Eq at ast.py:14948>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:14948
--# expr-start 1912 '<FieldAccess for name_symbol at ast.py:14948>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14948
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Var_Expr);
--# end
--# expr-done 1912
--# expr-start 1913 '<Symbol Ensures at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ensures); 
--# expr-done 1913
Is_Equal_1 := Fld_4 = Sym_1; 
--# expr-done 1914
   If_Result := Is_Equal_1;
end if;
Scope_Result := If_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   --# expr-start 1916 '<FieldAccess for sub_equation at ast.py:14952>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14952
--# expr-start 1915 '<FieldAccess for expr at ast.py:14952>' Fld /tmp/lal-23.0.0/ada/ast.py:14952
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1915
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 1916
   If_Result_1 := Fld_1;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14953") else null)); 
   If_Result_1 := True_Rel;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 1917
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 1918
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1085;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1085;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Test_Case_Assoc_Equation;
--# end
--# property-start AggregateAssoc.contract_cases_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14957
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Contract_Cases_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1086 with Inline_Always;
            procedure Finalizer_Scope_2045 with Inline_Always;
            procedure Finalizer_Scope_2046 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Alternatives_List;
Fld_1 : Bare_Alternatives_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
Fld_3 : Logic_Var;
Fld_4 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Item_92 : Internal_Entity;
Bare_Item_92 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_7 : Internal_Entity_Expr;
Fld_8 : Logic_Var;
Fld_9 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_10 : Internal_Entity_Expr;
Fld_11 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_12 : Internal_Entity_Expr;
Fld_13 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1086 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_11);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_13);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1086;
            procedure Finalizer_Scope_2045 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2045;
            procedure Finalizer_Scope_2046 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2046;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1941 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1940 '<And at ast.py:14963>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:14963
--# expr-start 1937 '<And at ast.py:14963>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:14963
--# expr-start 1934 '<And at ast.py:14963>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14963
--# expr-start 1929 '<LogicAll at ast.py:14964>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14964
--# expr-start 1928 '<Map at ast.py:14964>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14964
   --# expr-start 1919 '<FieldAccess for designators at ast.py:14964>' Fld /tmp/lal-23.0.0/ada/ast.py:14964
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Alternatives_List (Node => Ent.Node.Aggregate_Assoc_F_Designators, Info => Ent.Info);
--# expr-done 1919
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_1;
      begin
         for Untyped_Item_92 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_92 := Untyped_Item_92; 
Is_Null := Bare_Item_92 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_92); 
   If_Result := As_Entity;
end if;
                  Item_92 := If_Result; 
   --# scope-start
               --# bind d Item_92
--# expr-start 1920 '<Cast to Expr at ast.py:14965>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14965
Cast_Expr := Item_92; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Expr;
   end if;
--# expr-done 1920
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 1927 '<And at ast.py:14967>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14967
--# expr-start 1925 '<And at ast.py:14967>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14967
--# expr-start 1923 '<Bind at ast.py:14967>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14967
--# expr-start 1921 '<FieldAccess for expected_type_var at ast.py:14967>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14967
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 1921
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 1922 '<FieldAccess for bool_type at ast.py:14967>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14967
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_4 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 1922
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Bind_Result := Solver.Create_Assign (Fld_3, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14967") else null)); 
--# expr-done 1923
--# expr-start 1924 '<FieldAccess for sub_equation at ast.py:14968>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14968
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1924
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14967") else null)); 
--# expr-done 1925
--# expr-start 1926 '<FieldAccess for matches_expected_formal_prim_type at ast.py:14969>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14969
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 1926
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14967") else null)); 
--# expr-done 1927
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2046;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14972") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
         declare
            Item_To_Append : constant Logic_Equation := Result_Var;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2045;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1928
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14964") else null)); 
--# expr-done 1929
--# expr-start 1933 '<Bind at ast.py:14975>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14975
--# expr-start 1931 '<FieldAccess for expected_type_var at ast.py:14975>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14975
--# expr-start 1930 '<FieldAccess for expr at ast.py:14975>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14975
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1930
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_7.Node);
--# expr-done 1931
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
--# expr-start 1932 '<FieldAccess for bool_type at ast.py:14975>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14975
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_9 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 1932
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_8, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14975") else null)); 
--# expr-done 1933
And_Pred_2 := Create_And (Logic_Boolean_Op, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14963") else null)); 
--# expr-done 1934
--# expr-start 1936 '<FieldAccess for sub_equation at ast.py:14976>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14976
--# expr-start 1935 '<FieldAccess for expr at ast.py:14976>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14976
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1935
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_11 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_10.Node, Env => Env, Origin => Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 1936
And_Pred_3 := Create_And (And_Pred_2, Fld_11, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14963") else null)); 
--# expr-done 1937
--# expr-start 1939 '<FieldAccess for matches_expected_formal_prim_type at ast.py:14977>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14977
--# expr-start 1938 '<FieldAccess for expr at ast.py:14977>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14977
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_12 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1938
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_13 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_12.Node, Origin => Origin);
--# end
--# expr-done 1939
And_Pred_4 := Create_And (And_Pred_3, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14963") else null)); 
--# expr-done 1940
Let_Result := And_Pred_4; Inc_Ref (Let_Result);
--# end
--# expr-done 1941
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1086;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1086;
               Finalizer_Scope_2045;
               Finalizer_Scope_2046;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Contract_Cases_Assoc_Equation;
--# end
--# property-start AggregateAssoc.exprs_assoc_equation /tmp/lal-23.0.0/ada/ast.py:14981
pragma Warnings (Off, "is not referenced");
 function Aggregate_Assoc_P_Exprs_Assoc_Equation
  (Node : Bare_Aggregate_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Aggregate_Assoc := Bare_Aggregate_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Aggregate_Assoc :=
     Internal_Entity_Aggregate_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1087 with Inline_Always;
            procedure Finalizer_Scope_2047 with Inline_Always;
            procedure Finalizer_Scope_2048 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Fld : Internal_Entity_Alternatives_List;
Fld_1 : Bare_Alternatives_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_3 : Logic_Equation;
Item_93 : Internal_Entity;
Bare_Item_93 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_4 : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_5 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1087 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1087;
            procedure Finalizer_Scope_2047 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2047;
            procedure Finalizer_Scope_2048 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2048;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 1950 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1949 '<And at ast.py:14987>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14987
--# expr-start 1945 '<LogicAll at ast.py:14988>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14988
--# expr-start 1944 '<Map at ast.py:14988>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14988
   --# expr-start 1942 '<FieldAccess for designators at ast.py:14988>' Fld /tmp/lal-23.0.0/ada/ast.py:14988
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Alternatives_List (Node => Ent.Node.Aggregate_Assoc_F_Designators, Info => Ent.Info);
--# expr-done 1942
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_1;
      begin
         for Untyped_Item_93 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_93 := Untyped_Item_93; 
Is_Null := Bare_Item_93 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_93); 
   If_Result := As_Entity;
end if;
                  Item_93 := If_Result; 
   --# scope-start
               --# bind d Item_93
      --# expr-start 1943 '<FieldAccess for sub_equation at ast.py:14988>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14988
      if Item_93.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_93.Node, Env => Env, Origin => Origin, E_Info => Item_93.Info);
--# end
--# expr-done 1943
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2047;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1944
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14988") else null)); 
--# expr-done 1945
--# expr-start 1947 '<Cast to Name at ast.py:14989>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14989
--# expr-start 1946 '<FieldAccess for expr at ast.py:14989>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14989
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1946
   if Fld_4.Node = null
      or else Fld_4.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 1947
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind n Var_Expr
--# expr-start 1948 '<FieldAccess for sub_equation at ast.py:14990>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14990
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1948
Scope_Result := Fld_5;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2048;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14991") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Logic_Boolean_Op, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14987") else null)); 
--# expr-done 1949
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 1950
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1087;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1087;
               Finalizer_Scope_2047;
               Finalizer_Scope_2048;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Aggregate_Assoc_P_Exprs_Assoc_Equation;
--# end
   --
   --  Primitives for Bare_Multi_Dim_Array_Assoc
   --
      procedure Initialize_Fields_For_Multi_Dim_Array_Assoc
        (Self : Bare_Multi_Dim_Array_Assoc
         ; Aggregate_Assoc_F_Designators : Bare_Alternatives_List
         ; Aggregate_Assoc_F_R_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Aggregate_Assoc
              (Self, Aggregate_Assoc_F_Designators, Aggregate_Assoc_F_R_Expr);
      end Initialize_Fields_For_Multi_Dim_Array_Assoc;
   --
   --  Primitives for Bare_Composite_Constraint_Assoc
   --
      procedure Initialize_Fields_For_Composite_Constraint_Assoc
        (Self : Bare_Composite_Constraint_Assoc
         ; Composite_Constraint_Assoc_F_Ids : Bare_Discriminant_Choice_List
         ; Composite_Constraint_Assoc_F_Constraint_Expr : Bare_Ada_Node
        ) is
      begin
            Self.Composite_Constraint_Assoc_F_Ids := Composite_Constraint_Assoc_F_Ids;
            Self.Composite_Constraint_Assoc_F_Constraint_Expr := Composite_Constraint_Assoc_F_Constraint_Expr;
      end Initialize_Fields_For_Composite_Constraint_Assoc;
   function Composite_Constraint_Assoc_F_Ids
     (Node : Bare_Composite_Constraint_Assoc) return Bare_Discriminant_Choice_List
   is
   begin
         return Node.Composite_Constraint_Assoc_F_Ids;
   end;
   function Composite_Constraint_Assoc_F_Constraint_Expr
     (Node : Bare_Composite_Constraint_Assoc) return Bare_Ada_Node
   is
   begin
         return Node.Composite_Constraint_Assoc_F_Constraint_Expr;
   end;
--# property-start CompositeConstraintAssoc.expr /tmp/lal-23.0.0/ada/ast.py:8079
pragma Warnings (Off, "is not referenced");
 function Composite_Constraint_Assoc_P_Expr
  (Node : Bare_Composite_Constraint_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Composite_Constraint_Assoc := Bare_Composite_Constraint_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Composite_Constraint_Assoc :=
     Internal_Entity_Composite_Constraint_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1952 '<Cast to Expr at ast.py:8079>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8079
--# expr-start 1951 '<FieldAccess for constraint_expr at ast.py:8079>' Fld /tmp/lal-23.0.0/ada/ast.py:8079
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Composite_Constraint_Assoc_F_Constraint_Expr, Info => Ent.Info);
--# expr-done 1951
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1952
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Composite_Constraint_Assoc_P_Expr;
--# end
--# property-start CompositeConstraintAssoc.names /tmp/lal-23.0.0/ada/ast.py:8080
pragma Warnings (Off, "is not referenced");
 function Composite_Constraint_Assoc_P_Names
  (Node : Bare_Composite_Constraint_Assoc
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Composite_Constraint_Assoc := Bare_Composite_Constraint_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_606 with Inline_Always;
      Fld : Bare_Discriminant_Choice_List;
Cast_Expr : Bare_Identifier;
Cast_Result : Bare_Ada_Node;
Item_94 : Bare_Identifier;
Map_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_606 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_606;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1955 '<Map at ast.py:8080>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8080
   --# expr-start 1953 '<FieldAccess for ids at ast.py:8080>' Fld /tmp/lal-23.0.0/ada/ast.py:8080
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Composite_Constraint_Assoc_F_Ids;
--# expr-done 1953
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Discriminant_Choice_List := Fld;
      begin
         for Untyped_Item_94 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_94 := Untyped_Item_94; 
   --# scope-start
               --# bind i Item_94
      --# expr-start 1954 '<Cast to AdaNode at ast.py:8080>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8080
Cast_Expr := Item_94; 
      Cast_Result := Cast_Expr;
--# expr-done 1954
         declare
            Item_To_Append : constant Bare_Ada_Node := Cast_Result;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 1955
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_606;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_606;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Composite_Constraint_Assoc_P_Names;
--# end
   --
   --  Primitives for Bare_Iterated_Assoc
   --
      procedure Initialize_Fields_For_Iterated_Assoc
        (Self : Bare_Iterated_Assoc
         ; Iterated_Assoc_F_Spec : Bare_For_Loop_Spec
         ; Iterated_Assoc_F_R_Expr : Bare_Expr
        ) is
      begin
            Self.Iterated_Assoc_F_Spec := Iterated_Assoc_F_Spec;
            Self.Iterated_Assoc_F_R_Expr := Iterated_Assoc_F_R_Expr;
      end Initialize_Fields_For_Iterated_Assoc;
   function Iterated_Assoc_F_Spec
     (Node : Bare_Iterated_Assoc) return Bare_For_Loop_Spec
   is
   begin
         return Node.Iterated_Assoc_F_Spec;
   end;
   function Iterated_Assoc_F_R_Expr
     (Node : Bare_Iterated_Assoc) return Bare_Expr
   is
   begin
         return Node.Iterated_Assoc_F_R_Expr;
   end;
--# property-start IteratedAssoc.expr /tmp/lal-23.0.0/ada/ast.py:15003
pragma Warnings (Off, "is not referenced");
 function Iterated_Assoc_P_Expr
  (Node : Bare_Iterated_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Iterated_Assoc := Bare_Iterated_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Iterated_Assoc :=
     Internal_Entity_Iterated_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Fld : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1956 '<FieldAccess for r_expr at ast.py:15003>' Fld /tmp/lal-23.0.0/ada/ast.py:15003
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Iterated_Assoc_F_R_Expr, Info => Ent.Info);
--# expr-done 1956
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Iterated_Assoc_P_Expr;
--# end
--# property-start IteratedAssoc.names /tmp/lal-23.0.0/ada/ast.py:15004
pragma Warnings (Off, "is not referenced");
 function Iterated_Assoc_P_Names
  (Node : Bare_Iterated_Assoc
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Iterated_Assoc := Bare_Iterated_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Bare_Ada_Node_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Iterated_Assoc_P_Names;
--# end
--# property-start IteratedAssoc.base_aggregate /tmp/lal-23.0.0/ada/ast.py:15006
pragma Warnings (Off, "is not referenced");
 function Iterated_Assoc_P_Base_Aggregate
  (Node : Bare_Iterated_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Aggregate
is
   Self : Bare_Iterated_Assoc := Bare_Iterated_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Iterated_Assoc :=
     Internal_Entity_Iterated_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Aggregate;
      Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Aggregate;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1959 '<Cast to BaseAggregate at ast.py:15007>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15007
--# expr-start 1958 '<parent at ast.py:15007>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15007
--# expr-start 1957 '<parent at ast.py:15007>' Fld /tmp/lal-23.0.0/ada/ast.py:15007
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 1957
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 1958
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Aggregate
   then
      Cast_Result := Create_Internal_Entity_Base_Aggregate
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 1959
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Iterated_Assoc_P_Base_Aggregate;
--# end
--# property-start IteratedAssoc.xref_stop_resolution /tmp/lal-23.0.0/ada/ast.py:15010
pragma Warnings (Off, "is not referenced");
 function Iterated_Assoc_P_Xref_Stop_Resolution
  (Node : Bare_Iterated_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Iterated_Assoc := Bare_Iterated_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Iterated_Assoc :=
     Internal_Entity_Iterated_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 1962 '<IsA BaseAggregate at ast.py:15010>' Is_A /tmp/lal-23.0.0/ada/ast.py:15010
--# expr-start 1961 '<parent at ast.py:15010>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15010
--# expr-start 1960 '<parent at ast.py:15010>' Fld /tmp/lal-23.0.0/ada/ast.py:15010
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 1960
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 1961
Is_A := Fld_1.Node /= null 
and then Fld_1.Node.Kind in Ada_Base_Aggregate; 
--# expr-done 1962
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Iterated_Assoc_P_Xref_Stop_Resolution;
--# end
--# property-start IteratedAssoc.xref_equation /tmp/lal-23.0.0/ada/ast.py:15013
pragma Warnings (Off, "is not referenced");
 function Iterated_Assoc_P_Xref_Equation
  (Node : Bare_Iterated_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Iterated_Assoc := Bare_Iterated_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Iterated_Assoc :=
     Internal_Entity_Iterated_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1092 with Inline_Always;
      Block_Var : Internal_Entity_Base_Aggregate;
Block_Var_1 : Internal_Multidim_Aggregate_Info;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Block_Var_3 : Internal_Entity_Array_Type_Def;
Block_Var_4 : Boolean;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Aggregate;
Fld_1 : Internal_Multidim_Aggregate_Info;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Is_Equal : Boolean;
Not_Val : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Result_Var : Internal_Entity_Array_Type_Def;
Fld_5 : Internal_Entity_For_Loop_Spec;
Fld_6 : Internal_Entity_For_Loop_Spec;
Fld_7 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Expr;
Fld_8 : Logic_Var;
Fld_9 : Integer;
Fld_10 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_11 : Internal_Entity_For_Loop_Spec;
Fld_12 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Expr;
Fld_13 : Logic_Equation;
And_Pred : Logic_Equation;
True_Rel : Logic_Equation;
Fld_14 : Bare_For_Loop_Spec;
Fld_15 : Bare_Iter_Type;
Is_A : Boolean;
If_Result_1 : Logic_Equation;
Fld_16 : Boolean;
Fld_17 : Internal_Entity_Expr;
Fld_18 : Logic_Equation;
Fld_19 : Internal_Entity_Expr;
Fld_20 : Logic_Var;
Fld_21 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_22 : Internal_Entity_Expr;
Fld_23 : Logic_Equation;
And_Pred_2 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Is_Equal_1 : Boolean;
Fld_24 : Integer;
Fld_25 : Integer;
Arith_Result : Integer;
Is_Equal_2 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Logic_Equation;
False_Rel : Logic_Equation;
If_Result_4 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1092 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_13);
                     Dec_Ref (And_Pred);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_23);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1092;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2007 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 1963 '<FieldAccess for base_aggregate at ast.py:15014>' Fld /tmp/lal-23.0.0/ada/ast.py:15014
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start IteratedAssoc.base_aggregate
Fld := Libadalang.Implementation.Iterated_Assoc_P_Base_Aggregate (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1963
Block_Var := Fld; 
--# bind aggregate Block_Var
--# expr-start 1964 '<FieldAccess for multidim_root_aggregate at ast.py:15016>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15016
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.multidim_root_aggregate
Fld_1 := Libadalang.Implementation.Base_Aggregate_P_Multidim_Root_Aggregate (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 1964
Block_Var_1 := Fld_1; 
--# bind root_agg Block_Var_1
--# expr-start 1970 '<If at ast.py:15021>' If_Result /tmp/lal-23.0.0/ada/ast.py:15021
--# expr-start 1966 '<Not at ast.py:15022>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15022
--# expr-start 1965 '<IsNull at ast.py:15022>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15022
Is_Equal := Block_Var_1 = No_Multidim_Aggregate_Info; 
--# expr-done 1965
Not_Val := not (Is_Equal); 
--# expr-done 1966
if Not_Val then
   --# expr-start 1967 '<FieldAccess for typ at ast.py:15023>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15023
Fld_2 := Block_Var_1.Typ;
--# expr-done 1967
   If_Result := Fld_2;
else
   --# expr-start 1969 '<Cast to BaseTypeDecl at ast.py:15024>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15024
--# expr-start 1968 '<FieldAccess for type_val at ast.py:15024>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15024
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_3 := Libadalang.Implementation.Expr_P_Type_Val (Node => Block_Var.Node);
--# end
--# expr-done 1968
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 1969
   If_Result := Cast_Result;
end if;
--# expr-done 1970
Block_Var_2 := If_Result; 
--# bind type_decl Block_Var_2
Var_Expr := Block_Var_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 1971 '<FieldAccess for array_def at ast.py:15027>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15027
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 1971
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Array_Type_Def;
end if;
Block_Var_3 := Result_Var; 
--# bind array_type_def Block_Var_3
--# expr-start 1989 '<FieldAccess for resolve_names_internal_with_eq at ast.py:15035>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15035
--# expr-start 1972 '<FieldAccess for spec at ast.py:15035>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15035
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Iterated_Assoc_F_Spec, Info => Ent.Info);
--# expr-done 1972
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1988 '<If at ast.py:15036>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15036
--# expr-start 1975 '<IsA IterType.In at ast.py:15036>' Is_A /tmp/lal-23.0.0/ada/ast.py:15036
--# expr-start 1974 '<FieldAccess for loop_type at ast.py:15036>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:15036
--# expr-start 1973 '<FieldAccess for spec at ast.py:15036>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:15036
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Self.Iterated_Assoc_F_Spec;
--# expr-done 1973
      if Fld_14 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Fld_14.For_Loop_Spec_F_Loop_Type;
--# expr-done 1974
Is_A := Fld_15 /= null 
and then Fld_15.Kind in Ada_Iter_Type_In_Range; 
--# expr-done 1975
if Is_A then
   --# expr-start 1987 '<And at ast.py:15037>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15037
--# expr-start 1982 '<Bind at ast.py:15037>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15037
--# expr-start 1979 '<FieldAccess for expected_type_var at ast.py:15037>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15037
--# expr-start 1978 '<Cast to Expr at ast.py:15037>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15037
--# expr-start 1977 '<FieldAccess for iter_expr at ast.py:15037>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15037
--# expr-start 1976 '<FieldAccess for spec at ast.py:15037>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15037
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Iterated_Assoc_F_Spec, Info => Ent.Info);
--# expr-done 1976
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity (Node => Fld_6.Node.For_Loop_Spec_F_Iter_Expr, Info => Fld_6.Info);
--# expr-done 1977
   if Fld_7.Node = null
      or else Fld_7.Node.Kind in Ada_Expr
   then
      Cast_Result_1 := Create_Internal_Entity_Expr
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
   else
         Cast_Result_1 := No_Entity_Expr;
   end if;
--# expr-done 1978
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Cast_Result_1.Node);
--# expr-done 1979
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
--# expr-start 1981 '<FieldAccess for index_type at ast.py:15038>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15038
      if Block_Var_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 1980 '<FieldAccess for rank at ast.py:15038>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15038
Fld_9 := Block_Var_1.Rank;
--# expr-done 1980
--# property-call-start ArrayTypeDef.index_type
Fld_10 := Libadalang.Implementation.Array_Type_Def_P_Index_Type (Node => Block_Var_3.Node, Dim => Fld_9, Origin => Origin, E_Info => Block_Var_3.Info);
--# end
--# expr-done 1981
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_10.Node,
         Info => Fld_10.Info);
Bind_Result := Solver.Create_Assign (Fld_8, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15037") else null)); 
--# expr-done 1982
--# expr-start 1986 '<FieldAccess for matches_expected_type at ast.py:15039>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15039
--# expr-start 1985 '<Cast to Expr at ast.py:15039>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:15039
--# expr-start 1984 '<FieldAccess for iter_expr at ast.py:15039>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15039
--# expr-start 1983 '<FieldAccess for spec at ast.py:15039>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15039
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Iterated_Assoc_F_Spec, Info => Ent.Info);
--# expr-done 1983
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity (Node => Fld_11.Node.For_Loop_Spec_F_Iter_Expr, Info => Fld_11.Info);
--# expr-done 1984
   if Fld_12.Node = null
      or else Fld_12.Node.Kind in Ada_Expr
   then
      Cast_Result_3 := Create_Internal_Entity_Expr
        (Node => Fld_12.Node,
         Info => Fld_12.Info);
   else
         Cast_Result_3 := No_Entity_Expr;
   end if;
--# expr-done 1985
      if Cast_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_13 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Cast_Result_3.Node, Origin => Origin);
--# end
--# expr-done 1986
And_Pred := Create_And (Bind_Result, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15037") else null)); 
--# expr-done 1987
   If_Result_1 := And_Pred;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15040") else null)); 
   If_Result_1 := True_Rel;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 1988
--# property-call-start AdaNode.resolve_names_internal_with_eq
Fld_16 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal_With_Eq (Node => Fld_5.Node, Additional_Equation => If_Result_1, Env => Env, Origin => Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 1989
Block_Var_4 := Fld_16; 
--# bind spec_success Block_Var_4
--# expr-start 2006 '<If at ast.py:15043>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:15043
if Block_Var_4 then
   --# expr-start 2005 '<If at ast.py:15045>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:15045
--# expr-start 1990 '<IsNull at ast.py:15048>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:15048
Is_Equal_1 := Block_Var_1 = No_Multidim_Aggregate_Info; 
--# expr-done 1990
if Is_Equal_1 then
   If_Result_2 := True;
else
   --# expr-start 1994 '<Eq at ast.py:15049>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:15049
--# expr-start 1991 '<FieldAccess for rank at ast.py:15049>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:15049
Fld_24 := Block_Var_1.Rank;
--# expr-done 1991
--# expr-start 1993 '<Arithmetic - at ast.py:15049>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:15049
--# expr-start 1992 '<FieldAccess for array_ndims at ast.py:15049>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:15049
      if Block_Var_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_25 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Block_Var_3.Node, Origin => Origin, E_Info => Block_Var_3.Info);
--# end
--# expr-done 1992
Arith_Result := (Fld_25 - 1); 
--# expr-done 1993
Is_Equal_2 := Fld_24 = Arith_Result; 
--# expr-done 1994
   If_Result_2 := Is_Equal_2;
end if;
if If_Result_2 then
   --# expr-start 2004 '<And at ast.py:15052>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:15052
--# expr-start 2001 '<And at ast.py:15052>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15052
--# expr-start 1996 '<FieldAccess for sub_equation at ast.py:15052>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:15052
--# expr-start 1995 '<FieldAccess for expr at ast.py:15052>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15052
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_17 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1995
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_18 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_17.Node, Env => Env, Origin => Origin, E_Info => Fld_17.Info);
--# end
--# expr-done 1996
--# expr-start 2000 '<Bind at ast.py:15053>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15053
--# expr-start 1998 '<FieldAccess for expected_type_var at ast.py:15053>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:15053
--# expr-start 1997 '<FieldAccess for expr at ast.py:15053>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:15053
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_19 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 1997
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_19.Node);
--# expr-done 1998
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
--# expr-start 1999 '<FieldAccess for comp_type at ast.py:15053>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:15053
      if Block_Var_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ArrayTypeDef.comp_type
Fld_21 := Libadalang.Implementation.Array_Type_Def_P_Comp_Type (Node => Block_Var_3.Node, Origin => Origin, E_Info => Block_Var_3.Info);
--# end
--# expr-done 1999
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_21.Node,
         Info => Fld_21.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_20, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15053") else null)); 
--# expr-done 2000
And_Pred_1 := Create_And (Fld_18, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15052") else null)); 
--# expr-done 2001
--# expr-start 2003 '<FieldAccess for matches_expected_type at ast.py:15054>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:15054
--# expr-start 2002 '<FieldAccess for expr at ast.py:15054>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:15054
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_22 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2002
      if Fld_22.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_23 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_22.Node, Origin => Origin);
--# end
--# expr-done 2003
And_Pred_2 := Create_And (And_Pred_1, Fld_23, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15052") else null)); 
--# expr-done 2004
   If_Result_3 := And_Pred_2;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15058") else null)); 
   If_Result_3 := True_Rel_1;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 2005
   If_Result_4 := If_Result_3;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15060") else null)); 
   If_Result_4 := False_Rel;
end if;
      Inc_Ref (If_Result_4);
--# expr-done 2006
Let_Result := If_Result_4; Inc_Ref (Let_Result);
--# end
--# expr-done 2007
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1092;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1092;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Iterated_Assoc_P_Xref_Equation;
--# end
--# property-start IteratedAssoc.xref_equation_for_reduce /tmp/lal-23.0.0/ada/ast.py:15064
pragma Warnings (Off, "is not referenced");
 function Iterated_Assoc_P_Xref_Equation_For_Reduce
  (Node : Bare_Iterated_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Iterated_Assoc := Bare_Iterated_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Iterated_Assoc :=
     Internal_Entity_Iterated_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1093 with Inline_Always;
      Block_Var : Logic_Var;
Block_Var_1 : Boolean;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Value_Sequence;
Fld_1 : Internal_Entity_Iterated_Assoc;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Var;
Fld_4 : Internal_Entity_For_Loop_Spec;
Fld_5 : Internal_Entity_For_Loop_Spec;
Fld_6 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Expr;
Fld_7 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_8 : Internal_Entity_For_Loop_Spec;
Fld_9 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Expr;
Fld_10 : Logic_Equation;
And_Pred : Logic_Equation;
True_Rel : Logic_Equation;
Fld_11 : Bare_For_Loop_Spec;
Fld_12 : Bare_Iter_Type;
Is_A : Boolean;
If_Result : Logic_Equation;
Fld_13 : Boolean;
Fld_14 : Internal_Entity_Expr;
Fld_15 : Logic_Equation;
Fld_16 : Internal_Entity_Expr;
Fld_17 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_18 : Internal_Entity_Expr;
Fld_19 : Logic_Equation;
And_Pred_2 : Logic_Equation;
False_Rel : Logic_Equation;
If_Result_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1093 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_10);
                     Dec_Ref (And_Pred);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_19);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1093;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2039 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2012 '<FieldAccess for expected_type_var at ast.py:15072>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15072
--# expr-start 2011 '<FieldAccess for expr at ast.py:15071>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15071
--# expr-start 2010 '<FieldAccess for iter_assoc at ast.py:15071>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15071
--# expr-start 2009 '<Cast to ValueSequence at ast.py:15071>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15071
--# expr-start 2008 '<parent at ast.py:15071>' Fld /tmp/lal-23.0.0/ada/ast.py:15071
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2008
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Value_Sequence_Range
   then
      Cast_Result := Create_Internal_Entity_Value_Sequence
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Value_Sequence;
   end if;
--# expr-done 2009
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Iterated_Assoc (Node => Cast_Result.Node.Value_Sequence_F_Iter_Assoc, Info => Cast_Result.Info);
--# expr-done 2010
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 2011
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2.Node);
--# expr-done 2012
Block_Var := Fld_3; 
--# bind expected_typ Block_Var
--# expr-start 2028 '<FieldAccess for resolve_names_internal_with_eq at ast.py:15075>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15075
--# expr-start 2013 '<FieldAccess for spec at ast.py:15075>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15075
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Iterated_Assoc_F_Spec, Info => Ent.Info);
--# expr-done 2013
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2027 '<If at ast.py:15076>' If_Result /tmp/lal-23.0.0/ada/ast.py:15076
--# expr-start 2016 '<IsA IterType.In at ast.py:15076>' Is_A /tmp/lal-23.0.0/ada/ast.py:15076
--# expr-start 2015 '<FieldAccess for loop_type at ast.py:15076>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15076
--# expr-start 2014 '<FieldAccess for spec at ast.py:15076>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15076
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Self.Iterated_Assoc_F_Spec;
--# expr-done 2014
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Fld_11.For_Loop_Spec_F_Loop_Type;
--# expr-done 2015
Is_A := Fld_12 /= null 
and then Fld_12.Kind in Ada_Iter_Type_In_Range; 
--# expr-done 2016
if Is_A then
   --# expr-start 2026 '<And at ast.py:15077>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15077
--# expr-start 2021 '<Bind at ast.py:15077>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15077
--# expr-start 2020 '<FieldAccess for expected_type_var at ast.py:15077>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15077
--# expr-start 2019 '<Cast to Expr at ast.py:15077>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15077
--# expr-start 2018 '<FieldAccess for iter_expr at ast.py:15077>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15077
--# expr-start 2017 '<FieldAccess for spec at ast.py:15077>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15077
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Iterated_Assoc_F_Spec, Info => Ent.Info);
--# expr-done 2017
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity (Node => Fld_5.Node.For_Loop_Spec_F_Iter_Expr, Info => Fld_5.Info);
--# expr-done 2018
   if Fld_6.Node = null
      or else Fld_6.Node.Kind in Ada_Expr
   then
      Cast_Result_1 := Create_Internal_Entity_Expr
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
   else
         Cast_Result_1 := No_Entity_Expr;
   end if;
--# expr-done 2019
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Cast_Result_1.Node);
--# expr-done 2020
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Block_Var.Value := No_Entity;
Entity_Vars.Reset (Block_Var);
Bind_Result := Solver.Create_Unify (Fld_7, Block_Var, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15077") else null)); 
--# expr-done 2021
--# expr-start 2025 '<FieldAccess for matches_expected_type at ast.py:15079>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15079
--# expr-start 2024 '<Cast to Expr at ast.py:15079>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:15079
--# expr-start 2023 '<FieldAccess for iter_expr at ast.py:15079>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15079
--# expr-start 2022 '<FieldAccess for spec at ast.py:15079>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15079
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Iterated_Assoc_F_Spec, Info => Ent.Info);
--# expr-done 2022
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity (Node => Fld_8.Node.For_Loop_Spec_F_Iter_Expr, Info => Fld_8.Info);
--# expr-done 2023
   if Fld_9.Node = null
      or else Fld_9.Node.Kind in Ada_Expr
   then
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   else
         Cast_Result_2 := No_Entity_Expr;
   end if;
--# expr-done 2024
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_10 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Cast_Result_2.Node, Origin => Origin);
--# end
--# expr-done 2025
And_Pred := Create_And (Bind_Result, Fld_10, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15077") else null)); 
--# expr-done 2026
   If_Result := And_Pred;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15080") else null)); 
   If_Result := True_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 2027
--# property-call-start AdaNode.resolve_names_internal_with_eq
Fld_13 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal_With_Eq (Node => Fld_4.Node, Additional_Equation => If_Result, Env => Env, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 2028
Block_Var_1 := Fld_13; 
--# bind spec_success Block_Var_1
--# expr-start 2038 '<If at ast.py:15083>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15083
if Block_Var_1 then
   --# expr-start 2037 '<And at ast.py:15084>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:15084
--# expr-start 2034 '<And at ast.py:15084>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15084
--# expr-start 2030 '<FieldAccess for sub_equation at ast.py:15084>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:15084
--# expr-start 2029 '<FieldAccess for expr at ast.py:15084>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:15084
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_14 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2029
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_15 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_14.Node, Env => Env, Origin => Origin, E_Info => Fld_14.Info);
--# end
--# expr-done 2030
--# expr-start 2033 '<Bind at ast.py:15085>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15085
--# expr-start 2032 '<FieldAccess for expected_type_var at ast.py:15085>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15085
--# expr-start 2031 '<FieldAccess for expr at ast.py:15085>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15085
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_16 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2031
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_16.Node);
--# expr-done 2032
Fld_17.Value := No_Entity;
Entity_Vars.Reset (Fld_17);
Block_Var.Value := No_Entity;
Entity_Vars.Reset (Block_Var);
Bind_Result_1 := Solver.Create_Unify (Fld_17, Block_Var, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15085") else null)); 
--# expr-done 2033
And_Pred_1 := Create_And (Fld_15, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15084") else null)); 
--# expr-done 2034
--# expr-start 2036 '<FieldAccess for matches_expected_type at ast.py:15086>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:15086
--# expr-start 2035 '<FieldAccess for expr at ast.py:15086>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:15086
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_18 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2035
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_19 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_18.Node, Origin => Origin);
--# end
--# expr-done 2036
And_Pred_2 := Create_And (And_Pred_1, Fld_19, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15084") else null)); 
--# expr-done 2037
   If_Result_1 := And_Pred_2;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15087") else null)); 
   If_Result_1 := False_Rel;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 2038
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 2039
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1093;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1093;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Iterated_Assoc_P_Xref_Equation_For_Reduce;
--# end
   --
   --  Primitives for Bare_Param_Assoc
   --
      procedure Initialize_Fields_For_Param_Assoc
        (Self : Bare_Param_Assoc
         ; Param_Assoc_F_Designator : Bare_Ada_Node
         ; Param_Assoc_F_R_Expr : Bare_Expr
        ) is
      begin
            Self.Param_Assoc_F_Designator := Param_Assoc_F_Designator;
            Self.Param_Assoc_F_R_Expr := Param_Assoc_F_R_Expr;
      end Initialize_Fields_For_Param_Assoc;
   function Param_Assoc_F_Designator
     (Node : Bare_Param_Assoc) return Bare_Ada_Node
   is
   begin
         return Node.Param_Assoc_F_Designator;
   end;
   function Param_Assoc_F_R_Expr
     (Node : Bare_Param_Assoc) return Bare_Expr
   is
   begin
         return Node.Param_Assoc_F_R_Expr;
   end;
--# property-start ParamAssoc.expr /tmp/lal-23.0.0/ada/ast.py:14715
pragma Warnings (Off, "is not referenced");
 function Param_Assoc_P_Expr
  (Node : Bare_Param_Assoc
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Param_Assoc := Bare_Param_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Param_Assoc :=
     Internal_Entity_Param_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Fld : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2040 '<FieldAccess for r_expr at ast.py:14715>' Fld /tmp/lal-23.0.0/ada/ast.py:14715
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Param_Assoc_F_R_Expr, Info => Ent.Info);
--# expr-done 2040
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Assoc_P_Expr;
--# end
--# property-start ParamAssoc.names /tmp/lal-23.0.0/ada/ast.py:14716
pragma Warnings (Off, "is not referenced");
 function Param_Assoc_P_Names
  (Node : Bare_Param_Assoc
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Param_Assoc := Bare_Param_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1072 with Inline_Always;
      Fld : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Fld_1 : Bare_Ada_Node;
Is_Null : Boolean;
If_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1072 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_1072;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2044 '<If at ast.py:14716>' If_Result /tmp/lal-23.0.0/ada/ast.py:14716
--# expr-start 2042 '<IsNull at ast.py:14716>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14716
--# expr-start 2041 '<FieldAccess for designator at ast.py:14716>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14716
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Param_Assoc_F_Designator;
--# expr-done 2041
Is_Null := Fld_1 = null; 
--# expr-done 2042
if Is_Null then
   If_Result := No_Bare_Ada_Node_Array_Type;
else
   --# expr-start 2043 '<FieldAccess for designator at ast.py:14717>' Fld /tmp/lal-23.0.0/ada/ast.py:14717
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Param_Assoc_F_Designator;
--# expr-done 2043
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
   If_Result := Singleton;
end if;
      Inc_Ref (If_Result);
--# expr-done 2044
      Property_Result := If_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1072;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1072;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Assoc_P_Names;
--# end
--# property-start ParamAssoc.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:14719
pragma Warnings (Off, "is not referenced");
 function Param_Assoc_P_Xref_Entry_Point
  (Node : Bare_Param_Assoc
  )
   return Boolean
is
   Self : Bare_Param_Assoc := Bare_Param_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2045 '<FieldAccess for is_static_attribute_assoc at ast.py:14719>' Fld /tmp/lal-23.0.0/ada/ast.py:14719
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ParamAssoc.is_static_attribute_assoc
Fld := Libadalang.Implementation.Param_Assoc_P_Is_Static_Attribute_Assoc (Node => Self);
--# end
--# expr-done 2045
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Assoc_P_Xref_Entry_Point;
--# end
--# property-start ParamAssoc.xref_equation /tmp/lal-23.0.0/ada/ast.py:14720
pragma Warnings (Off, "is not referenced");
 function Param_Assoc_P_Xref_Equation
  (Node : Bare_Param_Assoc
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Param_Assoc := Bare_Param_Assoc (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Param_Assoc :=
     Internal_Entity_Param_Assoc'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1074 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
False_Rel : Logic_Equation;
Fld_2 : Boolean;
If_Result : Logic_Equation;
            procedure Finalizer_Scope_1074 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_1074;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2049 '<If at ast.py:14720>' If_Result /tmp/lal-23.0.0/ada/ast.py:14720
--# expr-start 2046 '<FieldAccess for xref_entry_point at ast.py:14721>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14721
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_entry_point'
Fld_2 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Entry_Point (Node => Self);
--# end
--# expr-done 2046
if Fld_2 then
   --# expr-start 2048 '<FieldAccess for sub_equation at ast.py:14722>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14722
--# expr-start 2047 '<FieldAccess for expr at ast.py:14722>' Fld /tmp/lal-23.0.0/ada/ast.py:14722
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2047
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 2048
   If_Result := Fld_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14723") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 2049
      Property_Result := If_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1074;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1074;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Assoc_P_Xref_Equation;
--# end
--# property-start ParamAssoc.is_static_attribute_assoc /tmp/lal-23.0.0/ada/ast.py:14727
pragma Warnings (Off, "is not referenced");
 function Param_Assoc_P_Is_Static_Attribute_Assoc
  (Node : Bare_Param_Assoc
  )
   return Boolean
is
   Self : Bare_Param_Assoc := Bare_Param_Assoc (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Attribute_Ref;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Attribute_Ref;
Fld_2 : Bare_Identifier;
Fld_3 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_4 : Bare_Identifier;
Fld_5 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_6 : Bare_Identifier;
Fld_7 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_8 : Bare_Identifier;
Fld_9 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2069 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2052 '<Cast to AttributeRef at ast.py:14728>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14728
--# expr-start 2051 '<parent at ast.py:14728>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14728
--# expr-start 2050 '<parent at ast.py:14728>' Fld /tmp/lal-23.0.0/ada/ast.py:14728
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2050
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 2051
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 2052
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind ar Var_Expr
--# expr-start 2056 '<Eq at ast.py:14729>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2054 '<FieldAccess for name_symbol at ast.py:14729>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2053 '<FieldAccess for attribute at ast.py:14729>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14729
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr.Attribute_Ref_F_Attribute;
--# expr-done 2053
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_2);
--# end
--# expr-done 2054
--# expr-start 2055 '<Symbol First at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_First); 
--# expr-done 2055
Is_Equal := Fld_3 = Sym; 
--# expr-done 2056
if Is_Equal then
   If_Result := True;
else
   --# expr-start 2060 '<Eq at ast.py:14729>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2058 '<FieldAccess for name_symbol at ast.py:14729>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2057 '<FieldAccess for attribute at ast.py:14729>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14729
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Var_Expr.Attribute_Ref_F_Attribute;
--# expr-done 2057
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_4);
--# end
--# expr-done 2058
--# expr-start 2059 '<Symbol Last at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Last); 
--# expr-done 2059
Is_Equal_1 := Fld_5 = Sym_1; 
--# expr-done 2060
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 2064 '<Eq at ast.py:14729>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2062 '<FieldAccess for name_symbol at ast.py:14729>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2061 '<FieldAccess for attribute at ast.py:14729>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14729
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Var_Expr.Attribute_Ref_F_Attribute;
--# expr-done 2061
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_6);
--# end
--# expr-done 2062
--# expr-start 2063 '<Symbol Range at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range); 
--# expr-done 2063
Is_Equal_2 := Fld_7 = Sym_2; 
--# expr-done 2064
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 2068 '<Eq at ast.py:14729>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2066 '<FieldAccess for name_symbol at ast.py:14729>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14729
--# expr-start 2065 '<FieldAccess for attribute at ast.py:14729>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14729
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Var_Expr.Attribute_Ref_F_Attribute;
--# expr-done 2065
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_9 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_8);
--# end
--# expr-done 2066
--# expr-start 2067 '<Symbol Length at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Length); 
--# expr-done 2067
Is_Equal_3 := Fld_9 = Sym_3; 
--# expr-done 2068
   If_Result_2 := Is_Equal_3;
end if;
Scope_Result := If_Result_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2069
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Assoc_P_Is_Static_Attribute_Assoc;
--# end
   --
   --  Primitives for Bare_Basic_Decl
   --
   function Basic_Decl_F_Aspects
     (Node : Bare_Basic_Decl) return Bare_Aspect_Spec
   is
         Kind : constant Ada_Basic_Decl := Node.Kind;
   begin
         case Kind is
               when Ada_Error_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Discriminant_Spec =>
         return Node.Discriminant_Spec_F_Aspects;
               when Ada_Component_Decl =>
         return Node.Component_Decl_F_Aspects;
               when Ada_Classwide_Type_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Concrete_Type_Decl =>
         return Node.Concrete_Type_Decl_F_Aspects;
               when Ada_Formal_Type_Decl =>
         return Node.Formal_Type_Decl_F_Aspects;
               when Ada_Anonymous_Type_Decl | Ada_Synth_Anonymous_Type_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Subtype_Decl =>
         return Node.Subtype_Decl_F_Aspects;
               when Ada_Discrete_Base_Subtype_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Task_Type_Decl | Ada_Single_Task_Type_Decl =>
         return Node.Task_Type_Decl_F_Aspects;
               when Ada_Protected_Type_Decl =>
         return Node.Protected_Type_Decl_F_Aspects;
               when Ada_Param_Spec =>
         return Node.Param_Spec_F_Aspects;
               when Ada_Subp_Decl =>
         return Node.Subp_Decl_F_Aspects;
               when Ada_Abstract_Subp_Decl =>
         return Node.Abstract_Subp_Decl_F_Aspects;
               when Ada_Single_Task_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Single_Protected_Decl =>
         return Node.Single_Protected_Decl_F_Aspects;
               when Ada_Number_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Object_Decl | Ada_Extended_Return_Stmt_Object_Decl | Ada_No_Type_Object_Renaming_Decl =>
         return Node.Object_Decl_F_Aspects;
               when Ada_Anonymous_Expr_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Generic_Package_Internal | Ada_Package_Decl =>
         return Node.Base_Package_Decl_F_Aspects;
               when Ada_Exception_Decl =>
         return Node.Exception_Decl_F_Aspects;
               when Ada_Generic_Subp_Instantiation =>
         return Node.Generic_Subp_Instantiation_F_Aspects;
               when Ada_Generic_Package_Instantiation =>
         return Node.Generic_Package_Instantiation_F_Aspects;
               when Ada_Package_Renaming_Decl =>
         return Node.Package_Renaming_Decl_F_Aspects;
               when Ada_Generic_Package_Renaming_Decl =>
         return Node.Generic_Package_Renaming_Decl_F_Aspects;
               when Ada_Generic_Subp_Renaming_Decl =>
         return Node.Generic_Subp_Renaming_Decl_F_Aspects;
               when Ada_Abstract_Formal_Subp_Decl | Ada_Concrete_Formal_Subp_Decl =>
         return Node.Formal_Subp_Decl_F_Aspects;
               when Ada_Generic_Formal_Obj_Decl | Ada_Generic_Formal_Package | Ada_Generic_Formal_Subp_Decl | Ada_Generic_Formal_Type_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Generic_Subp_Internal =>
         return Node.Generic_Subp_Internal_F_Aspects;
               when Ada_Generic_Subp_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Generic_Package_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Enum_Literal_Decl | Ada_Synthetic_Char_Enum_Lit =>
                     return No_Bare_Ada_Node;
               when Ada_Synthetic_Formal_Param_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Synthetic_Subp_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Entry_Decl =>
         return Node.Entry_Decl_F_Aspects;
               when Ada_For_Loop_Var_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Expr_Function =>
         return Node.Expr_Function_F_Aspects;
               when Ada_Null_Subp_Decl =>
         return Node.Null_Subp_Decl_F_Aspects;
               when Ada_Subp_Renaming_Decl =>
         return Node.Subp_Renaming_Decl_F_Aspects;
               when Ada_Subp_Body =>
         return Node.Subp_Body_F_Aspects;
               when Ada_Exception_Handler =>
                     return No_Bare_Ada_Node;
               when Ada_Label_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Named_Stmt_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Package_Body =>
         return Node.Package_Body_F_Aspects;
               when Ada_Task_Body =>
         return Node.Task_Body_F_Aspects;
               when Ada_Protected_Body =>
         return Node.Protected_Body_F_Aspects;
               when Ada_Entry_Body =>
         return Node.Entry_Body_F_Aspects;
               when Ada_Entry_Index_Spec =>
         return Node.Entry_Index_Spec_F_Aspects;
               when Ada_Protected_Body_Stub =>
         return Node.Protected_Body_Stub_F_Aspects;
               when Ada_Subp_Body_Stub =>
         return Node.Subp_Body_Stub_F_Aspects;
               when Ada_Package_Body_Stub =>
         return Node.Package_Body_Stub_F_Aspects;
               when Ada_Task_Body_Stub =>
         return Node.Task_Body_Stub_F_Aspects;
               when Ada_Incomplete_Type_Decl | Ada_Incomplete_Formal_Type_Decl | Ada_Incomplete_Tagged_Type_Decl =>
                     return No_Bare_Ada_Node;
               when Ada_Abstract_State_Decl =>
         return Node.Abstract_State_Decl_F_Aspects;
         end case;
   end;
--# property-start BasicDecl.env_hook_basic_decl /tmp/lal-23.0.0/ada/ast.py:1718
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Env_Hook_Basic_Decl
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
            procedure Finalizer_Scope_1868 with Inline_Always;
      Var_Expr : Internal_Entity_Dotted_Name;
Var_Expr_1 : Internal_Unit;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Name;
Cast_Result : Internal_Entity_Dotted_Name;
Fld_2 : Internal_Entity_Name;
Fld_3 : Symbol_Type_Array_Access;
Is_A : Boolean;
Not_Val : Boolean;
Fld_4 : Internal_Unit;
Scope_Result : Boolean;
Result_Var : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Is_A_1 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_1868 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_1868;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2081 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2080 '<If at ast.py:1722>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1722
--# expr-start 2070 '<IsA PackageDecl, BasicSubpDecl, PackageRenamingDecl, GenericPackageDecl, GenericPackageInstantiation, GenericSubpInstantiation, GenericSubpDecl, SubpBody at ast.py:1725>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:1725
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Package_Decl_Range | Ada_Basic_Subp_Decl | Ada_Package_Renaming_Decl_Range | Ada_Generic_Package_Decl_Range | Ada_Generic_Package_Instantiation_Range | Ada_Generic_Subp_Instantiation_Range | Ada_Generic_Subp_Decl_Range | Ada_Subp_Body_Range; 
--# expr-done 2070
if Is_A_1 then
--# expr-start 2074 '<Cast to DottedName at ast.py:1730>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1730
--# expr-start 2073 '<FieldAccess for name at ast.py:1730>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1730
--# expr-start 2072 '<FieldAccess for defining_name at ast.py:1730>' Fld /tmp/lal-23.0.0/ada/ast.py:1730
--# expr-start 2071 '<as_bare_entity at ast.py:1730>' If_Result /tmp/lal-23.0.0/ada/ast.py:1730
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 2071
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 2072
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Fld.Node.Defining_Name_F_Name, Info => Fld.Info);
--# expr-done 2073
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Create_Internal_Entity_Dotted_Name
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Dotted_Name;
   end if;
--# expr-done 2074
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Dotted_Name then
   --# scope-start
   --# bind dn Var_Expr
--# expr-start 2079 '<FieldAccess for get_unit at ast.py:1732>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1732
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2076 '<FieldAccess for as_symbol_array at ast.py:1732>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1732
--# expr-start 2075 '<FieldAccess for prefix at ast.py:1732>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1732
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Dotted_Name_F_Prefix, Info => Var_Expr.Info);
--# expr-done 2075
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld_2.Node);
--# end
--# expr-done 2076
--# expr-start 2078 '<Not at ast.py:1735>' Not_Val /tmp/lal-23.0.0/ada/ast.py:1735
--# expr-start 2077 '<IsA SubpBody at ast.py:1735>' Is_A /tmp/lal-23.0.0/ada/ast.py:1735
Is_A := Self /= null 
and then Self.Kind in Ada_Subp_Body_Range; 
--# expr-done 2077
Not_Val := not (Is_A); 
--# expr-done 2078
Fld_4 := Libadalang.Implementation.Extensions.Ada_Node_P_Get_Unit (Node => Self, Name => Fld_3, Kind => Unit_Specification, Load_If_Needed => True, Not_Found_Is_Error => Not_Val);
--# expr-done 2079
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= null then
   --# scope-start
   --# bind _ Var_Expr_1
Scope_Result := False;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Scope_Result_1 := Result_Var;
   --# end
      Finalizer_Scope_1868;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_1 := Result_Var_1;
else
   If_Result_1 := False;
end if;
--# expr-done 2080
Let_Result := If_Result_1; 
--# end
--# expr-done 2081
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1868;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Env_Hook_Basic_Decl;
--# end
--# property-start BasicDecl.populate_body_unit /tmp/lal-23.0.0/ada/ast.py:1742
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Populate_Body_Unit
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
            procedure Finalizer_Scope_124 with Inline_Always;
      Var_Expr : Internal_Unit;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Name;
Fld_2 : Symbol_Type_Array_Access;
Fld_3 : Internal_Unit;
Scope_Result : Boolean;
Result_Var : Boolean;
Fld_4 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_124 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_124;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2089 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2088 '<If at ast.py:1748>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1748
--# expr-start 2082 '<FieldAccess for is_library_item at ast.py:1749>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1749
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 2082
if Fld_4 then
--# expr-start 2087 '<FieldAccess for get_unit at ast.py:1750>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1750
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2086 '<FieldAccess for as_symbol_array at ast.py:1751>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1751
--# expr-start 2085 '<FieldAccess for name at ast.py:1751>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1751
--# expr-start 2084 '<FieldAccess for defining_name at ast.py:1751>' Fld /tmp/lal-23.0.0/ada/ast.py:1751
--# expr-start 2083 '<as_bare_entity at ast.py:1751>' If_Result /tmp/lal-23.0.0/ada/ast.py:1751
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 2083
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 2084
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Fld.Node.Defining_Name_F_Name, Info => Fld.Info);
--# expr-done 2085
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld_1.Node);
--# end
--# expr-done 2086
Fld_3 := Libadalang.Implementation.Extensions.Ada_Node_P_Get_Unit (Node => Self, Name => Fld_2, Kind => Unit_Body, Load_If_Needed => True, Not_Found_Is_Error => False);
--# expr-done 2087
Var_Expr := Fld_3;
if Var_Expr /= null then
   --# scope-start
   --# bind _ Var_Expr
Scope_Result := False;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result_1 := Result_Var;
else
   If_Result_1 := False;
end if;
--# expr-done 2088
Let_Result := If_Result_1; 
--# end
--# expr-done 2089
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_124;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_124;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Populate_Body_Unit;
--# end
--# property-start BasicDecl.has_top_level_env_name_impl /tmp/lal-23.0.0/ada/ast.py:1760
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Has_Top_Level_Env_Name_Impl
  (Node : Bare_Basic_Decl
      ; Allow_Bodies : Boolean
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind allow_bodies Allow_Bodies
   Property_Result : Boolean;
            procedure Finalizer_Scope_125 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : Boolean;
Var_Expr : Bare_Ada_Node;
Var_Expr_1 : Bare_Basic_Decl;
Var_Expr_2 : Bare_Basic_Decl;
Is_A : Boolean;
Is_A_1 : Boolean;
Fld : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Fld_1 : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Basic_Decl;
Is_A_2 : Boolean;
Not_Val : Boolean;
If_Result_2 : Boolean;
Is_A_3 : Boolean;
Not_Val_1 : Boolean;
If_Result_3 : Boolean;
Fld_2 : Boolean;
Cast_Expr_1 : Bare_Basic_Decl;
Cast_Result_1 : Bare_Basic_Decl;
Is_Equal : Boolean;
If_Result_4 : Boolean;
Scope_Result : Boolean;
Is_A_4 : Boolean;
Fld_3 : Bare_Ada_Node;
Cast_Result_2 : Bare_Basic_Decl;
Fld_4 : Boolean;
Scope_Result_1 : Boolean;
Result_Var : Boolean;
If_Result_5 : Boolean;
Result_Var_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_6 : Boolean;
If_Result_7 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_125 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_125;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2107 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2090 '<IsA BasePackageDecl, BasicSubpDecl, GenericDecl, TaskTypeDecl, ProtectedTypeDecl, SingleTaskDecl, SingleProtectedDecl at ast.py:1765>' Is_A /tmp/lal-23.0.0/ada/ast.py:1765
Is_A := Self /= null 
and then Self.Kind in Ada_Base_Package_Decl | Ada_Basic_Subp_Decl | Ada_Generic_Decl | Ada_Task_Type_Decl_Range | Ada_Protected_Type_Decl_Range | Ada_Single_Task_Decl_Range | Ada_Single_Protected_Decl_Range; 
--# expr-done 2090
Block_Var := Is_A; 
--# bind is_decl Block_Var
--# expr-start 2091 '<IsA Body at ast.py:1771>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:1771
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Body_Node; 
--# expr-done 2091
Block_Var_1 := Is_A_1; 
--# bind is_body Block_Var_1
--# expr-start 2092 '<FieldAccess for is_compilation_unit_root at ast.py:1773>' Fld /tmp/lal-23.0.0/ada/ast.py:1773
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 2092
if Fld then
   If_Result_7 := True;
else
if Block_Var then
   If_Result_1 := True;
else
if Allow_Bodies then
   If_Result := Block_Var_1;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
end if;
if If_Result_1 then
--# expr-start 2094 '<env_node at ast.py:1775>' Env_Node /tmp/lal-23.0.0/ada/ast.py:1775
--# expr-start 2093 '<FieldAccess for node_env at ast.py:1775>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1775
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Node_Env (Node => Self);
--# expr-done 2093
Env_Node := AST_Envs.Env_Node (Fld_1); 
--# expr-done 2094
Var_Expr := Env_Node;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind node Var_Expr
--# expr-start 2095 '<Cast to BasicDecl at ast.py:1776>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1776
Cast_Expr := Var_Expr; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Basic_Decl
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 2095
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 2102 '<If at ast.py:1777>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:1777
--# expr-start 2096 '<Eq at ast.py:1778>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:1778
Cast_Expr_1 := Self; 
      Cast_Result_1 := Cast_Expr_1;
Is_Equal := Cast_Result_1 = Var_Expr_1; 
--# expr-done 2096
if Is_Equal then
   If_Result_4 := True;
else
   --# expr-start 2101 '<FieldAccess for has_top_level_env_name_impl at ast.py:1780>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1780
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
if Allow_Bodies then
   --# expr-start 2098 '<Not at ast.py:1783>' Not_Val /tmp/lal-23.0.0/ada/ast.py:1783
--# expr-start 2097 '<IsA BaseSubpBody at ast.py:1783>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:1783
Is_A_2 := Self /= null 
and then Self.Kind in Ada_Base_Subp_Body; 
--# expr-done 2097
Not_Val := not (Is_A_2); 
--# expr-done 2098
   If_Result_2 := Not_Val;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   --# expr-start 2100 '<Not at ast.py:1784>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:1784
--# expr-start 2099 '<IsA BaseSubpBody at ast.py:1784>' Is_A_3 /tmp/lal-23.0.0/ada/ast.py:1784
Is_A_3 := Var_Expr_1 /= null 
and then Var_Expr_1.Kind in Ada_Base_Subp_Body; 
--# expr-done 2099
Not_Val_1 := not (Is_A_3); 
--# expr-done 2100
   If_Result_3 := Not_Val_1;
else
   If_Result_3 := False;
end if;
--# property-call-start BasicDecl.has_top_level_env_name_impl
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Has_Top_Level_Env_Name_Impl (Node => Var_Expr_1, Allow_Bodies => If_Result_3);
--# end
--# expr-done 2101
   If_Result_4 := Fld_2;
end if;
--# expr-done 2102
Scope_Result := If_Result_4;
   --# end
   Result_Var_1 := Scope_Result;
else
--# expr-start 2103 '<IsA PrivatePart at ast.py:1789>' Is_A_4 /tmp/lal-23.0.0/ada/ast.py:1789
Is_A_4 := Var_Expr /= null 
and then Var_Expr.Kind in Ada_Private_Part_Range; 
--# expr-done 2103
if Is_A_4 then
--# expr-start 2105 '<Cast to BasicDecl at ast.py:1790>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1790
--# expr-start 2104 '<parent at ast.py:1790>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1790
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Var_Expr.Parent; 
--# expr-done 2104
   if Fld_3 = null
      or else Fld_3.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Fld_3;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 2105
Var_Expr_2 := Cast_Result_2;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind bd Var_Expr_2
--# expr-start 2106 '<FieldAccess for has_top_level_env_name_impl at ast.py:1792>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1792
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.has_top_level_env_name_impl
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Has_Top_Level_Env_Name_Impl (Node => Var_Expr_2, Allow_Bodies => Allow_Bodies);
--# end
--# expr-done 2106
Scope_Result_1 := Fld_4;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := False;
end if;
   If_Result_5 := Result_Var;
else
   If_Result_5 := False;
end if;
   Result_Var_1 := If_Result_5;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := True;
end if;
   If_Result_6 := Result_Var_2;
else
   If_Result_6 := False;
end if;
   If_Result_7 := If_Result_6;
end if;
Let_Result := If_Result_7; 
--# end
--# expr-done 2107
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_125;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_125;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Has_Top_Level_Env_Name_Impl;
--# end
--# property-start BasicDecl.has_top_level_env_name /tmp/lal-23.0.0/ada/ast.py:1801
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Has_Top_Level_Env_Name
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
            procedure Finalizer_Scope_126 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Var_Expr_1 : Bare_Basic_Decl;
Var_Expr_2 : Bare_Basic_Decl;
Fld : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Basic_Decl;
Fld_1 : Boolean;
Scope_Result : Boolean;
Is_A : Boolean;
Fld_2 : Bare_Ada_Node;
Cast_Result_1 : Bare_Basic_Decl;
Fld_3 : Boolean;
Scope_Result_1 : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Result_Var_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_126 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_126;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2116 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2109 '<env_node at ast.py:1869>' Env_Node /tmp/lal-23.0.0/ada/ast.py:1869
--# expr-start 2108 '<FieldAccess for children_env at ast.py:1869>' Fld /tmp/lal-23.0.0/ada/ast.py:1869
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Self);
--# expr-done 2108
Env_Node := AST_Envs.Env_Node (Fld); 
--# expr-done 2109
Var_Expr := Env_Node;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind node Var_Expr
--# expr-start 2110 '<Cast to BasicDecl at ast.py:1870>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1870
Cast_Expr := Var_Expr; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Basic_Decl
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 2110
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind bd Var_Expr_1
--# expr-start 2111 '<FieldAccess for has_top_level_env_name_impl at ast.py:1871>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1871
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.has_top_level_env_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Has_Top_Level_Env_Name_Impl (Node => Var_Expr_1, Allow_Bodies => True);
--# end
--# expr-done 2111
Scope_Result := Fld_1;
   --# end
   Result_Var_1 := Scope_Result;
else
--# expr-start 2112 '<IsA PrivatePart at ast.py:1875>' Is_A /tmp/lal-23.0.0/ada/ast.py:1875
Is_A := Var_Expr /= null 
and then Var_Expr.Kind in Ada_Private_Part_Range; 
--# expr-done 2112
if Is_A then
--# expr-start 2114 '<Cast to BasicDecl at ast.py:1876>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1876
--# expr-start 2113 '<parent at ast.py:1876>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1876
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr.Parent; 
--# expr-done 2113
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Fld_2;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 2114
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind bd Var_Expr_2
--# expr-start 2115 '<FieldAccess for has_top_level_env_name_impl at ast.py:1877>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1877
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.has_top_level_env_name_impl
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Has_Top_Level_Env_Name_Impl (Node => Var_Expr_2, Allow_Bodies => True);
--# end
--# expr-done 2115
Scope_Result_1 := Fld_3;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
else
   If_Result := False;
end if;
   Result_Var_1 := If_Result;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := True;
end if;
Let_Result := Result_Var_2; 
--# end
--# expr-done 2116
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_126;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_126;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Has_Top_Level_Env_Name;
--# end
--# property-start BasicDecl.env_spec_fully_qualified_name_impl /tmp/lal-23.0.0/ada/ast.py:1887
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Env_Spec_Fully_Qualified_Name_Impl
  (Node : Bare_Basic_Decl
      ; Self_Env : Lexical_Env
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind self_env Self_Env
   Property_Result : String_Type;
            procedure Finalizer_Scope_127 with Inline_Always;
            procedure Finalizer_Scope_2061 with Inline_Always;
      Var_Expr : Bare_Basic_Decl;
Var_Expr_1 : Bare_Basic_Decl;
Var_Expr_2 : Bare_Private_Part;
Fld : Boolean;
Fld_1 : Bare_Compilation_Unit;
Fld_2 : Symbol_Type_Array_Access;
Str : String_Type;
Fld_3 : String_Type;
Is_A : Boolean;
Fld_4 : Bare_Ada_Node;
Cast_Result : Bare_Basic_Decl;
Fld_5 : Bare_Ada_Node;
Fld_6 : Lexical_Env := Empty_Env;
Fld_7 : String_Type;
Env_Node : Bare_Ada_Node;
Cast_Result_1 : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Env_Node_1 : Bare_Ada_Node;
Cast_Result_2 : Bare_Private_Part;
Fld_8 : Bare_Ada_Node;
Scope_Result_1 : Bare_Ada_Node;
Result_Var : Bare_Ada_Node;
Cast_Result_3 : Bare_Basic_Decl;
Result_Var_1 : Bare_Basic_Decl;
Fld_9 : Lexical_Env := Empty_Env;
Fld_10 : String_Type;
Str_1 : String_Type;
Concat_Result : String_Type;
Fld_11 : Symbol_Type;
Fld_12 : String_Type;
Concat_Result_1 : String_Type;
Scope_Result_2 : String_Type;
Result_Var_2 : String_Type;
If_Result : String_Type;
If_Result_1 : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_127 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Str);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_127;
            procedure Finalizer_Scope_2061 is
            begin
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Str_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Concat_Result_1);
            end Finalizer_Scope_2061;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2142 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2141 '<Cond at ast.py:1891>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1891
--# expr-start 2117 '<FieldAccess for is_compilation_unit_root at ast.py:1894>' Fld /tmp/lal-23.0.0/ada/ast.py:1894
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 2117
if Fld then
   --# expr-start 2121 '<FieldAccess for sym_join at ast.py:1895>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1895
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2119 '<FieldAccess for syntactic_fully_qualified_name at ast.py:1896>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1896
--# expr-start 2118 '<FieldAccess for enclosing_compilation_unit at ast.py:1896>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1896
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld_1 := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Self);
--# end
--# expr-done 2118
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.syntactic_fully_qualified_name
Fld_2 := Libadalang.Implementation.Compilation_Unit_P_Syntactic_Fully_Qualified_Name (Node => Fld_1);
--# end
--# expr-done 2119
--# expr-start 2120 '<String at ast.py:1897>' Str /tmp/lal-23.0.0/ada/ast.py:1897
Str := Create_String ("."); 
--# expr-done 2120
--# property-call-start AdaNode.sym_join
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sym_Join (Node => Self, Syms => Fld_2, Sep => Str);
--# end
--# expr-done 2121
   If_Result_1 := Fld_3;
else
--# expr-start 2122 '<IsA GenericPackageInternal, GenericSubpInternal at ast.py:1902>' Is_A /tmp/lal-23.0.0/ada/ast.py:1902
Is_A := Self /= null 
and then Self.Kind in Ada_Generic_Package_Internal_Range | Ada_Generic_Subp_Internal_Range; 
--# expr-done 2122
if Is_A then
   --# expr-start 2127 '<FieldAccess for env_spec_fully_qualified_name_impl at ast.py:1903>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:1903
--# expr-start 2124 '<Cast to BasicDecl at ast.py:1903>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1903
--# expr-start 2123 '<parent at ast.py:1903>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1903
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Parent; 
--# expr-done 2123
   if Fld_4 = null
      or else Fld_4.Kind in Ada_Basic_Decl
   then
      Cast_Result := Fld_4;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 2124
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2126 '<FieldAccess for node_env at ast.py:1904>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:1904
--# expr-start 2125 '<parent at ast.py:1904>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1904
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Parent; 
--# expr-done 2125
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Node_Env (Node => Fld_5);
--# expr-done 2126
--# property-call-start BasicDecl.env_spec_fully_qualified_name_impl
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Env_Spec_Fully_Qualified_Name_Impl (Node => Cast_Result, Self_Env => Fld_6);
--# end
--# expr-done 2127
   If_Result := Fld_7;
else
--# expr-start 2129 '<Cast to BasicDecl at ast.py:1908>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:1908
--# expr-start 2128 '<env_node at ast.py:1908>' Env_Node /tmp/lal-23.0.0/ada/ast.py:1908
Env_Node := AST_Envs.Env_Node (Self_Env); 
--# expr-done 2128
   if Env_Node = null
      or else Env_Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Env_Node;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 2129
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result := Var_Expr_1;
   --# end
   Result_Var_1 := Scope_Result;
else
   --# expr-start 2133 '<Cast to BasicDecl at ast.py:1909>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:1909
--# expr-start 2131 '<Cast to PrivatePart at ast.py:1909>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:1909
--# expr-start 2130 '<env_node at ast.py:1909>' Env_Node_1 /tmp/lal-23.0.0/ada/ast.py:1909
Env_Node_1 := AST_Envs.Env_Node (Self_Env); 
--# expr-done 2130
   if Env_Node_1 = null
      or else Env_Node_1.Kind in Ada_Private_Part_Range
   then
      Cast_Result_2 := Env_Node_1;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 2131
Var_Expr_2 := Cast_Result_2;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 2132 '<parent at ast.py:1909>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:1909
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Var_Expr_2.Parent; 
--# expr-done 2132
Scope_Result_1 := Fld_8;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := No_Bare_Ada_Node;
end if;
   if Result_Var = null
      or else Result_Var.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Result_Var;
   else
         Cast_Result_3 := No_Bare_Ada_Node;
   end if;
--# expr-done 2133
   Result_Var_1 := Cast_Result_3;
end if;
Var_Expr := Result_Var_1;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind bd Var_Expr
--# expr-start 2140 '<Concat at ast.py:1915>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:1915
--# expr-start 2137 '<Concat at ast.py:1914>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:1914
--# expr-start 2135 '<FieldAccess for env_spec_fully_qualified_name_impl at ast.py:1913>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:1913
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2134 '<FieldAccess for node_env at ast.py:1913>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:1913
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Node_Env (Node => Var_Expr);
--# expr-done 2134
--# property-call-start BasicDecl.env_spec_fully_qualified_name_impl
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Env_Spec_Fully_Qualified_Name_Impl (Node => Var_Expr, Self_Env => Fld_9);
--# end
--# expr-done 2135
--# expr-start 2136 '<String at ast.py:1914>' Str_1 /tmp/lal-23.0.0/ada/ast.py:1914
Str_1 := Create_String ("."); 
--# expr-done 2136
Concat_Result := Concat_String (Fld_10, Str_1); 
--# expr-done 2137
--# expr-start 2139 '<FieldAccess for image at ast.py:1915>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:1915
--# expr-start 2138 '<FieldAccess for name_symbol at ast.py:1915>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:1915
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 2138
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Image (Self => Fld_11);
--# expr-done 2139
Concat_Result_1 := Concat_String (Concat_Result, Fld_12); 
--# expr-done 2140
Scope_Result_2 := Concat_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2061;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Empty_String;
end if;
      Inc_Ref (Result_Var_2);
   If_Result := Result_Var_2;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 2141
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 2142
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_127;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_127;
               Finalizer_Scope_2061;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Env_Spec_Fully_Qualified_Name_Impl;
--# end
--# property-start BasicDecl.env_spec_fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:1920
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Env_Spec_Fully_Qualified_Name
  (Node : Bare_Basic_Decl
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : String_Type;
            procedure Finalizer_Scope_128 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Fld_1 : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_128 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_128;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2145 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2144 '<FieldAccess for env_spec_fully_qualified_name_impl at ast.py:1929>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1929
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2143 '<FieldAccess for children_env at ast.py:1929>' Fld /tmp/lal-23.0.0/ada/ast.py:1929
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Self);
--# expr-done 2143
--# property-call-start BasicDecl.env_spec_fully_qualified_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Env_Spec_Fully_Qualified_Name_Impl (Node => Self, Self_Env => Fld);
--# end
--# expr-done 2144
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 2145
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_128;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_128;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Env_Spec_Fully_Qualified_Name;
--# end
--# property-start BasicDecl.top_level_env_name /tmp/lal-23.0.0/ada/ast.py:1932
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Top_Level_Env_Name
  (Node : Bare_Basic_Decl
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : String_Type;
            procedure Finalizer_Scope_129 with Inline_Always;
      Fld : String_Type;
Fld_1 : Boolean;
If_Result : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_129 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_129;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2149 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2148 '<If at ast.py:1938>' If_Result /tmp/lal-23.0.0/ada/ast.py:1938
--# expr-start 2146 '<FieldAccess for has_top_level_env_name at ast.py:1939>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1939
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.has_top_level_env_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Has_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 2146
if Fld_1 then
   --# expr-start 2147 '<FieldAccess for env_spec_fully_qualified_name at ast.py:1940>' Fld /tmp/lal-23.0.0/ada/ast.py:1940
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.env_spec_fully_qualified_name
Fld := Libadalang.Implementation.Basic_Decl_P_Env_Spec_Fully_Qualified_Name (Node => Self);
--# end
--# expr-done 2147
   If_Result := Fld;
else
   If_Result := Empty_String;
end if;
      Inc_Ref (If_Result);
--# expr-done 2148
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2149
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_129;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_129;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Top_Level_Env_Name;
--# end
--# property-start '[dispatcher]BasicDecl.child_decl_initial_env_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Child_Decl_Initial_Env_Name
  (Node : Bare_Basic_Decl
      ; Private_Part : Boolean
         := False
  )
   return Symbol_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind private_part Private_Part
   Property_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Entry_Index_Spec | Ada_Exception_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.child_decl_initial_env_name
                  Property_Result := Basic_Decl_P_Child_Decl_Initial_Env_Name
                    (Self
                        , Private_Part
                    );
                  --# end
               when Ada_Error_Decl =>
                  --# property-call-start ErrorDecl.child_decl_initial_env_name
                  Property_Result := Error_Decl_P_Child_Decl_Initial_Env_Name
                    (Self
                        , Private_Part
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Child_Decl_Initial_Env_Name;
--# end
--# property-start BasicDecl.child_decl_initial_env /tmp/lal-23.0.0/ada/ast.py:1979
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Child_Decl_Initial_Env
  (Node : Bare_Basic_Decl
      ; Private_Part : Boolean
         := False
  )
   return Internal_Designated_Env
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind private_part Private_Part
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_131 with Inline_Always;
            procedure Finalizer_Scope_2063 with Inline_Always;
      Var_Expr : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
Fld_1 : Lexical_Env := Empty_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
Let_Result : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_131 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Fld_1);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_131;
            procedure Finalizer_Scope_2063 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2063;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2154 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2150 '<FieldAccess for child_decl_initial_env_name at ast.py:1988>' Fld /tmp/lal-23.0.0/ada/ast.py:1988
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.child_decl_initial_env_name'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Child_Decl_Initial_Env_Name (Node => Self, Private_Part => Private_Part);
--# end
--# expr-done 2150
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind name Var_Expr
--# expr-start 2151 '<New DesignatedEnv at ast.py:1989>' New_Struct /tmp/lal-23.0.0/ada/ast.py:1989
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 2151
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2063;
   Result_Var := Scope_Result;
else
   --# expr-start 2153 '<New DesignatedEnv at ast.py:1990>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:1990
--# expr-start 2152 '<FieldAccess for default_initial_env at ast.py:1990>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1990
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld_1 := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 2152
Inc_Ref (Fld_1);
New_Struct_1 := (Direct_Env => Fld_1, Env_Name => null, Kind => Direct_Env); 
--# expr-done 2153
   Result_Var := New_Struct_1;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 2154
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_131;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_131;
               Finalizer_Scope_2063;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Child_Decl_Initial_Env;
--# end
--# property-start BasicDecl.basic_decl_env_assocs /tmp/lal-23.0.0/ada/ast.py:1994
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Basic_Decl_Env_Assocs
  (Node : Bare_Basic_Decl
      ; Dest_Env : Internal_Designated_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind dest_env Dest_Env
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_133 with Inline_Always;
      Block_Var : Symbol_Type;
Block_Var_1 : Internal_Env_Assoc_Array_Access;
Block_Var_2 : Internal_Env_Assoc_Array_Access;
Fld : Symbol_Type;
Fld_1 : Symbol_Type;
Cast_Expr : Bare_Basic_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct : Internal_Env_Assoc := No_Env_Assoc;
Singleton : Internal_Env_Assoc_Array_Access;
Sym : Symbol_Type;
Cast_Expr_1 : Bare_Basic_Decl;
Cast_Result_1 : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Singleton_1 : Internal_Env_Assoc_Array_Access;
Sym_1 : Symbol_Type;
Is_Equal : Boolean;
If_Result : Internal_Env_Assoc_Array_Access;
Concat_Result : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_133 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (Singleton);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Singleton_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_133;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2164 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2155 '<FieldAccess for name_symbol at ast.py:2003>' Fld /tmp/lal-23.0.0/ada/ast.py:2003
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2155
Block_Var := Fld; 
--# bind name Block_Var
--# expr-start 2157 '<New EnvAssoc at ast.py:2006>' New_Struct /tmp/lal-23.0.0/ada/ast.py:2006
--# expr-start 2156 '<FieldAccess for name_symbol at ast.py:2007>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2007
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2156
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (Dest_Env);
New_Struct := (Dest_Env => Dest_Env, Key => Fld_1, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 2157
                Singleton := Create_Internal_Env_Assoc_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
                Inc_Ref (Singleton.Items (1));
Block_Var_1 := Singleton; Inc_Ref (Block_Var_1);
--# bind base_assoc Block_Var_1
--# expr-start 2162 '<If at ast.py:2013>' If_Result /tmp/lal-23.0.0/ada/ast.py:2013
--# expr-start 2159 '<Eq at ast.py:2014>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2014
--# expr-start 2158 '<Symbol "=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 2158
Is_Equal := Block_Var = Sym_1; 
--# expr-done 2159
if Is_Equal then
   --# expr-start 2161 '<New EnvAssoc at ast.py:2015>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:2015
--# expr-start 2160 '<Symbol "/=" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 2160
Cast_Expr_1 := Self; 
      Cast_Result_1 := Cast_Expr_1;
Inc_Ref (Dest_Env);
New_Struct_1 := (Dest_Env => Dest_Env, Key => Sym, Metadata => No_Metadata, Value => Cast_Result_1); 
--# expr-done 2161
                Singleton_1 := Create_Internal_Env_Assoc_Array (Items_Count => 1);
                Singleton_1.Items (1) := New_Struct_1;
                Inc_Ref (Singleton_1.Items (1));
   If_Result := Singleton_1;
else
   If_Result := No_Internal_Env_Assoc_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 2162
Block_Var_2 := If_Result; Inc_Ref (Block_Var_2);
--# bind implicit_neq_assoc Block_Var_2
--# expr-start 2163 '<Concat at ast.py:2023>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:2023
Concat_Result := Concat (Block_Var_1, Block_Var_2); 
--# expr-done 2163
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2164
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_133;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_133;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Basic_Decl_Env_Assocs;
--# end
--# property-start BasicDecl.child_decl_env_assocs /tmp/lal-23.0.0/ada/ast.py:2026
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Child_Decl_Env_Assocs
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_134 with Inline_Always;
            procedure Finalizer_Scope_2064 with Inline_Always;
      Block_Var : Internal_Designated_Env := No_Designated_Env;
Var_Expr : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
Fld_1 : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_134 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_134;
            procedure Finalizer_Scope_2064 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2064;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2169 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2165 '<FieldAccess for child_decl_initial_env_name at ast.py:2037>' Fld /tmp/lal-23.0.0/ada/ast.py:2037
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.child_decl_initial_env_name'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Child_Decl_Initial_Env_Name (Node => Self, Private_Part => False);
--# end
--# expr-done 2165
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind non_null_name Var_Expr
--# expr-start 2166 '<New DesignatedEnv at ???>' New_Struct None
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 2166
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2064;
   Result_Var := Scope_Result;
else
   --# expr-start 2167 '<New DesignatedEnv at ast.py:2036>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:2036
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 2167
   Result_Var := New_Struct_1;
end if;
      Inc_Ref (Result_Var);
Block_Var := Result_Var; Inc_Ref (Block_Var);
--# bind dest_env Block_Var
--# expr-start 2168 '<FieldAccess for basic_decl_env_assocs at ast.py:2040>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2040
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.basic_decl_env_assocs
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Env_Assocs (Node => Ent.Node, Dest_Env => Block_Var, E_Info => Ent.Info);
--# end
--# expr-done 2168
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 2169
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_134;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_134;
               Finalizer_Scope_2064;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Child_Decl_Env_Assocs;
--# end
--# property-start BasicDecl.is_formal /tmp/lal-23.0.0/ada/ast.py:2042
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Formal
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2171 '<IsA GenericFormal at ast.py:2043>' Is_A /tmp/lal-23.0.0/ada/ast.py:2043
--# expr-start 2170 '<parent at ast.py:2043>' Fld /tmp/lal-23.0.0/ada/ast.py:2043
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2170
Is_A := Fld /= null 
and then Fld.Kind in Ada_Generic_Formal; 
--# expr-done 2171
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Formal;
--# end
--# property-start '[dispatcher]BasicDecl.previous_part_for_decl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Previous_Part_For_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Generic_Package_Internal .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.previous_part_for_decl
                  Property_Result := Basic_Decl_P_Previous_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl .. Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start BaseFormalParamDecl.previous_part_for_decl
                  Property_Result := Base_Formal_Param_Decl_P_Previous_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.previous_part_for_decl
                  Property_Result := Object_Decl_P_Previous_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Previous_Part_For_Decl;
--# end
--# property-start BasicDecl.canonical_part /tmp/lal-23.0.0/ada/ast.py:2101
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Canonical_Part
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Basic_Decl_Basic_Decl_P_Canonical_Part,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Basic_Decl,
                                As_Bare_Basic_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Imprecise_Fallback);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 2174 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2172 '<FieldAccess for previous_part_for_decl at ast.py:2106>' Fld /tmp/lal-23.0.0/ada/ast.py:2106
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_decl'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2172
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind pp Var_Expr
--# expr-start 2173 '<FieldAccess for canonical_part at ast.py:2107>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2107
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2173
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := Ent;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2174
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl,
                        As_Internal_Entity_Basic_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Canonical_Part;
--# end
--# property-start BasicDecl.all_previous_parts /tmp/lal-23.0.0/ada/ast.py:2112
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_All_Previous_Parts
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_140 with Inline_Always;
            procedure Finalizer_Scope_2069 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
Singleton : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result : Internal_Entity_Basic_Decl_Array_Access;
Result_Var : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_140 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_140;
            procedure Finalizer_Scope_2069 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2069;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2180 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2175 '<FieldAccess for previous_part_for_decl at ast.py:2117>' Fld /tmp/lal-23.0.0/ada/ast.py:2117
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_decl'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2175
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind pp Var_Expr
--# expr-start 2179 '<If at ast.py:2118>' If_Result /tmp/lal-23.0.0/ada/ast.py:2118
--# expr-start 2176 '<Eq at ast.py:2119>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:2119
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Var_Expr; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 2176
if Is_Equiv then
   If_Result := No_Internal_Entity_Basic_Decl_Array_Type;
else
   --# expr-start 2178 '<Concat at ast.py:2121>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:2121
--# expr-start 2177 '<FieldAccess for all_previous_parts at ast.py:2121>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2121
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.all_previous_parts
Fld_1 := Libadalang.Implementation.Basic_Decl_P_All_Previous_Parts (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2177
                Singleton := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Concat_Result := Concat (Fld_1, Singleton); 
--# expr-done 2178
   If_Result := Concat_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 2179
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2069;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 2180
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_140;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_140;
               Finalizer_Scope_2069;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_All_Previous_Parts;
--# end
--# property-start BasicDecl.all_next_parts /tmp/lal-23.0.0/ada/ast.py:2127
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_All_Next_Parts
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_141 with Inline_Always;
            procedure Finalizer_Scope_2074 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Singleton : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result : Internal_Entity_Basic_Decl_Array_Access;
Result_Var : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_141 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_141;
            procedure Finalizer_Scope_2074 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2074;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2186 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2181 '<FieldAccess for next_part_for_decl at ast.py:2132>' Fld /tmp/lal-23.0.0/ada/ast.py:2132
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2181
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind np Var_Expr
--# expr-start 2185 '<If at ast.py:2133>' If_Result /tmp/lal-23.0.0/ada/ast.py:2133
--# expr-start 2182 '<Eq at ast.py:2134>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:2134
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Var_Expr; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 2182
if Is_Equiv then
   If_Result := No_Internal_Entity_Basic_Decl_Array_Type;
else
   --# expr-start 2184 '<Concat at ast.py:2136>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:2136
                Singleton := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
--# expr-start 2183 '<FieldAccess for all_next_parts at ast.py:2136>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2136
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.all_next_parts
Fld_1 := Libadalang.Implementation.Basic_Decl_P_All_Next_Parts (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2183
Concat_Result := Concat (Singleton, Fld_1); 
--# expr-done 2184
   If_Result := Concat_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 2185
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2074;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 2186
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_141;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_141;
               Finalizer_Scope_2074;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_All_Next_Parts;
--# end
--# property-start BasicDecl.all_parts /tmp/lal-23.0.0/ada/ast.py:2142
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_All_Parts
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_142 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl_Array_Access;
Block_Var_1 : Internal_Entity_Basic_Decl_Array_Access;
Fld : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
Singleton : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_142 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_142;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2191 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2187 '<FieldAccess for all_previous_parts at ast.py:2147>' Fld /tmp/lal-23.0.0/ada/ast.py:2147
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.all_previous_parts
Fld := Libadalang.Implementation.Basic_Decl_P_All_Previous_Parts (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2187
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind prevs Block_Var
--# expr-start 2188 '<FieldAccess for all_next_parts at ast.py:2148>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2148
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.all_next_parts
Fld_1 := Libadalang.Implementation.Basic_Decl_P_All_Next_Parts (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2188
Block_Var_1 := Fld_1; Inc_Ref (Block_Var_1);
--# bind nexts Block_Var_1
--# expr-start 2190 '<Concat at ast.py:2149>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:2149
--# expr-start 2189 '<Concat at ast.py:2149>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:2149
                Singleton := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Ent;
Concat_Result := Concat (Block_Var, Singleton); 
--# expr-done 2189
Concat_Result_1 := Concat (Concat_Result, Block_Var_1); 
--# expr-done 2190
Let_Result := Concat_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 2191
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_142;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_142;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_All_Parts;
--# end
--# property-start '[dispatcher]BasicDecl.is_static_decl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Is_Static_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl | Ada_Component_Decl .. Ada_Package_Decl | Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl | Ada_Abstract_Subp_Decl .. Ada_Entry_Decl | Ada_Generic_Subp_Internal | Ada_Expr_Function .. Ada_Named_Stmt_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.is_static_decl
                  Property_Result := Basic_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Expr_Decl =>
                  --# property-call-start AnonymousExprDecl.is_static_decl
                  Property_Result := Anonymous_Expr_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl =>
                  --# property-call-start DiscreteBaseSubtypeDecl.is_static_decl
                  Property_Result := Discrete_Base_Subtype_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Decl =>
                  --# property-call-start SubtypeDecl.is_static_decl
                  Property_Result := Subtype_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_static_decl
                  Property_Result := Type_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Literal_Decl .. Ada_Synthetic_Char_Enum_Lit =>
                  --# property-call-start EnumLiteralDecl.is_static_decl
                  Property_Result := Enum_Literal_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Subp_Decl =>
                  --# property-call-start SyntheticSubpDecl.is_static_decl
                  Property_Result := Synthetic_Subp_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Number_Decl =>
                  --# property-call-start NumberDecl.is_static_decl
                  Property_Result := Number_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.is_static_decl
                  Property_Result := Object_Decl_P_Is_Static_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Is_Static_Decl;
--# end
--# property-start BasicDecl.unshed_rebindings /tmp/lal-23.0.0/ada/ast.py:2159
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Unshed_Rebindings
  (Node : Bare_Basic_Decl
      ; Rebindings : Env_Rebindings
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind rebindings Rebindings
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_144 with Inline_Always;
      Is_Equal : Boolean;
Fld : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Cast_Expr : Bare_Basic_Decl;
Cast_Result : Bare_Ada_Node;
Is_Equal_1 : Boolean;
Fld_1 : Internal_Entity_Info;
Fld_2 : Internal_Metadata;
Fld_3 : Internal_Entity_Info;
Fld_4 : Boolean;
New_Struct : Internal_Entity_Info;
New_Struct_1 : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Info;
Fld_6 : Env_Rebindings;
Is_Equal_2 : Boolean;
Fld_7 : Env_Rebindings;
Fld_8 : Internal_Entity_Info;
Fld_9 : Env_Rebindings;
Is_Equal_3 : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Fld_10 : Env_Rebindings;
Fld_11 : Internal_Entity_Basic_Decl;
If_Result_2 : Internal_Entity_Basic_Decl;
If_Result_3 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_144 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_144;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2213 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2212 '<Cond at ast.py:2166>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:2166
--# expr-start 2192 '<Eq at ast.py:2167>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2167
Is_Equal := Rebindings = null; 
--# expr-done 2192
if Is_Equal then
   If_Result_3 := Ent;
else
--# expr-start 2195 '<Eq at ast.py:2170>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:2170
--# expr-start 2194 '<env_node at ast.py:2170>' Env_Node /tmp/lal-23.0.0/ada/ast.py:2170
--# expr-start 2193 '<FieldAccess for old_env at ast.py:2170>' Fld /tmp/lal-23.0.0/ada/ast.py:2170
      if Rebindings = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Rebindings.Old_Env;
Inc_Ref (Fld);
--# expr-done 2193
Env_Node := AST_Envs.Env_Node (Fld); 
--# expr-done 2194
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Is_Equal_1 := Env_Node = Cast_Result; 
--# expr-done 2195
if Is_Equal_1 then
   --# expr-start 2209 '<If at ast.py:2172>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2172
--# expr-start 2198 '<Eq at ast.py:2174>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:2174
--# expr-start 2197 '<FieldAccess for rebindings at ast.py:2174>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2174
--# expr-start 2196 '<FieldAccess for info at ast.py:2174>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2174
Fld_5 := Ent.Info;
--# expr-done 2196
Fld_6 := Fld_5.Rebindings;
--# expr-done 2197
Is_Equal_2 := Fld_6 = null; 
--# expr-done 2198
if Is_Equal_2 then
   If_Result := True;
else
   --# expr-start 2202 '<Eq at ast.py:2175>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:2175
--# expr-start 2199 '<FieldAccess for get_parent at ast.py:2175>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2175
      if Rebindings = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Rebindings.Parent;
--# expr-done 2199
--# expr-start 2201 '<FieldAccess for rebindings at ast.py:2175>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2175
--# expr-start 2200 '<FieldAccess for info at ast.py:2175>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2175
Fld_8 := Ent.Info;
--# expr-done 2200
Fld_9 := Fld_8.Rebindings;
--# expr-done 2201
Is_Equal_3 := Fld_7 = Fld_9; 
--# expr-done 2202
   If_Result := Is_Equal_3;
end if;
if If_Result then
   --# expr-start 2208 '<New BasicDecl.entity at ???>' New_Struct_1 None
--# expr-start 2207 '<New EntityInfo at ast.py:2180>' New_Struct /tmp/lal-23.0.0/ada/ast.py:2180
--# expr-start 2204 '<FieldAccess for from_rebound at ast.py:2183>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2183
--# expr-start 2203 '<FieldAccess for info at ast.py:2183>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2183
Fld_3 := Ent.Info;
--# expr-done 2203
Fld_4 := Fld_3.From_Rebound;
--# expr-done 2204
--# expr-start 2206 '<FieldAccess for md at ast.py:2182>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2182
--# expr-start 2205 '<FieldAccess for info at ast.py:2182>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2182
Fld_1 := Ent.Info;
--# expr-done 2205
Fld_2 := Fld_1.Md;
--# expr-done 2206
New_Struct := (From_Rebound => Fld_4, Md => Fld_2, Rebindings => Rebindings); 
--# expr-done 2207
New_Struct_1 := (Info => New_Struct, Node => Self); 
--# expr-done 2208
   If_Result_1 := New_Struct_1;
else
   If_Result_1 := raise Property_Error with "Incorrect rebindings";
end if;
--# expr-done 2209
   If_Result_2 := If_Result_1;
else
   --# expr-start 2211 '<FieldAccess for unshed_rebindings at ast.py:2189>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2189
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2210 '<FieldAccess for get_parent at ast.py:2189>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2189
      if Rebindings = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Rebindings.Parent;
--# expr-done 2210
--# property-call-start BasicDecl.unshed_rebindings
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Unshed_Rebindings (Node => Ent.Node, Rebindings => Fld_10, E_Info => Ent.Info);
--# end
--# expr-done 2211
   If_Result_2 := Fld_11;
end if;
   If_Result_3 := If_Result_2;
end if;
--# expr-done 2212
Let_Result := If_Result_3; 
--# end
--# expr-done 2213
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_144;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_144;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Unshed_Rebindings;
--# end
--# property-start '[dispatcher]BasicDecl.is_library_item' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Is_Library_Item
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Synthetic_Formal_Param_Decl | Ada_Package_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.is_library_item
                  Property_Result := Basic_Decl_P_Is_Library_Item
                    (Self
                    );
                  --# end
               when Ada_Generic_Package_Internal =>
                  --# property-call-start GenericPackageInternal.is_library_item
                  Property_Result := Generic_Package_Internal_P_Is_Library_Item
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Is_Library_Item;
--# end
--# property-start BasicDecl.decl_private_part /tmp/lal-23.0.0/ada/ast.py:2199
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Decl_Private_Part
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Private_Part
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Private_Part;
      Match_0 : Internal_Entity_Base_Package_Decl;
Match_1 : Internal_Entity_Task_Type_Decl;
Match_2 : Internal_Entity_Single_Task_Decl;
Match_3 : Internal_Entity_Protected_Type_Decl;
Match_4 : Internal_Entity_Single_Protected_Decl;
Match_5 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Private_Part;
Fld_1 : Internal_Entity_Task_Def;
Fld_2 : Internal_Entity_Private_Part;
Fld_3 : Internal_Entity_Single_Task_Type_Decl;
Fld_4 : Internal_Entity_Task_Def;
Fld_5 : Internal_Entity_Private_Part;
Fld_6 : Internal_Entity_Protected_Def;
Fld_7 : Internal_Entity_Private_Part;
Fld_8 : Internal_Entity_Protected_Def;
Fld_9 : Internal_Entity_Private_Part;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Base_Package_Decl;
Let_Result : Internal_Entity_Private_Part;
Scope_Result : Internal_Entity_Private_Part;
Cast_Result_1 : Internal_Entity_Task_Type_Decl;
Let_Result_1 : Internal_Entity_Private_Part;
Scope_Result_1 : Internal_Entity_Private_Part;
Cast_Result_2 : Internal_Entity_Single_Task_Decl;
Let_Result_2 : Internal_Entity_Private_Part;
Scope_Result_2 : Internal_Entity_Private_Part;
Cast_Result_3 : Internal_Entity_Protected_Type_Decl;
Let_Result_3 : Internal_Entity_Private_Part;
Scope_Result_3 : Internal_Entity_Private_Part;
Cast_Result_4 : Internal_Entity_Single_Protected_Decl;
Let_Result_4 : Internal_Entity_Private_Part;
Scope_Result_4 : Internal_Entity_Private_Part;
Cast_Result_5 : Internal_Entity_Basic_Decl;
Let_Result_5 : Internal_Entity_Private_Part;
Scope_Result_5 : Internal_Entity_Private_Part;
Match_Result : Internal_Entity_Private_Part;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2224 '<Match at ast.py:2199>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2199
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Generic_Package_Internal .. Ada_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Base_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind bpd Match_0
--# expr-start 2214 '<FieldAccess for private_part at ast.py:2200>' Fld /tmp/lal-23.0.0/ada/ast.py:2200
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Private_Part (Node => Match_0.Node.Base_Package_Decl_F_Private_Part, Info => Match_0.Info);
--# expr-done 2214
Let_Result := Fld; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Task_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind ttd Match_1
--# expr-start 2216 '<FieldAccess for private_part at ast.py:2201>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2201
--# expr-start 2215 '<FieldAccess for definition at ast.py:2201>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2201
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Task_Def (Node => Match_1.Node.Task_Type_Decl_F_Definition, Info => Match_1.Info);
--# expr-done 2215
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Private_Part (Node => Fld_1.Node.Task_Def_F_Private_Part, Info => Fld_1.Info);
--# expr-done 2216
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Single_Task_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind td Match_2
--# expr-start 2219 '<FieldAccess for private_part at ast.py:2202>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2202
--# expr-start 2218 '<FieldAccess for definition at ast.py:2202>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2202
--# expr-start 2217 '<FieldAccess for task_type at ast.py:2202>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2202
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Single_Task_Type_Decl (Node => Match_2.Node.Single_Task_Decl_F_Task_Type, Info => Match_2.Info);
--# expr-done 2217
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Task_Def (Node => Fld_3.Node.Task_Type_Decl_F_Definition, Info => Fld_3.Info);
--# expr-done 2218
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Private_Part (Node => Fld_4.Node.Task_Def_F_Private_Part, Info => Fld_4.Info);
--# expr-done 2219
Let_Result_2 := Fld_5; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Protected_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Protected_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_3; 
--# bind ptd Match_3
--# expr-start 2221 '<FieldAccess for private_part at ast.py:2203>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2203
--# expr-start 2220 '<FieldAccess for definition at ast.py:2203>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2203
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Protected_Def (Node => Match_3.Node.Protected_Type_Decl_F_Definition, Info => Match_3.Info);
--# expr-done 2220
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Private_Part (Node => Fld_6.Node.Protected_Def_F_Private_Part, Info => Fld_6.Info);
--# expr-done 2221
Let_Result_3 := Fld_7; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Single_Protected_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Single_Protected_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_4; 
--# bind spd Match_4
--# expr-start 2223 '<FieldAccess for private_part at ast.py:2204>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2204
--# expr-start 2222 '<FieldAccess for definition at ast.py:2204>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2204
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Protected_Def (Node => Match_4.Node.Single_Protected_Decl_F_Definition, Info => Match_4.Info);
--# expr-done 2222
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Private_Part (Node => Fld_8.Node.Protected_Def_F_Private_Part, Info => Fld_8.Info);
--# expr-done 2223
Let_Result_4 := Fld_9; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Abstract_State_Decl .. Ada_Synthetic_Formal_Param_Decl | Ada_Discrete_Base_Subtype_Decl .. Ada_Incomplete_Tagged_Type_Decl | Ada_Anonymous_Type_Decl .. Ada_Package_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_5; 
--# bind _ Match_5
Let_Result_5 := No_Entity_Private_Part; 
--# end
Scope_Result_5 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_5; 
end case;
--# expr-done 2224
      Property_Result := Match_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Decl_Private_Part;
--# end
--# property-start '[dispatcher]BasicDecl.declarative_parts' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Declarative_Parts
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Synthetic_Formal_Param_Decl | Ada_Discrete_Base_Subtype_Decl .. Ada_Incomplete_Tagged_Type_Decl | Ada_Anonymous_Type_Decl .. Ada_Null_Subp_Decl | Ada_Subp_Renaming_Decl .. Ada_Task_Body_Stub | Ada_Entry_Index_Spec .. Ada_Package_Renaming_Decl | Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.declarative_parts
                  Property_Result := Basic_Decl_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Internal .. Ada_Package_Decl =>
                  --# property-call-start BasePackageDecl.declarative_parts
                  Property_Result := Base_Package_Decl_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.declarative_parts
                  Property_Result := Protected_Type_Decl_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.declarative_parts
                  Property_Result := Task_Type_Decl_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Body =>
                  --# property-call-start SubpBody.declarative_parts
                  Property_Result := Subp_Body_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Body =>
                  --# property-call-start EntryBody.declarative_parts
                  Property_Result := Entry_Body_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Package_Body =>
                  --# property-call-start PackageBody.declarative_parts
                  Property_Result := Package_Body_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Body =>
                  --# property-call-start ProtectedBody.declarative_parts
                  Property_Result := Protected_Body_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Task_Body =>
                  --# property-call-start TaskBody.declarative_parts
                  Property_Result := Task_Body_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Single_Protected_Decl =>
                  --# property-call-start SingleProtectedDecl.declarative_parts
                  Property_Result := Single_Protected_Decl_P_Declarative_Parts
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Declarative_Parts;
--# end
--# property-start BasicDecl.immediate_declarative_region /tmp/lal-23.0.0/ada/ast.py:2217
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Immediate_Declarative_Region
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_148 with Inline_Always;
            procedure Finalizer_Scope_2081 with Inline_Always;
            procedure Finalizer_Scope_2082 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl_Array_Access;
Singleton : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Internal_Entity_Declarative_Part_Array_Access;
Fld_2 : Lexical_Env := Empty_Env;
Map_Result : Lexical_Env_Array_Access;
Map_Result_1 : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_148 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_148;
            procedure Finalizer_Scope_2081 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2081;
            procedure Finalizer_Scope_2082 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2082;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Basic_Decl_Basic_Decl_P_Immediate_Declarative_Region,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Basic_Decl,
                                As_Bare_Basic_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Lexical_Env;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 2232 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2231 '<env_group at ast.py:2222>' Group_Env /tmp/lal-23.0.0/ada/ast.py:2222
--# expr-start 2230 '<Mapcat at ast.py:2218>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:2218
   --# expr-start 2226 '<Concat at ast.py:2218>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:2218
--# expr-start 2225 '<FieldAccess for all_previous_parts at ast.py:2218>' Fld /tmp/lal-23.0.0/ada/ast.py:2218
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.all_previous_parts
Fld := Libadalang.Implementation.Basic_Decl_P_All_Previous_Parts (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 2225
                Singleton := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Ent;
Concat_Result := Concat (Fld, Singleton); 
--# expr-done 2226
      declare
         Map_Result_1_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Concat_Result;
      begin
         for Item_95 of
               Collection.Items
         loop
   --# scope-start
               --# bind part Item_95
      --# expr-start 2229 '<Map at ast.py:2219>' Map_Result /tmp/lal-23.0.0/ada/ast.py:2219
   --# expr-start 2227 '<FieldAccess for declarative_parts at ast.py:2219>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2219
      if Item_95.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.declarative_parts'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Declarative_Parts (Node => Item_95.Node, E_Info => Item_95.Info);
--# end
--# expr-done 2227
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Declarative_Part_Array_Access := Fld_1;
      begin
         for Item_96 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_96
      --# expr-start 2228 '<FieldAccess for children_env at ast.py:2220>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2220
      if Item_96.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Item_96.Node, E_Info => Item_96.Info);
--# expr-done 2228
         declare
            Item_To_Append : constant Lexical_Env := Fld_2;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2082;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2229
         for Item_To_Append of
               Map_Result.Items
         loop
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2081;
         end loop;
      end;
         Map_Result_1 := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_1_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 2230
Group_Env := Group (Map_Result_1, No_Metadata); 
--# expr-done 2231
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 2232
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_148;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Lexical_Env,
                        As_Lexical_Env => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_148;
               Finalizer_Scope_2081;
               Finalizer_Scope_2082;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Immediate_Declarative_Region;
--# end
--# property-start '[dispatcher]BasicDecl.get_aspect_assoc' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Get_Aspect_Assoc
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Aspect_Assoc
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Aspect_Assoc;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Subtype_Decl | Ada_Incomplete_Type_Decl .. Ada_For_Loop_Var_Decl | Ada_Generic_Package_Instantiation .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.get_aspect_assoc
                  Property_Result := Basic_Decl_P_Get_Aspect_Assoc
                    (Self
                        , Name
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.get_aspect_assoc
                  Property_Result := Classwide_Type_Decl_P_Get_Aspect_Assoc
                    (Self
                        , Name
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Decl .. Ada_Generic_Subp_Decl =>
                  --# property-call-start GenericDecl.get_aspect_assoc
                  Property_Result := Generic_Decl_P_Get_Aspect_Assoc
                    (Self
                        , Name
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Get_Aspect_Assoc;
--# end
--# property-start BasicDecl.get_aspect_spec_expr /tmp/lal-23.0.0/ada/ast.py:2238
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_Aspect_Spec_Expr
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Expr;
      Var_Expr : Internal_Entity_Aspect_Assoc;
Fld : Internal_Entity_Aspect_Assoc;
Fld_1 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Let_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2235 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2233 '<FieldAccess for get_aspect_assoc at ast.py:2243>' Fld /tmp/lal-23.0.0/ada/ast.py:2243
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.get_aspect_assoc'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Get_Aspect_Assoc (Node => Ent.Node, Name => Name, E_Info => Ent.Info);
--# end
--# expr-done 2233
Var_Expr := Fld;
if Var_Expr /= No_Entity_Aspect_Assoc then
   --# scope-start
--# expr-start 2234 '<FieldAccess for expr at ast.py:2243>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2243
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Aspect_Assoc_F_Expr, Info => Var_Expr.Info);
--# expr-done 2234
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Expr;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2235
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_Aspect_Spec_Expr;
--# end
--# property-start BasicDecl.library_item_pragmas /tmp/lal-23.0.0/ada/ast.py:2246
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Library_Item_Pragmas
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Pragma_Node_List
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Pragma_Node_List;
      Fld : Internal_Entity;
Is_A : Boolean;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity;
Cast_Result : Internal_Entity_Compilation_Unit;
Fld_3 : Internal_Entity_Pragma_Node_List;
Fld_4 : Internal_Entity;
Fld_5 : Internal_Entity;
Is_A_1 : Boolean;
Fld_6 : Internal_Entity;
Fld_7 : Internal_Entity;
Fld_8 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Compilation_Unit;
Fld_9 : Internal_Entity_Pragma_Node_List;
If_Result : Internal_Entity_Pragma_Node_List;
If_Result_1 : Internal_Entity_Pragma_Node_List;
Let_Result : Internal_Entity_Pragma_Node_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2251 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2250 '<Cond at ast.py:2250>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2250
--# expr-start 2237 '<IsA LibraryItem at ast.py:2251>' Is_A /tmp/lal-23.0.0/ada/ast.py:2251
--# expr-start 2236 '<parent at ast.py:2251>' Fld /tmp/lal-23.0.0/ada/ast.py:2251
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2236
Is_A := Fld.Node /= null 
and then Fld.Node.Kind in Ada_Library_Item_Range; 
--# expr-done 2237
if Is_A then
   --# expr-start 2241 '<FieldAccess for pragmas at ast.py:2252>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2252
--# expr-start 2240 '<Cast to CompilationUnit at ast.py:2252>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2252
--# expr-start 2239 '<parent at ast.py:2252>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2252
--# expr-start 2238 '<parent at ast.py:2252>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2252
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2238
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 2239
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Create_Internal_Entity_Compilation_Unit
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result := No_Entity_Compilation_Unit;
   end if;
--# expr-done 2240
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Pragma_Node_List (Node => Cast_Result.Node.Compilation_Unit_F_Pragmas, Info => Cast_Result.Info);
--# expr-done 2241
   If_Result_1 := Fld_3;
else
--# expr-start 2244 '<IsA LibraryItem at ast.py:2254>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:2254
--# expr-start 2243 '<parent at ast.py:2254>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2254
--# expr-start 2242 '<parent at ast.py:2254>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2254
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2242
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Parent (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# expr-done 2243
Is_A_1 := Fld_5.Node /= null 
and then Fld_5.Node.Kind in Ada_Library_Item_Range; 
--# expr-done 2244
if Is_A_1 then
   --# expr-start 2249 '<FieldAccess for pragmas at ast.py:2255>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2255
--# expr-start 2248 '<Cast to CompilationUnit at ast.py:2255>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:2255
--# expr-start 2247 '<parent at ast.py:2255>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2255
--# expr-start 2246 '<parent at ast.py:2255>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2255
--# expr-start 2245 '<parent at ast.py:2255>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2255
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2245
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Parent (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# expr-done 2246
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Parent (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# expr-done 2247
   if Fld_8.Node = null
      or else Fld_8.Node.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Compilation_Unit
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
   else
         Cast_Result_1 := No_Entity_Compilation_Unit;
   end if;
--# expr-done 2248
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Pragma_Node_List (Node => Cast_Result_1.Node.Compilation_Unit_F_Pragmas, Info => Cast_Result_1.Info);
--# expr-done 2249
   If_Result := Fld_9;
else
   If_Result := No_Entity_Pragma_Node_List;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 2250
Let_Result := If_Result_1; 
--# end
--# expr-done 2251
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Library_Item_Pragmas;
--# end
--# property-start BasicDecl.get_aspect /tmp/lal-23.0.0/ada/ast.py:2262
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_Aspect
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Aspect
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Aspect;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Aspect;
Scope_Result : Internal_Aspect;
Result_Var : Internal_Aspect;
Let_Result : Internal_Aspect;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2254 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2252 '<FieldAccess for defining_name_or_raise at ast.py:2275>' Fld /tmp/lal-23.0.0/ada/ast.py:2275
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2252
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2253 '<FieldAccess for get_aspect at ast.py:2275>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2275
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_aspect
Fld_1 := Libadalang.Implementation.Defining_Name_P_Get_Aspect (Node => Var_Expr.Node, Name => Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2253
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Aspect;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2254
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_Aspect;
--# end
--# property-start BasicDecl.has_aspect /tmp/lal-23.0.0/ada/ast.py:2279
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Has_Aspect
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2257 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2255 '<FieldAccess for defining_name_or_raise at ast.py:2286>' Fld /tmp/lal-23.0.0/ada/ast.py:2286
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2255
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2256 '<FieldAccess for has_aspect at ast.py:2286>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2286
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.has_aspect
Fld_1 := Libadalang.Implementation.Defining_Name_P_Has_Aspect (Node => Var_Expr.Node, Name => Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2256
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2257
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Has_Aspect;
--# end
--# property-start BasicDecl.get_pragma /tmp/lal-23.0.0/ada/ast.py:2289
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_Pragma
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Pragma_Node
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Pragma_Node;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Pragma_Node;
Scope_Result : Internal_Entity_Pragma_Node;
Result_Var : Internal_Entity_Pragma_Node;
Let_Result : Internal_Entity_Pragma_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2260 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2258 '<FieldAccess for defining_name_or_raise at ast.py:2297>' Fld /tmp/lal-23.0.0/ada/ast.py:2297
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2258
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2259 '<FieldAccess for get_pragma at ast.py:2297>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2297
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_pragma
Fld_1 := Libadalang.Implementation.Defining_Name_P_Get_Pragma (Node => Var_Expr.Node, Name => Name, E_Info => Var_Expr.Info);
--# end
--# expr-done 2259
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Pragma_Node;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2260
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_Pragma;
--# end
--# property-start BasicDecl.get_representation_clause /tmp/lal-23.0.0/ada/ast.py:2301
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_Representation_Clause
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Attribute_Def_Clause
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Attribute_Def_Clause;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Attribute_Def_Clause;
Scope_Result : Internal_Entity_Attribute_Def_Clause;
Result_Var : Internal_Entity_Attribute_Def_Clause;
Let_Result : Internal_Entity_Attribute_Def_Clause;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2263 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2261 '<FieldAccess for defining_name_or_raise at ast.py:2306>' Fld /tmp/lal-23.0.0/ada/ast.py:2306
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2261
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2262 '<FieldAccess for get_representation_clause at ast.py:2306>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2306
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_representation_clause
Fld_1 := Libadalang.Implementation.Defining_Name_P_Get_Representation_Clause (Node => Var_Expr.Node, Name => Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2262
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Attribute_Def_Clause;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2263
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_Representation_Clause;
--# end
--# property-start BasicDecl.get_at_clause /tmp/lal-23.0.0/ada/ast.py:2310
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_At_Clause
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_At_Clause
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_At_Clause;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_At_Clause;
Scope_Result : Internal_Entity_At_Clause;
Result_Var : Internal_Entity_At_Clause;
Let_Result : Internal_Entity_At_Clause;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2266 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2264 '<FieldAccess for defining_name_or_raise at ast.py:2314>' Fld /tmp/lal-23.0.0/ada/ast.py:2314
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2264
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2265 '<FieldAccess for get_at_clause at ast.py:2314>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2314
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_at_clause
Fld_1 := Libadalang.Implementation.Defining_Name_P_Get_At_Clause (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2265
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_At_Clause;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2266
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_At_Clause;
--# end
--# property-start '[dispatcher]BasicDecl.is_imported' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Is_Imported
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Generic_Package_Decl | Ada_Generic_Package_Instantiation .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.is_imported
                  Property_Result := Basic_Decl_P_Is_Imported
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Decl =>
                  --# property-call-start GenericSubpDecl.is_imported
                  Property_Result := Generic_Subp_Decl_P_Is_Imported
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Is_Imported;
--# end
--# property-start BasicDecl.is_ghost_code /tmp/lal-23.0.0/ada/ast.py:2324
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Ghost_Code
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2269 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2267 '<FieldAccess for defining_name_or_raise at ast.py:2328>' Fld /tmp/lal-23.0.0/ada/ast.py:2328
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2267
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2268 '<FieldAccess for is_ghost_code at ast.py:2328>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2328
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_ghost_code
Fld_1 := Libadalang.Implementation.Defining_Name_P_Is_Ghost_Code (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2268
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2269
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Ghost_Code;
--# end
--# property-start BasicDecl.get_instantiation /tmp/lal-23.0.0/ada/ast.py:2331
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_Instantiation
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Generic_Instantiation
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Generic_Instantiation;
            procedure Finalizer_Scope_2093 with Inline_Always;
      Block_Var : Bare_Generic_Instantiation;
Block_Var_1 : Internal_Entity_Basic_Decl;
Var_Expr : Env_Rebindings;
Var_Expr_1 : Internal_Entity_Generic_Instantiation;
Fld : Internal_Entity_Info;
Fld_1 : Env_Rebindings;
Fld_2 : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Cast_Result : Bare_Generic_Instantiation;
Scope_Result : Bare_Generic_Instantiation;
Result_Var : Bare_Generic_Instantiation;
As_Entity : Internal_Entity_Generic_Instantiation;
Is_Null : Boolean;
If_Result : Internal_Entity_Generic_Instantiation;
Fld_3 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Info;
Fld_5 : Env_Rebindings;
Fld_6 : Internal_Entity_Info;
Fld_7 : Env_Rebindings;
Fld_8 : Env_Rebindings;
Fld_9 : Internal_Entity_Info;
Fld_10 : Boolean;
New_Struct : Internal_Metadata;
New_Struct_1 : Internal_Entity_Info;
New_Struct_2 : Internal_Entity_Generic_Instantiation;
Fld_11 : Bare_Basic_Decl;
Fld_12 : Bare_Ada_Node;
Cast_Result_1 : Bare_Ada_Node;
Is_Equal : Boolean;
If_Result_1 : Internal_Entity_Generic_Instantiation;
Let_Result : Internal_Entity_Generic_Instantiation;
            procedure Finalizer_Scope_2093 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2093;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2291 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2271 '<FieldAccess for rebindings at ast.py:2343>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2343
--# expr-start 2270 '<FieldAccess for info at ast.py:2343>' Fld /tmp/lal-23.0.0/ada/ast.py:2343
Fld := Ent.Info;
--# expr-done 2270
Fld_1 := Fld.Rebindings;
--# expr-done 2271
Var_Expr := Fld_1;
if Var_Expr /= null then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 2274 '<Cast to GenericInstantiation at ast.py:2344>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2344
--# expr-start 2273 '<env_node at ast.py:2344>' Env_Node /tmp/lal-23.0.0/ada/ast.py:2344
--# expr-start 2272 '<FieldAccess for new_env at ast.py:2344>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2344
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr.New_Env;
Inc_Ref (Fld_2);
--# expr-done 2272
Env_Node := AST_Envs.Env_Node (Fld_2); 
--# expr-done 2273
   if Env_Node = null
      or else Env_Node.Kind in Ada_Generic_Instantiation
   then
      Cast_Result := Env_Node;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 2274
Scope_Result := Cast_Result;
   --# end
      Finalizer_Scope_2093;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Block_Var := Result_Var; 
--# bind inst_node Block_Var
--# expr-start 2275 '<as_bare_entity at ast.py:2347>' If_Result /tmp/lal-23.0.0/ada/ast.py:2347
Is_Null := Block_Var = null; 
if Is_Null then
   If_Result := No_Entity_Generic_Instantiation;
else
As_Entity := (Info => No_Entity_Info, Node => Block_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 2275
Var_Expr_1 := If_Result;
if Var_Expr_1 /= No_Entity_Generic_Instantiation then
   --# scope-start
--# expr-start 2276 '<FieldAccess for designated_generic_decl at ast.py:2347>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2347
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.designated_generic_decl'
Fld_3 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Designated_Generic_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2276
Scope_Result_1 := Fld_3;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
Block_Var_1 := Result_Var_1; 
--# bind designated_decl Block_Var_1
--# expr-start 2290 '<If at ast.py:2349>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2349
--# expr-start 2279 '<Eq at ast.py:2350>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2350
--# expr-start 2277 '<FieldAccess for node at ast.py:2350>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2350
Fld_11 := Block_Var_1.Node;
--# expr-done 2277
      Cast_Result_1 := Fld_11;
--# expr-start 2278 '<parent at ast.py:2350>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:2350
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.Parent; 
--# expr-done 2278
Is_Equal := Cast_Result_1 = Fld_12; 
--# expr-done 2279
if Is_Equal then
   --# expr-start 2289 '<New GenericInstantiation.entity at ???>' New_Struct_2 None
--# expr-start 2288 '<New EntityInfo at ast.py:2353>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:2353
--# expr-start 2281 '<FieldAccess for from_rebound at ast.py:2360>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2360
--# expr-start 2280 '<FieldAccess for info at ast.py:2360>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2360
Fld_9 := Ent.Info;
--# expr-done 2280
Fld_10 := Fld_9.From_Rebound;
--# expr-done 2281
--# expr-start 2282 '<New Metadata at ast.py:2361>' New_Struct /tmp/lal-23.0.0/ada/ast.py:2361
New_Struct := (Dottable_Subp => False, Primitive => No_Bare_Ada_Node, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 2282
--# expr-start 2287 '<FieldAccess for remove_rebindings at ast.py:2356>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2356
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2284 '<FieldAccess for rebindings at ast.py:2357>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2357
--# expr-start 2283 '<FieldAccess for info at ast.py:2357>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2357
Fld_4 := Ent.Info;
--# expr-done 2283
Fld_5 := Fld_4.Rebindings;
--# expr-done 2284
--# expr-start 2286 '<FieldAccess for rebindings at ast.py:2358>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2358
--# expr-start 2285 '<FieldAccess for info at ast.py:2358>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2358
Fld_6 := Block_Var_1.Info;
--# expr-done 2285
Fld_7 := Fld_6.Rebindings;
--# expr-done 2286
--# property-call-start AdaNode.remove_rebindings
Fld_8 := Libadalang.Implementation.Ada_Node_P_Remove_Rebindings (Node => Self, Base => Fld_5, Suffix => Fld_7);
--# end
--# expr-done 2287
New_Struct_1 := (From_Rebound => Fld_10, Md => New_Struct, Rebindings => Fld_8); 
--# expr-done 2288
New_Struct_2 := (Info => New_Struct_1, Node => Block_Var); 
--# expr-done 2289
   If_Result_1 := New_Struct_2;
else
   If_Result_1 := No_Entity_Generic_Instantiation;
end if;
--# expr-done 2290
Let_Result := If_Result_1; 
--# end
--# expr-done 2291
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2093;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_Instantiation;
--# end
--# property-start BasicDecl.is_compilation_unit_root /tmp/lal-23.0.0/ada/ast.py:2368
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Compilation_Unit_Root
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Ada_Node;
Match_0 : Bare_Library_Item;
Match_1 : Bare_Generic_Package_Decl;
Match_2 : Bare_Subunit;
Match_3 : Bare_Ada_Node;
Var_Expr_1 : Bare_Ada_Node;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Library_Item;
Let_Result : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_1 : Bare_Generic_Package_Decl;
Let_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_2 : Bare_Subunit;
Let_Result_2 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_3 : Bare_Ada_Node;
Let_Result_3 : Boolean;
Scope_Result_4 : Boolean;
Match_Result : Boolean;
Scope_Result_5 : Boolean;
Result_Var_1 : Boolean;
Let_Result_4 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2296 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 2292 '<parent at ast.py:2372>' Fld /tmp/lal-23.0.0/ada/ast.py:2372
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2292
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 2295 '<Match at ast.py:2372>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2372
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind _ Match_0
Let_Result := True; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Generic_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind gen_pkg_decl Match_1
--# expr-start 2293 '<parent at ast.py:2375>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2375
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Match_1.Parent; 
--# expr-done 2293
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 2294 '<IsA LibraryItem at ast.py:2375>' Is_A /tmp/lal-23.0.0/ada/ast.py:2375
Is_A := Var_Expr_1 /= null 
and then Var_Expr_1.Kind in Ada_Library_Item_Range; 
--# expr-done 2294
Scope_Result := Is_A;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result_1 := Result_Var; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := True; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Abort_Absent .. Ada_For_Loop_Var_Decl | Ada_Generic_Subp_Decl .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_3 := Cast_Result_3; 
--# bind _ Match_3
Let_Result_3 := False; 
--# end
Scope_Result_4 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_4; 
end case;
--# expr-done 2295
Scope_Result_5 := Match_Result;
   --# end
   Result_Var_1 := Scope_Result_5;
else
   Result_Var_1 := False;
end if;
Let_Result_4 := Result_Var_1; 
--# end
--# expr-done 2296
      Property_Result := Let_Result_4;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Compilation_Unit_Root;
--# end
--# property-start BasicDecl.populate_dependent_units /tmp/lal-23.0.0/ada/ast.py:2381
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Populate_Dependent_Units
  (Node : Bare_Basic_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_161 with Inline_Always;
      Fld : Bare_Name_Array_Access;
Fld_1 : Bare_Compilation_Unit;
Map_Result : Bare_Compilation_Unit_Array_Access;
Fld_2 : Boolean;
If_Result : Bare_Compilation_Unit_Array_Access;
Let_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_161 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_161;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2302 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2301 '<If at ast.py:2382>' If_Result /tmp/lal-23.0.0/ada/ast.py:2382
--# expr-start 2297 '<FieldAccess for is_compilation_unit_root at ast.py:2383>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2383
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 2297
if Fld_2 then
   --# expr-start 2300 '<Map at ast.py:2384>' Map_Result /tmp/lal-23.0.0/ada/ast.py:2384
   --# expr-start 2298 '<FieldAccess for top_level_with_package_clauses at ast.py:2384>' Fld /tmp/lal-23.0.0/ada/ast.py:2384
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_with_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_With_Package_Clauses (Node => Self);
--# end
--# expr-done 2298
      declare
         Map_Result_Vec : Bare_Compilation_Unit_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Name_Array_Access := Fld;
      begin
         for Item_98 of
               Collection.Items
         loop
   --# scope-start
               --# bind package_name Item_98
      --# expr-start 2299 '<FieldAccess for withed_unit_helper at ast.py:2386>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2386
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.withed_unit_helper
Fld_1 := Libadalang.Implementation.Ada_Node_P_Withed_Unit_Helper (Node => Self, Unit_Name => Item_98);
--# end
--# expr-done 2299
         declare
            Item_To_Append : constant Bare_Compilation_Unit := Fld_1;
         begin
            Bare_Compilation_Unit_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Bare_Compilation_Unit_Array
           (Items_Count => Natural (Bare_Compilation_Unit_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Compilation_Unit_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Compilation_Unit_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Compilation_Unit_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2300
   If_Result := Map_Result;
else
   If_Result := No_Bare_Compilation_Unit_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 2301
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2302
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_161;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_161;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Populate_Dependent_Units;
--# end
--# property-start BasicDecl.should_ref_generic_formals /tmp/lal-23.0.0/ada/ast.py:2392
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Should_Ref_Generic_Formals
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
If_Result : Boolean;
Is_A_1 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2308 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2304 '<Not at ast.py:2402>' Not_Val /tmp/lal-23.0.0/ada/ast.py:2402
--# expr-start 2303 '<FieldAccess for is_compilation_unit_root at ast.py:2402>' Fld /tmp/lal-23.0.0/ada/ast.py:2402
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 2303
Not_Val := not (Fld); 
--# expr-done 2304
if Not_Val then
   If_Result := True;
else
   --# expr-start 2306 '<IsA Subunit at ast.py:2407>' Is_A /tmp/lal-23.0.0/ada/ast.py:2407
--# expr-start 2305 '<parent at ast.py:2407>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2407
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Parent; 
--# expr-done 2305
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Subunit_Range; 
--# expr-done 2306
   If_Result := Is_A;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 2307 '<IsA BaseSubpBody at ast.py:2413>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:2413
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Base_Subp_Body; 
--# expr-done 2307
   If_Result_1 := Is_A_1;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 2308
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Should_Ref_Generic_Formals;
--# end
--# property-start BasicDecl.is_in_public_part /tmp/lal-23.0.0/ada/ast.py:2416
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_In_Public_Part
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2311 '<IsA PublicPart at ast.py:2416>' Is_A /tmp/lal-23.0.0/ada/ast.py:2416
--# expr-start 2310 '<parent at ast.py:2416>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2416
--# expr-start 2309 '<parent at ast.py:2416>' Fld /tmp/lal-23.0.0/ada/ast.py:2416
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2309
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 2310
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Public_Part_Range; 
--# expr-done 2311
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_In_Public_Part;
--# end
--# property-start '[dispatcher]BasicDecl.is_in_private_part' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Is_In_Private_Part
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Subtype_Decl | Ada_Incomplete_Type_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.is_in_private_part
                  Property_Result := Basic_Decl_P_Is_In_Private_Part
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.is_in_private_part
                  Property_Result := Classwide_Type_Decl_P_Is_In_Private_Part
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Is_In_Private_Part;
--# end
--# property-start BasicDecl.is_visible /tmp/lal-23.0.0/ada/ast.py:2420
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Visible
  (Node : Bare_Basic_Decl
      ; From_Node : Internal_Entity
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind from_node From_Node
   Property_Result : Boolean;
            procedure Finalizer_Scope_165 with Inline_Always;
      Var_Expr : Internal_Entity_Body_Node;
Fld : Boolean;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result : Boolean;
Fld_3 : Internal_Entity;
Fld_4 : Internal_Entity;
Fld_5 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Package_Decl;
Fld_6 : Boolean;
Fld_7 : Boolean;
If_Result : Boolean;
Not_Val : Boolean;
If_Result_1 : Boolean;
Fld_8 : Boolean;
Fld_9 : Internal_Entity_Basic_Decl;
Fld_10 : Boolean;
Fld_11 : Boolean;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Body_Node;
Fld_12 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Not_Val_1 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Boolean;
If_Result_5 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_165 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_165;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2333 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2332 '<Cond at ast.py:2429>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:2429
--# expr-start 2312 '<FieldAccess for is_in_private_part at ast.py:2432>' Fld /tmp/lal-23.0.0/ada/ast.py:2432
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2312
if Fld then
--# expr-start 2317 '<Contains at ast.py:2433>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:2433
   --# expr-start 2315 '<EnvGet at ast.py:2433>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:2433
--# expr-start 2313 '<FieldAccess for node_env at ast.py:2433>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2433
      if From_Node.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Node_Env (Node => From_Node.Node, E_Info => From_Node.Info);
--# expr-done 2313
--# expr-start 2314 '<FieldAccess for name_symbol at ast.py:2433>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2433
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2314
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_1, Key => Fld_2, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 2315
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_99 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_99
      --# expr-start 2316 '<Eq at ???>' Is_Equiv None
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Item_99, Cast_Result); 
--# expr-done 2316
      Quantifier_Result := Is_Equiv;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 2317
if Quantifier_Result then
   --# expr-start 2324 '<Not at ast.py:2440>' Not_Val /tmp/lal-23.0.0/ada/ast.py:2440
--# expr-start 2322 '<FieldAccess for is_compilation_unit_root at ast.py:2442>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2442
--# expr-start 2321 '<Cast to PackageDecl at ast.py:2441>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:2441
--# expr-start 2320 '<parent at ast.py:2441>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2441
--# expr-start 2319 '<parent at ast.py:2441>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2441
--# expr-start 2318 '<parent at ast.py:2441>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2441
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2318
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Parent (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# expr-done 2319
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Parent (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# expr-done 2320
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Package_Decl_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Package_Decl
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_1 := No_Entity_Package_Decl;
   end if;
--# expr-done 2321
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Cast_Result_1.Node);
--# end
--# expr-done 2322
if Fld_6 then
   --# expr-start 2323 '<FieldAccess for is_in_top_level_public_part at ast.py:2443>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2443
      if From_Node.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.is_in_top_level_public_part
Fld_7 := Libadalang.Implementation.Ada_Node_P_Is_In_Top_Level_Public_Part (Node => From_Node.Node, E_Info => From_Node.Info);
--# end
--# expr-done 2323
   If_Result := Fld_7;
else
   If_Result := False;
end if;
Not_Val := not (If_Result); 
--# expr-done 2324
   If_Result_1 := Not_Val;
else
   If_Result_1 := False;
end if;
   If_Result_5 := If_Result_1;
else
--# expr-start 2325 '<FieldAccess for is_in_public_part at ast.py:2449>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2449
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_in_public_part
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Is_In_Public_Part (Node => Ent.Node);
--# end
--# expr-done 2325
if Fld_8 then
   --# expr-start 2327 '<FieldAccess for is_visible at ast.py:2450>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2450
--# expr-start 2326 '<FieldAccess for parent_basic_decl at ast.py:2450>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2450
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_9 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2326
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_visible
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Is_Visible (Node => Fld_9.Node, From_Node => From_Node, E_Info => Fld_9.Info);
--# end
--# expr-done 2327
   If_Result_4 := Fld_10;
else
--# expr-start 2328 '<FieldAccess for is_compilation_unit_root at ast.py:2455>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2455
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Ent.Node);
--# end
--# expr-done 2328
if Fld_11 then
   --# expr-start 2331 '<Not at ast.py:2456>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:2456
--# expr-start 2329 '<Cast to Body at ast.py:2456>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:2456
Cast_Expr_1 := Ent; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Body_Node
   then
      Cast_Result_2 := Create_Internal_Entity_Body_Node
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Body_Node;
   end if;
--# expr-done 2329
Var_Expr := Cast_Result_2;
if Var_Expr /= No_Entity_Body_Node then
   --# scope-start
--# expr-start 2330 '<FieldAccess for is_subunit at ast.py:2456>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:2456
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld_12 := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Var_Expr.Node);
--# end
--# expr-done 2330
Scope_Result := Fld_12;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Not_Val_1 := not (Result_Var); 
--# expr-done 2331
   If_Result_2 := Not_Val_1;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   If_Result_3 := raise Property_Error with "Only package-level declaration support visibility checks for now.";
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
--# expr-done 2332
Let_Result := If_Result_5; 
--# end
--# expr-done 2333
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_165;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_165;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Visible;
--# end
--# property-start BasicDecl.subp_decl_match_signature /tmp/lal-23.0.0/ada/ast.py:2466
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Subp_Decl_Match_Signature
  (Node : Bare_Basic_Decl
      ; Other : Internal_Entity_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Subp_Spec;
Cast_Result : Internal_Entity_Subp_Spec;
Cast_Result_1 : Internal_Entity_Base_Subp_Spec;
Fld_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2338 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2337 '<FieldAccess for match_signature at ast.py:2468>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2468
--# expr-start 2334 '<FieldAccess for subp_spec_or_null at ast.py:2468>' Fld /tmp/lal-23.0.0/ada/ast.py:2468
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2334
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2336 '<Cast to SubpSpec at ast.py:2469>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2469
--# expr-start 2335 '<FieldAccess for subp_spec_or_null at ast.py:2469>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2469
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Other.Node, E_Info => Other.Info);
--# end
--# expr-done 2335
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Subp_Spec_Range
   then
      Cast_Result := Create_Internal_Entity_Subp_Spec
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 2336
      Cast_Result_1 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Result.Node,
         Info => Cast_Result.Info);
--# property-call-start BaseSubpSpec.match_signature
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld.Node, Other => Cast_Result_1, Match_Name => False, E_Info => Fld.Info);
--# end
--# expr-done 2337
Let_Result := Fld_2; 
--# end
--# expr-done 2338
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Subp_Decl_Match_Signature;
--# end
--# property-start BasicDecl.base_subp_declarations_impl /tmp/lal-23.0.0/ada/ast.py:2476
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Base_Subp_Declarations_Impl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_167 with Inline_Always;
            procedure Finalizer_Scope_2099 with Inline_Always;
            procedure Finalizer_Scope_2100 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Block_Var_1 : Boolean;
Block_Var_2 : Internal_Entity_Base_Subp_Spec;
Block_Var_3 : Lexical_Env := Empty_Env;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Var_Expr_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Is_A : Boolean;
Fld_2 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Base_Subp_Spec;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Lexical_Env := Empty_Env;
Map_Result : Lexical_Env_Array_Access;
Fld_7 : Lexical_Env := Empty_Env;
Singleton : Lexical_Env_Array_Access;
Concat_Result : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Internal_Entity_Base_Type_Decl;
Fld_10 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
If_Result : Lexical_Env := Empty_Env;
Fld_11 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_12 : Internal_Entity_Basic_Decl;
Cast_Expr_2 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Fld_13 : Internal_Entity_Base_Subp_Spec;
Scope_Result_1 : Internal_Entity_Base_Subp_Spec;
Result_Var_1 : Internal_Entity_Base_Subp_Spec;
Fld_14 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Map_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
Unique_Array : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_167 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (If_Result);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_167;
            procedure Finalizer_Scope_2099 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2099;
            procedure Finalizer_Scope_2100 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_2100;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2366 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2340 '<FieldAccess for parent_basic_decl at ast.py:2481>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2481
--# expr-start 2339 '<FieldAccess for canonical_part at ast.py:2481>' Fld /tmp/lal-23.0.0/ada/ast.py:2481
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2339
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_1 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 2340
Block_Var := Fld_1; 
--# bind parent Block_Var
--# expr-start 2341 '<IsA ProtectedTypeDecl, TaskTypeDecl at ast.py:2482>' Is_A /tmp/lal-23.0.0/ada/ast.py:2482
Is_A := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Protected_Type_Decl_Range | Ada_Task_Type_Decl_Range; 
--# expr-done 2341
Block_Var_1 := Is_A; 
--# bind task_or_protected Block_Var_1
--# expr-start 2344 '<FieldAccess for subp_spec_or_null at ast.py:2487>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2487
--# expr-start 2343 '<Cast to BasicDecl at ast.py:2487>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2487
--# expr-start 2342 '<FieldAccess for without_md at ast.py:2487>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2487
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.without_md
Fld_2 := Libadalang.Implementation.Ada_Node_P_Without_Md (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2342
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 2343
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 2344
Block_Var_2 := Fld_3; 
--# bind spec Block_Var_2
--# expr-start 2356 '<If at ast.py:2491>' If_Result /tmp/lal-23.0.0/ada/ast.py:2491
if Block_Var_1 then
   --# expr-start 2352 '<env_group at ast.py:2498>' Group_Env /tmp/lal-23.0.0/ada/ast.py:2498
--# expr-start 2351 '<Concat at ast.py:2498>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:2498
--# expr-start 2349 '<Map at ast.py:2496>' Map_Result /tmp/lal-23.0.0/ada/ast.py:2496
   --# expr-start 2346 '<FieldAccess for base_types at ast.py:2496>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2496
--# expr-start 2345 '<Cast to BaseTypeDecl at ast.py:2496>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:2496
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 2345
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_types'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Types (Node => Cast_Result_1.Node, Origin => No_Bare_Ada_Node, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 2346
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_4;
      begin
         for Item_100 of
               Collection.Items
         loop
   --# scope-start
               --# bind bt Item_100
      --# expr-start 2348 '<FieldAccess for primitives_env at ast.py:2497>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2497
--# expr-start 2347 '<FieldAccess for full_view at ast.py:2497>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2497
      if Item_100.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Item_100.Node, E_Info => Item_100.Info);
--# end
--# expr-done 2347
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Fld_5.Node, E_Info => Fld_5.Info);
--# end
--# expr-done 2348
         declare
            Item_To_Append : constant Lexical_Env := Fld_6;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2099;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2349
--# expr-start 2350 '<FieldAccess for children_env at ast.py:2498>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2498
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Children_Env (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 2350
                Singleton := Create_Lexical_Env_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_7;
                Inc_Ref (Singleton.Items (1));
Concat_Result := Concat (Map_Result, Singleton); 
--# expr-done 2351
Group_Env := Group (Concat_Result, No_Metadata); 
--# expr-done 2352
   If_Result := Group_Env;
else
--# expr-start 2353 '<FieldAccess for candidate_primitive_subp_tagged_type at ast.py:2501>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2501
      if Block_Var_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_tagged_type
Fld_8 := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type (Node => Block_Var_2.Node, Canonicalize => False, E_Info => Block_Var_2.Info);
--# end
--# expr-done 2353
Var_Expr := Fld_8;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 2355 '<FieldAccess for primitives_env at ast.py:2502>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2502
--# expr-start 2354 '<FieldAccess for full_view at ast.py:2502>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2502
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2354
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_10 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Fld_9.Node, E_Info => Fld_9.Info);
--# end
--# expr-done 2355
Scope_Result := Fld_10;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2100;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
   If_Result := Result_Var;
end if;
      Inc_Ref (If_Result);
--# expr-done 2356
Block_Var_3 := If_Result; Inc_Ref (Block_Var_3);
--# bind prims_env Block_Var_3
--# expr-start 2365 '<unique at ast.py:2534>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:2534
--# expr-start 2364 '<FilterMap at ast.py:2518>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:2518
   --# expr-start 2358 '<EnvGet at ast.py:2518>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:2518
--# expr-start 2357 '<FieldAccess for name_symbol at ast.py:2518>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2518
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2357
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Block_Var_3, Key => Fld_11, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 2358
      declare
         Map_Result_1_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_101 of
               Collection.Items
         loop
   --# scope-start
               --# bind bd Item_101
--# expr-start 2359 '<Cast to BasicDecl at ast.py:2520>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:2520
Cast_Expr_2 := Item_101; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_3 := No_Entity_Basic_Decl;
   end if;
--# expr-done 2359
Var_Expr_2 := Cast_Result_3;
if Var_Expr_2 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 2360 '<FieldAccess for subp_spec_or_null at ast.py:2520>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:2520
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_13 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 2360
Scope_Result_1 := Fld_13;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Subp_Spec;
end if;
Var_Expr_1 := Result_Var_1;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind s Var_Expr_1
--# expr-start 2361 '<FieldAccess for match_signature at ast.py:2527>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:2527
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.match_signature
Fld_14 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Var_Expr_1.Node, Other => Block_Var_2, Match_Name => False, Use_Entity_Info => True, Ignore_First_Param => Block_Var_1, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2361
Scope_Result_2 := Fld_14;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
         if Result_Var_2 then
      --# expr-start 2363 '<FieldAccess for canonical_part at ast.py:2519>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:2519
--# expr-start 2362 '<Cast to BasicDecl at ast.py:2519>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:2519
Cast_Expr_1 := Item_101; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 2362
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld_12 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Cast_Result_2.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 2363
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Fld_12;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 2364
Unique_Array := Make_Unique (Map_Result_1); 
--# expr-done 2365
Let_Result := Unique_Array; Inc_Ref (Let_Result);
--# end
--# expr-done 2366
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_167;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_167;
               Finalizer_Scope_2099;
               Finalizer_Scope_2100;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Base_Subp_Declarations_Impl;
--# end
--# property-start BasicDecl.base_subp_declarations /tmp/lal-23.0.0/ada/ast.py:2538
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Base_Subp_Declarations
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_168 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Boolean;
If_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_168 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_168;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Basic_Decl_Basic_Decl_P_Base_Subp_Declarations,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Basic_Decl,
                                As_Bare_Basic_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Imprecise_Fallback);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 2370 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2369 '<If at ast.py:2547>' If_Result /tmp/lal-23.0.0/ada/ast.py:2547
--# expr-start 2367 '<FieldAccess for is_subprogram at ast.py:2548>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2548
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Ent.Node);
--# end
--# expr-done 2367
if Fld_1 then
   --# expr-start 2368 '<FieldAccess for base_subp_declarations_impl at ast.py:2549>' Fld /tmp/lal-23.0.0/ada/ast.py:2549
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.base_subp_declarations_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Base_Subp_Declarations_Impl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2368
   If_Result := Fld;
else
   If_Result := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 2369
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2370
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_168;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl_Array_Access,
                        As_Internal_Entity_Basic_Decl_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_168;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Base_Subp_Declarations;
--# end
--# property-start BasicDecl.root_subp_declarations_impl /tmp/lal-23.0.0/ada/ast.py:2555
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Root_Subp_Declarations_Impl
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_169 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl_Array_Access;
Block_Var_1 : Internal_Entity_Basic_Decl;
Block_Var_2 : Boolean;
Block_Var_3 : Internal_Entity_Basic_Decl_Array_Access;
Block_Var_4 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Basic_Decl;
Is_A : Boolean;
Fld_3 : Bare_Basic_Decl;
Cast_Result : Bare_Basic_Decl;
Is_Equal : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Len : Integer;
Comp_Result : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
Fld_4 : Internal_Entity_Info;
Fld_5 : Internal_Metadata;
Fld_6 : Bare_Ada_Node;
Cast_Result_1 : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result_2 : Internal_Entity_Base_Type_Decl;
Map_Result_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Unique_Array : Internal_Entity_Base_Type_Decl_Array_Access;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Is_Equiv : Boolean;
Not_Val_1 : Boolean;
Fld_7 : Boolean;
If_Result_3 : Boolean;
Quantifier_Result : Boolean;
Not_Val_2 : Boolean;
Map_Result_2 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_8 : Internal_Entity_Info;
Fld_9 : Internal_Metadata;
Fld_10 : Bare_Ada_Node;
Fld_11 : Bare_Base_Type_Decl;
Cast_Result_4 : Bare_Ada_Node;
Is_Equal_1 : Boolean;
Find_Result : Internal_Entity_Basic_Decl;
Map_Result_3 : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_169 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Block_Var_4);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Map_Result_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_169;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2401 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2371 '<FieldAccess for base_subp_declarations at ast.py:2564>' Fld /tmp/lal-23.0.0/ada/ast.py:2564
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.base_subp_declarations
Fld := Libadalang.Implementation.Basic_Decl_P_Base_Subp_Declarations (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2371
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind raw_base_decls Block_Var
--# expr-start 2373 '<FieldAccess for parent_basic_decl at ast.py:2573>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2573
--# expr-start 2372 '<FieldAccess for canonical_part at ast.py:2573>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2573
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2372
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_2 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 2373
Block_Var_1 := Fld_2; 
--# bind parent Block_Var_1
--# expr-start 2374 '<IsA ProtectedTypeDecl, TaskTypeDecl at ast.py:2574>' Is_A /tmp/lal-23.0.0/ada/ast.py:2574
Is_A := Block_Var_1.Node /= null 
and then Block_Var_1.Node.Kind in Ada_Protected_Type_Decl_Range | Ada_Task_Type_Decl_Range; 
--# expr-done 2374
Block_Var_2 := Is_A; 
--# bind task_or_protected Block_Var_2
--# expr-start 2380 '<If at ast.py:2575>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2575
if Block_Var_2 then
   --# expr-start 2375 '<length at ast.py:2576>' Len /tmp/lal-23.0.0/ada/ast.py:2576
Len := Length (Block_Var); 
--# expr-done 2375
Comp_Result := Len > 1; 
   If_Result := Comp_Result;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 2379 '<Filter at ast.py:2577>' Map_Result /tmp/lal-23.0.0/ada/ast.py:2577
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var;
      begin
         for Item_102 of
               Collection.Items
         loop
   --# scope-start
               --# bind bd Item_102
         --# expr-start 2378 '<Not at ast.py:2577>' Not_Val /tmp/lal-23.0.0/ada/ast.py:2577
--# expr-start 2377 '<Eq at ast.py:2577>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2577
--# expr-start 2376 '<FieldAccess for node at ast.py:2577>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2577
Fld_3 := Item_102.Node;
--# expr-done 2376
      Cast_Result := Fld_3;
Is_Equal := Cast_Result = Self; 
--# expr-done 2377
Not_Val := not (Is_Equal); 
--# expr-done 2378
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Item_102;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2379
   If_Result_1 := Map_Result;
else
   If_Result_1 := Block_Var;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 2380
Block_Var_3 := If_Result_1; Inc_Ref (Block_Var_3);
--# bind base_decls Block_Var_3
--# expr-start 2387 '<unique at ast.py:2584>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:2584
--# expr-start 2386 '<Map at ast.py:2582>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:2582
      declare
         Map_Result_1_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_3;
      begin
         for Item_103 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_103
      --# expr-start 2385 '<as_bare_entity at ast.py:2583>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:2583
--# expr-start 2384 '<Cast to BaseTypeDecl at ast.py:2583>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:2583
--# expr-start 2383 '<FieldAccess for primitive at ast.py:2583>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2583
--# expr-start 2382 '<FieldAccess for md at ast.py:2583>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2583
--# expr-start 2381 '<FieldAccess for info at ast.py:2583>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2583
Fld_4 := Item_103.Info;
--# expr-done 2381
Fld_5 := Fld_4.Md;
--# expr-done 2382
Fld_6 := Fld_5.Primitive;
--# expr-done 2383
   if Fld_6 = null
      or else Fld_6.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Fld_6;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 2384
Is_Null := Cast_Result_1 = null; 
if Is_Null then
   If_Result_2 := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Cast_Result_1); 
   If_Result_2 := As_Entity;
end if;
--# expr-done 2385
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := If_Result_2;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 2386
Unique_Array := Make_Unique (Map_Result_1); 
--# expr-done 2387
Block_Var_4 := Unique_Array; Inc_Ref (Block_Var_4);
--# bind base_types Block_Var_4
--# expr-start 2400 '<Map at ast.py:2596>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:2596
   --# expr-start 2393 '<Filter at ast.py:2589>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:2589
      declare
         Map_Result_2_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Block_Var_4;
      begin
         for Item_105 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_105
         --# expr-start 2392 '<Not at ast.py:2590>' Not_Val_2 /tmp/lal-23.0.0/ada/ast.py:2590
--# expr-start 2391 '<AnyQuantifier at ast.py:2590>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:2590
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Block_Var_4;
      begin
         for Item_106 of
               Collection.Items
         loop
   --# scope-start
               --# bind u Item_106
--# expr-start 2389 '<Not at ast.py:2592>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:2592
--# expr-start 2388 '<Eq at ast.py:2592>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:2592
Cast_Expr := Item_105; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Item_106; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 2388
Not_Val_1 := not (Is_Equiv); 
--# expr-done 2389
if Not_Val_1 then
   --# expr-start 2390 '<FieldAccess for is_derived_type at ast.py:2593>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2593
      if Item_105.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_derived_type
Fld_7 := Libadalang.Implementation.Base_Type_Decl_P_Is_Derived_Type (Node => Item_105.Node, Other_Type => Item_106, Origin => Origin, E_Info => Item_105.Info);
--# end
--# expr-done 2390
   If_Result_3 := Fld_7;
else
   If_Result_3 := False;
end if;
      Quantifier_Result := If_Result_3;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 2391
Not_Val_2 := not (Quantifier_Result); 
--# expr-done 2392
         if Not_Val_2 then
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Item_105;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 2393
      declare
         Map_Result_3_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Map_Result_2;
      begin
         for Item_104 of
               Collection.Items
         loop
   --# scope-start
               --# bind root_type Item_104
      --# expr-start 2399 '<Find at ast.py:2598>' Find_Result /tmp/lal-23.0.0/ada/ast.py:2598
      Find_Result := No_Entity_Basic_Decl;
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_3;
      begin
         for Item_107 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_107
      --# expr-start 2398 '<Eq at ast.py:2599>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:2599
--# expr-start 2396 '<FieldAccess for primitive at ast.py:2599>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2599
--# expr-start 2395 '<FieldAccess for md at ast.py:2599>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2599
--# expr-start 2394 '<FieldAccess for info at ast.py:2599>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2599
Fld_8 := Item_107.Info;
--# expr-done 2394
Fld_9 := Fld_8.Md;
--# expr-done 2395
Fld_10 := Fld_9.Primitive;
--# expr-done 2396
--# expr-start 2397 '<FieldAccess for node at ast.py:2599>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2599
Fld_11 := Item_104.Node;
--# expr-done 2397
      Cast_Result_4 := Fld_11;
Is_Equal_1 := Fld_10 = Cast_Result_4; 
--# expr-done 2398
      if Is_Equal_1 then
         Find_Result := Item_107;
      end if;
   --# end
               exit when Is_Equal_1;
         end loop;
      end;
--# expr-done 2399
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Find_Result;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_3 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_3_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 2400
Let_Result := Map_Result_3; Inc_Ref (Let_Result);
--# end
--# expr-done 2401
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_169;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_169;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Root_Subp_Declarations_Impl;
--# end
--# property-start BasicDecl.root_subp_declarations /tmp/lal-23.0.0/ada/ast.py:2606
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Root_Subp_Declarations
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_170 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Boolean;
If_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_170 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_170;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2405 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2404 '<If at ast.py:2620>' If_Result /tmp/lal-23.0.0/ada/ast.py:2620
--# expr-start 2402 '<FieldAccess for is_subprogram at ast.py:2621>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2621
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Ent.Node);
--# end
--# expr-done 2402
if Fld_1 then
   --# expr-start 2403 '<FieldAccess for root_subp_declarations_impl at ast.py:2622>' Fld /tmp/lal-23.0.0/ada/ast.py:2622
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.root_subp_declarations_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Root_Subp_Declarations_Impl (Node => Ent.Node, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2403
   If_Result := Fld;
else
   If_Result := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 2404
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2405
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_170;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_170;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Root_Subp_Declarations;
--# end
--# property-start BasicDecl.find_all_overrides /tmp/lal-23.0.0/ada/ast.py:2628
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Find_All_Overrides
  (Node : Bare_Basic_Decl
      ; Units : Internal_Unit_Array_Access
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind units Units
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_172 with Inline_Always;
            procedure Finalizer_Scope_2111 with Inline_Always;
            procedure Finalizer_Scope_2112 with Inline_Always;
      Block_Var : Internal_Entity_Base_Subp_Spec;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Block_Var_2 : Internal_Entity_Type_Decl_Array_Access;
Var_Expr : Internal_Entity_Base_Subp_Spec;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Prims : Internal_Entity_Basic_Decl_Array_Access;
Base_P : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Type_Decl_Array_Access;
Scope_Result_1 : Internal_Entity_Type_Decl_Array_Access;
Result_Var_1 : Internal_Entity_Type_Decl_Array_Access;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Fld_5 : Bare_Basic_Decl;
Cast_Result_1 : Bare_Basic_Decl;
Is_Equal : Boolean;
Find_Result : Internal_Entity_Basic_Decl;
Fld_6 : Internal_Entity_Info;
Fld_7 : Internal_Metadata;
Fld_8 : Bare_Ada_Node;
Fld_9 : Bare_Type_Decl;
Cast_Result_2 : Bare_Ada_Node;
Is_Equal_1 : Boolean;
Fld_10 : Internal_Entity_Base_Subp_Spec;
Fld_11 : Internal_Entity_Base_Subp_Spec;
Fld_12 : Boolean;
If_Result : Boolean;
Map_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
Fld_13 : Internal_Entity_Basic_Decl;
Fld_14 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Map_Result_2 : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
Map_Result_3 : Internal_Entity_Basic_Decl_Array_Access;
Unique_Array : Internal_Entity_Basic_Decl_Array_Access;
Let_Result_2 : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_172 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Map_Result_3);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_172;
            procedure Finalizer_Scope_2111 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2111;
            procedure Finalizer_Scope_2112 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Prims);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_2112;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2434 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 2406 '<FieldAccess for subp_spec_or_null at ast.py:2634>' Fld /tmp/lal-23.0.0/ada/ast.py:2634
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2406
Block_Var := Fld; 
--# bind spec Block_Var
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 2407 '<FieldAccess for candidate_primitive_subp_tagged_type at ast.py:2638>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2638
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_tagged_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Tagged_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2407
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Block_Var_1 := Result_Var; 
--# bind prim_type Block_Var_1
Var_Expr_1 := Block_Var_1;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 2408 '<FieldAccess for find_all_derived_types at ast.py:2640>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2640
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.find_all_derived_types
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Find_All_Derived_Types (Node => Var_Expr_1.Node, Units => Units, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2408
Scope_Result_1 := Fld_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2111;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Block_Var_2 := Result_Var_1; Inc_Ref (Block_Var_2);
--# bind derivations Block_Var_2
--# expr-start 2433 '<unique at ast.py:2672>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:2672
--# expr-start 2432 '<Mapcat at ast.py:2642>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:2642
      declare
         Map_Result_3_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Type_Decl_Array_Access := Block_Var_2;
      begin
         for Item_108 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_108
      --# expr-start 2431 '<Let at ast.py:2643>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:2643
--# scope-start
--# expr-start 2413 '<Map at ast.py:2645>' Map_Result /tmp/lal-23.0.0/ada/ast.py:2645
   --# expr-start 2411 '<EnvGet at ast.py:2645>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:2645
--# expr-start 2409 '<FieldAccess for primitives_env at ast.py:2645>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2645
      if Item_108.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Item_108.Node, E_Info => Item_108.Info);
--# end
--# expr-done 2409
--# expr-start 2410 '<FieldAccess for name_symbol at ast.py:2645>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2645
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2410
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_3, Key => Fld_4, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 2411
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_109 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_109
      --# expr-start 2412 '<Cast to BasicDecl at ast.py:2646>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2646
Cast_Expr := Item_109; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 2412
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2413
Prims := Map_Result; Inc_Ref (Prims);
--# bind prims Prims
--# expr-start 2430 '<Let at ast.py:2647>' Let_Result /tmp/lal-23.0.0/ada/ast.py:2647
--# scope-start
--# expr-start 2416 '<Find at ast.py:2650>' Find_Result /tmp/lal-23.0.0/ada/ast.py:2650
      Find_Result := No_Entity_Basic_Decl;
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Prims;
      begin
         for Item_110 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_110
      --# expr-start 2415 '<Eq at ast.py:2650>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2650
--# expr-start 2414 '<FieldAccess for node at ast.py:2650>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2650
Fld_5 := Item_110.Node;
--# expr-done 2414
      Cast_Result_1 := Fld_5;
Is_Equal := Cast_Result_1 = Self; 
--# expr-done 2415
      if Is_Equal then
         Find_Result := Item_110;
      end if;
   --# end
               exit when Is_Equal;
         end loop;
      end;
--# expr-done 2416
Base_P := Find_Result; 
--# bind base_p Base_P
--# expr-start 2429 '<Map at ast.py:2666>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:2666
   --# expr-start 2425 '<Filter at ast.py:2652>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:2652
      declare
         Map_Result_1_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Prims;
      begin
         for Item_112 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_112
--# expr-start 2421 '<Eq at ast.py:2658>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:2658
--# expr-start 2419 '<FieldAccess for primitive at ast.py:2658>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2658
--# expr-start 2418 '<FieldAccess for md at ast.py:2658>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2658
--# expr-start 2417 '<FieldAccess for info at ast.py:2658>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2658
Fld_6 := Item_112.Info;
--# expr-done 2417
Fld_7 := Fld_6.Md;
--# expr-done 2418
Fld_8 := Fld_7.Primitive;
--# expr-done 2419
--# expr-start 2420 '<FieldAccess for node at ast.py:2658>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2658
Fld_9 := Item_108.Node;
--# expr-done 2420
      Cast_Result_2 := Fld_9;
Is_Equal_1 := Fld_8 = Cast_Result_2; 
--# expr-done 2421
if Is_Equal_1 then
   --# expr-start 2424 '<FieldAccess for match_signature at ast.py:2661>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:2661
--# expr-start 2422 '<FieldAccess for subp_spec_or_null at ast.py:2661>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2661
      if Base_P.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Base_P.Node, E_Info => Base_P.Info);
--# end
--# expr-done 2422
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2423 '<FieldAccess for subp_spec_or_null at ast.py:2662>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2662
      if Item_112.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Item_112.Node, E_Info => Item_112.Info);
--# end
--# expr-done 2423
--# property-call-start BaseSubpSpec.match_signature
Fld_12 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld_10.Node, Other => Fld_11, Match_Name => False, Use_Entity_Info => True, E_Info => Fld_10.Info);
--# end
--# expr-done 2424
   If_Result := Fld_12;
else
   If_Result := False;
end if;
         if If_Result then
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Item_112;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 2425
      declare
         Map_Result_2_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Map_Result_1;
      begin
         for Item_111 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_111
      --# expr-start 2428 '<Cast to BasicDecl at ast.py:2668>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:2668
--# expr-start 2427 '<FieldAccess for without_md at ast.py:2668>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:2668
--# expr-start 2426 '<FieldAccess for canonical_part at ast.py:2668>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:2668
      if Item_111.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld_13 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Item_111.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Item_111.Info);
--# end
--# expr-done 2426
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.without_md
Fld_14 := Libadalang.Implementation.Ada_Node_P_Without_Md (Node => Fld_13.Node, E_Info => Fld_13.Info);
--# end
--# expr-done 2427
   if Fld_14.Node = null
      or else Fld_14.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_14.Node,
         Info => Fld_14.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 2428
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result_3;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 2429
Let_Result := Map_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 2430
Let_Result_1 := Let_Result; Inc_Ref (Let_Result_1);
--# end
--# expr-done 2431
         for Item_To_Append of
               Let_Result_1.Items
         loop
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2112;
         end loop;
      end;
         Map_Result_3 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_3_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 2432
Unique_Array := Make_Unique (Map_Result_3); 
--# expr-done 2433
Let_Result_2 := Unique_Array; Inc_Ref (Let_Result_2);
--# end
--# expr-done 2434
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_172;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_172;
               Finalizer_Scope_2111;
               Finalizer_Scope_2112;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Find_All_Overrides;
--# end
--# property-start '[dispatcher]BasicDecl.defining_names' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Defining_Names
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl =>
                  --# property-call-start AbstractStateDecl.defining_names
                  Property_Result := Abstract_State_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Expr_Decl =>
                  --# property-call-start AnonymousExprDecl.defining_names
                  Property_Result := Anonymous_Expr_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.defining_names
                  Property_Result := Component_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discriminant_Spec =>
                  --# property-call-start DiscriminantSpec.defining_names
                  Property_Result := Discriminant_Spec_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Formal_Obj_Decl .. Ada_Generic_Formal_Type_Decl =>
                  --# property-call-start GenericFormal.defining_names
                  Property_Result := Generic_Formal_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.defining_names
                  Property_Result := Param_Spec_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start SyntheticFormalParamDecl.defining_names
                  Property_Result := Synthetic_Formal_Param_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Internal .. Ada_Package_Decl =>
                  --# property-call-start BasePackageDecl.defining_names
                  Property_Result := Base_Package_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.defining_names
                  Property_Result := Base_Type_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Subp_Decl | Ada_Subp_Decl | Ada_Generic_Subp_Internal .. Ada_Synthetic_Subp_Decl =>
                  --# property-call-start BasicSubpDecl.defining_names
                  Property_Result := Basic_Subp_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Formal_Subp_Decl .. Ada_Concrete_Formal_Subp_Decl =>
                  --# property-call-start FormalSubpDecl.defining_names
                  Property_Result := Formal_Subp_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Decl =>
                  --# property-call-start EntryDecl.defining_names
                  Property_Result := Entry_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Literal_Decl =>
                  --# property-call-start EnumLiteralDecl.defining_names
                  Property_Result := Enum_Literal_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Char_Enum_Lit =>
                  --# property-call-start SyntheticCharEnumLit.defining_names
                  Property_Result := Synthetic_Char_Enum_Lit_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
                  --# property-call-start BaseSubpBody.defining_names
                  Property_Result := Base_Subp_Body_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Package_Body_Stub =>
                  --# property-call-start PackageBodyStub.defining_names
                  Property_Result := Package_Body_Stub_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Body_Stub =>
                  --# property-call-start ProtectedBodyStub.defining_names
                  Property_Result := Protected_Body_Stub_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Body_Stub =>
                  --# property-call-start SubpBodyStub.defining_names
                  Property_Result := Subp_Body_Stub_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Task_Body_Stub =>
                  --# property-call-start TaskBodyStub.defining_names
                  Property_Result := Task_Body_Stub_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Body =>
                  --# property-call-start EntryBody.defining_names
                  Property_Result := Entry_Body_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Package_Body =>
                  --# property-call-start PackageBody.defining_names
                  Property_Result := Package_Body_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Body =>
                  --# property-call-start ProtectedBody.defining_names
                  Property_Result := Protected_Body_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Task_Body =>
                  --# property-call-start TaskBody.defining_names
                  Property_Result := Task_Body_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Index_Spec =>
                  --# property-call-start EntryIndexSpec.defining_names
                  Property_Result := Entry_Index_Spec_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Error_Decl =>
                  --# property-call-start ErrorDecl.defining_names
                  Property_Result := Error_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Decl =>
                  --# property-call-start ExceptionDecl.defining_names
                  Property_Result := Exception_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Handler =>
                  --# property-call-start ExceptionHandler.defining_names
                  Property_Result := Exception_Handler_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Var_Decl =>
                  --# property-call-start ForLoopVarDecl.defining_names
                  Property_Result := For_Loop_Var_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Decl =>
                  --# property-call-start GenericPackageDecl.defining_names
                  Property_Result := Generic_Package_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Decl =>
                  --# property-call-start GenericSubpDecl.defining_names
                  Property_Result := Generic_Subp_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Instantiation =>
                  --# property-call-start GenericPackageInstantiation.defining_names
                  Property_Result := Generic_Package_Instantiation_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericSubpInstantiation.defining_names
                  Property_Result := Generic_Subp_Instantiation_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Renaming_Decl =>
                  --# property-call-start GenericPackageRenamingDecl.defining_names
                  Property_Result := Generic_Package_Renaming_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Renaming_Decl =>
                  --# property-call-start GenericSubpRenamingDecl.defining_names
                  Property_Result := Generic_Subp_Renaming_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Label_Decl =>
                  --# property-call-start LabelDecl.defining_names
                  Property_Result := Label_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Named_Stmt_Decl =>
                  --# property-call-start NamedStmtDecl.defining_names
                  Property_Result := Named_Stmt_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Number_Decl =>
                  --# property-call-start NumberDecl.defining_names
                  Property_Result := Number_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.defining_names
                  Property_Result := Object_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Package_Renaming_Decl =>
                  --# property-call-start PackageRenamingDecl.defining_names
                  Property_Result := Package_Renaming_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Single_Protected_Decl =>
                  --# property-call-start SingleProtectedDecl.defining_names
                  Property_Result := Single_Protected_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Single_Task_Decl =>
                  --# property-call-start SingleTaskDecl.defining_names
                  Property_Result := Single_Task_Decl_P_Defining_Names
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Defining_Names;
--# end
--# property-start BasicDecl.defining_name /tmp/lal-23.0.0/ada/ast.py:2683
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Defining_Name
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_174 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_174 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_174;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2436 '<at at ast.py:2684>' Get_Result /tmp/lal-23.0.0/ada/ast.py:2684
--# expr-start 2435 '<FieldAccess for defining_names at ast.py:2684>' Fld /tmp/lal-23.0.0/ada/ast.py:2684
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2435
Get_Result := Get (Self, Fld, 0, True); 
--# expr-done 2436
      Property_Result := Get_Result;
   --# end
      Finalizer_Scope_174;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_174;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Defining_Name;
--# end
--# property-start '[dispatcher]BasicDecl.defining_env' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Defining_Env
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl | Ada_Generic_Formal_Obj_Decl .. Ada_Generic_Formal_Type_Decl | Ada_Synthetic_Formal_Param_Decl | Ada_Package_Body_Stub .. Ada_Entry_Body | Ada_Protected_Body .. Ada_Task_Body | Ada_Error_Decl .. Ada_Exception_Handler | Ada_Generic_Subp_Decl | Ada_Generic_Subp_Renaming_Decl .. Ada_Label_Decl | Ada_Number_Decl =>
                  --# property-call-start BasicDecl.defining_env
                  Property_Result := Basic_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Expr_Decl =>
                  --# property-call-start AnonymousExprDecl.defining_env
                  Property_Result := Anonymous_Expr_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.defining_env
                  Property_Result := Component_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Discriminant_Spec =>
                  --# property-call-start DiscriminantSpec.defining_env
                  Property_Result := Discriminant_Spec_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.defining_env
                  Property_Result := Param_Spec_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Internal .. Ada_Package_Decl =>
                  --# property-call-start BasePackageDecl.defining_env
                  Property_Result := Base_Package_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.defining_env
                  Property_Result := Base_Subtype_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.defining_env
                  Property_Result := Classwide_Type_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
                  --# property-call-start IncompleteTypeDecl.defining_env
                  Property_Result := Incomplete_Type_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.defining_env
                  Property_Result := Protected_Type_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.defining_env
                  Property_Result := Task_Type_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.defining_env
                  Property_Result := Type_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl =>
                  --# property-call-start BasicSubpDecl.defining_env
                  Property_Result := Basic_Subp_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
                  --# property-call-start BaseSubpBody.defining_env
                  Property_Result := Base_Subp_Body_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Package_Body =>
                  --# property-call-start PackageBody.defining_env
                  Property_Result := Package_Body_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Index_Spec =>
                  --# property-call-start EntryIndexSpec.defining_env
                  Property_Result := Entry_Index_Spec_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Var_Decl =>
                  --# property-call-start ForLoopVarDecl.defining_env
                  Property_Result := For_Loop_Var_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Decl =>
                  --# property-call-start GenericPackageDecl.defining_env
                  Property_Result := Generic_Package_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Instantiation =>
                  --# property-call-start GenericPackageInstantiation.defining_env
                  Property_Result := Generic_Package_Instantiation_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericSubpInstantiation.defining_env
                  Property_Result := Generic_Subp_Instantiation_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Renaming_Decl =>
                  --# property-call-start GenericPackageRenamingDecl.defining_env
                  Property_Result := Generic_Package_Renaming_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Named_Stmt_Decl =>
                  --# property-call-start NamedStmtDecl.defining_env
                  Property_Result := Named_Stmt_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.defining_env
                  Property_Result := Object_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Package_Renaming_Decl =>
                  --# property-call-start PackageRenamingDecl.defining_env
                  Property_Result := Package_Renaming_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Single_Protected_Decl =>
                  --# property-call-start SingleProtectedDecl.defining_env
                  Property_Result := Single_Protected_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
               when Ada_Single_Task_Decl =>
                  --# property-call-start SingleTaskDecl.defining_env
                  Property_Result := Single_Task_Decl_P_Defining_Env
                    (Self
                        , Origin
                        , Include_Ud_Indexing
                        , Dottable_Type
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Defining_Env;
--# end
--# property-start BasicDecl.defining_name_or_raise /tmp/lal-23.0.0/ada/ast.py:2702
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Defining_Name_Or_Raise
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_176 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Len : Integer;
Comp_Result : Boolean;
If_Result : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_176 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_176;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2441 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2437 '<FieldAccess for defining_names at ast.py:2707>' Fld /tmp/lal-23.0.0/ada/ast.py:2707
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2437
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind dns Block_Var
--# expr-start 2440 '<If at ast.py:2708>' If_Result /tmp/lal-23.0.0/ada/ast.py:2708
--# expr-start 2438 '<length at ast.py:2709>' Len /tmp/lal-23.0.0/ada/ast.py:2709
Len := Length (Block_Var); 
--# expr-done 2438
Comp_Result := Len > 1; 
if Comp_Result then
   If_Result := raise Property_Error with "BasicDecl with multiple defining names";
else
   --# expr-start 2439 '<at at ast.py:2712>' Get_Result /tmp/lal-23.0.0/ada/ast.py:2712
Get_Result := Get (Self, Block_Var, 0, True); 
--# expr-done 2439
   If_Result := Get_Result;
end if;
--# expr-done 2440
Let_Result := If_Result; 
--# end
--# expr-done 2441
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_176;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_176;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Defining_Name_Or_Raise;
--# end
--# property-start BasicDecl.identity_type /tmp/lal-23.0.0/ada/ast.py:2716
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Identity_Type
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Exception_Decl;
Match_1 : Internal_Entity_Single_Task_Decl;
Match_2 : Internal_Entity_Object_Decl;
Match_3 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Exception_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Single_Task_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Object_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Let_Result_4 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2446 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 2445 '<Match at ast.py:2717>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2717
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Exception_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Exception_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind _ Match_0
--# expr-start 2442 '<FieldAccess for exc_id_type at ast.py:2718>' Fld /tmp/lal-23.0.0/ada/ast.py:2718
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.exc_id_type
Fld := Libadalang.Implementation.Ada_Node_P_Exc_Id_Type (Node => Self);
--# end
--# expr-done 2442
Let_Result := Fld; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Single_Task_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
--# expr-start 2443 '<FieldAccess for task_id_type at ast.py:2719>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2719
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.task_id_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Task_Id_Type (Node => Self);
--# end
--# expr-done 2443
Let_Result_1 := Fld_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Object_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
--# expr-start 2444 '<FieldAccess for task_id_type at ast.py:2723>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2723
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.task_id_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Task_Id_Type (Node => Self);
--# end
--# expr-done 2444
Let_Result_2 := Fld_2; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Abstract_State_Decl .. Ada_Error_Decl | Ada_Exception_Handler .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Protected_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_3; 
--# bind _ Match_3
Let_Result_3 := No_Entity_Base_Type_Decl; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 2445
Let_Result_4 := Match_Result; 
--# end
--# expr-done 2446
      Property_Result := Let_Result_4;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Identity_Type;
--# end
--# property-start '[dispatcher]BasicDecl.array_ndims' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Array_Ndims
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Discriminant_Spec .. Ada_Package_Decl | Ada_Abstract_Subp_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.array_ndims
                  Property_Result := Basic_Decl_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.array_ndims
                  Property_Result := Component_Decl_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.array_ndims
                  Property_Result := Base_Type_Decl_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.array_ndims
                  Property_Result := Base_Subtype_Decl_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.array_ndims
                  Property_Result := Type_Decl_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Array_Ndims;
--# end
--# property-start BasicDecl.is_array /tmp/lal-23.0.0/ada/ast.py:2731
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Array
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Integer;
Comp_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2447 '<FieldAccess for array_ndims at ast.py:2731>' Fld /tmp/lal-23.0.0/ada/ast.py:2731
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 2447
Comp_Result := Fld > 0; 
      Property_Result := Comp_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Array;
--# end
--# property-start '[dispatcher]BasicDecl.expr_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Expr_Type
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Package_Decl | Ada_Package_Body_Stub .. Ada_Task_Body | Ada_Error_Decl .. Ada_Exception_Decl | Ada_Generic_Package_Decl .. Ada_Generic_Package_Instantiation | Ada_Generic_Package_Renaming_Decl .. Ada_Named_Stmt_Decl | Ada_Object_Decl .. Ada_Single_Protected_Decl =>
                  --# property-call-start BasicDecl.expr_type
                  Property_Result := Basic_Decl_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.expr_type
                  Property_Result := Base_Type_Decl_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl =>
                  --# property-call-start BasicSubpDecl.expr_type
                  Property_Result := Basic_Subp_Decl_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
                  --# property-call-start BaseSubpBody.expr_type
                  Property_Result := Base_Subp_Body_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Index_Spec =>
                  --# property-call-start EntryIndexSpec.expr_type
                  Property_Result := Entry_Index_Spec_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Handler =>
                  --# property-call-start ExceptionHandler.expr_type
                  Property_Result := Exception_Handler_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Var_Decl =>
                  --# property-call-start ForLoopVarDecl.expr_type
                  Property_Result := For_Loop_Var_Decl_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericSubpInstantiation.expr_type
                  Property_Result := Generic_Subp_Instantiation_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Number_Decl =>
                  --# property-call-start NumberDecl.expr_type
                  Property_Result := Number_Decl_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Single_Task_Decl =>
                  --# property-call-start SingleTaskDecl.expr_type
                  Property_Result := Single_Task_Decl_P_Expr_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Expr_Type;
--# end
--# property-start '[dispatcher]BasicDecl.type_expression' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Type_Expression
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Generic_Package_Internal .. Ada_Formal_Type_Decl | Ada_Package_Body_Stub .. Ada_Protected_Body_Stub | Ada_Task_Body_Stub .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.type_expression
                  Property_Result := Basic_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_State_Decl =>
                  --# property-call-start AbstractStateDecl.type_expression
                  Property_Result := Abstract_State_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Expr_Decl =>
                  --# property-call-start AnonymousExprDecl.type_expression
                  Property_Result := Anonymous_Expr_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.type_expression
                  Property_Result := Component_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discriminant_Spec =>
                  --# property-call-start DiscriminantSpec.type_expression
                  Property_Result := Discriminant_Spec_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Formal_Obj_Decl .. Ada_Generic_Formal_Type_Decl =>
                  --# property-call-start GenericFormal.type_expression
                  Property_Result := Generic_Formal_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.type_expression
                  Property_Result := Param_Spec_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start SyntheticFormalParamDecl.type_expression
                  Property_Result := Synthetic_Formal_Param_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl =>
                  --# property-call-start BasicSubpDecl.type_expression
                  Property_Result := Basic_Subp_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
                  --# property-call-start BaseSubpBody.type_expression
                  Property_Result := Base_Subp_Body_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Body_Stub =>
                  --# property-call-start SubpBodyStub.type_expression
                  Property_Result := Subp_Body_Stub_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.type_expression
                  Property_Result := Object_Decl_P_Type_Expression
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Type_Expression;
--# end
--# property-start BasicDecl.subp_spec_or_null /tmp/lal-23.0.0/ada/ast.py:2768
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Subp_Spec_Or_Null
  (Node : Bare_Basic_Decl
      ; Follow_Generic : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind follow_generic Follow_Generic
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Match_0 : Internal_Entity_Basic_Subp_Decl;
Match_1 : Internal_Entity_Base_Subp_Body;
Match_2 : Internal_Entity_Subp_Body_Stub;
Match_3 : Internal_Entity_Generic_Subp_Decl;
Match_4 : Internal_Entity_Generic_Subp_Instantiation;
Match_5 : Internal_Entity_Generic_Subp_Renaming_Decl;
Match_6 : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Basic_Subp_Decl;
Var_Expr_1 : Internal_Entity_Generic_Decl;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Subp_Spec;
Fld_2 : Internal_Entity_Subp_Spec;
Fld_3 : Internal_Entity_Generic_Subp_Internal;
Fld_4 : Internal_Entity_Subp_Spec;
If_Result : Internal_Entity_Subp_Spec;
Fld_5 : Internal_Entity_Basic_Subp_Decl;
Fld_6 : Internal_Entity_Base_Subp_Spec;
Scope_Result : Internal_Entity_Base_Subp_Spec;
Result_Var : Internal_Entity_Base_Subp_Spec;
Cast_Expr : Internal_Entity_Subp_Spec;
Cast_Result : Internal_Entity_Base_Subp_Spec;
If_Result_1 : Internal_Entity_Base_Subp_Spec;
Fld_7 : Internal_Entity_Generic_Decl;
Fld_8 : Internal_Entity_Base_Subp_Spec;
Scope_Result_1 : Internal_Entity_Base_Subp_Spec;
Result_Var_1 : Internal_Entity_Base_Subp_Spec;
Cast_Expr_1 : Internal_Entity_Subp_Spec;
Cast_Result_1 : Internal_Entity_Base_Subp_Spec;
If_Result_2 : Internal_Entity_Base_Subp_Spec;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Basic_Subp_Decl;
Let_Result : Internal_Entity_Base_Subp_Spec;
Scope_Result_2 : Internal_Entity_Base_Subp_Spec;
Cast_Result_3 : Internal_Entity_Base_Subp_Body;
Cast_Result_4 : Internal_Entity_Base_Subp_Spec;
Let_Result_1 : Internal_Entity_Base_Subp_Spec;
Scope_Result_3 : Internal_Entity_Base_Subp_Spec;
Cast_Result_5 : Internal_Entity_Subp_Body_Stub;
Cast_Result_6 : Internal_Entity_Base_Subp_Spec;
Let_Result_2 : Internal_Entity_Base_Subp_Spec;
Scope_Result_4 : Internal_Entity_Base_Subp_Spec;
Cast_Result_7 : Internal_Entity_Generic_Subp_Decl;
Cast_Result_8 : Internal_Entity_Base_Subp_Spec;
Let_Result_3 : Internal_Entity_Base_Subp_Spec;
Scope_Result_5 : Internal_Entity_Base_Subp_Spec;
Cast_Result_9 : Internal_Entity_Generic_Subp_Instantiation;
Let_Result_4 : Internal_Entity_Base_Subp_Spec;
Scope_Result_6 : Internal_Entity_Base_Subp_Spec;
Cast_Result_10 : Internal_Entity_Generic_Subp_Renaming_Decl;
Let_Result_5 : Internal_Entity_Base_Subp_Spec;
Scope_Result_7 : Internal_Entity_Base_Subp_Spec;
Cast_Result_11 : Internal_Entity_Basic_Decl;
Cast_Expr_2 : Internal_Entity_Subp_Spec;
Cast_Result_12 : Internal_Entity_Base_Subp_Spec;
Let_Result_6 : Internal_Entity_Base_Subp_Spec;
Scope_Result_8 : Internal_Entity_Base_Subp_Spec;
Match_Result : Internal_Entity_Base_Subp_Spec;
Let_Result_7 : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2461 '<Block at ???>' Let_Result_7 None
--# scope-start
--# expr-start 2460 '<Match at ast.py:2775>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2775
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Basic_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind subp Match_0
--# expr-start 2448 '<FieldAccess for subp_decl_spec at ast.py:2776>' Fld /tmp/lal-23.0.0/ada/ast.py:2776
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 2448
Let_Result := Fld; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Base_Subp_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind subp Match_1
--# expr-start 2449 '<FieldAccess for subp_spec at ast.py:2777>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2777
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Subp_Spec (Node => Match_1.Node.Base_Subp_Body_F_Subp_Spec, Info => Match_1.Info);
--# expr-done 2449
      Cast_Result_4 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Let_Result_1 := Cast_Result_4; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Subp_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Subp_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_5; 
--# bind subp Match_2
--# expr-start 2450 '<FieldAccess for subp_spec at ast.py:2778>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2778
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Subp_Spec (Node => Match_2.Node.Subp_Body_Stub_F_Subp_Spec, Info => Match_2.Info);
--# expr-done 2450
      Cast_Result_6 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Let_Result_2 := Cast_Result_6; 
--# end
Scope_Result_4 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Generic_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Generic_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_7; 
--# bind gsp Match_3
--# expr-start 2453 '<If at ast.py:2780>' If_Result /tmp/lal-23.0.0/ada/ast.py:2780
if Follow_Generic then
   --# expr-start 2452 '<FieldAccess for subp_spec at ast.py:2780>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2780
--# expr-start 2451 '<FieldAccess for subp_decl at ast.py:2780>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2780
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Generic_Subp_Internal (Node => Match_3.Node.Generic_Subp_Decl_F_Subp_Decl, Info => Match_3.Info);
--# expr-done 2451
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Subp_Spec (Node => Fld_3.Node.Generic_Subp_Internal_F_Subp_Spec, Info => Fld_3.Info);
--# expr-done 2452
   If_Result := Fld_4;
else
   If_Result := No_Entity_Subp_Spec;
end if;
--# expr-done 2453
      Cast_Result_8 := Create_Internal_Entity_Base_Subp_Spec
        (Node => If_Result.Node,
         Info => If_Result.Info);
Let_Result_3 := Cast_Result_8; 
--# end
Scope_Result_5 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Generic_Subp_Instantiation =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Generic_Subp_Instantiation
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_9; 
--# bind gsi Match_4
--# expr-start 2456 '<If at ast.py:2782>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2782
if Follow_Generic then
--# expr-start 2454 '<FieldAccess for designated_subp at ast.py:2783>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2783
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericSubpInstantiation.designated_subp
Fld_5 := Libadalang.Implementation.Generic_Subp_Instantiation_P_Designated_Subp (Node => Match_4.Node, E_Info => Match_4.Info);
--# end
--# expr-done 2454
Var_Expr := Fld_5;
if Var_Expr /= No_Entity_Basic_Subp_Decl then
   --# scope-start
--# expr-start 2455 '<FieldAccess for subp_spec_or_null at ast.py:2783>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2783
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2455
Scope_Result := Fld_6;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Subp_Spec;
end if;
   If_Result_1 := Result_Var;
else
Cast_Expr := No_Entity_Subp_Spec; 
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   If_Result_1 := Cast_Result;
end if;
--# expr-done 2456
Let_Result_4 := If_Result_1; 
--# end
Scope_Result_6 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Generic_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity_Generic_Subp_Renaming_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_10; 
--# bind gsr Match_5
--# expr-start 2459 '<If at ast.py:2786>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:2786
if Follow_Generic then
--# expr-start 2457 '<FieldAccess for resolve at ast.py:2787>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2787
      if Match_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericRenamingDecl.resolve
Fld_7 := Libadalang.Implementation.Generic_Renaming_Decl_P_Resolve (Node => Match_5.Node, E_Info => Match_5.Info);
--# end
--# expr-done 2457
Var_Expr_1 := Fld_7;
if Var_Expr_1 /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 2458 '<FieldAccess for subp_spec_or_null at ast.py:2787>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2787
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2458
Scope_Result_1 := Fld_8;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Subp_Spec;
end if;
   If_Result_2 := Result_Var_1;
else
Cast_Expr_1 := No_Entity_Subp_Spec; 
      Cast_Result_1 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   If_Result_2 := Cast_Result_1;
end if;
--# expr-done 2459
Let_Result_5 := If_Result_2; 
--# end
Scope_Result_7 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Abstract_State_Decl .. Ada_Formal_Type_Decl | Ada_Package_Body_Stub .. Ada_Protected_Body_Stub | Ada_Task_Body_Stub .. Ada_Generic_Package_Decl | Ada_Generic_Package_Instantiation | Ada_Generic_Package_Renaming_Decl | Ada_Label_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_6 := Cast_Result_11; 
--# bind _ Match_6
Cast_Expr_2 := No_Entity_Subp_Spec; 
      Cast_Result_12 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Let_Result_6 := Cast_Result_12; 
--# end
Scope_Result_8 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_8; 
end case;
--# expr-done 2460
Let_Result_7 := Match_Result; 
--# end
--# expr-done 2461
      Property_Result := Let_Result_7;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Subp_Spec_Or_Null;
--# end
--# property-start BasicDecl.formal_param_holder_or_null /tmp/lal-23.0.0/ada/ast.py:2793
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Formal_Param_Holder_Or_Null
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Holder
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Holder;
      Match_0 : Internal_Entity_Type_Decl;
Match_1 : Internal_Entity_Entry_Body;
Match_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Discriminant_Part;
Fld_1 : Internal_Entity_Entry_Completion_Formal_Params;
Fld_2 : Internal_Entity_Base_Subp_Spec;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Let_Result : Internal_Entity_Base_Formal_Param_Holder;
Scope_Result : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result_2 : Internal_Entity_Entry_Body;
Cast_Result_3 : Internal_Entity_Base_Formal_Param_Holder;
Let_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Scope_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result_4 : Internal_Entity_Basic_Decl;
Cast_Result_5 : Internal_Entity_Base_Formal_Param_Holder;
Let_Result_2 : Internal_Entity_Base_Formal_Param_Holder;
Scope_Result_2 : Internal_Entity_Base_Formal_Param_Holder;
Match_Result : Internal_Entity_Base_Formal_Param_Holder;
Let_Result_3 : Internal_Entity_Base_Formal_Param_Holder;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2466 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 2465 '<Match at ast.py:2794>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2794
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind t Match_0
--# expr-start 2462 '<FieldAccess for discriminants at ast.py:2795>' Fld /tmp/lal-23.0.0/ada/ast.py:2795
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Discriminant_Part (Node => Match_0.Node.Type_Decl_F_Discriminants, Info => Match_0.Info);
--# expr-done 2462
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld.Node,
         Info => Fld.Info);
Let_Result := Cast_Result_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Entry_Body =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Entry_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind e Match_1
--# expr-start 2463 '<FieldAccess for params at ast.py:2796>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2796
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Entry_Completion_Formal_Params (Node => Match_1.Node.Entry_Body_F_Params, Info => Match_1.Info);
--# expr-done 2463
      Cast_Result_3 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Let_Result_1 := Cast_Result_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Single_Task_Type_Decl | Ada_Abstract_Subp_Decl .. Ada_Task_Body_Stub | Ada_Package_Body .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
--# expr-start 2464 '<FieldAccess for subp_spec_or_null at ast.py:2797>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2797
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2464
      Cast_Result_5 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Let_Result_2 := Cast_Result_5; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 2465
Let_Result_3 := Match_Result; 
--# end
--# expr-done 2466
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Formal_Param_Holder_Or_Null;
--# end
--# property-start BasicDecl.is_subprogram /tmp/lal-23.0.0/ada/ast.py:2801
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Subprogram
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2468 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2467 '<IsA BasicSubpDecl, BaseSubpBody, SubpBodyStub, EntryDecl, GenericSubpDecl, GenericSubpInstantiation, GenericSubpRenamingDecl at ast.py:2811>' Is_A /tmp/lal-23.0.0/ada/ast.py:2811
Is_A := Self /= null 
and then Self.Kind in Ada_Basic_Subp_Decl | Ada_Base_Subp_Body | Ada_Subp_Body_Stub_Range | Ada_Entry_Decl_Range | Ada_Generic_Subp_Decl_Range | Ada_Generic_Subp_Instantiation_Range | Ada_Generic_Subp_Renaming_Decl_Range; 
--# expr-done 2467
Let_Result := Is_A; 
--# end
--# expr-done 2468
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Subprogram;
--# end
--# property-start BasicDecl.is_valid_reducer_candidate /tmp/lal-23.0.0/ada/ast.py:2816
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Valid_Reducer_Candidate
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
            procedure Finalizer_Scope_2144 with Inline_Always;
      Var_Expr : Boolean;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Param_Types : Internal_Entity_Base_Type_Decl_Array_Access;
Return_Type : Internal_Entity_Base_Type_Decl;
Param_Modes : Internal_Entity_Mode_Array_Access;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Subp_Spec;
Fld_2 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_3 : Internal_Entity_Base_Type_Decl;
Len : Integer;
Is_Equal : Boolean;
Fld_4 : Internal_Entity_Mode_Array_Access;
Get_Result : Internal_Entity_Mode;
Is_A : Boolean;
Get_Result_1 : Internal_Entity_Mode;
Is_A_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
Get_Result_2 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Is_Null : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Let_Result_2 : Boolean;
            procedure Finalizer_Scope_2144 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Param_Types);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Param_Modes);
            end Finalizer_Scope_2144;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2486 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 2469 '<FieldAccess for is_subprogram at ast.py:2823>' Fld /tmp/lal-23.0.0/ada/ast.py:2823
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Ent.Node);
--# end
--# expr-done 2469
Var_Expr := Fld;
if Var_Expr /= False then
   --# scope-start
   --# bind _ Var_Expr
--# expr-start 2470 '<FieldAccess for subp_spec_or_null at ast.py:2824>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2824
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2470
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr_1
--# expr-start 2485 '<Let at ast.py:2825>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:2825
--# scope-start
--# expr-start 2471 '<FieldAccess for param_types at ast.py:2826>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2826
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.param_types
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Param_Types (Node => Var_Expr_1.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2471
Param_Types := Fld_2; Inc_Ref (Param_Types);
--# bind param_types Param_Types
--# expr-start 2472 '<FieldAccess for return_type at ast.py:2827>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2827
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_3 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr_1.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2472
Return_Type := Fld_3; 
--# bind return_type Return_Type
--# expr-start 2474 '<Eq at ast.py:2831>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2831
--# expr-start 2473 '<length at ast.py:2831>' Len /tmp/lal-23.0.0/ada/ast.py:2831
Len := Length (Param_Types); 
--# expr-done 2473
Is_Equal := Len = 2; 
--# expr-done 2474
if Is_Equal then
   --# expr-start 2484 '<If at ast.py:2833>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2833
--# expr-start 2475 '<IsNull at ast.py:2834>' Is_Null /tmp/lal-23.0.0/ada/ast.py:2834
Is_Null := Return_Type.Node = null; 
--# expr-done 2475
if Is_Null then
   --# expr-start 2481 '<Let at ast.py:2837>' Let_Result /tmp/lal-23.0.0/ada/ast.py:2837
--# scope-start
--# expr-start 2476 '<FieldAccess for param_modes at ast.py:2838>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2838
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.param_modes
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Param_Modes (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2476
Param_Modes := Fld_4; Inc_Ref (Param_Modes);
--# bind param_modes Param_Modes
--# expr-start 2478 '<IsA Mode.InOut at ast.py:2839>' Is_A /tmp/lal-23.0.0/ada/ast.py:2839
--# expr-start 2477 '<at at ast.py:2839>' Get_Result /tmp/lal-23.0.0/ada/ast.py:2839
Get_Result := Get (Self, Param_Modes, 0, True); 
--# expr-done 2477
Is_A := Get_Result.Node /= null 
and then Get_Result.Node.Kind in Ada_Mode_In_Out_Range; 
--# expr-done 2478
if Is_A then
   --# expr-start 2480 '<IsA Mode.In, Mode.Default at ast.py:2840>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:2840
--# expr-start 2479 '<at at ast.py:2840>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:2840
Get_Result_1 := Get (Self, Param_Modes, 1, True); 
--# expr-done 2479
Is_A_1 := Get_Result_1.Node /= null 
and then Get_Result_1.Node.Kind in Ada_Mode_In_Range | Ada_Mode_Default_Range; 
--# expr-done 2480
   If_Result := Is_A_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 2481
   If_Result_1 := Let_Result;
else
   --# expr-start 2483 '<Eq at ast.py:2845>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:2845
Cast_Expr := Return_Type; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 2482 '<at at ast.py:2845>' Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:2845
Get_Result_2 := Get (Self, Param_Types, 0, True); 
--# expr-done 2482
      Cast_Result_1 := Create_Internal_Entity
        (Node => Get_Result_2.Node,
         Info => Get_Result_2.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 2483
   If_Result_1 := Is_Equiv;
end if;
--# expr-done 2484
   If_Result_2 := If_Result_1;
else
   If_Result_2 := False;
end if;
Let_Result_1 := If_Result_2; 
--# end
--# expr-done 2485
Scope_Result := Let_Result_1;
   --# end
      Finalizer_Scope_2144;
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Let_Result_2 := Result_Var_1; 
--# end
--# expr-done 2486
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2144;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Valid_Reducer_Candidate;
--# end
--# property-start BasicDecl.is_stream_subprogram_for_type /tmp/lal-23.0.0/ada/ast.py:2853
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Stream_Subprogram_For_Type
  (Node : Bare_Basic_Decl
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Return_Obj : Boolean
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind return_obj Return_Obj
   Property_Result : Boolean;
            procedure Finalizer_Scope_186 with Inline_Always;
            procedure Finalizer_Scope_2145 with Inline_Always;
            procedure Finalizer_Scope_2146 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Var_Expr : Bare_Basic_Decl;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Classwide_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Subp_Spec;
Fld_4 : Internal_Entity_Defining_Name_Array_Access;
Scope_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Result_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Fld_5 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_6 : Boolean;
Get_Result : Internal_Entity_Defining_Name;
Fld_7 : Internal_Entity_Base_Formal_Param_Decl;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Boolean;
If_Result : Boolean;
Fld_10 : Internal_Entity_Base_Subp_Spec;
Fld_11 : Internal_Entity_Base_Type_Decl;
Fld_12 : Boolean;
Get_Result_1 : Internal_Entity_Defining_Name;
Fld_13 : Internal_Entity_Base_Formal_Param_Decl;
Fld_14 : Internal_Entity_Base_Type_Decl;
Fld_15 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_186 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Block_Var_1);
            end Finalizer_Scope_186;
            procedure Finalizer_Scope_2145 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2145;
            procedure Finalizer_Scope_2146 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2146;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2514 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2496 '<Cast to BaseTypeDecl at ast.py:2860>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:2860
--# expr-start 2495 '<FieldAccess for classwide_type at ast.py:2860>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2860
--# expr-start 2494 '<Cast to BaseTypeDecl at ast.py:2860>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2860
--# expr-start 2493 '<EnvGet at ast.py:2856>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:2856
--# expr-start 2490 '<FieldAccess for get_unit_root_decl at ast.py:2857>' Fld /tmp/lal-23.0.0/ada/ast.py:2857
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2489 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 2487 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 2487
--# expr-start 2488 '<Symbol Streams at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Streams); 
--# expr-done 2488
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 2489
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 2490
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 2491 '<FieldAccess for children_env at ast.py:2858>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2858
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 2491
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2145;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 2492 '<Symbol Root_Stream_Type at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Stream_Type); 
--# expr-done 2492
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 2493
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 2494
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 2495
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# expr-done 2496
Block_Var := Cast_Result_1; 
--# bind root_stream_type Block_Var
--# expr-start 2497 '<FieldAccess for subp_spec_or_null at ast.py:2862>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2862
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2497
Var_Expr_1 := Fld_3;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 2498 '<FieldAccess for unpacked_formal_params at ast.py:2862>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2862
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2498
Scope_Result_1 := Fld_4;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2146;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Block_Var_1 := Result_Var_1; Inc_Ref (Block_Var_1);
--# bind params Block_Var_1
--# expr-start 2513 '<bind at ast.py:2864>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:2864
--# expr-start 2499 '<FieldAccess for origin_node at ast.py:2865>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2865
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_5 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 2499
Bound_Origin := Fld_5; 
--# expr-start 2500 '<FieldAccess for is_subprogram at ast.py:2866>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2866
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Self);
--# end
--# expr-done 2500
if Fld_6 then
   --# expr-start 2504 '<FieldAccess for is_access_to at ast.py:2868>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2868
--# expr-start 2503 '<FieldAccess for formal_type at ast.py:2867>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2867
--# expr-start 2502 '<FieldAccess for formal_decl at ast.py:2867>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2867
--# expr-start 2501 '<at at ast.py:2867>' Get_Result /tmp/lal-23.0.0/ada/ast.py:2867
Get_Result := Get (Self, Block_Var_1, 0, True); 
--# expr-done 2501
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_7 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 2502
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_8 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_7.Node, Origin => Bound_Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 2503
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_access_to
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Is_Access_To (Node => Fld_8.Node, Typ => Block_Var, Origin => Bound_Origin, E_Info => Fld_8.Info);
--# end
--# expr-done 2504
   If_Result := Fld_9;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 2512 '<If at ast.py:2869>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2869
if Return_Obj then
   --# expr-start 2507 '<FieldAccess for matching_formal_type at ast.py:2871>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:2871
--# expr-start 2506 '<FieldAccess for return_type at ast.py:2871>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2871
--# expr-start 2505 '<FieldAccess for subp_spec_or_null at ast.py:2871>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2871
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2505
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_11 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld_10.Node, Origin => Bound_Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 2506
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_12 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Fld_11.Node, Formal_Type => Typ, Origin => Bound_Origin, E_Info => Fld_11.Info);
--# end
--# expr-done 2507
   If_Result_1 := Fld_12;
else
   --# expr-start 2511 '<FieldAccess for matching_formal_type at ast.py:2872>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:2872
--# expr-start 2510 '<FieldAccess for formal_type at ast.py:2872>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:2872
--# expr-start 2509 '<FieldAccess for formal_decl at ast.py:2872>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:2872
--# expr-start 2508 '<at at ast.py:2872>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:2872
Get_Result_1 := Get (Self, Block_Var_1, 1, True); 
--# expr-done 2508
      if Get_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_13 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result_1.Node, E_Info => Get_Result_1.Info);
--# end
--# expr-done 2509
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_14 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_13.Node, Origin => Bound_Origin, E_Info => Fld_13.Info);
--# end
--# expr-done 2510
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_15 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Fld_14.Node, Formal_Type => Typ, Origin => Bound_Origin, E_Info => Fld_14.Info);
--# end
--# expr-done 2511
   If_Result_1 := Fld_15;
end if;
--# expr-done 2512
   If_Result_2 := If_Result_1;
else
   If_Result_2 := False;
end if;
Dyn_Var_Bind_Result := If_Result_2; 
--# expr-done 2513
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 2514
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_186;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_186;
               Finalizer_Scope_2145;
               Finalizer_Scope_2146;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Stream_Subprogram_For_Type;
--# end
--# property-start BasicDecl.is_put_image_subprogram_for_type /tmp/lal-23.0.0/ada/ast.py:2877
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Put_Image_Subprogram_For_Type
  (Node : Bare_Basic_Decl
      ; Typ : Internal_Entity_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   Property_Result : Boolean;
            procedure Finalizer_Scope_187 with Inline_Always;
            procedure Finalizer_Scope_2147 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Classwide_Type_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Subp_Spec;
Fld_3 : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Fld_4 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_5 : Boolean;
Get_Result : Internal_Entity_Defining_Name;
Fld_6 : Internal_Entity_Base_Formal_Param_Decl;
Fld_7 : Internal_Entity_Base_Type_Decl;
Fld_8 : Boolean;
If_Result : Boolean;
Get_Result_1 : Internal_Entity_Defining_Name;
Fld_9 : Internal_Entity_Base_Formal_Param_Decl;
Fld_10 : Internal_Entity_Base_Type_Decl;
Fld_11 : Boolean;
If_Result_1 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_187 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Block_Var_1);
            end Finalizer_Scope_187;
            procedure Finalizer_Scope_2147 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2147;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2531 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2517 '<Cast to BaseTypeDecl at ast.py:2883>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2883
--# expr-start 2516 '<FieldAccess for classwide_type at ast.py:2883>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2883
--# expr-start 2515 '<FieldAccess for root_buffer_type at ast.py:2883>' Fld /tmp/lal-23.0.0/ada/ast.py:2883
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_buffer_type
Fld := Libadalang.Implementation.Ada_Node_P_Root_Buffer_Type (Node => Self);
--# end
--# expr-done 2515
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 2516
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
--# expr-done 2517
Block_Var := Cast_Result; 
--# bind root_buffer_type Block_Var
--# expr-start 2518 '<FieldAccess for subp_spec_or_null at ast.py:2885>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2885
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2518
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 2519 '<FieldAccess for unpacked_formal_params at ast.py:2885>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2885
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2519
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2147;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
Block_Var_1 := Result_Var; Inc_Ref (Block_Var_1);
--# bind params Block_Var_1
--# expr-start 2530 '<bind at ast.py:2887>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:2887
--# expr-start 2520 '<FieldAccess for origin_node at ast.py:2888>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2888
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_4 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 2520
Bound_Origin := Fld_4; 
--# expr-start 2521 '<FieldAccess for is_subprogram at ast.py:2889>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2889
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Self);
--# end
--# expr-done 2521
if Fld_5 then
   --# expr-start 2525 '<FieldAccess for matching_formal_type at ast.py:2892>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:2892
--# expr-start 2524 '<FieldAccess for formal_type at ast.py:2891>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:2891
--# expr-start 2523 '<FieldAccess for formal_decl at ast.py:2891>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2891
--# expr-start 2522 '<at at ast.py:2891>' Get_Result /tmp/lal-23.0.0/ada/ast.py:2891
Get_Result := Get (Self, Block_Var_1, 0, True); 
--# expr-done 2522
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_6 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 2523
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_7 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_6.Node, Origin => Bound_Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 2524
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_8 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Fld_7.Node, Formal_Type => Block_Var, Origin => Bound_Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 2525
   If_Result := Fld_8;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 2529 '<FieldAccess for matching_formal_type at ast.py:2895>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:2895
--# expr-start 2528 '<FieldAccess for formal_type at ast.py:2894>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:2894
--# expr-start 2527 '<FieldAccess for formal_decl at ast.py:2894>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:2894
--# expr-start 2526 '<at at ast.py:2894>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:2894
Get_Result_1 := Get (Self, Block_Var_1, 1, True); 
--# expr-done 2526
      if Get_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_9 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result_1.Node, E_Info => Get_Result_1.Info);
--# end
--# expr-done 2527
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_10 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_9.Node, Origin => Bound_Origin, E_Info => Fld_9.Info);
--# end
--# expr-done 2528
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_11 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Fld_10.Node, Formal_Type => Typ, Origin => Bound_Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 2529
   If_Result_1 := Fld_11;
else
   If_Result_1 := False;
end if;
Dyn_Var_Bind_Result := If_Result_1; 
--# expr-done 2530
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 2531
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_187;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_187;
               Finalizer_Scope_2147;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Put_Image_Subprogram_For_Type;
--# end
--# property-start BasicDecl.can_be_paramless /tmp/lal-23.0.0/ada/ast.py:2899
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Can_Be_Paramless
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Info;
Fld_2 : Internal_Metadata;
Fld_3 : Boolean;
Fld_4 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2537 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2532 '<FieldAccess for subp_spec_or_null at ast.py:2904>' Fld /tmp/lal-23.0.0/ada/ast.py:2904
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2532
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr
--# expr-start 2536 '<FieldAccess for paramless at ast.py:2905>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2905
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2535 '<FieldAccess for dottable_subp at ast.py:2906>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2906
--# expr-start 2534 '<FieldAccess for md at ast.py:2906>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2906
--# expr-start 2533 '<FieldAccess for info at ast.py:2906>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2906
Fld_1 := Ent.Info;
--# expr-done 2533
Fld_2 := Fld_1.Md;
--# expr-done 2534
Fld_3 := Fld_2.Dottable_Subp;
--# expr-done 2535
--# property-call-start BaseFormalParamHolder.paramless
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Paramless (Node => Var_Expr.Node, Dottable_Subp => Fld_3, Can_Be => True);
--# end
--# expr-done 2536
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2537
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Can_Be_Paramless;
--# end
--# property-start BasicDecl.is_paramless /tmp/lal-23.0.0/ada/ast.py:2912
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Paramless
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Info;
Fld_2 : Internal_Metadata;
Fld_3 : Boolean;
Fld_4 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2543 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2538 '<FieldAccess for subp_spec_or_null at ast.py:2917>' Fld /tmp/lal-23.0.0/ada/ast.py:2917
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2538
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr
--# expr-start 2542 '<FieldAccess for paramless at ast.py:2918>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2918
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2541 '<FieldAccess for dottable_subp at ast.py:2919>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2919
--# expr-start 2540 '<FieldAccess for md at ast.py:2919>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2919
--# expr-start 2539 '<FieldAccess for info at ast.py:2919>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2919
Fld_1 := Ent.Info;
--# expr-done 2539
Fld_2 := Fld_1.Md;
--# expr-done 2540
Fld_3 := Fld_2.Dottable_Subp;
--# expr-done 2541
--# property-call-start BaseFormalParamHolder.paramless
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Paramless (Node => Var_Expr.Node, Dottable_Subp => Fld_3, Can_Be => False);
--# end
--# expr-done 2542
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2543
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Paramless;
--# end
--# property-start '[dispatcher]BasicDecl.constrain_prefix' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Constrain_Prefix
  (Node : Bare_Basic_Decl
      ; Prefix : Bare_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind prefix Prefix
   --# bind origin Origin
   Property_Result : Logic_Equation;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Discriminant_Spec .. Ada_Generic_Formal_Type_Decl | Ada_Synthetic_Formal_Param_Decl .. Ada_Formal_Type_Decl | Ada_Expr_Function .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.constrain_prefix
                  Property_Result := Basic_Decl_P_Constrain_Prefix
                    (Self
                        , Prefix
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.constrain_prefix
                  Property_Result := Component_Decl_P_Constrain_Prefix
                    (Self
                        , Prefix
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.constrain_prefix
                  Property_Result := Param_Spec_P_Constrain_Prefix
                    (Self
                        , Prefix
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl =>
                  --# property-call-start BasicSubpDecl.constrain_prefix
                  Property_Result := Basic_Subp_Decl_P_Constrain_Prefix
                    (Self
                        , Prefix
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Constrain_Prefix;
--# end
--# property-start BasicDecl.relative_name /tmp/lal-23.0.0/ada/ast.py:2951
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Relative_Name
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
Scope_Result : Internal_Entity_Single_Tok_Node;
Result_Var : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
--# expr-start 2544 '<FieldAccess for defining_name at ast.py:2952>' Fld /tmp/lal-23.0.0/ada/ast.py:2952
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2544
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2545 '<FieldAccess for relative_name at ast.py:2952>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2952
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2545
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Single_Tok_Node;
end if;
      Property_Result := Result_Var;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Relative_Name;
--# end
--# property-start BasicDecl.relative_name_text /tmp/lal-23.0.0/ada/ast.py:2958
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Relative_Name_Text
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Symbol_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Symbol_Type;
      Var_Expr : Internal_Entity_Single_Tok_Node;
Fld : Internal_Entity_Single_Tok_Node;
Fld_1 : Bare_Single_Tok_Node;
Sym : Symbol_Type;
Scope_Result : Symbol_Type;
Result_Var : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
--# expr-start 2546 '<FieldAccess for relative_name at ast.py:2959>' Fld /tmp/lal-23.0.0/ada/ast.py:2959
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.relative_name
Fld := Libadalang.Implementation.Basic_Decl_P_Relative_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2546
Var_Expr := Fld;
if Var_Expr /= No_Entity_Single_Tok_Node then
   --# scope-start
--# expr-start 2547 '<GetSymbol at ast.py:2959>' Sym /tmp/lal-23.0.0/ada/ast.py:2959
Fld_1 := Var_Expr.Node; 
Sym := Get_Symbol (Fld_1); 
--# expr-done 2547
Scope_Result := Sym;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := null;
end if;
      Property_Result := Result_Var;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Relative_Name_Text;
--# end
--# property-start BasicDecl.name_symbol /tmp/lal-23.0.0/ada/ast.py:2964
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Name_Symbol
  (Node : Bare_Basic_Decl
  )
   return Symbol_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Single_Tok_Node;
Fld_1 : Bare_Single_Tok_Node;
Sym : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2550 '<GetSymbol at ast.py:2964>' Sym /tmp/lal-23.0.0/ada/ast.py:2964
--# expr-start 2549 '<FieldAccess for relative_name at ast.py:2964>' Fld /tmp/lal-23.0.0/ada/ast.py:2964
--# expr-start 2548 '<as_bare_entity at ast.py:2964>' If_Result /tmp/lal-23.0.0/ada/ast.py:2964
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 2548
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.relative_name
Fld := Libadalang.Implementation.Basic_Decl_P_Relative_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 2549
Fld_1 := Fld.Node; 
Sym := Get_Symbol (Fld_1); 
--# expr-done 2550
      Property_Result := Sym;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Name_Symbol;
--# end
--# property-start BasicDecl.basic_decl_next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:2967
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Basic_Decl_Next_Part_For_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_194 with Inline_Always;
      Block_Var : Internal_Unit;
Match_0 : Bare_Body_Node;
Match_1 : Bare_Basic_Decl;
Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Bare_Compilation_Unit;
Fld_1 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Defining_Name;
Scope_Result : Internal_Entity_Defining_Name;
Result_Var : Internal_Entity_Defining_Name;
Is_A : Boolean;
Is_A_1 : Boolean;
As_Entity_1 : Internal_Entity_Basic_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Sym : Symbol_Type;
Fld_3 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Not_Val : Boolean;
Fld_4 : Internal_Unit;
Scope_Result_1 : Internal_Unit;
Result_Var_1 : Internal_Unit;
Match_Prefix : Bare_Basic_Decl;
Cast_Result : Bare_Body_Node;
Let_Result : Internal_Unit;
Scope_Result_2 : Internal_Unit;
Cast_Result_1 : Bare_Basic_Decl;
Let_Result_1 : Internal_Unit;
Scope_Result_3 : Internal_Unit;
Match_Result : Internal_Unit;
Fld_5 : Lexical_Env := Empty_Env;
Sym_1 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_194 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_194;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2567 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 2562 '<Match at ast.py:2975>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2975
--# expr-start 2552 '<FieldAccess for decl at ast.py:2975>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2975
--# expr-start 2551 '<FieldAccess for enclosing_compilation_unit at ast.py:2975>' Fld /tmp/lal-23.0.0/ada/ast.py:2975
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Self);
--# end
--# expr-done 2551
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Fld);
--# end
--# expr-done 2552
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_1; 
case Ada_Basic_Decl (Match_Prefix.Kind) is
         when Ada_Expr_Function .. Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind _ Match_0
Let_Result := null; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Abstract_State_Decl .. Ada_Synthetic_Subp_Decl | Ada_Entry_Index_Spec .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind b Match_1
--# expr-start 2553 '<as_bare_entity at ast.py:2978>' If_Result /tmp/lal-23.0.0/ada/ast.py:2978
Is_Null := Match_1 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Match_1); 
   If_Result := As_Entity;
end if;
--# expr-done 2553
Var_Expr_1 := If_Result;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 2554 '<FieldAccess for defining_name at ast.py:2978>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:2978
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2554
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Defining_Name;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2561 '<FieldAccess for referenced_unit at ast.py:2978>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2978
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2560 '<Not at ast.py:2980>' Not_Val /tmp/lal-23.0.0/ada/ast.py:2980
--# expr-start 2555 '<IsA BasePackageDecl, GenericPackageDecl, GenericPackageInstantiation, PackageRenamingDecl, SubpRenamingDecl, GenericRenamingDecl at ast.py:2984>' Is_A /tmp/lal-23.0.0/ada/ast.py:2984
Is_A := Match_1 /= null 
and then Match_1.Kind in Ada_Base_Package_Decl | Ada_Generic_Package_Decl_Range | Ada_Generic_Package_Instantiation_Range | Ada_Package_Renaming_Decl_Range | Ada_Subp_Renaming_Decl_Range | Ada_Generic_Renaming_Decl; 
--# expr-done 2555
if Is_A then
   If_Result_3 := True;
else
--# expr-start 2556 '<IsA BasicSubpDecl, GenericSubpDecl at ast.py:2995>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:2995
Is_A_1 := Match_1 /= null 
and then Match_1.Kind in Ada_Basic_Subp_Decl | Ada_Generic_Subp_Decl_Range; 
--# expr-done 2556
if Is_A_1 then
   --# expr-start 2559 '<FieldAccess for has_aspect at ast.py:2996>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:2996
--# expr-start 2557 '<as_entity at ast.py:2996>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:2996
Is_Null_1 := Match_1 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Match_1); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 2557
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2558 '<Symbol Import at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import); 
--# expr-done 2558
--# property-call-start BasicDecl.has_aspect
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => If_Result_1.Node, Name => Sym, Imprecise_Fallback => Imprecise_Fallback, E_Info => If_Result_1.Info);
--# end
--# expr-done 2559
   If_Result_2 := Fld_3;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
Not_Val := not (If_Result_3); 
--# expr-done 2560
--# property-call-start Name.referenced_unit
Fld_4 := Libadalang.Implementation.Name_P_Referenced_Unit (Node => Var_Expr.Node, Kind => Unit_Body, Not_Found_Is_Error => Not_Val);
--# end
--# expr-done 2561
Scope_Result_1 := Fld_4;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := null;
end if;
Let_Result_1 := Result_Var_1; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 2562
Block_Var := Match_Result; 
--# expr-start 2566 '<Cast to BasicDecl at ast.py:3006>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:3006
--# expr-start 2565 '<EnvGet at ast.py:3002>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3002
--# expr-start 2563 '<FieldAccess for children_env at ast.py:3002>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3002
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2563
--# expr-start 2564 '<Symbol __nextpart at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Nextpart); 
--# expr-done 2564
Env_Get_Result := AST_Envs.Get_First (Self => Fld_5, Key => Sym_1, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 2565
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 2566
Let_Result_2 := Cast_Result_2; 
--# end
--# expr-done 2567
      Property_Result := Let_Result_2;
   --# end
      Finalizer_Scope_194;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_194;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Basic_Decl_Next_Part_For_Decl;
--# end
--# property-start '[dispatcher]BasicDecl.next_part_for_decl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Next_Part_For_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Generic_Package_Internal .. Ada_Package_Decl | Ada_Entry_Index_Spec .. Ada_Error_Decl | Ada_Exception_Handler .. Ada_For_Loop_Var_Decl | Ada_Generic_Package_Instantiation .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.next_part_for_decl
                  Property_Result := Basic_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl .. Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start BaseFormalParamDecl.next_part_for_decl
                  Property_Result := Base_Formal_Param_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Incomplete_Tagged_Type_Decl | Ada_Task_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.next_part_for_decl
                  Property_Result := Base_Type_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.next_part_for_decl
                  Property_Result := Protected_Type_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Abstract_Subp_Decl .. Ada_Generic_Subp_Internal =>
                  --# property-call-start BasicSubpDecl.next_part_for_decl
                  Property_Result := Basic_Subp_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Subp_Decl =>
                  --# property-call-start SyntheticSubpDecl.next_part_for_decl
                  Property_Result := Synthetic_Subp_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl | Ada_Entry_Body .. Ada_Task_Body =>
                  --# property-call-start Body.next_part_for_decl
                  Property_Result := Body_Node_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Package_Body_Stub .. Ada_Task_Body_Stub =>
                  --# property-call-start BodyStub.next_part_for_decl
                  Property_Result := Body_Stub_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Decl =>
                  --# property-call-start ExceptionDecl.next_part_for_decl
                  Property_Result := Exception_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Package_Decl =>
                  --# property-call-start GenericDecl.next_part_for_decl
                  Property_Result := Generic_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Decl =>
                  --# property-call-start GenericSubpDecl.next_part_for_decl
                  Property_Result := Generic_Subp_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.next_part_for_decl
                  Property_Result := Object_Decl_P_Next_Part_For_Decl
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Next_Part_For_Decl;
--# end
--# property-start BasicDecl.body_part_for_decl /tmp/lal-23.0.0/ada/ast.py:3021
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Body_Part_For_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Body_Node
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Body_Node;
      Var_Expr : Internal_Entity_Basic_Decl;
Match_0 : Internal_Entity_Body_Stub;
Match_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Body_Stub;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Body_Node;
Let_Result_2 : Internal_Entity_Body_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2572 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 2571 '<Cast to Body at ast.py:3035>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:3035
--# expr-start 2568 '<FieldAccess for next_part_for_decl at ast.py:3030>' Fld /tmp/lal-23.0.0/ada/ast.py:3030
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2568
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind np Var_Expr
--# expr-start 2570 '<Match at ast.py:3031>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3031
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Package_Body_Stub .. Ada_Task_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind stub Match_0
--# expr-start 2569 '<FieldAccess for next_part_for_decl at ast.py:3032>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3032
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Match_0.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_0.Info);
--# end
--# expr-done 2569
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl .. Ada_Subp_Renaming_Decl | Ada_Entry_Body .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind other Match_1
Let_Result_1 := Match_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 2570
Scope_Result_2 := Match_Result;
   --# end
   Result_Var := Scope_Result_2;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Body_Node
   then
      Cast_Result_2 := Create_Internal_Entity_Body_Node
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result_2 := No_Entity_Body_Node;
   end if;
--# expr-done 2571
Let_Result_2 := Cast_Result_2; 
--# end
--# expr-done 2572
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Body_Part_For_Decl;
--# end
--# property-start '[dispatcher]BasicDecl.next_part_for_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Next_Part_For_Name
  (Node : Bare_Basic_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Generic_Package_Internal .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.next_part_for_name
                  Property_Result := Basic_Decl_P_Next_Part_For_Name
                    (Self
                        , Sym
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl .. Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start BaseFormalParamDecl.next_part_for_name
                  Property_Result := Base_Formal_Param_Decl_P_Next_Part_For_Name
                    (Self
                        , Sym
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.next_part_for_name
                  Property_Result := Object_Decl_P_Next_Part_For_Name
                    (Self
                        , Sym
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Next_Part_For_Name;
--# end
--# property-start '[dispatcher]BasicDecl.previous_part_for_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Previous_Part_For_Name
  (Node : Bare_Basic_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Generic_Package_Internal .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.previous_part_for_name
                  Property_Result := Basic_Decl_P_Previous_Part_For_Name
                    (Self
                        , Sym
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl .. Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start BaseFormalParamDecl.previous_part_for_name
                  Property_Result := Base_Formal_Param_Decl_P_Previous_Part_For_Name
                    (Self
                        , Sym
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.previous_part_for_name
                  Property_Result := Object_Decl_P_Previous_Part_For_Name
                    (Self
                        , Sym
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Previous_Part_For_Name;
--# end
--# property-start BasicDecl.canonical_part_for_name /tmp/lal-23.0.0/ada/ast.py:3087
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Canonical_Part_For_Name
  (Node : Bare_Basic_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2575 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2573 '<FieldAccess for previous_part_for_name at ast.py:3092>' Fld /tmp/lal-23.0.0/ada/ast.py:3092
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_name'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Name (Node => Ent.Node, Sym => Sym, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2573
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind pp Var_Expr
--# expr-start 2574 '<FieldAccess for canonical_part_for_name at ast.py:3093>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3093
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part_for_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part_For_Name (Node => Var_Expr.Node, Sym => Sym, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 2574
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := Ent;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2575
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Canonical_Part_For_Name;
--# end
--# property-start BasicDecl.most_visible_part /tmp/lal-23.0.0/ada/ast.py:3098
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Most_Visible_Part
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Defining_Name;
Fld_2 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2579 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2577 '<FieldAccess for most_visible_part at ast.py:3104>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3104
--# expr-start 2576 '<FieldAccess for defining_name_or_raise at ast.py:3104>' Fld /tmp/lal-23.0.0/ada/ast.py:3104
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2576
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.most_visible_part
Fld_1 := Libadalang.Implementation.Defining_Name_P_Most_Visible_Part (Node => Fld.Node, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 2577
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2578 '<FieldAccess for basic_decl at ast.py:3104>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3104
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_2 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2578
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2579
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Most_Visible_Part;
--# end
--# property-start BasicDecl.most_visible_part_for_name /tmp/lal-23.0.0/ada/ast.py:3108
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Most_Visible_Part_For_Name
  (Node : Bare_Basic_Decl
      ; Sym : Symbol_Type
      ; Origin : Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind origin Origin
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_201 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
Is_Null_1 : Boolean;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Boolean;
Fld_3 : Boolean;
If_Result : Boolean;
Not_Val : Boolean;
Fld_4 : Internal_Entity_Basic_Decl;
Fld_5 : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
As_Entity : Internal_Entity;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity;
Fld_6 : Boolean;
Fld_7 : Internal_Entity_Basic_Decl;
If_Result_3 : Internal_Entity_Basic_Decl;
If_Result_4 : Internal_Entity_Basic_Decl;
If_Result_5 : Internal_Entity_Basic_Decl;
If_Result_6 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_201 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_201;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2597 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2580 '<FieldAccess for next_part_for_name at ast.py:3113>' Fld /tmp/lal-23.0.0/ada/ast.py:3113
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_name'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Name (Node => Ent.Node, Sym => Sym, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2580
Block_Var := Fld; 
--# bind np Block_Var
--# expr-start 2596 '<Cond at ast.py:3114>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:3114
--# expr-start 2581 '<IsNull at ast.py:3116>' Is_Null /tmp/lal-23.0.0/ada/ast.py:3116
Is_Null := Block_Var.Node = null; 
--# expr-done 2581
if Is_Null then
   If_Result_6 := Ent;
else
--# expr-start 2582 '<IsNull at ast.py:3120>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:3120
Is_Null_1 := Origin = null; 
--# expr-done 2582
if Is_Null_1 then
   --# expr-start 2583 '<FieldAccess for most_visible_part_for_name at ast.py:3121>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3121
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.most_visible_part_for_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Most_Visible_Part_For_Name (Node => Block_Var.Node, Sym => Sym, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var.Info);
--# end
--# expr-done 2583
   If_Result_5 := Fld_1;
else
--# expr-start 2586 '<Not at ast.py:3125>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3125
--# expr-start 2584 '<FieldAccess for is_in_private_part at ast.py:3125>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3125
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 2584
if Fld_2 then
   If_Result := True;
else
   --# expr-start 2585 '<FieldAccess for is_in_public_part at ast.py:3125>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3125
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_in_public_part
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Is_In_Public_Part (Node => Block_Var.Node);
--# end
--# expr-done 2585
   If_Result := Fld_3;
end if;
Not_Val := not (If_Result); 
--# expr-done 2586
if Not_Val then
   --# expr-start 2592 '<If at ast.py:3126>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3126
--# expr-start 2590 '<Contains at ast.py:3127>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:3127
   --# expr-start 2588 '<EnvGet at ast.py:3127>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3127
--# expr-start 2587 '<FieldAccess for node_env at ast.py:3127>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3127
      if Origin = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Node_Env (Node => Origin);
--# expr-done 2587
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_5, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 2588
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_113 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_113
      --# expr-start 2589 '<Eq at ???>' Is_Equiv None
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Item_113, Cast_Result); 
--# expr-done 2589
      Quantifier_Result := Is_Equiv;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 2590
if Quantifier_Result then
   --# expr-start 2591 '<FieldAccess for most_visible_part_for_name at ast.py:3128>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3128
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.most_visible_part_for_name
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Most_Visible_Part_For_Name (Node => Block_Var.Node, Sym => Sym, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var.Info);
--# end
--# expr-done 2591
   If_Result_1 := Fld_4;
else
   If_Result_1 := Ent;
end if;
--# expr-done 2592
   If_Result_4 := If_Result_1;
else
--# expr-start 2594 '<FieldAccess for is_visible at ast.py:3134>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3134
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2593 '<as_bare_entity at ast.py:3134>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:3134
Is_Null_2 := Origin = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Origin); 
   If_Result_2 := As_Entity;
end if;
--# expr-done 2593
--# property-call-start BasicDecl.is_visible
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Is_Visible (Node => Block_Var.Node, From_Node => If_Result_2, E_Info => Block_Var.Info);
--# end
--# expr-done 2594
if Fld_6 then
   --# expr-start 2595 '<FieldAccess for most_visible_part_for_name at ast.py:3135>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3135
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.most_visible_part_for_name
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Most_Visible_Part_For_Name (Node => Block_Var.Node, Sym => Sym, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var.Info);
--# end
--# expr-done 2595
   If_Result_3 := Fld_7;
else
   If_Result_3 := Ent;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
   If_Result_6 := If_Result_5;
end if;
--# expr-done 2596
Let_Result := If_Result_6; 
--# end
--# expr-done 2597
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_201;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_201;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Most_Visible_Part_For_Name;
--# end
--# property-start BasicDecl.fully_qualified_name_impl /tmp/lal-23.0.0/ada/ast.py:3142
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Fully_Qualified_Name_Impl
  (Node : Bare_Basic_Decl
      ; Include_Profile : Boolean
         := False
      ; Dn : Internal_Entity_Defining_Name
         := No_Entity_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind include_profile Include_Profile
   --# bind dn Dn
   Property_Result : String_Type_Array_Access;
            procedure Finalizer_Scope_203 with Inline_Always;
            procedure Finalizer_Scope_2157 with Inline_Always;
            procedure Finalizer_Scope_2158 with Inline_Always;
            procedure Finalizer_Scope_2159 with Inline_Always;
            procedure Finalizer_Scope_2160 with Inline_Always;
            procedure Finalizer_Scope_2161 with Inline_Always;
            procedure Finalizer_Scope_2162 with Inline_Always;
            procedure Finalizer_Scope_2163 with Inline_Always;
            procedure Finalizer_Scope_2164 with Inline_Always;
            procedure Finalizer_Scope_2165 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : String_Type_Array_Access;
Block_Var_2 : String_Type_Array_Access;
Block_Var_3 : String_Type_Array_Access;
Match_0 : Internal_Entity_Synthetic_Defining_Name;
Match_1 : Internal_Entity_Defining_Name;
Var_Expr : String_Type_Array_Access;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Var_Expr_2 : String_Type_Array_Access;
Var_Expr_3 : Bare_Subunit;
Is_Null : Boolean;
Fld : Internal_Entity_Defining_Name_Array_Access;
Len : Integer;
Comp_Result : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Fld_1 : Internal_Entity_Defining_Name;
Is_Null_1 : Boolean;
If_Result_2 : Internal_Entity_Defining_Name;
Fld_2 : Symbol_Type;
Fld_3 : String_Type;
Array_Lit : String_Type_Array_Access;
Fld_4 : Bare_Single_Tok_Node_Array_Access;
Fld_5 : String_Type;
Map_Result : String_Type_Array_Access;
Match_Prefix : Internal_Entity_Defining_Name;
Cast_Result : Internal_Entity_Synthetic_Defining_Name;
Let_Result : String_Type_Array_Access;
Scope_Result : String_Type_Array_Access;
Cast_Result_1 : Internal_Entity_Defining_Name;
Let_Result_1 : String_Type_Array_Access;
Scope_Result_1 : String_Type_Array_Access;
Match_Result : String_Type_Array_Access;
Fld_6 : String_Type;
Str : String_Type;
If_Result_3 : String_Type;
Concat_Result : String_Type;
Is_A : Boolean;
Str_1 : String_Type;
Is_A_1 : Boolean;
Str_2 : String_Type;
Is_A_2 : Boolean;
Str_3 : String_Type;
Str_4 : String_Type;
If_Result_4 : String_Type;
If_Result_5 : String_Type;
If_Result_6 : String_Type;
Str_5 : String_Type;
Len_1 : Integer;
Arith_Result : Integer;
Is_Equal : Boolean;
If_Result_7 : String_Type;
Concat_Result_1 : String_Type;
Index_116 : Integer;
Map_Result_1 : String_Type_Array_Access;
Fld_7 : Internal_Entity_Basic_Decl;
Fld_8 : String_Type_Array_Access;
Scope_Result_2 : String_Type_Array_Access;
Result_Var : String_Type_Array_Access;
Concat_Result_2 : String_Type_Array_Access;
Is_A_3 : Boolean;
If_Result_8 : String_Type_Array_Access;
Scope_Result_3 : String_Type_Array_Access;
Result_Var_1 : String_Type_Array_Access;
Fld_9 : Boolean;
If_Result_9 : String_Type_Array_Access;
Fld_10 : Bare_Ada_Node;
Cast_Result_2 : Bare_Subunit;
Fld_11 : Bare_Name;
Fld_12 : Bare_Single_Tok_Node_Array_Access;
Scope_Result_4 : Bare_Single_Tok_Node_Array_Access;
Result_Var_2 : Bare_Single_Tok_Node_Array_Access;
Fld_13 : String_Type;
Map_Result_2 : String_Type_Array_Access;
Concat_Result_3 : String_Type_Array_Access;
Scope_Result_5 : String_Type_Array_Access;
Result_Var_3 : String_Type_Array_Access;
Let_Result_2 : String_Type_Array_Access;
            procedure Finalizer_Scope_203 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Concat_Result_3);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_203;
            procedure Finalizer_Scope_2157 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Array_Lit);
            end Finalizer_Scope_2157;
            procedure Finalizer_Scope_2158 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2158;
            procedure Finalizer_Scope_2159 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2159;
            procedure Finalizer_Scope_2160 is
            begin
                     Dec_Ref (Fld_6);
                     Dec_Ref (Str);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Str_1);
                     Dec_Ref (Str_2);
                     Dec_Ref (Str_3);
                     Dec_Ref (Str_4);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (Str_5);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (Concat_Result_1);
            end Finalizer_Scope_2160;
            procedure Finalizer_Scope_2161 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_2161;
            procedure Finalizer_Scope_2162 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Concat_Result_2);
                     Dec_Ref (If_Result_8);
            end Finalizer_Scope_2162;
            procedure Finalizer_Scope_2163 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2163;
            procedure Finalizer_Scope_2164 is
            begin
                     Dec_Ref (Fld_13);
            end Finalizer_Scope_2164;
            procedure Finalizer_Scope_2165 is
            begin
                     Dec_Ref (Var_Expr_2);
            end Finalizer_Scope_2165;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2645 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 2601 '<If at ast.py:3158>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3158
--# expr-start 2598 '<IsNull at ast.py:3159>' Is_Null /tmp/lal-23.0.0/ada/ast.py:3159
Is_Null := Dn.Node = null; 
--# expr-done 2598
if Is_Null then
   --# expr-start 2600 '<length at ast.py:3159>' Len /tmp/lal-23.0.0/ada/ast.py:3159
--# expr-start 2599 '<FieldAccess for defining_names at ast.py:3159>' Fld /tmp/lal-23.0.0/ada/ast.py:3159
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2599
Len := Length (Fld); 
--# expr-done 2600
Comp_Result := Len > 1; 
   If_Result := Comp_Result;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_1 := raise Property_Error with "Can't call on a declaration with several names";
else
   If_Result_1 := False;
end if;
--# expr-done 2601
Block_Var := If_Result_1; 
--# expr-start 2611 '<Match at ast.py:3167>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3167
--# expr-start 2604 '<If at ast.py:3165>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:3165
--# expr-start 2602 '<IsNull at ast.py:3166>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:3166
Is_Null_1 := Dn.Node = null; 
--# expr-done 2602
if Is_Null_1 then
   --# expr-start 2603 '<FieldAccess for defining_name at ast.py:3166>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3166
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2603
   If_Result_2 := Fld_1;
else
   If_Result_2 := Dn;
end if;
--# expr-done 2604
      if If_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := If_Result_2; 
case Ada_Defining_Name_Range (Match_Prefix.Node.Kind) is
         when Ada_Synthetic_Defining_Name =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Synthetic_Defining_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind scel Match_0
--# expr-start 2607 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 2606 '<FieldAccess for image at ast.py:3168>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3168
--# expr-start 2605 '<FieldAccess for name_symbol at ast.py:3168>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3168
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Match_0.Node);
--# end
--# expr-done 2605
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Image (Self => Fld_2);
--# expr-done 2606
Array_Lit := Create_String_Type_Array (Internal_String_Type_Array'(1 => Fld_3)); 
--# expr-done 2607
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2157;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Defining_Name =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Defining_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind n Match_1
--# expr-start 2610 '<Map at ast.py:3169>' Map_Result /tmp/lal-23.0.0/ada/ast.py:3169
   --# expr-start 2608 '<FieldAccess for as_single_tok_node_array at ast.py:3169>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3169
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.as_single_tok_node_array
Fld_4 := Libadalang.Implementation.Name_P_As_Single_Tok_Node_Array (Node => Match_1.Node);
--# end
--# expr-done 2608
      declare
         Map_Result_Vec : String_Type_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Single_Tok_Node_Array_Access := Fld_4;
      begin
         for Item_114 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_114
      --# expr-start 2609 '<FieldAccess for text at ast.py:3169>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3169
      if Item_114 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Text (Node => Item_114);
--# expr-done 2609
         declare
            Item_To_Append : constant String_Type := Fld_5;
         begin
               Inc_Ref (Item_To_Append);
            String_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2159;
         end loop;
      end;
         Map_Result := Create_String_Type_Array
           (Items_Count => Natural (String_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := String_Type_Vectors.Get
              (Map_Result_Vec,
               I + String_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         String_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2610
Let_Result_1 := Map_Result; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2158;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
end case;
--# expr-done 2611
Block_Var_1 := Match_Result; Inc_Ref (Block_Var_1);
--# bind def_name Block_Var_1
--# expr-start 2630 '<Map at ast.py:3172>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:3172
      declare
         Map_Result_1_Vec : String_Type_Vectors.Vector;
      begin
         Index_116 := 0;
      declare
         Collection : constant String_Type_Array_Access := Block_Var_1;
      begin
         for Item_115 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_115
               --# bind i Index_116
      --# expr-start 2629 '<Concat at ast.py:3175>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:3175
--# expr-start 2615 '<Concat at ast.py:3173>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:3173
--# expr-start 2614 '<If at ast.py:3174>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:3174
if Include_Profile then
   --# expr-start 2612 '<FieldAccess for custom_id_text at ast.py:3174>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3174
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.custom_id_text'
Fld_6 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Custom_Id_Text (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2612
   If_Result_3 := Fld_6;
else
   --# expr-start 2613 '<String at ast.py:3174>' Str /tmp/lal-23.0.0/ada/ast.py:3174
Str := Create_String (""); 
--# expr-done 2613
   If_Result_3 := Str;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 2614
Concat_Result := Concat_String (Item_115, If_Result_3); 
--# expr-done 2615
--# expr-start 2628 '<If at ast.py:3175>' If_Result_7 /tmp/lal-23.0.0/ada/ast.py:3175
--# expr-start 2618 '<Eq at ast.py:3176>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:3176
--# expr-start 2617 '<Arithmetic - at ast.py:3176>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:3176
--# expr-start 2616 '<length at ast.py:3176>' Len_1 /tmp/lal-23.0.0/ada/ast.py:3176
Len_1 := Length (Block_Var_1); 
--# expr-done 2616
Arith_Result := (Len_1 - 1); 
--# expr-done 2617
Is_Equal := Index_116 = Arith_Result; 
--# expr-done 2618
if Is_Equal then
   --# expr-start 2626 '<Cond at ast.py:3177>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:3177
--# expr-start 2619 '<IsA ClasswideTypeDecl at ast.py:3177>' Is_A /tmp/lal-23.0.0/ada/ast.py:3177
Is_A := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Classwide_Type_Decl_Range; 
--# expr-done 2619
if Is_A then
   --# expr-start 2620 '<String at ast.py:3177>' Str_1 /tmp/lal-23.0.0/ada/ast.py:3177
Str_1 := Create_String ("'Class"); 
--# expr-done 2620
   If_Result_6 := Str_1;
else
--# expr-start 2621 '<IsA DiscreteBaseSubtypeDecl at ast.py:3178>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:3178
Is_A_1 := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Discrete_Base_Subtype_Decl_Range; 
--# expr-done 2621
if Is_A_1 then
   --# expr-start 2622 '<String at ast.py:3178>' Str_2 /tmp/lal-23.0.0/ada/ast.py:3178
Str_2 := Create_String ("'Base"); 
--# expr-done 2622
   If_Result_5 := Str_2;
else
--# expr-start 2623 '<IsA SynthAnonymousTypeDecl at ast.py:3186>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:3186
Is_A_2 := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Synth_Anonymous_Type_Decl_Range; 
--# expr-done 2623
if Is_A_2 then
   --# expr-start 2624 '<String at ast.py:3187>' Str_3 /tmp/lal-23.0.0/ada/ast.py:3187
Str_3 := Create_String ("'Anonymous_Access"); 
--# expr-done 2624
   If_Result_4 := Str_3;
else
   --# expr-start 2625 '<String at ast.py:3189>' Str_4 /tmp/lal-23.0.0/ada/ast.py:3189
Str_4 := Create_String (""); 
--# expr-done 2625
   If_Result_4 := Str_4;
end if;
      Inc_Ref (If_Result_4);
   If_Result_5 := If_Result_4;
end if;
      Inc_Ref (If_Result_5);
   If_Result_6 := If_Result_5;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 2626
   If_Result_7 := If_Result_6;
else
   --# expr-start 2627 '<String at ast.py:3190>' Str_5 /tmp/lal-23.0.0/ada/ast.py:3190
Str_5 := Create_String (""); 
--# expr-done 2627
   If_Result_7 := Str_5;
end if;
      Inc_Ref (If_Result_7);
--# expr-done 2628
Concat_Result_1 := Concat_String (Concat_Result, If_Result_7); 
--# expr-done 2629
         declare
            Item_To_Append : constant String_Type := Concat_Result_1;
         begin
               Inc_Ref (Item_To_Append);
            String_Type_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2160;
               Index_116 := Index_116 + 1;
         end loop;
      end;
         Map_Result_1 := Create_String_Type_Array
           (Items_Count => Natural (String_Type_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := String_Type_Vectors.Get
              (Map_Result_1_Vec,
               I + String_Type_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         String_Type_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 2630
Block_Var_2 := Map_Result_1; Inc_Ref (Block_Var_2);
--# bind self_name Block_Var_2
--# expr-start 2637 '<If at ast.py:3194>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:3194
--# expr-start 2631 '<FieldAccess for is_compilation_unit_root at ast.py:3195>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:3195
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Ent.Node);
--# end
--# expr-done 2631
if Fld_9 then
   If_Result_9 := Block_Var_2;
else
--# expr-start 2632 '<FieldAccess for parent_basic_decl at ast.py:3198>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3198
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_7 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2632
Var_Expr_1 := Fld_7;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 2633 '<FieldAccess for fully_qualified_name_impl at ast.py:3198>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:3198
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_impl
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Impl (Node => Var_Expr_1.Node, Include_Profile => Include_Profile, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2633
Scope_Result_2 := Fld_8;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2161;
   Result_Var := Scope_Result_2;
else
   Result_Var := No_String_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Var_Expr := Result_Var;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_String_Type_Array_Type then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 2636 '<If at ast.py:3200>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:3200
--# expr-start 2634 '<IsA GenericPackageInternal, GenericSubpInternal at ast.py:3201>' Is_A_3 /tmp/lal-23.0.0/ada/ast.py:3201
Is_A_3 := Self /= null 
and then Self.Kind in Ada_Generic_Package_Internal_Range | Ada_Generic_Subp_Internal_Range; 
--# expr-done 2634
if Is_A_3 then
   If_Result_8 := Var_Expr;
else
   --# expr-start 2635 '<Concat at ast.py:3203>' Concat_Result_2 /tmp/lal-23.0.0/ada/ast.py:3203
Concat_Result_2 := Concat (Var_Expr, Block_Var_2); 
--# expr-done 2635
   If_Result_8 := Concat_Result_2;
end if;
      Inc_Ref (If_Result_8);
--# expr-done 2636
Scope_Result_3 := If_Result_8;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2162;
   Result_Var_1 := Scope_Result_3;
else
   Result_Var_1 := No_String_Type_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
   If_Result_9 := Result_Var_1;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 2637
Block_Var_3 := If_Result_9; Inc_Ref (Block_Var_3);
--# bind fqn Block_Var_3
--# expr-start 2644 '<Concat at ast.py:3209>' Concat_Result_3 /tmp/lal-23.0.0/ada/ast.py:3209
--# expr-start 2643 '<Map at ast.py:3208>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:3208
--# expr-start 2639 '<Cast to Subunit at ast.py:3207>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:3207
--# expr-start 2638 '<parent at ast.py:3207>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:3207
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Parent; 
--# expr-done 2638
   if Fld_10 = null
      or else Fld_10.Kind in Ada_Subunit_Range
   then
      Cast_Result_2 := Fld_10;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 2639
Var_Expr_3 := Cast_Result_2;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 2641 '<FieldAccess for as_single_tok_node_array at ast.py:3208>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:3208
--# expr-start 2640 '<FieldAccess for name at ast.py:3208>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:3208
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Var_Expr_3.Subunit_F_Name;
--# expr-done 2640
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.as_single_tok_node_array
Fld_12 := Libadalang.Implementation.Name_P_As_Single_Tok_Node_Array (Node => Fld_11);
--# end
--# expr-done 2641
Scope_Result_4 := Fld_12;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2163;
   Result_Var_2 := Scope_Result_4;
else
   Result_Var_2 := No_Bare_Single_Tok_Node_Array_Type;
end if;
      Inc_Ref (Result_Var_2);
      declare
         Map_Result_2_Vec : String_Type_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Single_Tok_Node_Array_Access := Result_Var_2;
      begin
         for Item_117 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_117
      --# expr-start 2642 '<FieldAccess for text at ast.py:3209>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:3209
      if Item_117 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Text (Node => Item_117);
--# expr-done 2642
         declare
            Item_To_Append : constant String_Type := Fld_13;
         begin
               Inc_Ref (Item_To_Append);
            String_Type_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2164;
         end loop;
      end;
         Map_Result_2 := Create_String_Type_Array
           (Items_Count => Natural (String_Type_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := String_Type_Vectors.Get
              (Map_Result_2_Vec,
               I + String_Type_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         String_Type_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 2643
Concat_Result_3 := Concat (Map_Result_2, Block_Var_3); 
--# expr-done 2644
Var_Expr_2 := Concat_Result_3;
      Inc_Ref (Var_Expr_2);
if Var_Expr_2 /= No_String_Type_Array_Type then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_5 := Var_Expr_2;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2165;
   Result_Var_3 := Scope_Result_5;
else
   Result_Var_3 := Block_Var_3;
end if;
      Inc_Ref (Result_Var_3);
Let_Result_2 := Result_Var_3; Inc_Ref (Let_Result_2);
--# end
--# expr-done 2645
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_203;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_203;
               Finalizer_Scope_2157;
               Finalizer_Scope_2158;
               Finalizer_Scope_2159;
               Finalizer_Scope_2160;
               Finalizer_Scope_2161;
               Finalizer_Scope_2162;
               Finalizer_Scope_2163;
               Finalizer_Scope_2164;
               Finalizer_Scope_2165;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Fully_Qualified_Name_Impl;
--# end
--# property-start BasicDecl.fully_qualified_name_string_array /tmp/lal-23.0.0/ada/ast.py:3212
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Fully_Qualified_Name_String_Array
  (Node : Bare_Basic_Decl
      ; Include_Profile : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind include_profile Include_Profile
   Property_Result : String_Type_Array_Access;
            procedure Finalizer_Scope_204 with Inline_Always;
      Fld : String_Type_Array_Access;
Let_Result : String_Type_Array_Access;
            procedure Finalizer_Scope_204 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_204;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2647 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2646 '<FieldAccess for fully_qualified_name_impl at ast.py:3217>' Fld /tmp/lal-23.0.0/ada/ast.py:3217
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Impl (Node => Ent.Node, Include_Profile => Include_Profile, E_Info => Ent.Info);
--# end
--# expr-done 2646
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 2647
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_204;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_204;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Fully_Qualified_Name_String_Array;
--# end
--# property-start BasicDecl.fully_qualified_name_array /tmp/lal-23.0.0/ada/ast.py:3222
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Fully_Qualified_Name_Array
  (Node : Bare_Basic_Decl
      ; Include_Profile : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind include_profile Include_Profile
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_205 with Inline_Always;
      Fld : String_Type_Array_Access;
Sym : Symbol_Type;
Map_Result : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_205 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_205;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2651 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2650 '<Map at ast.py:3229>' Map_Result /tmp/lal-23.0.0/ada/ast.py:3229
   --# expr-start 2648 '<FieldAccess for fully_qualified_name_string_array at ast.py:3227>' Fld /tmp/lal-23.0.0/ada/ast.py:3227
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_string_array
Fld := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_String_Array (Node => Ent.Node, Include_Profile => Include_Profile, E_Info => Ent.Info);
--# end
--# expr-done 2648
      declare
         Map_Result_Vec : Symbol_Type_Vectors.Vector;
      begin
      declare
         Collection : constant String_Type_Array_Access := Fld;
      begin
         for Item_118 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_118
      --# expr-start 2649 '<to_symbol at ast.py:3229>' Sym /tmp/lal-23.0.0/ada/ast.py:3229
Sym := String_To_Symbol (Self, Self.Unit.Context, Item_118); 
--# expr-done 2649
         declare
            Item_To_Append : constant Symbol_Type := Sym;
         begin
            Symbol_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Symbol_Type_Array
           (Items_Count => Natural (Symbol_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Symbol_Type_Vectors.Get
              (Map_Result_Vec,
               I + Symbol_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Symbol_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2650
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2651
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_205;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_205;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Fully_Qualified_Name_Array;
--# end
--# property-start BasicDecl.fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:3232
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Fully_Qualified_Name
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_206 with Inline_Always;
      Str : String_Type;
Fld : String_Type_Array_Access;
Join_Result : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_206 is
            begin
                     Dec_Ref (Str);
                     Dec_Ref (Fld);
                     Dec_Ref (Join_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_206;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2655 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2654 '<Join at ast.py:3236>' Join_Result /tmp/lal-23.0.0/ada/ast.py:3236
--# expr-start 2652 '<String at ast.py:3236>' Str /tmp/lal-23.0.0/ada/ast.py:3236
Str := Create_String ("."); 
--# expr-done 2652
--# expr-start 2653 '<FieldAccess for fully_qualified_name_impl at ast.py:3236>' Fld /tmp/lal-23.0.0/ada/ast.py:3236
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Impl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2653
Join_Result := Join_Strings (Str, Fld); 
--# expr-done 2654
Let_Result := Join_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2655
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_206;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_206;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Fully_Qualified_Name;
--# end
--# property-start BasicDecl.canonical_fully_qualified_name_impl /tmp/lal-23.0.0/ada/ast.py:3239
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Canonical_Fully_Qualified_Name_Impl
  (Node : Bare_Basic_Decl
      ; Include_Profile : Boolean
         := False
      ; Dn : Internal_Entity_Defining_Name
         := No_Entity_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind include_profile Include_Profile
   --# bind dn Dn
   Property_Result : String_Type;
            procedure Finalizer_Scope_207 with Inline_Always;
            procedure Finalizer_Scope_2168 with Inline_Always;
      Str : String_Type;
Fld : String_Type_Array_Access;
Sym : Symbol_Type;
Map_Result : Symbol_Type_Array_Access;
Fld_1 : String_Type;
Map_Result_1 : String_Type_Array_Access;
Join_Result : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_207 is
            begin
                     Dec_Ref (Str);
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Join_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_207;
            procedure Finalizer_Scope_2168 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2168;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2663 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2662 '<Join at ast.py:3246>' Join_Result /tmp/lal-23.0.0/ada/ast.py:3246
--# expr-start 2656 '<String at ast.py:3246>' Str /tmp/lal-23.0.0/ada/ast.py:3246
Str := Create_String ("."); 
--# expr-done 2656
--# expr-start 2661 '<Map at ast.py:3251>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:3251
   --# expr-start 2659 '<Map at ast.py:3251>' Map_Result /tmp/lal-23.0.0/ada/ast.py:3251
   --# expr-start 2657 '<FieldAccess for fully_qualified_name_impl at ast.py:3247>' Fld /tmp/lal-23.0.0/ada/ast.py:3247
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Impl (Node => Ent.Node, Include_Profile => Include_Profile, Dn => Dn, E_Info => Ent.Info);
--# end
--# expr-done 2657
      declare
         Map_Result_Vec : Symbol_Type_Vectors.Vector;
      begin
      declare
         Collection : constant String_Type_Array_Access := Fld;
      begin
         for Item_120 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_120
      --# expr-start 2658 '<to_symbol at ast.py:3251>' Sym /tmp/lal-23.0.0/ada/ast.py:3251
Sym := String_To_Symbol (Self, Self.Unit.Context, Item_120); 
--# expr-done 2658
         declare
            Item_To_Append : constant Symbol_Type := Sym;
         begin
            Symbol_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Symbol_Type_Array
           (Items_Count => Natural (Symbol_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Symbol_Type_Vectors.Get
              (Map_Result_Vec,
               I + Symbol_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Symbol_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2659
      declare
         Map_Result_1_Vec : String_Type_Vectors.Vector;
      begin
      declare
         Collection : constant Symbol_Type_Array_Access := Map_Result;
      begin
         for Item_119 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_119
      --# expr-start 2660 '<FieldAccess for image at ast.py:3251>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3251
      if Item_119 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Image (Self => Item_119);
--# expr-done 2660
         declare
            Item_To_Append : constant String_Type := Fld_1;
         begin
               Inc_Ref (Item_To_Append);
            String_Type_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2168;
         end loop;
      end;
         Map_Result_1 := Create_String_Type_Array
           (Items_Count => Natural (String_Type_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := String_Type_Vectors.Get
              (Map_Result_1_Vec,
               I + String_Type_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         String_Type_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 2661
Join_Result := Join_Strings (Str, Map_Result_1); 
--# expr-done 2662
Let_Result := Join_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2663
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_207;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_207;
               Finalizer_Scope_2168;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Canonical_Fully_Qualified_Name_Impl;
--# end
--# property-start BasicDecl.canonical_fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:3255
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Canonical_Fully_Qualified_Name
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_208 with Inline_Always;
      Fld : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_208 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_208;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2665 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2664 '<FieldAccess for canonical_fully_qualified_name_impl at ast.py:3260>' Fld /tmp/lal-23.0.0/ada/ast.py:3260
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_fully_qualified_name_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Canonical_Fully_Qualified_Name_Impl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2664
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 2665
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_208;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_208;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Canonical_Fully_Qualified_Name;
--# end
--# property-start BasicDecl.unique_identifying_name_impl /tmp/lal-23.0.0/ada/ast.py:3263
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Unique_Identifying_Name_Impl
  (Node : Bare_Basic_Decl
      ; Dn : Internal_Entity_Defining_Name
         := No_Entity_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind dn Dn
   Property_Result : String_Type;
            procedure Finalizer_Scope_209 with Inline_Always;
            procedure Finalizer_Scope_2169 with Inline_Always;
            procedure Finalizer_Scope_2170 with Inline_Always;
      Match_0 : Internal_Entity_Anonymous_Type_Decl;
Match_1 : Internal_Entity_Basic_Decl;
Fld : String_Type;
Fld_1 : String_Type;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Anonymous_Type_Decl;
Let_Result : String_Type;
Scope_Result : String_Type;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Let_Result_1 : String_Type;
Scope_Result_1 : String_Type;
Match_Result : String_Type;
Let_Result_2 : String_Type;
            procedure Finalizer_Scope_209 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_209;
            procedure Finalizer_Scope_2169 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_2169;
            procedure Finalizer_Scope_2170 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2170;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2669 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 2668 '<Match at ast.py:3269>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3269
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Synth_Anonymous_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Anonymous_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind _ Match_0
--# expr-start 2666 '<FieldAccess for custom_id_text at ast.py:3270>' Fld /tmp/lal-23.0.0/ada/ast.py:3270
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.custom_id_text'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Custom_Id_Text (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2666
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2169;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Abstract_State_Decl .. Ada_Single_Task_Type_Decl | Ada_Concrete_Type_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
--# expr-start 2667 '<FieldAccess for canonical_fully_qualified_name_impl at ast.py:3271>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3271
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_fully_qualified_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Fully_Qualified_Name_Impl (Node => Ent.Node, Include_Profile => True, Dn => Dn, E_Info => Ent.Info);
--# end
--# expr-done 2667
Let_Result_1 := Fld_1; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2170;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
end case;
--# expr-done 2668
Let_Result_2 := Match_Result; Inc_Ref (Let_Result_2);
--# end
--# expr-done 2669
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_209;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_209;
               Finalizer_Scope_2169;
               Finalizer_Scope_2170;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Unique_Identifying_Name_Impl;
--# end
--# property-start BasicDecl.unique_identifying_name /tmp/lal-23.0.0/ada/ast.py:3277
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Unique_Identifying_Name
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_210 with Inline_Always;
      Fld : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_210 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_210;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2671 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2670 '<FieldAccess for unique_identifying_name_impl at ast.py:3288>' Fld /tmp/lal-23.0.0/ada/ast.py:3288
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.unique_identifying_name_impl
Fld := Libadalang.Implementation.Basic_Decl_P_Unique_Identifying_Name_Impl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2670
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 2671
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_210;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_210;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Unique_Identifying_Name;
--# end
--# property-start BasicDecl.custom_id_text /tmp/lal-23.0.0/ada/ast.py:3291
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Custom_Id_Text
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_211 with Inline_Always;
            procedure Finalizer_Scope_2171 with Inline_Always;
            procedure Finalizer_Scope_2172 with Inline_Always;
            procedure Finalizer_Scope_2173 with Inline_Always;
            procedure Finalizer_Scope_2174 with Inline_Always;
            procedure Finalizer_Scope_2175 with Inline_Always;
            procedure Finalizer_Scope_2176 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Var_Expr_1 : Internal_Entity_Type_Expr;
Var_Expr_2 : Internal_Entity_Defining_Name_Array_Access;
Var_Expr_3 : Internal_Entity_Type_Expr;
Var_Expr_4 : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Base_Subp_Spec;
Str : String_Type;
Fld_1 : Internal_Entity_Type_Expr;
Str_1 : String_Type;
Scope_Result : String_Type;
Result_Var : String_Type;
Fld_2 : Internal_Entity_Defining_Name_Array_Access;
Str_2 : String_Type;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl;
Fld_4 : Internal_Entity_Type_Expr;
Fld_5 : String_Type;
Map_Result : String_Type_Array_Access;
Join_Result : String_Type;
Scope_Result_1 : String_Type;
Result_Var_1 : String_Type;
Fld_6 : Internal_Entity_Type_Expr;
Str_3 : String_Type;
Scope_Result_2 : String_Type;
Result_Var_2 : String_Type;
Concat_Result : String_Type;
Concat_Result_1 : String_Type;
Concat_Result_2 : String_Type;
Fld_7 : Internal_Entity_Type_Expr;
Str_4 : String_Type;
Fld_8 : String_Type;
Concat_Result_3 : String_Type;
Scope_Result_3 : String_Type;
Result_Var_3 : String_Type;
Concat_Result_4 : String_Type;
Str_5 : String_Type;
Concat_Result_5 : String_Type;
Scope_Result_4 : String_Type;
Str_6 : String_Type;
Result_Var_4 : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_211 is
            begin
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Str_6);
                     Dec_Ref (Result_Var_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_211;
            procedure Finalizer_Scope_2171 is
            begin
                     Dec_Ref (Str);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Concat_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Concat_Result_4);
                     Dec_Ref (Str_5);
                     Dec_Ref (Concat_Result_5);
            end Finalizer_Scope_2171;
            procedure Finalizer_Scope_2172 is
            begin
                     Dec_Ref (Str_1);
            end Finalizer_Scope_2172;
            procedure Finalizer_Scope_2173 is
            begin
                     Dec_Ref (Var_Expr_2);
                     Dec_Ref (Str_2);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Join_Result);
            end Finalizer_Scope_2173;
            procedure Finalizer_Scope_2174 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2174;
            procedure Finalizer_Scope_2175 is
            begin
                     Dec_Ref (Str_3);
            end Finalizer_Scope_2175;
            procedure Finalizer_Scope_2176 is
            begin
                     Dec_Ref (Str_4);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Concat_Result_3);
            end Finalizer_Scope_2176;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2696 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2672 '<FieldAccess for subp_spec_or_null at ast.py:3292>' Fld /tmp/lal-23.0.0/ada/ast.py:3292
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2672
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr
--# expr-start 2694 '<Concat at ast.py:3308>' Concat_Result_5 /tmp/lal-23.0.0/ada/ast.py:3308
--# expr-start 2692 '<Concat at ast.py:3306>' Concat_Result_4 /tmp/lal-23.0.0/ada/ast.py:3306
--# expr-start 2687 '<Concat at ast.py:3295>' Concat_Result_2 /tmp/lal-23.0.0/ada/ast.py:3295
--# expr-start 2673 '<String at ast.py:3295>' Str /tmp/lal-23.0.0/ada/ast.py:3295
Str := Create_String ("("); 
--# expr-done 2673
--# expr-start 2686 '<Concat at ast.py:3296>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:3296
--# expr-start 2674 '<FieldAccess for returns at ast.py:3296>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3296
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2674
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity_Type_Expr then
   --# scope-start
   --# bind _ Var_Expr_1
--# expr-start 2675 '<String at ast.py:3296>' Str_1 /tmp/lal-23.0.0/ada/ast.py:3296
Str_1 := Create_String ("("); 
--# expr-done 2675
Scope_Result := Str_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2172;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_String;
end if;
      Inc_Ref (Result_Var);
--# expr-start 2685 '<Concat at ast.py:3304>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:3304
--# expr-start 2676 '<FieldAccess for unpacked_formal_params at ast.py:3297>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3297
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2676
Var_Expr_2 := Fld_2;
      Inc_Ref (Var_Expr_2);
if Var_Expr_2 /= No_Internal_Entity_Defining_Name_Array_Type then
   --# scope-start
   --# bind ufp Var_Expr_2
--# expr-start 2682 '<Join at ast.py:3298>' Join_Result /tmp/lal-23.0.0/ada/ast.py:3298
--# expr-start 2677 '<String at ast.py:3298>' Str_2 /tmp/lal-23.0.0/ada/ast.py:3298
Str_2 := Create_String (", "); 
--# expr-done 2677
--# expr-start 2681 '<Map at ast.py:3299>' Map_Result /tmp/lal-23.0.0/ada/ast.py:3299
      declare
         Map_Result_Vec : String_Type_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Var_Expr_2;
      begin
         for Item_121 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_121
      --# expr-start 2680 '<FieldAccess for custom_id_text at ast.py:3301>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3301
--# expr-start 2679 '<FieldAccess for type_expression at ast.py:3301>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3301
--# expr-start 2678 '<FieldAccess for formal_decl at ast.py:3301>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3301
      if Item_121.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_3 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Item_121.Node, E_Info => Item_121.Info);
--# end
--# expr-done 2678
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# end
--# expr-done 2679
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.custom_id_text'
Fld_5 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Custom_Id_Text (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 2680
         declare
            Item_To_Append : constant String_Type := Fld_5;
         begin
               Inc_Ref (Item_To_Append);
            String_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2174;
         end loop;
      end;
         Map_Result := Create_String_Type_Array
           (Items_Count => Natural (String_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := String_Type_Vectors.Get
              (Map_Result_Vec,
               I + String_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         String_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2681
Join_Result := Join_Strings (Str_2, Map_Result); 
--# expr-done 2682
Scope_Result_1 := Join_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2173;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Empty_String;
end if;
      Inc_Ref (Result_Var_1);
--# expr-start 2683 '<FieldAccess for returns at ast.py:3304>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3304
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2683
Var_Expr_3 := Fld_6;
if Var_Expr_3 /= No_Entity_Type_Expr then
   --# scope-start
   --# bind _ Var_Expr_3
--# expr-start 2684 '<String at ast.py:3304>' Str_3 /tmp/lal-23.0.0/ada/ast.py:3304
Str_3 := Create_String (")"); 
--# expr-done 2684
Scope_Result_2 := Str_3;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2175;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Empty_String;
end if;
      Inc_Ref (Result_Var_2);
Concat_Result := Concat_String (Result_Var_1, Result_Var_2); 
--# expr-done 2685
Concat_Result_1 := Concat_String (Result_Var, Concat_Result); 
--# expr-done 2686
Concat_Result_2 := Concat_String (Str, Concat_Result_1); 
--# expr-done 2687
--# expr-start 2688 '<FieldAccess for returns at ast.py:3306>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3306
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2688
Var_Expr_4 := Fld_7;
if Var_Expr_4 /= No_Entity_Type_Expr then
   --# scope-start
   --# bind r Var_Expr_4
--# expr-start 2691 '<Concat at ast.py:3307>' Concat_Result_3 /tmp/lal-23.0.0/ada/ast.py:3307
--# expr-start 2689 '<String at ast.py:3307>' Str_4 /tmp/lal-23.0.0/ada/ast.py:3307
Str_4 := Create_String (" -> "); 
--# expr-done 2689
--# expr-start 2690 '<FieldAccess for custom_id_text at ast.py:3307>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:3307
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.custom_id_text'
Fld_8 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Custom_Id_Text (Node => Var_Expr_4.Node, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 2690
Concat_Result_3 := Concat_String (Str_4, Fld_8); 
--# expr-done 2691
Scope_Result_3 := Concat_Result_3;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2176;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := Empty_String;
end if;
      Inc_Ref (Result_Var_3);
Concat_Result_4 := Concat_String (Concat_Result_2, Result_Var_3); 
--# expr-done 2692
--# expr-start 2693 '<String at ast.py:3308>' Str_5 /tmp/lal-23.0.0/ada/ast.py:3308
Str_5 := Create_String (")"); 
--# expr-done 2693
Concat_Result_5 := Concat_String (Concat_Result_4, Str_5); 
--# expr-done 2694
Scope_Result_4 := Concat_Result_5;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2171;
   Result_Var_4 := Scope_Result_4;
else
   --# expr-start 2695 '<String at ast.py:3309>' Str_6 /tmp/lal-23.0.0/ada/ast.py:3309
Str_6 := Create_String (""); 
--# expr-done 2695
   Result_Var_4 := Str_6;
end if;
      Inc_Ref (Result_Var_4);
Let_Result := Result_Var_4; Inc_Ref (Let_Result);
--# end
--# expr-done 2696
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_211;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_211;
               Finalizer_Scope_2171;
               Finalizer_Scope_2172;
               Finalizer_Scope_2173;
               Finalizer_Scope_2174;
               Finalizer_Scope_2175;
               Finalizer_Scope_2176;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Custom_Id_Text;
--# end
--# property-start BasicDecl.does_aspects_make_preelaborable /tmp/lal-23.0.0/ada/ast.py:3313
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Does_Aspects_Make_Preelaborable
  (Node : Bare_Basic_Decl
      ; From_Body : Boolean
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind from_body From_Body
   Property_Result : Boolean;
      Bound_Imprecise_Fallback : Boolean;
Sym : Symbol_Type;
Fld : Boolean;
Sym_1 : Symbol_Type;
Fld_1 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Fld_2 : Boolean;
If_Result_1 : Boolean;
Not_Val : Boolean;
Sym_3 : Symbol_Type;
Fld_3 : Boolean;
Sym_4 : Symbol_Type;
Fld_4 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2709 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2708 '<bind at ast.py:3322>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3322
Bound_Imprecise_Fallback := False; 
--# expr-start 2698 '<FieldAccess for has_aspect at ast.py:3324>' Fld /tmp/lal-23.0.0/ada/ast.py:3324
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2697 '<Symbol Pure at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pure); 
--# expr-done 2697
--# property-call-start BasicDecl.has_aspect
Fld := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => Ent.Node, Name => Sym, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2698
if Fld then
   If_Result := True;
else
   --# expr-start 2700 '<FieldAccess for has_aspect at ast.py:3325>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3325
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2699 '<Symbol Preelaborate at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Preelaborate); 
--# expr-done 2699
--# property-call-start BasicDecl.has_aspect
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => Ent.Node, Name => Sym_1, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2700
   If_Result := Fld_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 2702 '<FieldAccess for has_aspect at ast.py:3326>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3326
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2701 '<Symbol Shared_Passive at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Shared_Passive); 
--# expr-done 2701
--# property-call-start BasicDecl.has_aspect
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => Ent.Node, Name => Sym_2, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2702
   If_Result_1 := Fld_2;
end if;
if If_Result_1 then
   If_Result_4 := True;
else
--# expr-start 2703 '<Not at ast.py:3327>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3327
Not_Val := not (From_Body); 
--# expr-done 2703
if Not_Val then
--# expr-start 2705 '<FieldAccess for has_aspect at ast.py:3329>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3329
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2704 '<Symbol Remote_Types at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Remote_Types); 
--# expr-done 2704
--# property-call-start BasicDecl.has_aspect
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => Ent.Node, Name => Sym_3, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2705
if Fld_3 then
   If_Result_2 := True;
else
   --# expr-start 2707 '<FieldAccess for has_aspect at ast.py:3330>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3330
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2706 '<Symbol Remote_Call_Interface at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Remote_Call_Interface); 
--# expr-done 2706
--# property-call-start BasicDecl.has_aspect
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => Ent.Node, Name => Sym_4, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2707
   If_Result_2 := Fld_4;
end if;
   If_Result_3 := If_Result_2;
else
   If_Result_3 := False;
end if;
   If_Result_4 := If_Result_3;
end if;
Dyn_Var_Bind_Result := If_Result_4; 
--# expr-done 2708
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 2709
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Does_Aspects_Make_Preelaborable;
--# end
--# property-start BasicDecl.wrap_public_reference /tmp/lal-23.0.0/ada/ast.py:3335
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Wrap_Public_Reference
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Generic_Instantiation;
Fld : Internal_Entity_Generic_Instantiation;
Scope_Result : Internal_Entity_Generic_Instantiation;
Cast_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Is_A : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2713 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2712 '<If at ast.py:3357>' If_Result /tmp/lal-23.0.0/ada/ast.py:3357
--# expr-start 2710 '<IsA GenericSubpInternal, GenericPackageInternal at ast.py:3358>' Is_A /tmp/lal-23.0.0/ada/ast.py:3358
Is_A := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Generic_Subp_Internal_Range | Ada_Generic_Package_Internal_Range; 
--# expr-done 2710
if Is_A then
--# expr-start 2711 '<FieldAccess for get_instantiation at ast.py:3359>' Fld /tmp/lal-23.0.0/ada/ast.py:3359
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.get_instantiation
Fld := Libadalang.Implementation.Basic_Decl_P_Get_Instantiation (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2711
Var_Expr := Fld;
if Var_Expr /= No_Entity_Generic_Instantiation then
   --# scope-start
   --# bind e Var_Expr
Scope_Result := Var_Expr;
   --# end
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Scope_Result.Node,
         Info => Scope_Result.Info);
   Result_Var := Cast_Result;
else
   Result_Var := Ent;
end if;
   If_Result := Result_Var;
else
   If_Result := Ent;
end if;
--# expr-done 2712
Let_Result := If_Result; 
--# end
--# expr-done 2713
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Wrap_Public_Reference;
--# end
--# property-start '[dispatcher]BasicDecl.is_constant_object' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Decl_P_Is_Constant_Object
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Decl (Self.Kind) is
               when Ada_Abstract_State_Decl .. Ada_Anonymous_Expr_Decl | Ada_Generic_Formal_Obj_Decl .. Ada_Generic_Formal_Type_Decl | Ada_Synthetic_Formal_Param_Decl .. Ada_Concrete_Formal_Subp_Decl | Ada_Entry_Decl | Ada_Generic_Subp_Internal .. Ada_Synthetic_Subp_Decl | Ada_Package_Body_Stub .. Ada_Exception_Decl | Ada_Generic_Package_Decl .. Ada_Named_Stmt_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
                  --# property-call-start BasicDecl.is_constant_object
                  Property_Result := Basic_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Component_Decl =>
                  --# property-call-start ComponentDecl.is_constant_object
                  Property_Result := Component_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discriminant_Spec =>
                  --# property-call-start DiscriminantSpec.is_constant_object
                  Property_Result := Discriminant_Spec_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.is_constant_object
                  Property_Result := Param_Spec_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subp_Decl =>
                  --# property-call-start SubpDecl.is_constant_object
                  Property_Result := Subp_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Literal_Decl .. Ada_Synthetic_Char_Enum_Lit =>
                  --# property-call-start EnumLiteralDecl.is_constant_object
                  Property_Result := Enum_Literal_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
                  --# property-call-start BaseSubpBody.is_constant_object
                  Property_Result := Base_Subp_Body_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Exception_Handler =>
                  --# property-call-start ExceptionHandler.is_constant_object
                  Property_Result := Exception_Handler_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_For_Loop_Var_Decl =>
                  --# property-call-start ForLoopVarDecl.is_constant_object
                  Property_Result := For_Loop_Var_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Number_Decl =>
                  --# property-call-start NumberDecl.is_constant_object
                  Property_Result := Number_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
                  --# property-call-start ObjectDecl.is_constant_object
                  Property_Result := Object_Decl_P_Is_Constant_Object
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Decl_P_Is_Constant_Object;
--# end
--# property-start BasicDecl.child_decl_initial_env_name /tmp/lal-23.0.0/ada/ast.py:1945
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Child_Decl_Initial_Env_Name
  (Node : Bare_Basic_Decl
      ; Private_Part : Boolean
         := False
  )
   return Symbol_Type
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind private_part Private_Part
   Property_Result : Symbol_Type;
            procedure Finalizer_Scope_130 with Inline_Always;
            procedure Finalizer_Scope_2062 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name;
Block_Var_1 : Internal_Entity_Dotted_Name;
Var_Expr : Internal_Entity_Dotted_Name;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Name;
Cast_Result : Internal_Entity_Dotted_Name;
Fld_2 : String_Type;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal : Boolean;
Fld_3 : Boolean;
Fld_4 : Internal_Entity_Name;
Fld_5 : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym_2 : Symbol_Type;
Fld_6 : Internal_Entity_Name;
Fld_7 : String_Type;
Sym_3 : Symbol_Type;
If_Result_1 : Symbol_Type;
Scope_Result : Symbol_Type;
Sym_4 : Symbol_Type;
Result_Var : Symbol_Type;
If_Result_2 : Symbol_Type;
If_Result_3 : Symbol_Type;
Let_Result : Symbol_Type;
            procedure Finalizer_Scope_130 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_130;
            procedure Finalizer_Scope_2062 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_2062;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2734 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2715 '<FieldAccess for defining_name at ast.py:1953>' Fld /tmp/lal-23.0.0/ada/ast.py:1953
--# expr-start 2714 '<as_bare_entity at ast.py:1953>' If_Result /tmp/lal-23.0.0/ada/ast.py:1953
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 2714
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 2715
Block_Var := Fld; 
--# bind defining_name Block_Var
--# expr-start 2717 '<Cast to DottedName at ast.py:1954>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:1954
--# expr-start 2716 '<FieldAccess for name at ast.py:1954>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:1954
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Block_Var.Node.Defining_Name_F_Name, Info => Block_Var.Info);
--# expr-done 2716
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Create_Internal_Entity_Dotted_Name
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Dotted_Name;
   end if;
--# expr-done 2717
Block_Var_1 := Cast_Result; 
--# bind child_name Block_Var_1
--# expr-start 2733 '<Cond at ast.py:1955>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:1955
--# expr-start 2721 '<Eq at ast.py:1958>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:1958
--# expr-start 2719 '<to_symbol at ast.py:1958>' Sym /tmp/lal-23.0.0/ada/ast.py:1958
--# expr-start 2718 '<FieldAccess for text at ast.py:1958>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:1958
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Text (Node => Block_Var.Node);
--# expr-done 2718
Sym := String_To_Symbol (Self, Self.Unit.Context, Fld_2); 
--# expr-done 2719
--# expr-start 2720 '<Symbol standard at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Standard_352); 
--# expr-done 2720
Is_Equal := Sym = Sym_1; 
--# expr-done 2721
if Is_Equal then
   If_Result_3 := null;
else
--# expr-start 2722 '<FieldAccess for is_library_item at ast.py:1961>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:1961
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 2722
if Fld_3 then
Var_Expr := Block_Var_1;
if Var_Expr /= No_Entity_Dotted_Name then
   --# scope-start
   --# bind n Var_Expr
--# expr-start 2731 '<If at ast.py:1965>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:1965
if Private_Part then
   --# expr-start 2727 '<to_symbol at ast.py:1967>' Sym_2 /tmp/lal-23.0.0/ada/ast.py:1967
--# expr-start 2726 '<Concat at ast.py:1967>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:1967
--# expr-start 2724 '<FieldAccess for text at ast.py:1967>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:1967
--# expr-start 2723 '<FieldAccess for prefix at ast.py:1967>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:1967
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Dotted_Name_F_Prefix, Info => Var_Expr.Info);
--# expr-done 2723
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Text (Node => Fld_4.Node);
--# expr-done 2724
--# expr-start 2725 '<String at ast.py:1967>' Str /tmp/lal-23.0.0/ada/ast.py:1967
Str := Create_String (".__privatepart"); 
--# expr-done 2725
Concat_Result := Concat_String (Fld_5, Str); 
--# expr-done 2726
Sym_2 := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 2727
   If_Result_1 := Sym_2;
else
   --# expr-start 2730 '<to_symbol at ast.py:1968>' Sym_3 /tmp/lal-23.0.0/ada/ast.py:1968
--# expr-start 2729 '<FieldAccess for text at ast.py:1968>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:1968
--# expr-start 2728 '<FieldAccess for prefix at ast.py:1968>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:1968
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Dotted_Name_F_Prefix, Info => Var_Expr.Info);
--# expr-done 2728
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Text (Node => Fld_6.Node);
--# expr-done 2729
Sym_3 := String_To_Symbol (Self, Self.Unit.Context, Fld_7); 
--# expr-done 2730
   If_Result_1 := Sym_3;
end if;
--# expr-done 2731
Scope_Result := If_Result_1;
   --# end
      Finalizer_Scope_2062;
   Result_Var := Scope_Result;
else
   --# expr-start 2732 '<Symbol standard at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Standard_352); 
--# expr-done 2732
   Result_Var := Sym_4;
end if;
   If_Result_2 := Result_Var;
else
   If_Result_2 := null;
end if;
   If_Result_3 := If_Result_2;
end if;
--# expr-done 2733
Let_Result := If_Result_3; 
--# end
--# expr-done 2734
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_130;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_130;
               Finalizer_Scope_2062;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Child_Decl_Initial_Env_Name;
--# end
--# property-start BasicDecl.previous_part_for_decl /tmp/lal-23.0.0/ada/ast.py:2082
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Previous_Part_For_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Match_0 : Internal_Entity_Base_Type_Decl;
Match_1 : Internal_Entity_Body_Node;
Match_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Body_Node;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2739 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 2738 '<Match at ast.py:2091>' Match_Result /tmp/lal-23.0.0/ada/ast.py:2091
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind btd Match_0
--# expr-start 2736 '<Cast to BasicDecl at ast.py:2093>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:2093
--# expr-start 2735 '<FieldAccess for previous_part at ast.py:2093>' Fld /tmp/lal-23.0.0/ada/ast.py:2093
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Match_0.Node, Go_To_Incomplete => True, E_Info => Match_0.Info);
--# end
--# expr-done 2735
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
--# expr-done 2736
Let_Result := Cast_Result; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Expr_Function .. Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Body_Node
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind bd Match_1
--# expr-start 2737 '<FieldAccess for previous_part_internal at ast.py:2094>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2094
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.previous_part_internal
Fld_1 := Libadalang.Implementation.Body_Node_P_Previous_Part_Internal (Node => Match_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_1.Info);
--# end
--# expr-done 2737
Let_Result_1 := Fld_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Package_Decl | Ada_Abstract_Subp_Decl .. Ada_Synthetic_Subp_Decl | Ada_Entry_Index_Spec .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Basic_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 2738
Let_Result_3 := Match_Result; 
--# end
--# expr-done 2739
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Previous_Part_For_Decl;
--# end
--# property-start BasicDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:2152
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Static_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2740 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 2740
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Static_Decl;
--# end
--# property-start BasicDecl.is_library_item /tmp/lal-23.0.0/ada/ast.py:2193
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Library_Item
  (Node : Bare_Basic_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2743 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2742 '<IsA LibraryItem at ast.py:2197>' Is_A /tmp/lal-23.0.0/ada/ast.py:2197
--# expr-start 2741 '<parent at ast.py:2197>' Fld /tmp/lal-23.0.0/ada/ast.py:2197
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2741
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range; 
--# expr-done 2742
Let_Result := Is_A; 
--# end
--# expr-done 2743
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Library_Item;
--# end
--# property-start BasicDecl.declarative_parts /tmp/lal-23.0.0/ada/ast.py:2209
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Declarative_Parts
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_147 with Inline_Always;
      Let_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_147 is
            begin
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_147;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2744 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Internal_Entity_Declarative_Part_Array_Type; Inc_Ref (Let_Result);
--# end
--# expr-done 2744
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_147;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_147;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Declarative_Parts;
--# end
--# property-start BasicDecl.get_aspect_assoc /tmp/lal-23.0.0/ada/ast.py:2229
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Get_Aspect_Assoc
  (Node : Bare_Basic_Decl
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Aspect_Assoc
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Aspect_Assoc;
            procedure Finalizer_Scope_2084 with Inline_Always;
      Var_Expr : Internal_Entity_Aspect_Spec;
Fld : Internal_Entity_Aspect_Spec;
Fld_1 : Internal_Entity_Aspect_Assoc_List;
Scope_Result : Internal_Entity_Aspect_Assoc_List;
Result_Var : Internal_Entity_Aspect_Assoc_List;
Fld_2 : Bare_Aspect_Assoc_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Aspect_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Aspect_Assoc;
Fld_4 : Internal_Entity_Name;
Fld_5 : String_Type;
Fld_6 : String_Type;
Is_Equal : Boolean;
Item_97 : Internal_Entity_Aspect_Assoc;
Bare_Item_97 : Bare_Aspect_Assoc;
Find_Result : Internal_Entity_Aspect_Assoc;
Let_Result : Internal_Entity_Aspect_Assoc;
            procedure Finalizer_Scope_2084 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2084;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2752 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2751 '<Find at ast.py:2233>' Find_Result /tmp/lal-23.0.0/ada/ast.py:2233
--# expr-start 2745 '<FieldAccess for aspects at ast.py:2233>' Fld /tmp/lal-23.0.0/ada/ast.py:2233
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Aspect_Spec (Node => Implementation.Basic_Decl_F_Aspects (Ent.Node), Info => Ent.Info);
--# expr-done 2745
Var_Expr := Fld;
if Var_Expr /= No_Entity_Aspect_Spec then
   --# scope-start
--# expr-start 2746 '<FieldAccess for aspect_assocs at ast.py:2233>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2233
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Aspect_Assoc_List (Node => Var_Expr.Node.Aspect_Spec_F_Aspect_Assocs, Info => Var_Expr.Info);
--# expr-done 2746
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Aspect_Assoc_List;
end if;
Fld_2 := Result_Var.Node;
      Find_Result := No_Entity_Aspect_Assoc;
      if Fld_2 = null then
      Find_Result := No_Entity_Aspect_Assoc;
      else
      declare
         Collection : constant Bare_Aspect_Assoc_List := Fld_2;
      begin
         for Untyped_Item_97 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_97 := Untyped_Item_97; 
Is_Null := Bare_Item_97 = null; 
if Is_Null then
   If_Result := No_Entity_Aspect_Assoc;
else
Fld_3 := Result_Var.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_97); 
   If_Result := As_Entity;
end if;
                  Item_97 := If_Result; 
   --# scope-start
               --# bind asp Item_97
      --# expr-start 2750 '<Eq at ast.py:2234>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:2234
--# expr-start 2748 '<FieldAccess for aspect_name at ast.py:2234>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:2234
      if Item_97.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2747 '<FieldAccess for id at ast.py:2234>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:2234
      if Item_97.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Item_97.Node.Aspect_Assoc_F_Id, Info => Item_97.Info);
--# expr-done 2747
--# property-call-start AspectAssoc.aspect_name
Fld_5 := Libadalang.Implementation.Aspect_Assoc_P_Aspect_Name (Node => Item_97.Node, N => Fld_4);
--# end
--# expr-done 2748
--# expr-start 2749 '<FieldAccess for image at ast.py:2234>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:2234
      if Name = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Image (Self => Name);
--# expr-done 2749
Is_Equal := Equivalent (Fld_5, Fld_6); 
--# expr-done 2750
      if Is_Equal then
         Find_Result := Item_97;
      end if;
   --# end
      Finalizer_Scope_2084;
               exit when Is_Equal;
         end loop;
      end;
      end if;
--# expr-done 2751
Let_Result := Find_Result; 
--# end
--# expr-done 2752
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2084;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Get_Aspect_Assoc;
--# end
--# property-start BasicDecl.is_imported /tmp/lal-23.0.0/ada/ast.py:2317
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_Imported
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2755 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2753 '<FieldAccess for defining_name_or_raise at ast.py:2321>' Fld /tmp/lal-23.0.0/ada/ast.py:2321
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2753
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2754 '<FieldAccess for is_imported at ast.py:2321>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2321
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_imported
Fld_1 := Libadalang.Implementation.Defining_Name_P_Is_Imported (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2754
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2755
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_Imported;
--# end
--# property-start BasicDecl.is_in_private_part /tmp/lal-23.0.0/ada/ast.py:2417
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Is_In_Private_Part
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2758 '<IsA PrivatePart at ast.py:2417>' Is_A /tmp/lal-23.0.0/ada/ast.py:2417
--# expr-start 2757 '<parent at ast.py:2417>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2417
--# expr-start 2756 '<parent at ast.py:2417>' Fld /tmp/lal-23.0.0/ada/ast.py:2417
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2756
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 2757
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Private_Part_Range; 
--# expr-done 2758
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Is_In_Private_Part;
--# end
--# property-start BasicDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:2691
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Defining_Env
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Empty_Env;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Defining_Env;
--# end
--# property-start BasicDecl.array_ndims /tmp/lal-23.0.0/ada/ast.py:2728
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Array_Ndims
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Integer;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Integer;
Let_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2761 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2760 '<FieldAccess for array_ndims at ast.py:2729>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2729
--# expr-start 2759 '<FieldAccess for expr_type at ast.py:2729>' Fld /tmp/lal-23.0.0/ada/ast.py:2729
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 2759
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 2760
Let_Result := Fld_1; 
--# end
--# expr-done 2761
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Array_Ndims;
--# end
--# property-start BasicDecl.expr_type /tmp/lal-23.0.0/ada/ast.py:2736
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Expr_Type
  (Node : Bare_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Type_Expr;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2764 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2762 '<FieldAccess for type_expression at ast.py:2755>' Fld /tmp/lal-23.0.0/ada/ast.py:2755
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2762
Var_Expr := Fld;
if Var_Expr /= No_Entity_Type_Expr then
   --# scope-start
   --# bind te Var_Expr
--# expr-start 2763 '<FieldAccess for designated_type at ast.py:2755>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:2755
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 2763
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2764
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Expr_Type;
--# end
--# property-start BasicDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:2757
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Type_Expression
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Expr;
      Node_For_Entity : Bare_Type_Expr;
As_Entity : Internal_Entity_Type_Expr;
Is_Null : Boolean;
If_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2766 '<as_entity at ast.py:2758>' If_Result /tmp/lal-23.0.0/ada/ast.py:2758
--# expr-start 2765 '<No TypeExpr at ast.py:2758>' Node_For_Entity /tmp/lal-23.0.0/ada/ast.py:2758
Node_For_Entity := No_Bare_Ada_Node;
--# expr-done 2765
Is_Null := Node_For_Entity = null; 
if Is_Null then
   If_Result := No_Entity_Type_Expr;
else
As_Entity := (Info => E_Info, Node => Node_For_Entity); 
   If_Result := As_Entity;
end if;
--# expr-done 2766
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Type_Expression;
--# end
--# property-start BasicDecl.constrain_prefix /tmp/lal-23.0.0/ada/ast.py:2925
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Constrain_Prefix
  (Node : Bare_Basic_Decl
      ; Prefix : Bare_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind prefix Prefix
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_190 with Inline_Always;
      True_Rel : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_190 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_190;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2767 '<Block at ???>' Let_Result None
--# scope-start
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:2949") else null)); 
Let_Result := True_Rel; Inc_Ref (Let_Result);
--# end
--# expr-done 2767
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_190;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_190;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Constrain_Prefix;
--# end
--# property-start BasicDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:3009
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Next_Part_For_Decl
  (Node : Bare_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2769 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2768 '<FieldAccess for basic_decl_next_part_for_decl at ast.py:3018>' Fld /tmp/lal-23.0.0/ada/ast.py:3018
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.basic_decl_next_part_for_decl
Fld := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Next_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2768
Let_Result := Fld; 
--# end
--# expr-done 2769
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Next_Part_For_Decl;
--# end
--# property-start BasicDecl.next_part_for_name /tmp/lal-23.0.0/ada/ast.py:3039
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Next_Part_For_Name
  (Node : Bare_Basic_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2771 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2770 '<FieldAccess for next_part_for_decl at ast.py:3059>' Fld /tmp/lal-23.0.0/ada/ast.py:3059
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2770
Let_Result := Fld; 
--# end
--# expr-done 2771
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Next_Part_For_Name;
--# end
--# property-start BasicDecl.previous_part_for_name /tmp/lal-23.0.0/ada/ast.py:3063
pragma Warnings (Off, "is not referenced");
 function Basic_Decl_P_Previous_Part_For_Name
  (Node : Bare_Basic_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Decl := Bare_Basic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Decl :=
     Internal_Entity_Basic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2773 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2772 '<FieldAccess for previous_part_for_decl at ast.py:3083>' Fld /tmp/lal-23.0.0/ada/ast.py:3083
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_decl'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2772
Let_Result := Fld; 
--# end
--# expr-done 2773
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Decl_P_Previous_Part_For_Name;
--# end
 function Basic_Decl_P_Is_Constant_Object
  (Node : Bare_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is (raise Property_Error
    with "Property BasicDecl.is_constant_object not implemented on type "
    & Kind_Name (Node));
   --
   --  Primitives for Bare_Abstract_State_Decl
   --
      procedure Abstract_State_Decl_Pre_Env_Actions
        (Self            : Bare_Abstract_State_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_233 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20905");
         Dec_Ref (Mapping.Dest_Env);
      end;
      end;
      procedure Initialize_Fields_For_Abstract_State_Decl
        (Self : Bare_Abstract_State_Decl
         ; Abstract_State_Decl_F_Name : Bare_Defining_Name
         ; Abstract_State_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Abstract_State_Decl_F_Name := Abstract_State_Decl_F_Name;
            Self.Abstract_State_Decl_F_Aspects := Abstract_State_Decl_F_Aspects;
      end Initialize_Fields_For_Abstract_State_Decl;
   function Abstract_State_Decl_F_Name
     (Node : Bare_Abstract_State_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Abstract_State_Decl_F_Name;
   end;
--# property-start AbstractStateDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:20901
pragma Warnings (Off, "is not referenced");
 function Abstract_State_Decl_P_Defining_Names
  (Node : Bare_Abstract_State_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Abstract_State_Decl := Bare_Abstract_State_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Abstract_State_Decl :=
     Internal_Entity_Abstract_State_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1465 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1465 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1465;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2774 '<FieldAccess for name at ast.py:20901>' Fld /tmp/lal-23.0.0/ada/ast.py:20901
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Abstract_State_Decl_F_Name, Info => Ent.Info);
--# expr-done 2774
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1465;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1465;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abstract_State_Decl_P_Defining_Names;
--# end
--# property-start AbstractStateDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:20902
pragma Warnings (Off, "is not referenced");
 function Abstract_State_Decl_P_Type_Expression
  (Node : Bare_Abstract_State_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Abstract_State_Decl := Bare_Abstract_State_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Type_Expr;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abstract_State_Decl_P_Type_Expression;
--# end
--# property-start AbstractStateDecl._env_mappings_233 /tmp/lal-23.0.0/ada/ast.py:20905
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_233
  (Node : Bare_Abstract_State_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Abstract_State_Decl := Bare_Abstract_State_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1702 with Inline_Always;
      Fld : Bare_Defining_Name;
Fld_1 : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Abstract_State_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1702 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1702;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2778 '<New EnvAssoc at ast.py:20905>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:20905
--# expr-start 2775 '<New DesignatedEnv at ast.py:20905>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20905
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 2775
--# expr-start 2777 '<FieldAccess for name_symbol at ast.py:20905>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20905
--# expr-start 2776 '<FieldAccess for name at ast.py:20905>' Fld /tmp/lal-23.0.0/ada/ast.py:20905
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Abstract_State_Decl_F_Name;
--# expr-done 2776
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld);
--# end
--# expr-done 2777
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld_1, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 2778
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1702;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1702;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_233;
--# end
   --
   --  Primitives for Bare_Anonymous_Expr_Decl
   --
      procedure Initialize_Fields_For_Anonymous_Expr_Decl
        (Self : Bare_Anonymous_Expr_Decl
         ; Anonymous_Expr_Decl_F_Expr : Bare_Expr
        ) is
      begin
            Self.Anonymous_Expr_Decl_F_Expr := Anonymous_Expr_Decl_F_Expr;
      end Initialize_Fields_For_Anonymous_Expr_Decl;
   function Anonymous_Expr_Decl_F_Expr
     (Node : Bare_Anonymous_Expr_Decl) return Bare_Expr
   is
   begin
         return Node.Anonymous_Expr_Decl_F_Expr;
   end;
--# property-start AnonymousExprDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:10349
pragma Warnings (Off, "is not referenced");
 function Anonymous_Expr_Decl_P_Defining_Names
  (Node : Bare_Anonymous_Expr_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Anonymous_Expr_Decl := Bare_Anonymous_Expr_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Defining_Name_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Expr_Decl_P_Defining_Names;
--# end
--# property-start AnonymousExprDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:10350
pragma Warnings (Off, "is not referenced");
 function Anonymous_Expr_Decl_P_Defining_Env
  (Node : Bare_Anonymous_Expr_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Anonymous_Expr_Decl := Bare_Anonymous_Expr_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Expr_Decl :=
     Internal_Entity_Anonymous_Expr_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_829 with Inline_Always;
      Fld : Internal_Entity_Type_Expr;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_829 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_829;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2780 '<FieldAccess for defining_env at ast.py:10350>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10350
--# expr-start 2779 '<FieldAccess for type_expression at ast.py:10350>' Fld /tmp/lal-23.0.0/ada/ast.py:10350
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2779
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.defining_env
Fld_1 := Libadalang.Implementation.Type_Expr_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 2780
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_829;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_829;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Expr_Decl_P_Defining_Env;
--# end
--# property-start AnonymousExprDecl.get_formal /tmp/lal-23.0.0/ada/ast.py:10355
pragma Warnings (Off, "is not referenced");
 function Anonymous_Expr_Decl_P_Get_Formal
  (Node : Bare_Anonymous_Expr_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Anonymous_Expr_Decl := Bare_Anonymous_Expr_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Expr_Decl :=
     Internal_Entity_Anonymous_Expr_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_830 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Assoc;
Fld : Internal_Entity_Expr;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Assoc;
Fld_2 : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_830 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_830;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Anonymous_Expr_Decl_Anonymous_Expr_Decl_P_Get_Formal,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Anonymous_Expr_Decl,
                                As_Bare_Anonymous_Expr_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Imprecise_Fallback);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Defining_Name;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 2786 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2783 '<Cast to BasicAssoc at ast.py:10360>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10360
--# expr-start 2782 '<parent at ast.py:10360>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10360
--# expr-start 2781 '<FieldAccess for expr at ast.py:10360>' Fld /tmp/lal-23.0.0/ada/ast.py:10360
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Anonymous_Expr_Decl_F_Expr, Info => Ent.Info);
--# expr-done 2781
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 2782
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Basic_Assoc
   then
      Cast_Result := Create_Internal_Entity_Basic_Assoc
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Basic_Assoc;
   end if;
--# expr-done 2783
Block_Var := Cast_Result; 
--# bind assoc Block_Var
--# expr-start 2785 '<at at ast.py:10361>' Get_Result /tmp/lal-23.0.0/ada/ast.py:10361
--# expr-start 2784 '<FieldAccess for get_params at ast.py:10361>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10361
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicAssoc.get_params
Fld_2 := Libadalang.Implementation.Basic_Assoc_P_Get_Params (Node => Block_Var.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var.Info);
--# end
--# expr-done 2784
Get_Result := Get (Self, Fld_2, 0, True); 
--# expr-done 2785
Let_Result := Get_Result; 
--# end
--# expr-done 2786
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_830;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Defining_Name,
                        As_Internal_Entity_Defining_Name => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_830;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Expr_Decl_P_Get_Formal;
--# end
--# property-start AnonymousExprDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:10364
pragma Warnings (Off, "is not referenced");
 function Anonymous_Expr_Decl_P_Type_Expression
  (Node : Bare_Anonymous_Expr_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Anonymous_Expr_Decl := Bare_Anonymous_Expr_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Expr_Decl :=
     Internal_Entity_Anonymous_Expr_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Type_Expr;
Let_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2790 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2789 '<FieldAccess for type_expression at ast.py:10370>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10370
--# expr-start 2788 '<FieldAccess for basic_decl at ast.py:10370>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10370
--# expr-start 2787 '<FieldAccess for get_formal at ast.py:10370>' Fld /tmp/lal-23.0.0/ada/ast.py:10370
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AnonymousExprDecl.get_formal
Fld := Libadalang.Implementation.Anonymous_Expr_Decl_P_Get_Formal (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 2787
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 2788
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 2789
Let_Result := Fld_2; 
--# end
--# expr-done 2790
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Expr_Decl_P_Type_Expression;
--# end
--# property-start AnonymousExprDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:10373
pragma Warnings (Off, "is not referenced");
 function Anonymous_Expr_Decl_P_Is_Static_Decl
  (Node : Bare_Anonymous_Expr_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Anonymous_Expr_Decl := Bare_Anonymous_Expr_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Expr_Decl :=
     Internal_Entity_Anonymous_Expr_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Expr;
Fld_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2793 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2792 '<FieldAccess for is_static_expr at ast.py:10374>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10374
--# expr-start 2791 '<FieldAccess for expr at ast.py:10374>' Fld /tmp/lal-23.0.0/ada/ast.py:10374
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Anonymous_Expr_Decl_F_Expr, Info => Ent.Info);
--# expr-done 2791
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_1 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 2792
Let_Result := Fld_1; 
--# end
--# expr-done 2793
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Expr_Decl_P_Is_Static_Decl;
--# end
   --
   --  Primitives for Bare_Base_Formal_Param_Decl
   --
--# property-start '[dispatcher]BaseFormalParamDecl.is_mandatory' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Formal_Param_Decl_P_Is_Mandatory
  (Node : Bare_Base_Formal_Param_Decl
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Formal_Param_Decl (Self.Kind) is
               when Ada_Component_Decl .. Ada_Generic_Formal_Type_Decl | Ada_Synthetic_Formal_Param_Decl =>
                  --# property-call-start BaseFormalParamDecl.is_mandatory
                  Property_Result := Base_Formal_Param_Decl_P_Is_Mandatory
                    (Self
                    );
                  --# end
               when Ada_Param_Spec =>
                  --# property-call-start ParamSpec.is_mandatory
                  Property_Result := Param_Spec_P_Is_Mandatory
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Formal_Param_Decl_P_Is_Mandatory;
--# end
--# property-start BaseFormalParamDecl.formal_type /tmp/lal-23.0.0/ada/ast.py:3987
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Formal_Type
  (Node : Bare_Base_Formal_Param_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Type_Expr;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2796 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2794 '<FieldAccess for type_expression at ast.py:3991>' Fld /tmp/lal-23.0.0/ada/ast.py:3991
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2794
Var_Expr := Fld;
if Var_Expr /= No_Entity_Type_Expr then
   --# scope-start
--# expr-start 2795 '<FieldAccess for designated_type at ast.py:3991>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3991
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 2795
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2796
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Formal_Type;
--# end
--# property-start BaseFormalParamDecl.parent_decl /tmp/lal-23.0.0/ada/ast.py:3994
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Parent_Decl
  (Node : Bare_Base_Formal_Param_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2799 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2798 '<Cast to BasicDecl at ast.py:3995>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3995
--# expr-start 2797 '<FieldAccess for semantic_parent at ast.py:3995>' Fld /tmp/lal-23.0.0/ada/ast.py:3995
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2797
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 2798
Let_Result := Cast_Result; 
--# end
--# expr-done 2799
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Parent_Decl;
--# end
--# property-start BaseFormalParamDecl.get_param /tmp/lal-23.0.0/ada/ast.py:3998
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Get_Param
  (Node : Bare_Base_Formal_Param_Decl
      ; Part : Internal_Entity_Basic_Decl
      ; Param : Symbol_Type
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind part Part
   --# bind param Param
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_2179 with Inline_Always;
            procedure Finalizer_Scope_2180 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld : Internal_Entity_Base_Formal_Param_Holder;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Fld_2 : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Scope_Result_1 : Internal_Entity_Defining_Name;
Result_Var_1 : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_2179 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2179;
            procedure Finalizer_Scope_2180 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2180;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2804 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr := Part;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind d Var_Expr
--# expr-start 2803 '<Find at ast.py:4002>' Find_Result /tmp/lal-23.0.0/ada/ast.py:4002
--# expr-start 2800 '<FieldAccess for formal_param_holder_or_null at ast.py:4001>' Fld /tmp/lal-23.0.0/ada/ast.py:4001
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.formal_param_holder_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Formal_Param_Holder_Or_Null (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2800
Var_Expr_1 := Fld;
if Var_Expr_1 /= No_Entity_Base_Formal_Param_Holder then
   --# scope-start
--# expr-start 2801 '<FieldAccess for unpacked_formal_params at ast.py:4001>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4001
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2801
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2180;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Result_Var;
      begin
         for Item_122 of
               Collection.Items
         loop
   --# scope-start
               --# bind sf Item_122
      --# expr-start 2802 '<FieldAccess for name_is at ast.py:4002>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4002
      if Item_122.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_2 := Libadalang.Implementation.Name_P_Name_Is (Node => Item_122.Node, Sym => Param);
--# end
--# expr-done 2802
      if Fld_2 then
         Find_Result := Item_122;
      end if;
   --# end
               exit when Fld_2;
         end loop;
      end;
--# expr-done 2803
Scope_Result_1 := Find_Result;
   --# end
      Finalizer_Scope_2179;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Defining_Name;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 2804
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2179;
               Finalizer_Scope_2180;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Get_Param;
--# end
--# property-start BaseFormalParamDecl.decl_param /tmp/lal-23.0.0/ada/ast.py:4007
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Decl_Param
  (Node : Bare_Base_Formal_Param_Decl
      ; Param : Internal_Entity_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind param Param
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
      Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Internal_Entity_Base_Subp_Body;
Fld : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Base_Subp_Body;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_2 : Symbol_Type;
Fld_3 : Internal_Entity_Defining_Name;
Scope_Result_1 : Internal_Entity_Defining_Name;
Result_Var_1 : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2810 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2809 '<FieldAccess for get_param at ast.py:4012>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4012
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2806 '<Cast to BaseSubpBody at ast.py:4013>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4013
--# expr-start 2805 '<FieldAccess for parent_decl at ast.py:4013>' Fld /tmp/lal-23.0.0/ada/ast.py:4013
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.parent_decl
Fld := Libadalang.Implementation.Base_Formal_Param_Decl_P_Parent_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2805
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Body
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 2806
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Base_Subp_Body then
   --# scope-start
--# expr-start 2807 '<FieldAccess for decl_part at ast.py:4013>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4013
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld_1 := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Var_Expr_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2807
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
--# expr-start 2808 '<FieldAccess for name_symbol at ast.py:4014>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4014
      if Param.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Param.Node);
--# end
--# expr-done 2808
--# property-call-start BaseFormalParamDecl.get_param
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Get_Param (Node => Ent.Node, Part => Result_Var, Param => Fld_2);
--# end
--# expr-done 2809
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_1 := Var_Expr;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Param;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 2810
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Decl_Param;
--# end
--# property-start BaseFormalParamDecl.next_part_for_name /tmp/lal-23.0.0/ada/ast.py:4018
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Next_Part_For_Name
  (Node : Bare_Base_Formal_Param_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Defining_Name;
Fld_3 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2815 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2813 '<FieldAccess for get_param at ast.py:4019>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4019
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2811 '<FieldAccess for parent_decl at ast.py:4020>' Fld /tmp/lal-23.0.0/ada/ast.py:4020
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.parent_decl
Fld := Libadalang.Implementation.Base_Formal_Param_Decl_P_Parent_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2811
Var_Expr_1 := Fld;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 2812 '<FieldAccess for next_part_for_decl at ast.py:4020>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4020
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Var_Expr_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2812
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
--# property-call-start BaseFormalParamDecl.get_param
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Get_Param (Node => Ent.Node, Part => Result_Var, Param => Sym);
--# end
--# expr-done 2813
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2814 '<FieldAccess for basic_decl at ast.py:4022>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4022
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_3 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2814
Scope_Result_1 := Fld_3;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 2815
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Next_Part_For_Name;
--# end
--# property-start BaseFormalParamDecl.previous_part_for_name /tmp/lal-23.0.0/ada/ast.py:4025
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Previous_Part_For_Name
  (Node : Bare_Base_Formal_Param_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Defining_Name;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Defining_Name;
Fld_3 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2820 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2818 '<FieldAccess for get_param at ast.py:4026>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4026
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2816 '<FieldAccess for parent_decl at ast.py:4027>' Fld /tmp/lal-23.0.0/ada/ast.py:4027
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.parent_decl
Fld := Libadalang.Implementation.Base_Formal_Param_Decl_P_Parent_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2816
Var_Expr_1 := Fld;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 2817 '<FieldAccess for previous_part_for_decl at ast.py:4027>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4027
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Decl (Node => Var_Expr_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 2817
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
--# property-call-start BaseFormalParamDecl.get_param
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Get_Param (Node => Ent.Node, Part => Result_Var, Param => Sym);
--# end
--# expr-done 2818
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 2819 '<FieldAccess for basic_decl at ast.py:4029>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4029
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_3 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2819
Scope_Result_1 := Fld_3;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 2820
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Previous_Part_For_Name;
--# end
--# property-start BaseFormalParamDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:4032
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Next_Part_For_Decl
  (Node : Bare_Base_Formal_Param_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Symbol_Type;
Fld_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2823 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2822 '<FieldAccess for next_part_for_name at ast.py:4033>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4033
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2821 '<FieldAccess for name_symbol at ast.py:4033>' Fld /tmp/lal-23.0.0/ada/ast.py:4033
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2821
--# property-call-start '[dispatcher]BasicDecl.next_part_for_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Name (Node => Ent.Node, Sym => Fld, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2822
Let_Result := Fld_1; 
--# end
--# expr-done 2823
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Next_Part_For_Decl;
--# end
--# property-start BaseFormalParamDecl.previous_part_for_decl /tmp/lal-23.0.0/ada/ast.py:4036
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Previous_Part_For_Decl
  (Node : Bare_Base_Formal_Param_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Formal_Param_Decl :=
     Internal_Entity_Base_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Symbol_Type;
Fld_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2826 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2825 '<FieldAccess for previous_part_for_name at ast.py:4037>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4037
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2824 '<FieldAccess for name_symbol at ast.py:4037>' Fld /tmp/lal-23.0.0/ada/ast.py:4037
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 2824
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Name (Node => Ent.Node, Sym => Fld, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2825
Let_Result := Fld_1; 
--# end
--# expr-done 2826
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Previous_Part_For_Decl;
--# end
--# property-start BaseFormalParamDecl.is_mandatory /tmp/lal-23.0.0/ada/ast.py:3983
pragma Warnings (Off, "is not referenced");
 function Base_Formal_Param_Decl_P_Is_Mandatory
  (Node : Bare_Base_Formal_Param_Decl
  )
   return Boolean
is
   Self : Bare_Base_Formal_Param_Decl := Bare_Base_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Formal_Param_Decl_P_Is_Mandatory;
--# end
   --
   --  Primitives for Bare_Component_Decl
   --
      procedure Component_Decl_Pre_Env_Actions
        (Self            : Bare_Component_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_1 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:4727");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Component_Decl
        (Self : Bare_Component_Decl
         ; Component_Decl_F_Ids : Bare_Defining_Name_List
         ; Component_Decl_F_Component_Def : Bare_Component_Def
         ; Component_Decl_F_Default_Expr : Bare_Expr
         ; Component_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Component_Decl_F_Ids := Component_Decl_F_Ids;
            Self.Component_Decl_F_Component_Def := Component_Decl_F_Component_Def;
            Self.Component_Decl_F_Default_Expr := Component_Decl_F_Default_Expr;
            Self.Component_Decl_F_Aspects := Component_Decl_F_Aspects;
      end Initialize_Fields_For_Component_Decl;
   function Component_Decl_F_Ids
     (Node : Bare_Component_Decl) return Bare_Defining_Name_List
   is
   begin
         return Node.Component_Decl_F_Ids;
   end;
   function Component_Decl_F_Component_Def
     (Node : Bare_Component_Decl) return Bare_Component_Def
   is
   begin
         return Node.Component_Decl_F_Component_Def;
   end;
   function Component_Decl_F_Default_Expr
     (Node : Bare_Component_Decl) return Bare_Expr
   is
   begin
         return Node.Component_Decl_F_Default_Expr;
   end;
--# property-start ComponentDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:4729
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Defining_Env
  (Node : Bare_Component_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_Decl :=
     Internal_Entity_Component_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_302 with Inline_Always;
      Fld : Internal_Entity_Component_Def;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_302 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_302;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2829 '<FieldAccess for defining_env at ast.py:4730>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4730
--# expr-start 2828 '<FieldAccess for type_expr at ast.py:4730>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4730
--# expr-start 2827 '<FieldAccess for component_def at ast.py:4730>' Fld /tmp/lal-23.0.0/ada/ast.py:4730
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Component_Def (Node => Ent.Node.Component_Decl_F_Component_Def, Info => Ent.Info);
--# expr-done 2827
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Expr (Node => Fld.Node.Component_Def_F_Type_Expr, Info => Fld.Info);
--# expr-done 2828
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.defining_env
Fld_2 := Libadalang.Implementation.Type_Expr_P_Defining_Env (Node => Fld_1.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld_1.Info);
--# end
--# expr-done 2829
      Property_Result := Fld_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_302;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_302;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Defining_Env;
--# end
--# property-start ComponentDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:4734
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Defining_Names
  (Node : Bare_Component_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_303 with Inline_Always;
      Fld : Bare_Defining_Name_List;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Item_123 : Bare_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_303 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_303;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2832 '<Map at ast.py:4734>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4734
   --# expr-start 2830 '<FieldAccess for ids at ast.py:4734>' Fld /tmp/lal-23.0.0/ada/ast.py:4734
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Component_Decl_F_Ids;
--# expr-done 2830
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Internal_Entity_Defining_Name_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld;
      begin
         for Untyped_Item_123 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_123 := Untyped_Item_123; 
   --# scope-start
               --# bind i Item_123
      --# expr-start 2831 '<as_entity at ast.py:4734>' If_Result /tmp/lal-23.0.0/ada/ast.py:4734
Is_Null := Item_123 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Item_123); 
   If_Result := As_Entity;
end if;
--# expr-done 2831
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := If_Result;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2832
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_303;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_303;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Defining_Names;
--# end
--# property-start ComponentDecl.array_ndims /tmp/lal-23.0.0/ada/ast.py:4736
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Array_Ndims
  (Node : Bare_Component_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_Decl :=
     Internal_Entity_Component_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Integer;
      Fld : Internal_Entity_Component_Def;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2835 '<FieldAccess for array_ndims at ast.py:4736>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4736
--# expr-start 2834 '<FieldAccess for type_expr at ast.py:4736>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4736
--# expr-start 2833 '<FieldAccess for component_def at ast.py:4736>' Fld /tmp/lal-23.0.0/ada/ast.py:4736
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Component_Def (Node => Ent.Node.Component_Decl_F_Component_Def, Info => Ent.Info);
--# expr-done 2833
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Expr (Node => Fld.Node.Component_Def_F_Type_Expr, Info => Fld.Info);
--# expr-done 2834
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.array_ndims
Fld_2 := Libadalang.Implementation.Type_Expr_P_Array_Ndims (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 2835
      Property_Result := Fld_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Array_Ndims;
--# end
--# property-start ComponentDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:4738
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Type_Expression
  (Node : Bare_Component_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Bare_Component_Def;
Fld_1 : Bare_Type_Expr;
As_Entity : Internal_Entity_Type_Expr;
Is_Null : Boolean;
If_Result : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2838 '<as_entity at ast.py:4738>' If_Result /tmp/lal-23.0.0/ada/ast.py:4738
--# expr-start 2837 '<FieldAccess for type_expr at ast.py:4738>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4738
--# expr-start 2836 '<FieldAccess for component_def at ast.py:4738>' Fld /tmp/lal-23.0.0/ada/ast.py:4738
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Component_Decl_F_Component_Def;
--# expr-done 2836
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Component_Def_F_Type_Expr;
--# expr-done 2837
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Type_Expr;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 2838
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Type_Expression;
--# end
--# property-start ComponentDecl.is_constant_object /tmp/lal-23.0.0/ada/ast.py:4740
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Is_Constant_Object
  (Node : Bare_Component_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Is_Constant_Object;
--# end
--# property-start ComponentDecl.constrain_prefix /tmp/lal-23.0.0/ada/ast.py:4743
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Constrain_Prefix
  (Node : Bare_Component_Decl
      ; Prefix : Bare_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_Decl :=
     Internal_Entity_Component_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind prefix Prefix
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_307 with Inline_Always;
      Var_Expr : Bare_Attribute_Ref;
True_Rel : Logic_Equation;
Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Logic_Equation;
And_Pred : Logic_Equation;
Cast_Expr : Bare_Expr;
Cast_Result_1 : Bare_Attribute_Ref;
Fld_3 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_307 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_307;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2847 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2846 '<If at ast.py:4744>' If_Result /tmp/lal-23.0.0/ada/ast.py:4744
--# expr-start 2839 '<Cast to AttributeRef at ast.py:4748>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:4748
Cast_Expr := Prefix; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result_1 := Cast_Expr;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 2839
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 2840 '<FieldAccess for is_access_attr at ast.py:4748>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4748
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.is_access_attr
Fld_3 := Libadalang.Implementation.Attribute_Ref_P_Is_Access_Attr (Node => Var_Expr);
--# end
--# expr-done 2840
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4750") else null)); 
   If_Result := True_Rel;
else
   --# expr-start 2845 '<And at ast.py:4754>' And_Pred /tmp/lal-23.0.0/ada/ast.py:4754
--# expr-start 2843 '<Bind at ast.py:4755>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:4755
--# expr-start 2841 '<FieldAccess for expected_type_var at ast.py:4755>' Fld /tmp/lal-23.0.0/ada/ast.py:4755
      if Prefix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Prefix);
--# expr-done 2841
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 2842 '<FieldAccess for container_type at ast.py:4755>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4755
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentDecl.container_type
Fld_1 := Libadalang.Implementation.Component_Decl_P_Container_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2842
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4755") else null)); 
--# expr-done 2843
--# expr-start 2844 '<FieldAccess for matches_expected_prefix_type at ast.py:4756>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4756
      if Prefix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_prefix_type
Fld_2 := Libadalang.Implementation.Expr_P_Matches_Expected_Prefix_Type (Node => Prefix, Origin => Origin);
--# end
--# expr-done 2844
And_Pred := Create_And (Bind_Result, Fld_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4754") else null)); 
--# expr-done 2845
   If_Result := And_Pred;
end if;
      Inc_Ref (If_Result);
--# expr-done 2846
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2847
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_307;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_307;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Constrain_Prefix;
--# end
--# property-start ComponentDecl.container_type /tmp/lal-23.0.0/ada/ast.py:4761
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Container_Type
  (Node : Bare_Component_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_308 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_308 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_308;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2853 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2852 '<as_entity at ast.py:4767>' If_Result /tmp/lal-23.0.0/ada/ast.py:4767
--# expr-start 2851 '<Cast to BaseTypeDecl at ast.py:4767>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4767
--# expr-start 2850 '<Find at ast.py:4765>' Find_Result /tmp/lal-23.0.0/ada/ast.py:4765
   --# expr-start 2848 '<FieldAccess for parents at ast.py:4765>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:4765
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 2848
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_124 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_124
      --# expr-start 2849 '<IsA BaseTypeDecl at ast.py:4766>' Is_A /tmp/lal-23.0.0/ada/ast.py:4766
Is_A := Item_124 /= null 
and then Item_124.Kind in Ada_Base_Type_Decl; 
--# expr-done 2849
      if Is_A then
         Find_Result := Item_124;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 2850
   if Find_Result = null
      or else Find_Result.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Find_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 2851
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 2852
Let_Result := If_Result; 
--# end
--# expr-done 2853
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_308;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_308;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Container_Type;
--# end
--# property-start ComponentDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:4770
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Xref_Equation
  (Node : Bare_Component_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_Decl :=
     Internal_Entity_Component_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_309 with Inline_Always;
            procedure Finalizer_Scope_2191 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Component_Def;
Fld_2 : Internal_Entity_Type_Expr;
Fld_3 : Logic_Equation;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_309 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_309;
            procedure Finalizer_Scope_2191 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2191;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2866 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2854 '<FieldAccess for expr_type at ast.py:4771>' Fld /tmp/lal-23.0.0/ada/ast.py:4771
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 2854
Block_Var := Fld; 
--# bind typ Block_Var
--# expr-start 2865 '<And at ast.py:4773>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:4773
--# expr-start 2857 '<FieldAccess for sub_equation at ast.py:4773>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4773
--# expr-start 2856 '<FieldAccess for type_expr at ast.py:4773>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4773
--# expr-start 2855 '<FieldAccess for component_def at ast.py:4773>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4773
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Component_Def (Node => Ent.Node.Component_Decl_F_Component_Def, Info => Ent.Info);
--# expr-done 2855
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Type_Expr (Node => Fld_1.Node.Component_Def_F_Type_Expr, Info => Fld_1.Info);
--# expr-done 2856
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 2857
--# expr-start 2858 '<FieldAccess for default_expr at ast.py:4774>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4774
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Ent.Node.Component_Decl_F_Default_Expr, Info => Ent.Info);
--# expr-done 2858
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind de Var_Expr
--# expr-start 2864 '<And at ast.py:4776>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:4776
--# expr-start 2862 '<And at ast.py:4776>' And_Pred /tmp/lal-23.0.0/ada/ast.py:4776
--# expr-start 2860 '<Bind at ast.py:4776>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:4776
--# expr-start 2859 '<FieldAccess for expected_type_var at ast.py:4776>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4776
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 2859
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4776") else null)); 
--# expr-done 2860
--# expr-start 2861 '<FieldAccess for sub_equation at ast.py:4777>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4777
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_6 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 2861
And_Pred := Create_And (Bind_Result, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4776") else null)); 
--# expr-done 2862
--# expr-start 2863 '<FieldAccess for matches_expected_assign_type at ast.py:4778>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4778
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_7 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 2863
And_Pred_1 := Create_And (And_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4776") else null)); 
--# expr-done 2864
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2191;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4779") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (Fld_3, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4773") else null)); 
--# expr-done 2865
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 2866
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_309;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_309;
               Finalizer_Scope_2191;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Xref_Equation;
--# end
--# property-start ComponentDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:4783
pragma Warnings (Off, "is not referenced");
 function Component_Decl_P_Xref_Entry_Point
  (Node : Bare_Component_Decl
  )
   return Boolean
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Decl_P_Xref_Entry_Point;
--# end
--# property-start ComponentDecl._env_mappings_1 /tmp/lal-23.0.0/ada/ast.py:4727
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_1
  (Node : Bare_Component_Decl
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Component_Decl := Bare_Component_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1469 with Inline_Always;
      Fld : Bare_Defining_Name_List;
Cast_Expr : Bare_Component_Decl;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1469 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1469;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2868 '<FieldAccess for env_mappings at ast.py:4727>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4727
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2867 '<FieldAccess for ids at ast.py:4727>' Fld /tmp/lal-23.0.0/ada/ast.py:4727
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Component_Decl_F_Ids;
--# expr-done 2867
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start AdaNode.env_mappings
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Mappings (Node => Self, Defining_Names => Fld, Value => Cast_Result);
--# end
--# expr-done 2868
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1469;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1469;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_1;
--# end
   --
   --  Primitives for Bare_Discriminant_Spec
   --
      procedure Discriminant_Spec_Pre_Env_Actions
        (Self            : Bare_Discriminant_Spec;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_0 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:4049");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Discriminant_Spec
        (Self : Bare_Discriminant_Spec
         ; Discriminant_Spec_F_Ids : Bare_Defining_Name_List
         ; Discriminant_Spec_F_Type_Expr : Bare_Type_Expr
         ; Discriminant_Spec_F_Default_Expr : Bare_Expr
         ; Discriminant_Spec_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Discriminant_Spec_F_Ids := Discriminant_Spec_F_Ids;
            Self.Discriminant_Spec_F_Type_Expr := Discriminant_Spec_F_Type_Expr;
            Self.Discriminant_Spec_F_Default_Expr := Discriminant_Spec_F_Default_Expr;
            Self.Discriminant_Spec_F_Aspects := Discriminant_Spec_F_Aspects;
      end Initialize_Fields_For_Discriminant_Spec;
   function Discriminant_Spec_F_Ids
     (Node : Bare_Discriminant_Spec) return Bare_Defining_Name_List
   is
   begin
         return Node.Discriminant_Spec_F_Ids;
   end;
   function Discriminant_Spec_F_Type_Expr
     (Node : Bare_Discriminant_Spec) return Bare_Type_Expr
   is
   begin
         return Node.Discriminant_Spec_F_Type_Expr;
   end;
   function Discriminant_Spec_F_Default_Expr
     (Node : Bare_Discriminant_Spec) return Bare_Expr
   is
   begin
         return Node.Discriminant_Spec_F_Default_Expr;
   end;
--# property-start DiscriminantSpec.defining_names /tmp/lal-23.0.0/ada/ast.py:4051
pragma Warnings (Off, "is not referenced");
 function Discriminant_Spec_P_Defining_Names
  (Node : Bare_Discriminant_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_252 with Inline_Always;
      Fld : Bare_Defining_Name_List;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Item_125 : Bare_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_252 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_252;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2871 '<Map at ast.py:4051>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4051
   --# expr-start 2869 '<FieldAccess for ids at ast.py:4051>' Fld /tmp/lal-23.0.0/ada/ast.py:4051
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Discriminant_Spec_F_Ids;
--# expr-done 2869
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Internal_Entity_Defining_Name_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld;
      begin
         for Untyped_Item_125 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_125 := Untyped_Item_125; 
   --# scope-start
               --# bind id Item_125
      --# expr-start 2870 '<as_entity at ast.py:4051>' If_Result /tmp/lal-23.0.0/ada/ast.py:4051
Is_Null := Item_125 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Item_125); 
   If_Result := As_Entity;
end if;
--# expr-done 2870
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := If_Result;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2871
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_252;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_252;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Spec_P_Defining_Names;
--# end
--# property-start DiscriminantSpec.defining_env /tmp/lal-23.0.0/ada/ast.py:4052
pragma Warnings (Off, "is not referenced");
 function Discriminant_Spec_P_Defining_Env
  (Node : Bare_Discriminant_Spec
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Discriminant_Spec :=
     Internal_Entity_Discriminant_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_253 with Inline_Always;
      Fld : Internal_Entity_Type_Expr;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_253 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_253;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2873 '<FieldAccess for defining_env at ast.py:4052>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4052
--# expr-start 2872 '<FieldAccess for type_expr at ast.py:4052>' Fld /tmp/lal-23.0.0/ada/ast.py:4052
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Discriminant_Spec_F_Type_Expr, Info => Ent.Info);
--# expr-done 2872
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.defining_env
Fld_1 := Libadalang.Implementation.Type_Expr_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 2873
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_253;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_253;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Spec_P_Defining_Env;
--# end
--# property-start DiscriminantSpec.type_expression /tmp/lal-23.0.0/ada/ast.py:4054
pragma Warnings (Off, "is not referenced");
 function Discriminant_Spec_P_Type_Expression
  (Node : Bare_Discriminant_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Discriminant_Spec :=
     Internal_Entity_Discriminant_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2874 '<FieldAccess for type_expr at ast.py:4054>' Fld /tmp/lal-23.0.0/ada/ast.py:4054
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Discriminant_Spec_F_Type_Expr, Info => Ent.Info);
--# expr-done 2874
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Spec_P_Type_Expression;
--# end
--# property-start DiscriminantSpec.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:4056
pragma Warnings (Off, "is not referenced");
 function Discriminant_Spec_P_Xref_Entry_Point
  (Node : Bare_Discriminant_Spec
  )
   return Boolean
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Spec_P_Xref_Entry_Point;
--# end
--# property-start DiscriminantSpec.is_constant_object /tmp/lal-23.0.0/ada/ast.py:4058
pragma Warnings (Off, "is not referenced");
 function Discriminant_Spec_P_Is_Constant_Object
  (Node : Bare_Discriminant_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Spec_P_Is_Constant_Object;
--# end
--# property-start DiscriminantSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:4061
pragma Warnings (Off, "is not referenced");
 function Discriminant_Spec_P_Xref_Equation
  (Node : Bare_Discriminant_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Discriminant_Spec :=
     Internal_Entity_Discriminant_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_257 with Inline_Always;
            procedure Finalizer_Scope_2193 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Type_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Var;
Fld_4 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_257 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_257;
            procedure Finalizer_Scope_2193 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2193;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2886 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2885 '<And at ast.py:4062>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:4062
--# expr-start 2876 '<FieldAccess for sub_equation at ast.py:4063>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4063
--# expr-start 2875 '<FieldAccess for type_expr at ast.py:4063>' Fld /tmp/lal-23.0.0/ada/ast.py:4063
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Discriminant_Spec_F_Type_Expr, Info => Ent.Info);
--# expr-done 2875
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 2876
--# expr-start 2877 '<FieldAccess for default_expr at ast.py:4064>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4064
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Discriminant_Spec_F_Default_Expr, Info => Ent.Info);
--# expr-done 2877
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind de Var_Expr
--# expr-start 2884 '<And at ast.py:4066>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:4066
--# expr-start 2882 '<And at ast.py:4066>' And_Pred /tmp/lal-23.0.0/ada/ast.py:4066
--# expr-start 2880 '<Bind at ast.py:4066>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:4066
--# expr-start 2878 '<FieldAccess for expected_type_var at ast.py:4066>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4066
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 2878
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 2879 '<FieldAccess for expr_type at ast.py:4066>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4066
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 2879
      Cast_Result := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Bind_Result := Solver.Create_Assign (Fld_3, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4066") else null)); 
--# expr-done 2880
--# expr-start 2881 '<FieldAccess for sub_equation at ast.py:4067>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4067
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 2881
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4066") else null)); 
--# expr-done 2882
--# expr-start 2883 '<FieldAccess for matches_expected_assign_type at ast.py:4068>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4068
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 2883
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4066") else null)); 
--# expr-done 2884
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2193;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4069") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (Fld_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4062") else null)); 
--# expr-done 2885
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 2886
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_257;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_257;
               Finalizer_Scope_2193;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discriminant_Spec_P_Xref_Equation;
--# end
--# property-start DiscriminantSpec._env_mappings_0 /tmp/lal-23.0.0/ada/ast.py:4049
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_0
  (Node : Bare_Discriminant_Spec
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Discriminant_Spec := Bare_Discriminant_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1468 with Inline_Always;
      Fld : Bare_Defining_Name_List;
Cast_Expr : Bare_Discriminant_Spec;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1468 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1468;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2888 '<FieldAccess for env_mappings at ast.py:4049>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4049
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2887 '<FieldAccess for ids at ast.py:4049>' Fld /tmp/lal-23.0.0/ada/ast.py:4049
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Discriminant_Spec_F_Ids;
--# expr-done 2887
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start AdaNode.env_mappings
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Mappings (Node => Self, Defining_Names => Fld, Value => Cast_Result);
--# end
--# expr-done 2888
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1468;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1468;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_0;
--# end
   --
   --  Primitives for Bare_Generic_Formal
   --
      procedure Initialize_Fields_For_Generic_Formal
        (Self : Bare_Generic_Formal
         ; Generic_Formal_F_Decl : Bare_Basic_Decl
        ) is
      begin
            Self.Generic_Formal_F_Decl := Generic_Formal_F_Decl;
      end Initialize_Fields_For_Generic_Formal;
   function Generic_Formal_F_Decl
     (Node : Bare_Generic_Formal) return Bare_Basic_Decl
   is
   begin
         return Node.Generic_Formal_F_Decl;
   end;
--# property-start GenericFormal.defining_names /tmp/lal-23.0.0/ada/ast.py:11334
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_P_Defining_Names
  (Node : Bare_Generic_Formal
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Formal := Bare_Generic_Formal (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Formal :=
     Internal_Entity_Generic_Formal'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_894 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_894 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_894;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2890 '<FieldAccess for defining_names at ast.py:11334>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11334
--# expr-start 2889 '<FieldAccess for decl at ast.py:11334>' Fld /tmp/lal-23.0.0/ada/ast.py:11334
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Basic_Decl (Node => Ent.Node.Generic_Formal_F_Decl, Info => Ent.Info);
--# expr-done 2889
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 2890
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_894;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_894;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_P_Defining_Names;
--# end
--# property-start GenericFormal.type_expression /tmp/lal-23.0.0/ada/ast.py:11335
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_P_Type_Expression
  (Node : Bare_Generic_Formal
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Generic_Formal := Bare_Generic_Formal (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Formal :=
     Internal_Entity_Generic_Formal'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2892 '<FieldAccess for type_expression at ast.py:11335>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11335
--# expr-start 2891 '<FieldAccess for decl at ast.py:11335>' Fld /tmp/lal-23.0.0/ada/ast.py:11335
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Basic_Decl (Node => Ent.Node.Generic_Formal_F_Decl, Info => Ent.Info);
--# expr-done 2891
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 2892
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_P_Type_Expression;
--# end
--# property-start GenericFormal.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:11337
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_P_Xref_Entry_Point
  (Node : Bare_Generic_Formal
  )
   return Boolean
is
   Self : Bare_Generic_Formal := Bare_Generic_Formal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_P_Xref_Entry_Point;
--# end
--# property-start GenericFormal.xref_equation /tmp/lal-23.0.0/ada/ast.py:11338
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_P_Xref_Equation
  (Node : Bare_Generic_Formal
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Generic_Formal := Bare_Generic_Formal (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Formal :=
     Internal_Entity_Generic_Formal'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_897 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Logic_Equation;
            procedure Finalizer_Scope_897 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_897;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2894 '<FieldAccess for xref_equation at ast.py:11338>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11338
--# expr-start 2893 '<FieldAccess for decl at ast.py:11338>' Fld /tmp/lal-23.0.0/ada/ast.py:11338
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Basic_Decl (Node => Ent.Node.Generic_Formal_F_Decl, Info => Ent.Info);
--# expr-done 2893
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 2894
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_897;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_897;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Generic_Formal_Obj_Decl
   --
      procedure Initialize_Fields_For_Generic_Formal_Obj_Decl
        (Self : Bare_Generic_Formal_Obj_Decl
         ; Generic_Formal_F_Decl : Bare_Basic_Decl
        ) is
      begin
            Initialize_Fields_For_Generic_Formal
              (Self, Generic_Formal_F_Decl);
      end Initialize_Fields_For_Generic_Formal_Obj_Decl;
   --
   --  Primitives for Bare_Generic_Formal_Package
   --
      procedure Initialize_Fields_For_Generic_Formal_Package
        (Self : Bare_Generic_Formal_Package
         ; Generic_Formal_F_Decl : Bare_Basic_Decl
        ) is
      begin
            Initialize_Fields_For_Generic_Formal
              (Self, Generic_Formal_F_Decl);
      end Initialize_Fields_For_Generic_Formal_Package;
   --
   --  Primitives for Bare_Generic_Formal_Subp_Decl
   --
      procedure Initialize_Fields_For_Generic_Formal_Subp_Decl
        (Self : Bare_Generic_Formal_Subp_Decl
         ; Generic_Formal_F_Decl : Bare_Basic_Decl
        ) is
      begin
            Initialize_Fields_For_Generic_Formal
              (Self, Generic_Formal_F_Decl);
      end Initialize_Fields_For_Generic_Formal_Subp_Decl;
   --
   --  Primitives for Bare_Generic_Formal_Type_Decl
   --
      procedure Initialize_Fields_For_Generic_Formal_Type_Decl
        (Self : Bare_Generic_Formal_Type_Decl
         ; Generic_Formal_F_Decl : Bare_Basic_Decl
        ) is
      begin
            Initialize_Fields_For_Generic_Formal
              (Self, Generic_Formal_F_Decl);
      end Initialize_Fields_For_Generic_Formal_Type_Decl;
--# property-start GenericFormalTypeDecl.default_type /tmp/lal-23.0.0/ada/ast.py:11353
pragma Warnings (Off, "is not referenced");
 function Generic_Formal_Type_Decl_P_Default_Type
  (Node : Bare_Generic_Formal_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Generic_Formal_Type_Decl := Bare_Generic_Formal_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Formal_Type_Decl :=
     Internal_Entity_Generic_Formal_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Name;
Match_0 : Internal_Entity_Formal_Type_Decl;
Match_1 : Internal_Entity_Incomplete_Formal_Type_Decl;
Match_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Name;
Fld_2 : Internal_Entity_Name;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Formal_Type_Decl;
Let_Result : Internal_Entity_Name;
Scope_Result : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Incomplete_Formal_Type_Decl;
Let_Result_1 : Internal_Entity_Name;
Scope_Result_1 : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Name;
Scope_Result_2 : Internal_Entity_Name;
Match_Result : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2900 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 2898 '<Match at ast.py:11354>' Match_Result /tmp/lal-23.0.0/ada/ast.py:11354
--# expr-start 2895 '<FieldAccess for decl at ast.py:11354>' Fld /tmp/lal-23.0.0/ada/ast.py:11354
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Basic_Decl (Node => Ent.Node.Generic_Formal_F_Decl, Info => Ent.Info);
--# expr-done 2895
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Formal_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind ft Match_0
--# expr-start 2896 '<FieldAccess for default_type at ast.py:11355>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11355
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Match_0.Node.Formal_Type_Decl_F_Default_Type, Info => Match_0.Info);
--# expr-done 2896
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Incomplete_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Incomplete_Formal_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind ift Match_1
--# expr-start 2897 '<FieldAccess for default_type at ast.py:11356>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11356
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Match_1.Node.Incomplete_Formal_Type_Decl_F_Default_Type, Info => Match_1.Info);
--# expr-done 2897
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Incomplete_Type_Decl | Ada_Incomplete_Tagged_Type_Decl .. Ada_Concrete_Type_Decl | Ada_Abstract_Subp_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Name; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 2898
Var_Expr := Match_Result;
if Var_Expr /= No_Entity_Name then
   --# scope-start
--# expr-start 2899 '<FieldAccess for name_designated_type at ast.py:11358>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11358
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2899
Scope_Result_3 := Fld_3;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result_3 := Result_Var; 
--# end
--# expr-done 2900
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Formal_Type_Decl_P_Default_Type;
--# end
   --
   --  Primitives for Bare_Param_Spec
   --
      procedure Param_Spec_Pre_Env_Actions
        (Self            : Bare_Param_Spec;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_24 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:9248");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Param_Spec
        (Self : Bare_Param_Spec
         ; Param_Spec_F_Ids : Bare_Defining_Name_List
         ; Param_Spec_F_Has_Aliased : Bare_Aliased_Node
         ; Param_Spec_F_Mode : Bare_Mode
         ; Param_Spec_F_Type_Expr : Bare_Type_Expr
         ; Param_Spec_F_Default_Expr : Bare_Expr
         ; Param_Spec_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Param_Spec_F_Ids := Param_Spec_F_Ids;
            Self.Param_Spec_F_Has_Aliased := Param_Spec_F_Has_Aliased;
            Self.Param_Spec_F_Mode := Param_Spec_F_Mode;
            Self.Param_Spec_F_Type_Expr := Param_Spec_F_Type_Expr;
            Self.Param_Spec_F_Default_Expr := Param_Spec_F_Default_Expr;
            Self.Param_Spec_F_Aspects := Param_Spec_F_Aspects;
      end Initialize_Fields_For_Param_Spec;
   function Param_Spec_F_Ids
     (Node : Bare_Param_Spec) return Bare_Defining_Name_List
   is
   begin
         return Node.Param_Spec_F_Ids;
   end;
   function Param_Spec_F_Has_Aliased
     (Node : Bare_Param_Spec) return Bare_Aliased_Node
   is
   begin
         return Node.Param_Spec_F_Has_Aliased;
   end;
   function Param_Spec_F_Mode
     (Node : Bare_Param_Spec) return Bare_Mode
   is
   begin
         return Node.Param_Spec_F_Mode;
   end;
   function Param_Spec_F_Type_Expr
     (Node : Bare_Param_Spec) return Bare_Type_Expr
   is
   begin
         return Node.Param_Spec_F_Type_Expr;
   end;
   function Param_Spec_F_Default_Expr
     (Node : Bare_Param_Spec) return Bare_Expr
   is
   begin
         return Node.Param_Spec_F_Default_Expr;
   end;
--# property-start ParamSpec.is_mandatory /tmp/lal-23.0.0/ada/ast.py:9244
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Is_Mandatory
  (Node : Bare_Param_Spec
  )
   return Boolean
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Expr;
Is_Null : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2902 '<IsNull at ast.py:9244>' Is_Null /tmp/lal-23.0.0/ada/ast.py:9244
--# expr-start 2901 '<FieldAccess for default_expr at ast.py:9244>' Fld /tmp/lal-23.0.0/ada/ast.py:9244
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Param_Spec_F_Default_Expr;
--# expr-done 2901
Is_Null := Fld = null; 
--# expr-done 2902
      Property_Result := Is_Null;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Is_Mandatory;
--# end
--# property-start ParamSpec.defining_names /tmp/lal-23.0.0/ada/ast.py:9245
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Defining_Names
  (Node : Bare_Param_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_757 with Inline_Always;
      Fld : Bare_Defining_Name_List;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Item_126 : Bare_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_757 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_757;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2905 '<Map at ast.py:9245>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9245
   --# expr-start 2903 '<FieldAccess for ids at ast.py:9245>' Fld /tmp/lal-23.0.0/ada/ast.py:9245
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Param_Spec_F_Ids;
--# expr-done 2903
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Internal_Entity_Defining_Name_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld;
      begin
         for Untyped_Item_126 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_126 := Untyped_Item_126; 
   --# scope-start
               --# bind id Item_126
      --# expr-start 2904 '<as_entity at ast.py:9245>' If_Result /tmp/lal-23.0.0/ada/ast.py:9245
Is_Null := Item_126 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Item_126); 
   If_Result := As_Entity;
end if;
--# expr-done 2904
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := If_Result;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 2905
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_757;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_757;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Defining_Names;
--# end
--# property-start ParamSpec.type_expression /tmp/lal-23.0.0/ada/ast.py:9251
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Type_Expression
  (Node : Bare_Param_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Param_Spec :=
     Internal_Entity_Param_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2906 '<FieldAccess for type_expr at ast.py:9251>' Fld /tmp/lal-23.0.0/ada/ast.py:9251
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Param_Spec_F_Type_Expr, Info => Ent.Info);
--# expr-done 2906
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Type_Expression;
--# end
--# property-start ParamSpec.is_constant_object /tmp/lal-23.0.0/ada/ast.py:9254
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Is_Constant_Object
  (Node : Bare_Param_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Mode;
Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2909 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2908 '<IsA Mode.In, Mode.Default at ast.py:9255>' Is_A /tmp/lal-23.0.0/ada/ast.py:9255
--# expr-start 2907 '<FieldAccess for mode at ast.py:9255>' Fld /tmp/lal-23.0.0/ada/ast.py:9255
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Param_Spec_F_Mode;
--# expr-done 2907
Is_A := Fld /= null 
and then Fld.Kind in Ada_Mode_In_Range | Ada_Mode_Default_Range; 
--# expr-done 2908
Let_Result := Is_A; 
--# end
--# expr-done 2909
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Is_Constant_Object;
--# end
--# property-start ParamSpec.defining_env /tmp/lal-23.0.0/ada/ast.py:9258
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Defining_Env
  (Node : Bare_Param_Spec
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Param_Spec :=
     Internal_Entity_Param_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_760 with Inline_Always;
      Fld : Internal_Entity_Type_Expr;
Fld_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_760 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_760;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2912 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2911 '<FieldAccess for defining_env at ast.py:9259>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9259
--# expr-start 2910 '<FieldAccess for type_expr at ast.py:9259>' Fld /tmp/lal-23.0.0/ada/ast.py:9259
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Param_Spec_F_Type_Expr, Info => Ent.Info);
--# expr-done 2910
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.defining_env
Fld_1 := Libadalang.Implementation.Type_Expr_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 2911
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 2912
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_760;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_760;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Defining_Env;
--# end
--# property-start ParamSpec.constrain_prefix /tmp/lal-23.0.0/ada/ast.py:9262
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Constrain_Prefix
  (Node : Bare_Param_Spec
      ; Prefix : Bare_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind prefix Prefix
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_761 with Inline_Always;
            procedure Finalizer_Scope_2199 with Inline_Always;
      Var_Expr : Bare_Name;
Fld : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Cast_Expr_1 : Bare_Expr;
Cast_Result_1 : Bare_Name;
Fld_1 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result_2 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Scope_Result : Logic_Equation;
False_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_761 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (False_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_761;
            procedure Finalizer_Scope_2199 is
            begin
                     Dec_Ref (Bind_Result_1);
            end Finalizer_Scope_2199;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2919 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2918 '<And at ast.py:9268>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9268
--# expr-start 2914 '<Bind at ast.py:9269>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:9269
--# expr-start 2913 '<FieldAccess for type_var at ast.py:9269>' Fld /tmp/lal-23.0.0/ada/ast.py:9269
      if Prefix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Prefix);
--# expr-done 2913
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
Cast_Expr := No_Entity_Base_Type_Decl; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9269") else null)); 
--# expr-done 2914
--# expr-start 2915 '<Cast to Name at ast.py:9270>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9270
Cast_Expr_1 := Prefix; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Name
   then
      Cast_Result_1 := Cast_Expr_1;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 2915
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind name Var_Expr
--# expr-start 2917 '<Bind at ast.py:9271>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:9271
--# expr-start 2916 '<FieldAccess for subp_spec_var at ast.py:9271>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9271
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Var_Expr);
--# end
--# expr-done 2916
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Cast_Expr_2 := No_Entity_Base_Formal_Param_Holder; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_1, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9271") else null)); 
--# expr-done 2917
Scope_Result := Bind_Result_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2199;
   Result_Var := Scope_Result;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9273") else null)); 
   Result_Var := False_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Bind_Result, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9268") else null)); 
--# expr-done 2918
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 2919
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_761;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_761;
               Finalizer_Scope_2199;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Constrain_Prefix;
--# end
--# property-start ParamSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:9278
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Xref_Equation
  (Node : Bare_Param_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Param_Spec :=
     Internal_Entity_Param_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_762 with Inline_Always;
            procedure Finalizer_Scope_2200 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_762 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_762;
            procedure Finalizer_Scope_2200 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2200;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2931 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2920 '<FieldAccess for expr_type at ast.py:9279>' Fld /tmp/lal-23.0.0/ada/ast.py:9279
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 2920
Block_Var := Fld; 
--# bind typ Block_Var
--# expr-start 2930 '<And at ast.py:9281>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:9281
--# expr-start 2922 '<FieldAccess for sub_equation at ast.py:9281>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9281
--# expr-start 2921 '<FieldAccess for type_expr at ast.py:9281>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9281
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Param_Spec_F_Type_Expr, Info => Ent.Info);
--# expr-done 2921
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_2 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 2922
--# expr-start 2923 '<FieldAccess for default_expr at ast.py:9283>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9283
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Param_Spec_F_Default_Expr, Info => Ent.Info);
--# expr-done 2923
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind de Var_Expr
--# expr-start 2929 '<And at ast.py:9285>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:9285
--# expr-start 2927 '<And at ast.py:9285>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9285
--# expr-start 2925 '<Bind at ast.py:9285>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:9285
--# expr-start 2924 '<FieldAccess for expected_type_var at ast.py:9285>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9285
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 2924
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9285") else null)); 
--# expr-done 2925
--# expr-start 2926 '<FieldAccess for sub_equation at ast.py:9286>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9286
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 2926
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9285") else null)); 
--# expr-done 2927
--# expr-start 2928 '<FieldAccess for matches_expected_assign_type at ast.py:9287>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9287
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 2928
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9285") else null)); 
--# expr-done 2929
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2200;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9288") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (Fld_2, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9281") else null)); 
--# expr-done 2930
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 2931
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_762;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_762;
               Finalizer_Scope_2200;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Xref_Equation;
--# end
--# property-start ParamSpec.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:9292
pragma Warnings (Off, "is not referenced");
 function Param_Spec_P_Xref_Entry_Point
  (Node : Bare_Param_Spec
  )
   return Boolean
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Param_Spec_P_Xref_Entry_Point;
--# end
--# property-start ParamSpec._env_mappings_24 /tmp/lal-23.0.0/ada/ast.py:9248
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_24
  (Node : Bare_Param_Spec
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Param_Spec := Bare_Param_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1493 with Inline_Always;
      Fld : Bare_Defining_Name_List;
Cast_Expr : Bare_Param_Spec;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1493 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1493;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2933 '<FieldAccess for env_mappings at ast.py:9248>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9248
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2932 '<FieldAccess for ids at ast.py:9248>' Fld /tmp/lal-23.0.0/ada/ast.py:9248
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Param_Spec_F_Ids;
--# expr-done 2932
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start AdaNode.env_mappings
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Mappings (Node => Self, Defining_Names => Fld, Value => Cast_Result);
--# end
--# expr-done 2933
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1493;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1493;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_24;
--# end
   --
   --  Primitives for Bare_Synthetic_Formal_Param_Decl
   --
      procedure Initialize_Fields_For_Synthetic_Formal_Param_Decl
        (Self : Bare_Synthetic_Formal_Param_Decl
         ; Synthetic_Formal_Param_Decl_F_Param_Type : Bare_Type_Expr
        ) is
      begin
            Self.Synthetic_Formal_Param_Decl_F_Param_Type := Synthetic_Formal_Param_Decl_F_Param_Type;
      Self.Synthetic_Formal_Param_Decl_Param_Name := null;
      end Initialize_Fields_For_Synthetic_Formal_Param_Decl;
   function Synthetic_Formal_Param_Decl_F_Param_Type
     (Node : Bare_Synthetic_Formal_Param_Decl) return Bare_Type_Expr
   is
   begin
         return Node.Synthetic_Formal_Param_Decl_F_Param_Type;
   end;
--# property-start SyntheticFormalParamDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:17521
pragma Warnings (Off, "is not referenced");
 function Synthetic_Formal_Param_Decl_P_Defining_Names
  (Node : Bare_Synthetic_Formal_Param_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Synthetic_Formal_Param_Decl := Bare_Synthetic_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1250 with Inline_Always;
      Fld : Symbol_Type;
Fld_1 : Bare_Defining_Name;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Array_Lit : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1250 is
            begin
                     Dec_Ref (Array_Lit);
            end Finalizer_Scope_1250;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2937 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 2936 '<as_entity at ast.py:17522>' If_Result /tmp/lal-23.0.0/ada/ast.py:17522
--# expr-start 2935 '<FieldAccess for synthesize_defining_name at ast.py:17522>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17522
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 2934 '<FieldAccess for param_name at ast.py:17522>' Fld /tmp/lal-23.0.0/ada/ast.py:17522
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Synthetic_Formal_Param_Decl_Param_Name;
--# expr-done 2934
--# property-call-start AdaNode.synthesize_defining_name
Fld_1 := Libadalang.Implementation.Ada_Node_P_Synthesize_Defining_Name (Node => Self, Sym => Fld);
--# end
--# expr-done 2935
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 2936
Array_Lit := Create_Internal_Entity_Defining_Name_Array (Internal_Internal_Entity_Defining_Name_Array'(1 => If_Result)); 
--# expr-done 2937
      Property_Result := Array_Lit;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1250;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1250;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Formal_Param_Decl_P_Defining_Names;
--# end
--# property-start SyntheticFormalParamDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:17525
pragma Warnings (Off, "is not referenced");
 function Synthetic_Formal_Param_Decl_P_Type_Expression
  (Node : Bare_Synthetic_Formal_Param_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Synthetic_Formal_Param_Decl := Bare_Synthetic_Formal_Param_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Formal_Param_Decl :=
     Internal_Entity_Synthetic_Formal_Param_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2938 '<FieldAccess for param_type at ast.py:17525>' Fld /tmp/lal-23.0.0/ada/ast.py:17525
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Synthetic_Formal_Param_Decl_F_Param_Type, Info => Ent.Info);
--# expr-done 2938
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Formal_Param_Decl_P_Type_Expression;
--# end
   --
   --  Primitives for Bare_Base_Package_Decl
   --
      procedure Initialize_Fields_For_Base_Package_Decl
        (Self : Bare_Base_Package_Decl
         ; Base_Package_Decl_F_Package_Name : Bare_Defining_Name
         ; Base_Package_Decl_F_Aspects : Bare_Aspect_Spec
         ; Base_Package_Decl_F_Public_Part : Bare_Public_Part
         ; Base_Package_Decl_F_Private_Part : Bare_Private_Part
         ; Base_Package_Decl_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Base_Package_Decl_F_Package_Name := Base_Package_Decl_F_Package_Name;
            Self.Base_Package_Decl_F_Aspects := Base_Package_Decl_F_Aspects;
            Self.Base_Package_Decl_F_Public_Part := Base_Package_Decl_F_Public_Part;
            Self.Base_Package_Decl_F_Private_Part := Base_Package_Decl_F_Private_Part;
            Self.Base_Package_Decl_F_End_Name := Base_Package_Decl_F_End_Name;
      end Initialize_Fields_For_Base_Package_Decl;
   function Base_Package_Decl_F_Package_Name
     (Node : Bare_Base_Package_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Base_Package_Decl_F_Package_Name;
   end;
   function Base_Package_Decl_F_Public_Part
     (Node : Bare_Base_Package_Decl) return Bare_Public_Part
   is
   begin
         return Node.Base_Package_Decl_F_Public_Part;
   end;
   function Base_Package_Decl_F_Private_Part
     (Node : Bare_Base_Package_Decl) return Bare_Private_Part
   is
   begin
         return Node.Base_Package_Decl_F_Private_Part;
   end;
   function Base_Package_Decl_F_End_Name
     (Node : Bare_Base_Package_Decl) return Bare_End_Name
   is
   begin
         return Node.Base_Package_Decl_F_End_Name;
   end;
--# property-start BasePackageDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:10466
pragma Warnings (Off, "is not referenced");
 function Base_Package_Decl_P_Defining_Names
  (Node : Bare_Base_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Base_Package_Decl := Bare_Base_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Package_Decl :=
     Internal_Entity_Base_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_837 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_837 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_837;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2939 '<FieldAccess for package_name at ast.py:10466>' Fld /tmp/lal-23.0.0/ada/ast.py:10466
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Base_Package_Decl_F_Package_Name, Info => Ent.Info);
--# expr-done 2939
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_837;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_837;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Package_Decl_P_Defining_Names;
--# end
--# property-start BasePackageDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:10467
pragma Warnings (Off, "is not referenced");
 function Base_Package_Decl_P_Defining_Env
  (Node : Bare_Base_Package_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Package_Decl := Bare_Base_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Package_Decl :=
     Internal_Entity_Base_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_838 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_838 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_838;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2940 '<FieldAccess for children_env at ast.py:10467>' Fld /tmp/lal-23.0.0/ada/ast.py:10467
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 2940
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_838;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_838;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Package_Decl_P_Defining_Env;
--# end
--# property-start BasePackageDecl.body_part /tmp/lal-23.0.0/ada/ast.py:10470
pragma Warnings (Off, "is not referenced");
 function Base_Package_Decl_P_Body_Part
  (Node : Bare_Base_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Package_Body
is
   Self : Bare_Base_Package_Decl := Bare_Base_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Package_Decl :=
     Internal_Entity_Base_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Package_Body;
      Bound_Imprecise_Fallback : Boolean;
Fld : Internal_Entity_Body_Node;
Cast_Result : Internal_Entity_Package_Body;
Dyn_Var_Bind_Result : Internal_Entity_Package_Body;
Let_Result : Internal_Entity_Package_Body;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2944 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2943 '<bind at ast.py:10474>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:10474
Bound_Imprecise_Fallback := False; 
--# expr-start 2942 '<Cast to PackageBody at ast.py:10477>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10477
--# expr-start 2941 '<FieldAccess for body_part_for_decl at ast.py:10476>' Fld /tmp/lal-23.0.0/ada/ast.py:10476
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 2941
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Package_Body_Range
   then
      Cast_Result := Create_Internal_Entity_Package_Body
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Package_Body;
   end if;
--# expr-done 2942
Dyn_Var_Bind_Result := Cast_Result; 
--# expr-done 2943
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 2944
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Package_Decl_P_Body_Part;
--# end
--# property-start BasePackageDecl.declarative_parts /tmp/lal-23.0.0/ada/ast.py:10481
pragma Warnings (Off, "is not referenced");
 function Base_Package_Decl_P_Declarative_Parts
  (Node : Bare_Base_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Base_Package_Decl := Bare_Base_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Package_Decl :=
     Internal_Entity_Base_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_840 with Inline_Always;
            procedure Finalizer_Scope_2201 with Inline_Always;
      Var_Expr : Internal_Entity_Declarative_Part;
Fld : Internal_Entity_Public_Part;
Cast_Result : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
Fld_1 : Internal_Entity_Private_Part;
Cast_Result_1 : Internal_Entity_Declarative_Part;
Singleton_1 : Internal_Entity_Declarative_Part_Array_Access;
Scope_Result : Internal_Entity_Declarative_Part_Array_Access;
Result_Var : Internal_Entity_Declarative_Part_Array_Access;
Concat_Result : Internal_Entity_Declarative_Part_Array_Access;
Let_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_840 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_840;
            procedure Finalizer_Scope_2201 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2201;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2950 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2949 '<Concat at ast.py:10482>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:10482
--# expr-start 2946 '<Cast to DeclarativePart at ast.py:10482>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10482
--# expr-start 2945 '<FieldAccess for public_part at ast.py:10482>' Fld /tmp/lal-23.0.0/ada/ast.py:10482
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Public_Part (Node => Ent.Node.Base_Package_Decl_F_Public_Part, Info => Ent.Info);
--# expr-done 2945
      Cast_Result := Create_Internal_Entity_Declarative_Part
        (Node => Fld.Node,
         Info => Fld.Info);
--# expr-done 2946
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
--# expr-start 2948 '<Cast to DeclarativePart at ast.py:10483>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:10483
--# expr-start 2947 '<FieldAccess for private_part at ast.py:10483>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10483
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Private_Part (Node => Ent.Node.Base_Package_Decl_F_Private_Part, Info => Ent.Info);
--# expr-done 2947
      Cast_Result_1 := Create_Internal_Entity_Declarative_Part
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
--# expr-done 2948
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Declarative_Part then
   --# scope-start
                Singleton_1 := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton_1.Items (1) := Var_Expr;
Scope_Result := Singleton_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2201;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Declarative_Part_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result := Concat (Singleton, Result_Var); 
--# expr-done 2949
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 2950
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_840;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_840;
               Finalizer_Scope_2201;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Package_Decl_P_Declarative_Parts;
--# end
--# property-start BasePackageDecl.env_names /tmp/lal-23.0.0/ada/ast.py:10487
pragma Warnings (Off, "is not referenced");
 function Base_Package_Decl_P_Env_Names
  (Node : Bare_Base_Package_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Base_Package_Decl := Bare_Base_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_841 with Inline_Always;
            procedure Finalizer_Scope_2202 with Inline_Always;
      Block_Var : String_Type;
Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Sym_1 : Symbol_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym_2 : Symbol_Type;
Array_Lit_1 : Symbol_Type_Array_Access;
Fld_1 : Bare_Private_Part;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_841 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_841;
            procedure Finalizer_Scope_2202 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2202;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2963 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2951 '<FieldAccess for top_level_env_name at ast.py:10494>' Fld /tmp/lal-23.0.0/ada/ast.py:10494
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 2951
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind fqn Block_Var
Var_Expr := Block_Var;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 2962 '<If at ast.py:10496>' If_Result /tmp/lal-23.0.0/ada/ast.py:10496
--# expr-start 2954 '<Not at ast.py:10497>' Not_Val /tmp/lal-23.0.0/ada/ast.py:10497
--# expr-start 2953 '<IsNull at ast.py:10497>' Is_Null /tmp/lal-23.0.0/ada/ast.py:10497
--# expr-start 2952 '<FieldAccess for private_part at ast.py:10497>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10497
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Base_Package_Decl_F_Private_Part;
--# expr-done 2952
Is_Null := Fld_1 = null; 
--# expr-done 2953
Not_Val := not (Is_Null); 
--# expr-done 2954
if Not_Val then
   --# expr-start 2956 '<ArrayLiteral at ast.py:10498>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:10498
--# expr-start 2955 '<to_symbol at ast.py:10499>' Sym /tmp/lal-23.0.0/ada/ast.py:10499
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 2955
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym)); 
--# expr-done 2956
   If_Result := Array_Lit;
else
   --# expr-start 2961 '<ArrayLiteral at ast.py:10501>' Array_Lit_1 /tmp/lal-23.0.0/ada/ast.py:10501
--# expr-start 2957 '<to_symbol at ast.py:10502>' Sym_1 /tmp/lal-23.0.0/ada/ast.py:10502
Sym_1 := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 2957
--# expr-start 2960 '<to_symbol at ast.py:10503>' Sym_2 /tmp/lal-23.0.0/ada/ast.py:10503
--# expr-start 2959 '<Concat at ast.py:10503>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:10503
--# expr-start 2958 '<String at ast.py:10503>' Str /tmp/lal-23.0.0/ada/ast.py:10503
Str := Create_String (".__privatepart"); 
--# expr-done 2958
Concat_Result := Concat_String (Var_Expr, Str); 
--# expr-done 2959
Sym_2 := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 2960
Array_Lit_1 := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym_1, 2 => Sym_2)); 
--# expr-done 2961
   If_Result := Array_Lit_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 2962
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2202;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 2963
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_841;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_841;
               Finalizer_Scope_2202;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Package_Decl_P_Env_Names;
--# end
   --
   --  Primitives for Bare_Generic_Package_Internal
   --
      procedure Generic_Package_Internal_Pre_Env_Actions
        (Self            : Bare_Generic_Package_Internal;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_117 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_118 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Generic_Package_Internal
        (Self : Bare_Generic_Package_Internal
         ; Base_Package_Decl_F_Package_Name : Bare_Defining_Name
         ; Base_Package_Decl_F_Aspects : Bare_Aspect_Spec
         ; Base_Package_Decl_F_Public_Part : Bare_Public_Part
         ; Base_Package_Decl_F_Private_Part : Bare_Private_Part
         ; Base_Package_Decl_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Base_Package_Decl
              (Self, Base_Package_Decl_F_Package_Name, Base_Package_Decl_F_Aspects, Base_Package_Decl_F_Public_Part, Base_Package_Decl_F_Private_Part, Base_Package_Decl_F_End_Name);
      end Initialize_Fields_For_Generic_Package_Internal;
--# property-start GenericPackageInternal.is_library_item /tmp/lal-23.0.0/ada/ast.py:11478
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Internal_P_Is_Library_Item
  (Node : Bare_Generic_Package_Internal
  )
   return Boolean
is
   Self : Bare_Generic_Package_Internal := Bare_Generic_Package_Internal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2967 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2966 '<IsA LibraryItem at ast.py:11482>' Is_A /tmp/lal-23.0.0/ada/ast.py:11482
--# expr-start 2965 '<parent at ast.py:11482>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11482
--# expr-start 2964 '<parent at ast.py:11482>' Fld /tmp/lal-23.0.0/ada/ast.py:11482
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2964
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 2965
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Library_Item_Range; 
--# expr-done 2966
Let_Result := Is_A; 
--# end
--# expr-done 2967
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Internal_P_Is_Library_Item;
--# end
--# property-start GenericPackageInternal._env_trans_parent_117 /tmp/lal-23.0.0/ada/ast.py:11484
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_117
  (Node : Bare_Generic_Package_Internal
  )
   return Boolean
is
   Self : Bare_Generic_Package_Internal := Bare_Generic_Package_Internal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_117;
--# end
--# property-start GenericPackageInternal._env_names_118 /tmp/lal-23.0.0/ada/ast.py:11484
pragma Warnings (Off, "is not referenced");
 function Env_Names_118
  (Node : Bare_Generic_Package_Internal
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Generic_Package_Internal := Bare_Generic_Package_Internal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1587 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1587 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1587;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2968 '<FieldAccess for env_names at ast.py:11484>' Fld /tmp/lal-23.0.0/ada/ast.py:11484
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasePackageDecl.env_names
Fld := Libadalang.Implementation.Base_Package_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 2968
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1587;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1587;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_118;
--# end
   --
   --  Primitives for Bare_Package_Decl
   --
      procedure Package_Decl_Pre_Env_Actions
        (Self            : Bare_Package_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_48 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_49 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:10516");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_50 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10523");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_51 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_52 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_53 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_55 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_54 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_57 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_56 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Package_Decl
        (Self : Bare_Package_Decl
         ; Base_Package_Decl_F_Package_Name : Bare_Defining_Name
         ; Base_Package_Decl_F_Aspects : Bare_Aspect_Spec
         ; Base_Package_Decl_F_Public_Part : Bare_Public_Part
         ; Base_Package_Decl_F_Private_Part : Bare_Private_Part
         ; Base_Package_Decl_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Base_Package_Decl
              (Self, Base_Package_Decl_F_Package_Name, Base_Package_Decl_F_Aspects, Base_Package_Decl_F_Public_Part, Base_Package_Decl_F_Private_Part, Base_Package_Decl_F_End_Name);
      end Initialize_Fields_For_Package_Decl;
--# property-start PackageDecl._env_do_48 /tmp/lal-23.0.0/ada/ast.py:10514
pragma Warnings (Off, "is not referenced");
 function Env_Do_48
  (Node : Bare_Package_Decl
  )
   return Boolean
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2969 '<FieldAccess for env_hook at ast.py:10514>' Fld /tmp/lal-23.0.0/ada/ast.py:10514
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 2969
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_48;
--# end
--# property-start PackageDecl._initial_env_49 /tmp/lal-23.0.0/ada/ast.py:10520
pragma Warnings (Off, "is not referenced");
 function Initial_Env_49
  (Node : Bare_Package_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1518 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1518 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1518;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2970 '<FieldAccess for child_decl_initial_env at ast.py:10520>' Fld /tmp/lal-23.0.0/ada/ast.py:10520
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self, Private_Part => True);
--# end
--# expr-done 2970
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1518;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1518;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_49;
--# end
--# property-start PackageDecl._env_mappings_50 /tmp/lal-23.0.0/ada/ast.py:10523
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_50
  (Node : Bare_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Decl :=
     Internal_Entity_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1519 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1519 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1519;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2971 '<FieldAccess for child_decl_env_assocs at ast.py:10523>' Fld /tmp/lal-23.0.0/ada/ast.py:10523
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_env_assocs
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Env_Assocs (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 2971
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1519;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1519;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_50;
--# end
--# property-start PackageDecl._env_trans_parent_51 /tmp/lal-23.0.0/ada/ast.py:10513
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_51
  (Node : Bare_Package_Decl
  )
   return Boolean
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_51;
--# end
--# property-start PackageDecl._env_names_52 /tmp/lal-23.0.0/ada/ast.py:10525
pragma Warnings (Off, "is not referenced");
 function Env_Names_52
  (Node : Bare_Package_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1521 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1521 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1521;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2972 '<FieldAccess for env_names at ast.py:10525>' Fld /tmp/lal-23.0.0/ada/ast.py:10525
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasePackageDecl.env_names
Fld := Libadalang.Implementation.Base_Package_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 2972
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1521;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1521;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_52;
--# end
--# property-start PackageDecl._env_do_53 /tmp/lal-23.0.0/ada/ast.py:10527
pragma Warnings (Off, "is not referenced");
 function Env_Do_53
  (Node : Bare_Package_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1522 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1522 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1522;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2973 '<FieldAccess for populate_dependent_units at ast.py:10527>' Fld /tmp/lal-23.0.0/ada/ast.py:10527
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 2973
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1522;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1522;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_53;
--# end
--# property-start PackageDecl._ref_env_nodes_54 /tmp/lal-23.0.0/ada/ast.py:10530
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_54
  (Node : Bare_Package_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1523 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1523 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1523;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2974 '<FieldAccess for top_level_use_package_clauses at ast.py:10530>' Fld /tmp/lal-23.0.0/ada/ast.py:10530
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 2974
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1523;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1523;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_54;
--# end
--# property-start PackageDecl._ref_cond_55 /tmp/lal-23.0.0/ada/ast.py:10532
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_55
  (Node : Bare_Package_Decl
  )
   return Boolean
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2976 '<IsA LibraryItem, Subunit at ast.py:10532>' Is_A /tmp/lal-23.0.0/ada/ast.py:10532
--# expr-start 2975 '<parent at ast.py:10532>' Fld /tmp/lal-23.0.0/ada/ast.py:10532
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2975
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 2976
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_55;
--# end
--# property-start PackageDecl._ref_env_nodes_56 /tmp/lal-23.0.0/ada/ast.py:10536
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_56
  (Node : Bare_Package_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1525 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1525 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1525;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2977 '<FieldAccess for top_level_use_type_clauses at ast.py:10536>' Fld /tmp/lal-23.0.0/ada/ast.py:10536
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 2977
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1525;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1525;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_56;
--# end
--# property-start PackageDecl._ref_cond_57 /tmp/lal-23.0.0/ada/ast.py:10538
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_57
  (Node : Bare_Package_Decl
  )
   return Boolean
is
   Self : Bare_Package_Decl := Bare_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2979 '<IsA LibraryItem, Subunit at ast.py:10538>' Is_A /tmp/lal-23.0.0/ada/ast.py:10538
--# expr-start 2978 '<parent at ast.py:10538>' Fld /tmp/lal-23.0.0/ada/ast.py:10538
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 2978
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 2979
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_57;
--# end
   --
   --  Primitives for Bare_Base_Type_Decl
   --
      procedure Base_Type_Decl_Pre_Env_Actions
        (Self            : Bare_Base_Type_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_2 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:5612");
         Dec_Ref (Mapping.Dest_Env);
      end;
      end;
      procedure Initialize_Fields_For_Base_Type_Decl
        (Self : Bare_Base_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Self.Base_Type_Decl_F_Name := Base_Type_Decl_F_Name;
      Self.Lf_Present_Attributes_Repo := False;
      Self.Lf_Stg_Attributes_Repo := No_Bare_Ada_Node;
      Self.Lf_Present_Dottable_Subps_Env := False;
      Self.Lf_Stg_Dottable_Subps_Env := Empty_Env;
      end Initialize_Fields_For_Base_Type_Decl;
   function Base_Type_Decl_F_Name
     (Node : Bare_Base_Type_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Base_Type_Decl_F_Name;
   end;
--# property-start BaseTypeDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:5614
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Defining_Names
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_411 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_411 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_411;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 2980 '<FieldAccess for name at ast.py:5614>' Fld /tmp/lal-23.0.0/ada/ast.py:5614
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Base_Type_Decl_F_Name, Info => Ent.Info);
--# expr-done 2980
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_411;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_411;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Defining_Names;
--# end
--# property-start BaseTypeDecl.base_subtype /tmp/lal-23.0.0/ada/ast.py:5619
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Base_Subtype
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Discrete_Base_Subtype_Decl;
Match_1 : Internal_Entity_Base_Subtype_Decl;
Match_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Discrete_Base_Subtype_Decl;
Cast_Expr : Internal_Entity_Discrete_Base_Subtype_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Base_Subtype_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Base_Subtype,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 2984 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 2983 '<Match at ast.py:5624>' Match_Result /tmp/lal-23.0.0/ada/ast.py:5624
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Discrete_Base_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Discrete_Base_Subtype_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind db Match_0
Cast_Expr := Match_0; 
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Let_Result := Cast_Result_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Base_Subtype_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind st Match_1
--# expr-start 2982 '<FieldAccess for base_subtype at ast.py:5626>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5626
--# expr-start 2981 '<FieldAccess for get_type at ast.py:5626>' Fld /tmp/lal-23.0.0/ada/ast.py:5626
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 2981
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 2982
Let_Result_1 := Fld_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Classwide_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := Ent; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 2983
Let_Result_3 := Match_Result; 
--# end
--# expr-done 2984
      Property_Result := Let_Result_3;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Base_Subtype;
--# end
--# property-start BaseTypeDecl.anonymous_access_type /tmp/lal-23.0.0/ada/ast.py:5631
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Anonymous_Access_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Defining_Name;
New_Node : Bare_Not_Null_Absent;
Cast_Result : Bare_Not_Null;
New_Node_1 : Bare_Anonymous_Type_Access_Def;
Cast_Result_1 : Bare_Type_Def;
New_Node_2 : Bare_Synth_Anonymous_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Anonymous_Access_Type,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 2991 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2990 '<as_entity at ???>' If_Result None
--# expr-start 2989 '<Cast to BaseTypeDecl at ???>' Cast_Result_2 None
--# expr-start 2988 '<New SynthAnonymousTypeDecl at ???>' New_Node_2 None
--# expr-start 2985 '<FieldAccess for name at ast.py:5633>' Fld /tmp/lal-23.0.0/ada/ast.py:5633
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Base_Type_Decl_F_Name;
--# expr-done 2985
--# expr-start 2987 '<New AnonymousTypeAccessDef at ???>' New_Node_1 None
--# expr-start 2986 '<New NotNull.Absent at ???>' New_Node None
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Not_Null_Absent);
Initialize
  (Self => New_Node,
   Kind => Ada_Not_Null_Absent,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
--# expr-done 2986
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Anonymous_Type_Access_Def);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Anonymous_Type_Access_Def,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Anonymous_Type_Access_Def
     (Self => New_Node_1,
      Access_Def_F_Has_Not_Null => Cast_Result, Anonymous_Type_Access_Def_F_Type_Decl => Self);
--# expr-done 2987
      Cast_Result_1 := New_Node_1;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synth_Anonymous_Type_Decl);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synth_Anonymous_Type_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synth_Anonymous_Type_Decl
     (Self => New_Node_2,
      Base_Type_Decl_F_Name => Fld, Type_Decl_F_Discriminants => No_Bare_Ada_Node, Type_Decl_F_Type_Def => Cast_Result_1);
--# expr-done 2988
      Cast_Result_2 := New_Node_2;
--# expr-done 2989
Is_Null := Cast_Result_2 = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result_2); 
   If_Result := As_Entity;
end if;
--# expr-done 2990
Let_Result := If_Result; 
--# end
--# expr-done 2991
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Anonymous_Access_Type;
--# end
--# property-start BaseTypeDecl.anonymous_access_type_or_null /tmp/lal-23.0.0/ada/ast.py:5642
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Anonymous_Access_Type_Or_Null
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2993 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr := Ent;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 2992 '<FieldAccess for anonymous_access_type at ast.py:5643>' Fld /tmp/lal-23.0.0/ada/ast.py:5643
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.anonymous_access_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Anonymous_Access_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 2992
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 2993
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Anonymous_Access_Type_Or_Null;
--# end
--# property-start BaseTypeDecl.attributes_repo /tmp/lal-23.0.0/ada/ast.py:5647
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_F_Attributes_Repo
  (Node : Bare_Base_Type_Decl
  )
   return Bare_Type_Attributes_Repository
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Type_Attributes_Repository;
      New_Node : Bare_Type_Attributes_Repository;
Let_Result : Bare_Type_Attributes_Repository;
begin
   --# property-body-start
      if Self.Lf_Present_Attributes_Repo then
         Property_Result := Self.Lf_Stg_Attributes_Repo;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 2995 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 2994 '<New TypeAttributesRepository at ast.py:5648>' New_Node /tmp/lal-23.0.0/ada/ast.py:5648
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Type_Attributes_Repository);
Initialize
  (Self => New_Node,
   Kind => Ada_Type_Attributes_Repository,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
      New_Node.Type_Attributes_Repository_Base_Type :=
         Self;
--# expr-done 2994
Let_Result := New_Node; 
--# end
--# expr-done 2995
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Attributes_Repo := True;
      Self.Lf_Stg_Attributes_Repo := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_F_Attributes_Repo;
--# end
--# property-start BaseTypeDecl.private_completion /tmp/lal-23.0.0/ada/ast.py:5653
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Private_Completion
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Bare_Ada_Node_List;
Var_Expr_1 : Bare_Private_Part;
Var_Expr_2 : Bare_Base_Package_Decl;
Var_Expr_3 : Bare_Public_Part;
Var_Expr_4 : Bare_Base_Type_Decl;
Fld : Bare_Declarative_Part;
Cast_Result : Bare_Public_Part;
Fld_1 : Bare_Ada_Node;
Scope_Result : Bare_Ada_Node;
Result_Var : Bare_Ada_Node;
Cast_Result_1 : Bare_Base_Package_Decl;
Fld_2 : Bare_Private_Part;
Scope_Result_1 : Bare_Private_Part;
Result_Var_1 : Bare_Private_Part;
Fld_3 : Bare_Ada_Node_List;
Scope_Result_2 : Bare_Ada_Node_List;
Result_Var_2 : Bare_Ada_Node_List;
Cast_Expr : Bare_Ada_Node;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_4 : Symbol_Type;
Fld_5 : Symbol_Type;
Is_Equal : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
Item_127 : Bare_Ada_Node;
Find_Result : Bare_Ada_Node;
Scope_Result_4 : Bare_Ada_Node;
Result_Var_4 : Bare_Ada_Node;
Cast_Result_3 : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Private_Completion,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 3009 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3008 '<as_entity at ast.py:5665>' If_Result /tmp/lal-23.0.0/ada/ast.py:5665
--# expr-start 3007 '<Cast to BaseTypeDecl at ast.py:5665>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:5665
--# expr-start 2999 '<Cast to BasePackageDecl at ast.py:5659>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:5659
--# expr-start 2997 '<Cast to PublicPart at ast.py:5658>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5658
--# expr-start 2996 '<FieldAccess for declarative_scope at ast.py:5658>' Fld /tmp/lal-23.0.0/ada/ast.py:5658
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 2996
   if Fld = null
      or else Fld.Kind in Ada_Public_Part_Range
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 2997
Var_Expr_3 := Cast_Result;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 2998 '<parent at ast.py:5659>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5659
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr_3.Parent; 
--# expr-done 2998
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
   if Result_Var = null
      or else Result_Var.Kind in Ada_Base_Package_Decl
   then
      Cast_Result_1 := Result_Var;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 2999
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3000 '<FieldAccess for private_part at ast.py:5660>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5660
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr_2.Base_Package_Decl_F_Private_Part;
--# expr-done 3000
Scope_Result_1 := Fld_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Bare_Ada_Node;
end if;
Var_Expr_1 := Result_Var_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3001 '<FieldAccess for decls at ast.py:5660>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5660
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Var_Expr_1.Declarative_Part_F_Decls;
--# expr-done 3001
Scope_Result_2 := Fld_3;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Bare_Ada_Node;
end if;
Var_Expr := Result_Var_2;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3006 '<Find at ast.py:5660>' Find_Result /tmp/lal-23.0.0/ada/ast.py:5660
      Find_Result := No_Bare_Ada_Node;
      if Var_Expr = null then
      Find_Result := No_Bare_Ada_Node;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Var_Expr;
      begin
         for Untyped_Item_127 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_127 := Untyped_Item_127; 
   --# scope-start
               --# bind d Item_127
--# expr-start 3002 '<Cast to BaseTypeDecl at ast.py:5661>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:5661
Cast_Expr := Item_127; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_2 := Cast_Expr;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 3002
Var_Expr_4 := Cast_Result_2;
if Var_Expr_4 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind pp Var_Expr_4
--# expr-start 3005 '<Eq at ast.py:5663>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:5663
--# expr-start 3003 '<FieldAccess for name_symbol at ast.py:5663>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5663
      if Var_Expr_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Var_Expr_4);
--# end
--# expr-done 3003
--# expr-start 3004 '<FieldAccess for name_symbol at ast.py:5663>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5663
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 3004
Is_Equal := Fld_4 = Fld_5; 
--# expr-done 3005
Scope_Result_3 := Is_Equal;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
      if Result_Var_3 then
         Find_Result := Item_127;
      end if;
   --# end
               exit when Result_Var_3;
         end loop;
      end;
      end if;
--# expr-done 3006
Scope_Result_4 := Find_Result;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Bare_Ada_Node;
end if;
   if Result_Var_4 = null
      or else Result_Var_4.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_3 := Result_Var_4;
   else
         Cast_Result_3 := No_Bare_Ada_Node;
   end if;
--# expr-done 3007
Is_Null := Cast_Result_3 = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result_3); 
   If_Result := As_Entity;
end if;
--# expr-done 3008
Let_Result := If_Result; 
--# end
--# expr-done 3009
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Private_Completion;
--# end
--# property-start BaseTypeDecl.is_view_of_type /tmp/lal-23.0.0/ada/ast.py:5669
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_View_Of_Type
  (Node : Bare_Base_Type_Decl
      ; Comp_View : Internal_Entity_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind comp_view Comp_View
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3015 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Ent; 
--# bind typ Block_Var
--# expr-start 3014 '<Cond at ast.py:5675>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:5675
--# expr-start 3010 '<IsNull at ast.py:5676>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5676
Is_Null := Comp_View.Node = null; 
--# expr-done 3010
if Is_Null then
   If_Result_1 := False;
else
--# expr-start 3011 '<Eq at ast.py:5677>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:5677
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Comp_View; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 3011
if Is_Equiv then
   If_Result := True;
else
   --# expr-start 3013 '<FieldAccess for is_view_of_type at ast.py:5678>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5678
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3012 '<FieldAccess for previous_part at ast.py:5678>' Fld /tmp/lal-23.0.0/ada/ast.py:5678
      if Comp_View.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Comp_View.Node, Go_To_Incomplete => True, E_Info => Comp_View.Info);
--# end
--# expr-done 3012
--# property-call-start BaseTypeDecl.is_view_of_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Is_View_Of_Type (Node => Block_Var.Node, Comp_View => Fld, E_Info => Block_Var.Info);
--# end
--# expr-done 3013
   If_Result := Fld_1;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 3014
Let_Result := If_Result_1; 
--# end
--# expr-done 3015
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_View_Of_Type;
--# end
--# property-start BaseTypeDecl.is_array_or_rec /tmp/lal-23.0.0/ada/ast.py:5682
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Array_Or_Rec
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3018 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3016 '<FieldAccess for is_array at ast.py:5683>' Fld /tmp/lal-23.0.0/ada/ast.py:5683
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_array
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Array (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3016
if Fld then
   If_Result := True;
else
   --# expr-start 3017 '<FieldAccess for is_record_type at ast.py:5683>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5683
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_record_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Record_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3017
   If_Result := Fld_1;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3018
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Array_Or_Rec;
--# end
--# property-start BaseTypeDecl.is_inherited_primitive /tmp/lal-23.0.0/ada/ast.py:5686
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Inherited_Primitive
  (Node : Bare_Base_Type_Decl
      ; P : Internal_Entity_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind p P
   Property_Result : Boolean;
      Fld : Bare_Base_Type_Decl;
Fld_1 : Internal_Entity_Info;
Fld_2 : Internal_Metadata;
Fld_3 : Bare_Ada_Node;
Cast_Result : Bare_Ada_Node;
Is_Equal : Boolean;
Not_Val : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3025 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3024 '<Not at ast.py:5691>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5691
--# expr-start 3023 '<Eq at ast.py:5691>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:5691
--# expr-start 3019 '<FieldAccess for node at ast.py:5691>' Fld /tmp/lal-23.0.0/ada/ast.py:5691
Fld := Ent.Node;
--# expr-done 3019
      Cast_Result := Fld;
--# expr-start 3022 '<FieldAccess for primitive at ast.py:5691>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5691
--# expr-start 3021 '<FieldAccess for md at ast.py:5691>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5691
--# expr-start 3020 '<FieldAccess for info at ast.py:5691>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5691
Fld_1 := P.Info;
--# expr-done 3020
Fld_2 := Fld_1.Md;
--# expr-done 3021
Fld_3 := Fld_2.Primitive;
--# expr-done 3022
Is_Equal := Cast_Result = Fld_3; 
--# expr-done 3023
Not_Val := not (Is_Equal); 
--# expr-done 3024
Let_Result := Not_Val; 
--# end
--# expr-done 3025
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Inherited_Primitive;
--# end
--# property-start BaseTypeDecl.get_record_representation_clause /tmp/lal-23.0.0/ada/ast.py:5695
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Get_Record_Representation_Clause
  (Node : Bare_Base_Type_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Record_Rep_Clause
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Record_Rep_Clause;
      Var_Expr : Bare_Declarative_Part;
Var_Expr_1 : Internal_Entity_Record_Rep_Clause;
Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node_List;
Scope_Result : Bare_Ada_Node_List;
Result_Var : Bare_Ada_Node_List;
As_Entity : Internal_Entity_Ada_Node_List;
Is_Null : Boolean;
If_Result : Internal_Entity_Ada_Node_List;
Fld_2 : Bare_Ada_Node_List;
Fld_3 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Record_Rep_Clause;
Fld_4 : Internal_Entity_Name;
Fld_5 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Item_128 : Internal_Entity;
Bare_Item_128 : Bare_Ada_Node;
Find_Result : Internal_Entity;
Cast_Result_3 : Internal_Entity_Record_Rep_Clause;
Let_Result : Internal_Entity_Record_Rep_Clause;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3035 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3034 '<Cast to RecordRepClause.entity at ast.py:5704>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:5704
--# expr-start 3033 '<Find at ast.py:5700>' Find_Result /tmp/lal-23.0.0/ada/ast.py:5700
   --# expr-start 3028 '<as_entity at ast.py:5700>' If_Result /tmp/lal-23.0.0/ada/ast.py:5700
--# expr-start 3026 '<FieldAccess for declarative_scope at ast.py:5700>' Fld /tmp/lal-23.0.0/ada/ast.py:5700
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 3026
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3027 '<FieldAccess for decls at ast.py:5700>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5700
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr.Declarative_Part_F_Decls;
--# expr-done 3027
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_Null := Result_Var = null; 
if Is_Null then
   If_Result := No_Entity_Ada_Node_List;
else
As_Entity := (Info => E_Info, Node => Result_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 3028
Fld_2 := If_Result.Node;
      Find_Result := No_Entity;
      if Fld_2 = null then
      Find_Result := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_128 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_128 := Untyped_Item_128; 
Is_Null_1 := Bare_Item_128 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_3 := If_Result.Info;
As_Entity_1 := (Info => Fld_3, Node => Bare_Item_128); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_128 := If_Result_1; 
   --# scope-start
               --# bind d Item_128
--# expr-start 3029 '<Cast to RecordRepClause at ast.py:5701>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5701
Cast_Expr := Item_128; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Record_Rep_Clause_Range
   then
      Cast_Result := Create_Internal_Entity_Record_Rep_Clause
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Record_Rep_Clause;
   end if;
--# expr-done 3029
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Record_Rep_Clause then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 3032 '<Eq at ast.py:5702>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:5702
--# expr-start 3031 '<FieldAccess for referenced_decl at ast.py:5702>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5702
--# expr-start 3030 '<FieldAccess for name at ast.py:5702>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5702
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Record_Rep_Clause_F_Name, Info => Var_Expr_1.Info);
--# expr-done 3030
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_5 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_4.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_4.Info);
--# end
--# expr-done 3031
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 3032
Scope_Result_1 := Is_Equiv;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
      if Result_Var_1 then
         Find_Result := Item_128;
      end if;
   --# end
               exit when Result_Var_1;
         end loop;
      end;
      end if;
--# expr-done 3033
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Record_Rep_Clause_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Record_Rep_Clause
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_3 := No_Entity_Record_Rep_Clause;
   end if;
--# expr-done 3034
Let_Result := Cast_Result_3; 
--# end
--# expr-done 3035
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Get_Record_Representation_Clause;
--# end
--# property-start BaseTypeDecl.get_enum_representation_clause /tmp/lal-23.0.0/ada/ast.py:5708
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Get_Enum_Representation_Clause
  (Node : Bare_Base_Type_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Enum_Rep_Clause
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Enum_Rep_Clause;
      Var_Expr : Bare_Declarative_Part;
Var_Expr_1 : Internal_Entity_Enum_Rep_Clause;
Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node_List;
Scope_Result : Bare_Ada_Node_List;
Result_Var : Bare_Ada_Node_List;
As_Entity : Internal_Entity_Ada_Node_List;
Is_Null : Boolean;
If_Result : Internal_Entity_Ada_Node_List;
Fld_2 : Bare_Ada_Node_List;
Fld_3 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Enum_Rep_Clause;
Fld_4 : Internal_Entity_Name;
Fld_5 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Item_129 : Internal_Entity;
Bare_Item_129 : Bare_Ada_Node;
Find_Result : Internal_Entity;
Cast_Result_3 : Internal_Entity_Enum_Rep_Clause;
Let_Result : Internal_Entity_Enum_Rep_Clause;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3045 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3044 '<Cast to EnumRepClause.entity at ast.py:5717>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:5717
--# expr-start 3043 '<Find at ast.py:5713>' Find_Result /tmp/lal-23.0.0/ada/ast.py:5713
   --# expr-start 3038 '<as_entity at ast.py:5713>' If_Result /tmp/lal-23.0.0/ada/ast.py:5713
--# expr-start 3036 '<FieldAccess for declarative_scope at ast.py:5713>' Fld /tmp/lal-23.0.0/ada/ast.py:5713
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 3036
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3037 '<FieldAccess for decls at ast.py:5713>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5713
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr.Declarative_Part_F_Decls;
--# expr-done 3037
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_Null := Result_Var = null; 
if Is_Null then
   If_Result := No_Entity_Ada_Node_List;
else
As_Entity := (Info => E_Info, Node => Result_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 3038
Fld_2 := If_Result.Node;
      Find_Result := No_Entity;
      if Fld_2 = null then
      Find_Result := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_129 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_129 := Untyped_Item_129; 
Is_Null_1 := Bare_Item_129 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_3 := If_Result.Info;
As_Entity_1 := (Info => Fld_3, Node => Bare_Item_129); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_129 := If_Result_1; 
   --# scope-start
               --# bind d Item_129
--# expr-start 3039 '<Cast to EnumRepClause at ast.py:5714>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5714
Cast_Expr := Item_129; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Enum_Rep_Clause_Range
   then
      Cast_Result := Create_Internal_Entity_Enum_Rep_Clause
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Enum_Rep_Clause;
   end if;
--# expr-done 3039
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Enum_Rep_Clause then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 3042 '<Eq at ast.py:5715>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:5715
--# expr-start 3041 '<FieldAccess for referenced_decl at ast.py:5715>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5715
--# expr-start 3040 '<FieldAccess for type_name at ast.py:5715>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5715
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Enum_Rep_Clause_F_Type_Name, Info => Var_Expr_1.Info);
--# expr-done 3040
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_5 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_4.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_4.Info);
--# end
--# expr-done 3041
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 3042
Scope_Result_1 := Is_Equiv;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
      if Result_Var_1 then
         Find_Result := Item_129;
      end if;
   --# end
               exit when Result_Var_1;
         end loop;
      end;
      end if;
--# expr-done 3043
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Enum_Rep_Clause_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Enum_Rep_Clause
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_3 := No_Entity_Enum_Rep_Clause;
   end if;
--# expr-done 3044
Let_Result := Cast_Result_3; 
--# end
--# expr-done 3045
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Get_Enum_Representation_Clause;
--# end
--# property-start '[dispatcher]BaseTypeDecl.primitives_env' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Primitives_Env
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.primitives_env
                  Property_Result := Base_Type_Decl_P_Primitives_Env
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.primitives_env
                  Property_Result := Base_Subtype_Decl_P_Primitives_Env
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.primitives_env
                  Property_Result := Type_Decl_P_Primitives_Env
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Primitives_Env;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_record_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Record_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_record_type
                  Property_Result := Base_Type_Decl_P_Is_Record_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_record_type
                  Property_Result := Base_Subtype_Decl_P_Is_Record_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Record_Type;
--# end
--# property-start BaseTypeDecl.is_array_type /tmp/lal-23.0.0/ada/ast.py:5734
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Array_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3047 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3046 '<FieldAccess for is_array at ast.py:5738>' Fld /tmp/lal-23.0.0/ada/ast.py:5738
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_array
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Array (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3046
Let_Result := Fld; 
--# end
--# expr-done 3047
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Array_Type;
--# end
--# property-start BaseTypeDecl.find_derived_types /tmp/lal-23.0.0/ada/ast.py:5742
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Find_Derived_Types
  (Node : Bare_Base_Type_Decl
      ; Root : Internal_Entity
      ; Origin : Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind origin Origin
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Type_Decl_Array_Access;
            procedure Finalizer_Scope_425 with Inline_Always;
            procedure Finalizer_Scope_2219 with Inline_Always;
            procedure Finalizer_Scope_2221 with Inline_Always;
            procedure Finalizer_Scope_2222 with Inline_Always;
            procedure Finalizer_Scope_2223 with Inline_Always;
      Var_Expr : Internal_Entity_Array_Access;
Var_Expr_1 : Internal_Entity_Type_Decl;
Var_Expr_2 : Boolean;
Fld : Internal_Entity_Array_Access;
Is_Null : Boolean;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Ada_Node;
Is_Equal : Boolean;
If_Result : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Array_Access;
Fld_2 : Internal_Entity_Type_Decl_Array_Access;
Map_Result_1 : Internal_Entity_Type_Decl_Array_Access;
Scope_Result : Internal_Entity_Type_Decl_Array_Access;
Result_Var : Internal_Entity_Type_Decl_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result_1 : Internal_Entity_Type_Decl;
Fld_3 : Boolean;
Singleton : Internal_Entity_Type_Decl_Array_Access;
Scope_Result_1 : Internal_Entity_Type_Decl_Array_Access;
Result_Var_1 : Internal_Entity_Type_Decl_Array_Access;
Scope_Result_2 : Internal_Entity_Type_Decl_Array_Access;
Result_Var_2 : Internal_Entity_Type_Decl_Array_Access;
Concat_Result : Internal_Entity_Type_Decl_Array_Access;
Let_Result : Internal_Entity_Type_Decl_Array_Access;
            procedure Finalizer_Scope_425 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_425;
            procedure Finalizer_Scope_2219 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_2219;
            procedure Finalizer_Scope_2221 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2221;
            procedure Finalizer_Scope_2222 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_2222;
            procedure Finalizer_Scope_2223 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2223;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3059 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3058 '<Concat at ast.py:5750>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:5750
--# expr-start 3048 '<children at ast.py:5747>' Fld /tmp/lal-23.0.0/ada/ast.py:5747
      if Root.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children (Node => Root.Node, E_Info => Root.Info);
--# expr-done 3048
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Array_Type then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 3055 '<Mapcat at ast.py:5749>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:5749
   --# expr-start 3053 '<Filter at ast.py:5748>' Map_Result /tmp/lal-23.0.0/ada/ast.py:5748
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Var_Expr;
      begin
         for Item_131 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_131
         --# expr-start 3052 '<Not at ast.py:5748>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5748
--# expr-start 3049 '<IsNull at ast.py:5748>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5748
Is_Null := Item_131.Node = null; 
--# expr-done 3049
if Is_Null then
   If_Result := True;
else
   --# expr-start 3051 '<Eq at ast.py:5748>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:5748
--# expr-start 3050 '<FieldAccess for node at ast.py:5748>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5748
Fld_1 := Item_131.Node;
--# expr-done 3050
      Cast_Result := Fld_1;
Is_Equal := Cast_Result = Origin; 
--# expr-done 3051
   If_Result := Is_Equal;
end if;
Not_Val := not (If_Result); 
--# expr-done 3052
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity := Item_131;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3053
      declare
         Map_Result_1_Vec : Internal_Entity_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result;
      begin
         for Item_130 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_130
      --# expr-start 3054 '<FieldAccess for find_derived_types at ast.py:5749>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5749
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.find_derived_types
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Find_Derived_Types (Node => Ent.Node, Root => Item_130, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3054
         for Item_To_Append of
               Fld_2.Items
         loop
            Internal_Entity_Type_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2221;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Type_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Type_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Type_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Type_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 3055
Scope_Result := Map_Result_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2219;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# expr-start 3056 '<Cast to TypeDecl at ast.py:5750>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:5750
Cast_Expr := Root; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Type_Decl;
   end if;
--# expr-done 3056
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Type_Decl then
   --# scope-start
   --# bind type_decl Var_Expr_1
--# expr-start 3057 '<FieldAccess for is_derived_type at ast.py:5751>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5751
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_derived_type
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Is_Derived_Type (Node => Var_Expr_1.Node, Other_Type => Ent, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 3057
Var_Expr_2 := Fld_3;
if Var_Expr_2 /= False then
   --# scope-start
   --# bind _ Var_Expr_2
                Singleton := Create_Internal_Entity_Type_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr_1;
Scope_Result_1 := Singleton;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2223;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Scope_Result_2 := Result_Var_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2222;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Internal_Entity_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_2);
Concat_Result := Concat (Result_Var, Result_Var_2); 
--# expr-done 3058
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 3059
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_425;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_425;
               Finalizer_Scope_2219;
               Finalizer_Scope_2221;
               Finalizer_Scope_2222;
               Finalizer_Scope_2223;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Find_Derived_Types;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_task_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Task_Type
  (Node : Bare_Base_Type_Decl
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Protected_Type_Decl | Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_task_type
                  Property_Result := Base_Type_Decl_P_Is_Task_Type
                    (Self
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.is_task_type
                  Property_Result := Task_Type_Decl_P_Is_Task_Type
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Task_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_real_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Real_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_real_type
                  Property_Result := Base_Type_Decl_P_Is_Real_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_real_type
                  Property_Result := Base_Subtype_Decl_P_Is_Real_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_real_type
                  Property_Result := Type_Decl_P_Is_Real_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Real_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_float_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Float_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_float_type
                  Property_Result := Base_Type_Decl_P_Is_Float_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_float_type
                  Property_Result := Base_Subtype_Decl_P_Is_Float_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_float_type
                  Property_Result := Type_Decl_P_Is_Float_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Float_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_fixed_point' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Fixed_Point
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_fixed_point
                  Property_Result := Base_Type_Decl_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_fixed_point
                  Property_Result := Base_Subtype_Decl_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_fixed_point
                  Property_Result := Type_Decl_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Fixed_Point;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_enum_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Enum_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_enum_type
                  Property_Result := Base_Type_Decl_P_Is_Enum_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_enum_type
                  Property_Result := Base_Subtype_Decl_P_Is_Enum_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_enum_type
                  Property_Result := Type_Decl_P_Is_Enum_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Enum_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_classwide' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Classwide
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_classwide
                  Property_Result := Base_Type_Decl_P_Is_Classwide
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_classwide
                  Property_Result := Base_Subtype_Decl_P_Is_Classwide
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.is_classwide
                  Property_Result := Classwide_Type_Decl_P_Is_Classwide
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Classwide;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_access_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Access_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_access_type
                  Property_Result := Base_Type_Decl_P_Is_Access_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_access_type
                  Property_Result := Base_Subtype_Decl_P_Is_Access_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_access_type
                  Property_Result := Type_Decl_P_Is_Access_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Access_Type;
--# end
--# property-start BaseTypeDecl.is_implicit_deref /tmp/lal-23.0.0/ada/ast.py:5784
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Implicit_Deref
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 3060 '<FieldAccess for is_access_type at ast.py:5785>' Fld /tmp/lal-23.0.0/ada/ast.py:5785
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3060
if Fld then
   If_Result := True;
else
   --# expr-start 3063 '<Not at ast.py:5785>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5785
--# expr-start 3062 '<IsNull at ast.py:5785>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5785
--# expr-start 3061 '<FieldAccess for get_imp_deref at ast.py:5785>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5785
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3061
Is_Null := Fld_1.Node = null; 
--# expr-done 3062
Not_Val := not (Is_Null); 
--# expr-done 3063
   If_Result := Not_Val;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Implicit_Deref;
--# end
--# property-start '[dispatcher]BaseTypeDecl.has_ud_indexing' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Has_Ud_Indexing
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.has_ud_indexing
                  Property_Result := Base_Type_Decl_P_Has_Ud_Indexing
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.has_ud_indexing
                  Property_Result := Base_Subtype_Decl_P_Has_Ud_Indexing
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.has_ud_indexing
                  Property_Result := Type_Decl_P_Has_Ud_Indexing
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Has_Ud_Indexing;
--# end
--# property-start '[dispatcher]BaseTypeDecl.constant_indexing_fns' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Constant_Indexing_Fns
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.constant_indexing_fns
                  Property_Result := Base_Type_Decl_P_Constant_Indexing_Fns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.constant_indexing_fns
                  Property_Result := Base_Subtype_Decl_P_Constant_Indexing_Fns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.constant_indexing_fns
                  Property_Result := Type_Decl_P_Constant_Indexing_Fns
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Constant_Indexing_Fns;
--# end
--# property-start '[dispatcher]BaseTypeDecl.variable_indexing_fns' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Variable_Indexing_Fns
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.variable_indexing_fns
                  Property_Result := Base_Type_Decl_P_Variable_Indexing_Fns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.variable_indexing_fns
                  Property_Result := Base_Subtype_Decl_P_Variable_Indexing_Fns
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.variable_indexing_fns
                  Property_Result := Type_Decl_P_Variable_Indexing_Fns
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Variable_Indexing_Fns;
--# end
--# property-start '[dispatcher]BaseTypeDecl.get_imp_deref' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Get_Imp_Deref
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.get_imp_deref
                  Property_Result := Base_Type_Decl_P_Get_Imp_Deref
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.get_imp_deref
                  Property_Result := Type_Decl_P_Get_Imp_Deref
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Get_Imp_Deref;
--# end
--# property-start BaseTypeDecl.specific_type /tmp/lal-23.0.0/ada/ast.py:5815
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Specific_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Classwide_Type_Decl;
Match_1 : Internal_Entity_Base_Subtype_Decl;
Match_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Classwide_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Subtype_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3069 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 3068 '<Match at ast.py:5824>' Match_Result /tmp/lal-23.0.0/ada/ast.py:5824
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Classwide_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Classwide_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind cw Match_0
--# expr-start 3065 '<FieldAccess for specific_type at ast.py:5827>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5827
--# expr-start 3064 '<FieldAccess for typedecl at ast.py:5827>' Fld /tmp/lal-23.0.0/ada/ast.py:5827
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 3064
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.specific_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Specific_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3065
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Base_Subtype_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind bt Match_1
--# expr-start 3067 '<FieldAccess for specific_type at ast.py:5828>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5828
--# expr-start 3066 '<FieldAccess for base_subtype at ast.py:5828>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5828
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Match_1.Node, Origin => No_Bare_Ada_Node, E_Info => Match_1.Info);
--# end
--# expr-done 3066
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.specific_type
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Specific_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 3067
Let_Result_1 := Fld_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Incomplete_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := Ent; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3068
Let_Result_3 := Match_Result; 
--# end
--# expr-done 3069
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Specific_Type;
--# end
--# property-start BaseTypeDecl.derefed_type /tmp/lal-23.0.0/ada/ast.py:5834
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Derefed_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Fld_1 : Internal_Entity_Expr;
Is_Null_1 : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3075 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3074 '<If at ast.py:5839>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:5839
--# expr-start 3070 '<IsNull at ast.py:5840>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5840
Is_Null := Ent.Node = null; 
--# expr-done 3070
if Is_Null then
   If_Result := True;
else
   --# expr-start 3072 '<IsNull at ast.py:5840>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:5840
--# expr-start 3071 '<FieldAccess for get_imp_deref at ast.py:5840>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5840
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3071
Is_Null_1 := Fld_1.Node = null; 
--# expr-done 3072
   If_Result := Is_Null_1;
end if;
if If_Result then
   If_Result_1 := Ent;
else
   --# expr-start 3073 '<FieldAccess for accessed_type at ast.py:5842>' Fld /tmp/lal-23.0.0/ada/ast.py:5842
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3073
   If_Result_1 := Fld;
end if;
--# expr-done 3074
Let_Result := If_Result_1; 
--# end
--# expr-done 3075
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Derefed_Type;
--# end
--# property-start BaseTypeDecl.derefed_base_subtype /tmp/lal-23.0.0/ada/ast.py:5847
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Derefed_Base_Subtype
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3084 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3083 '<If at ast.py:5853>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:5853
--# expr-start 3076 '<IsNull at ast.py:5854>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:5854
Is_Null_1 := Ent.Node = null; 
--# expr-done 3076
if Is_Null_1 then
   If_Result_1 := Ent;
else
   --# expr-start 3082 '<FieldAccess for base_subtype at ast.py:5860>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5860
--# expr-start 3081 '<If at ast.py:5856>' If_Result /tmp/lal-23.0.0/ada/ast.py:5856
--# expr-start 3079 '<Not at ast.py:5857>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5857
--# expr-start 3078 '<IsNull at ast.py:5857>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5857
--# expr-start 3077 '<FieldAccess for get_imp_deref at ast.py:5857>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5857
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3077
Is_Null := Fld_1.Node = null; 
--# expr-done 3078
Not_Val := not (Is_Null); 
--# expr-done 3079
if Not_Val then
   --# expr-start 3080 '<FieldAccess for accessed_type at ast.py:5858>' Fld /tmp/lal-23.0.0/ada/ast.py:5858
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3080
   If_Result := Fld;
else
   If_Result := Ent;
end if;
--# expr-done 3081
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => If_Result.Node, Origin => Origin, E_Info => If_Result.Info);
--# end
--# expr-done 3082
   If_Result_1 := Fld_2;
end if;
--# expr-done 3083
Let_Result := If_Result_1; 
--# end
--# expr-done 3084
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Derefed_Base_Subtype;
--# end
--# property-start BaseTypeDecl.one_non_universal /tmp/lal-23.0.0/ada/ast.py:5864
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_One_Non_Universal
  (Node : Bare_Base_Type_Decl
      ; Second : Internal_Entity_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind second Second
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Boolean;
If_Result : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
Fld_1 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3091 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3086 '<Not at ast.py:5866>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5866
--# expr-start 3085 '<IsNull at ast.py:5866>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5866
Is_Null := Ent.Node = null; 
--# expr-done 3085
Not_Val := not (Is_Null); 
--# expr-done 3086
if Not_Val then
   --# expr-start 3087 '<FieldAccess for is_not_universal_type at ast.py:5866>' Fld /tmp/lal-23.0.0/ada/ast.py:5866
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_not_universal_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Is_Not_Universal_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3087
   If_Result := Fld;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_2 := True;
else
--# expr-start 3089 '<Not at ast.py:5867>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:5867
--# expr-start 3088 '<IsNull at ast.py:5867>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:5867
Is_Null_1 := Second.Node = null; 
--# expr-done 3088
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3089
if Not_Val_1 then
   --# expr-start 3090 '<FieldAccess for is_not_universal_type at ast.py:5867>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5867
      if Second.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_not_universal_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Is_Not_Universal_Type (Node => Second.Node, E_Info => Second.Info);
--# end
--# expr-done 3090
   If_Result_1 := Fld_1;
else
   If_Result_1 := False;
end if;
   If_Result_2 := If_Result_1;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 3091
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_One_Non_Universal;
--# end
--# property-start BaseTypeDecl.non_universal_base_subtype /tmp/lal-23.0.0/ada/ast.py:5872
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Non_Universal_Base_Subtype
  (Node : Bare_Base_Type_Decl
      ; Second : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind second Second
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Block_Var : Boolean;
Block_Var_1 : Boolean;
First_St : Internal_Entity_Base_Type_Decl;
Second_St : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld : Boolean;
If_Result : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
Fld_1 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
If_Result_4 : Internal_Entity_Base_Type_Decl;
If_Result_5 : Internal_Entity_Base_Type_Decl;
If_Result_6 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3106 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 3093 '<Not at ast.py:5873>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5873
--# expr-start 3092 '<IsNull at ast.py:5873>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5873
Is_Null := Ent.Node = null; 
--# expr-done 3092
Not_Val := not (Is_Null); 
--# expr-done 3093
if Not_Val then
   --# expr-start 3094 '<FieldAccess for is_not_universal_type at ast.py:5873>' Fld /tmp/lal-23.0.0/ada/ast.py:5873
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_not_universal_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Is_Not_Universal_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3094
   If_Result := Fld;
else
   If_Result := False;
end if;
Block_Var := If_Result; 
--# bind first_ok Block_Var
--# expr-start 3096 '<Not at ast.py:5874>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:5874
--# expr-start 3095 '<IsNull at ast.py:5874>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:5874
Is_Null_1 := Second.Node = null; 
--# expr-done 3095
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3096
if Not_Val_1 then
   --# expr-start 3097 '<FieldAccess for is_not_universal_type at ast.py:5874>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5874
      if Second.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_not_universal_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Is_Not_Universal_Type (Node => Second.Node, E_Info => Second.Info);
--# end
--# expr-done 3097
   If_Result_1 := Fld_1;
else
   If_Result_1 := False;
end if;
Block_Var_1 := If_Result_1; 
--# bind second_ok Block_Var_1
--# expr-start 3105 '<Cond at ast.py:5875>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:5875
if Block_Var then
   If_Result_2 := Block_Var_1;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   --# expr-start 3102 '<Let at ast.py:5877>' Let_Result /tmp/lal-23.0.0/ada/ast.py:5877
--# scope-start
--# expr-start 3098 '<FieldAccess for derefed_base_subtype at ast.py:5879>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5879
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3098
First_St := Fld_2; 
--# bind first_st First_St
--# expr-start 3099 '<FieldAccess for derefed_base_subtype at ast.py:5880>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5880
      if Second.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Second.Node, Origin => Origin, E_Info => Second.Info);
--# end
--# expr-done 3099
Second_St := Fld_3; 
--# bind second_st Second_St
--# expr-start 3101 '<If at ast.py:5881>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:5881
--# expr-start 3100 '<FieldAccess for matching_formal_type at ast.py:5882>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5882
      if Second_St.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Second_St.Node, Formal_Type => First_St, Origin => Origin, E_Info => Second_St.Info);
--# end
--# expr-done 3100
if Fld_4 then
   If_Result_3 := First_St;
else
   If_Result_3 := Second_St;
end if;
--# expr-done 3101
Let_Result := If_Result_3; 
--# end
--# expr-done 3102
   If_Result_6 := Let_Result;
else
if Block_Var then
   --# expr-start 3103 '<FieldAccess for derefed_base_subtype at ast.py:5889>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5889
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3103
   If_Result_5 := Fld_5;
else
if Block_Var_1 then
   --# expr-start 3104 '<FieldAccess for derefed_base_subtype at ast.py:5892>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:5892
      if Second.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Second.Node, Origin => Origin, E_Info => Second.Info);
--# end
--# expr-done 3104
   If_Result_4 := Fld_6;
else
   If_Result_4 := No_Entity_Base_Type_Decl;
end if;
   If_Result_5 := If_Result_4;
end if;
   If_Result_6 := If_Result_5;
end if;
--# expr-done 3105
Let_Result_1 := If_Result_6; 
--# end
--# expr-done 3106
      Property_Result := Let_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Non_Universal_Base_Subtype;
--# end
--# property-start BaseTypeDecl.array_concat_result_type /tmp/lal-23.0.0/ada/ast.py:5899
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Array_Concat_Result_Type
  (Node : Bare_Base_Type_Decl
      ; Other : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Is_Null : Boolean;
Is_Null_1 : Boolean;
If_Result : Boolean;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
If_Result_1 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Boolean;
If_Result_2 : Boolean;
Fld_7 : Internal_Entity_Base_Type_Decl;
If_Result_3 : Internal_Entity_Base_Type_Decl;
If_Result_4 : Internal_Entity_Base_Type_Decl;
If_Result_5 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3118 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3117 '<Cond at ast.py:5905>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:5905
--# expr-start 3107 '<IsNull at ast.py:5906>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5906
Is_Null := Ent.Node = null; 
--# expr-done 3107
if Is_Null then
   If_Result := True;
else
   --# expr-start 3108 '<IsNull at ast.py:5906>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:5906
Is_Null_1 := Other.Node = null; 
--# expr-done 3108
   If_Result := Is_Null_1;
end if;
if If_Result then
   If_Result_5 := No_Entity_Base_Type_Decl;
else
--# expr-start 3109 '<FieldAccess for matching_formal_type at ast.py:5909>' Fld /tmp/lal-23.0.0/ada/ast.py:5909
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Other.Node, Formal_Type => Ent, Origin => Origin, E_Info => Other.Info);
--# end
--# expr-done 3109
if Fld then
   If_Result_1 := True;
else
   --# expr-start 3111 '<FieldAccess for matching_formal_type at ast.py:5910>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5910
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3110 '<FieldAccess for comp_type at ast.py:5910>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5910
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.comp_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3110
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Other.Node, Formal_Type => Fld_1, Origin => Origin, E_Info => Other.Info);
--# end
--# expr-done 3111
   If_Result_1 := Fld_2;
end if;
if If_Result_1 then
   --# expr-start 3112 '<FieldAccess for derefed_base_subtype at ast.py:5911>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5911
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3112
   If_Result_4 := Fld_3;
else
--# expr-start 3113 '<FieldAccess for matching_formal_type at ast.py:5913>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5913
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Ent.Node, Formal_Type => Other, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3113
if Fld_4 then
   If_Result_2 := True;
else
   --# expr-start 3115 '<FieldAccess for matching_formal_type at ast.py:5914>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:5914
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3114 '<FieldAccess for comp_type at ast.py:5914>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5914
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.comp_type
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Other.Node, Origin => Origin, E_Info => Other.Info);
--# end
--# expr-done 3114
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Ent.Node, Formal_Type => Fld_5, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3115
   If_Result_2 := Fld_6;
end if;
if If_Result_2 then
   --# expr-start 3116 '<FieldAccess for derefed_base_subtype at ast.py:5915>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:5915
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_7 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Other.Node, Origin => Origin, E_Info => Other.Info);
--# end
--# expr-done 3116
   If_Result_3 := Fld_7;
else
   If_Result_3 := No_Entity_Base_Type_Decl;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
--# expr-done 3117
Let_Result := If_Result_5; 
--# end
--# expr-done 3118
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Array_Concat_Result_Type;
--# end
--# property-start BaseTypeDecl.expected_array_concat_operand_type /tmp/lal-23.0.0/ada/ast.py:5922
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Expected_Array_Concat_Operand_Type
  (Node : Bare_Base_Type_Decl
      ; Operand_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind operand_type Operand_Type
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Is_Null : Boolean;
Is_Null_1 : Boolean;
If_Result : Boolean;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
If_Result_1 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
If_Result_2 : Internal_Entity_Base_Type_Decl;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3126 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3125 '<Cond at ast.py:5931>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:5931
--# expr-start 3119 '<IsNull at ast.py:5932>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5932
Is_Null := Ent.Node = null; 
--# expr-done 3119
if Is_Null then
   If_Result := True;
else
   --# expr-start 3120 '<IsNull at ast.py:5932>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:5932
Is_Null_1 := Operand_Type.Node = null; 
--# expr-done 3120
   If_Result := Is_Null_1;
end if;
if If_Result then
   If_Result_3 := No_Entity_Base_Type_Decl;
else
--# expr-start 3121 '<FieldAccess for matching_formal_type at ast.py:5935>' Fld /tmp/lal-23.0.0/ada/ast.py:5935
      if Operand_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Operand_Type.Node, Formal_Type => Ent, Origin => Origin, E_Info => Operand_Type.Info);
--# end
--# expr-done 3121
if Fld then
   If_Result_1 := True;
else
   --# expr-start 3123 '<FieldAccess for matching_formal_type at ast.py:5936>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5936
      if Operand_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3122 '<FieldAccess for comp_type at ast.py:5936>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5936
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.comp_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3122
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Operand_Type.Node, Formal_Type => Fld_1, Origin => Origin, E_Info => Operand_Type.Info);
--# end
--# expr-done 3123
   If_Result_1 := Fld_2;
end if;
if If_Result_1 then
   --# expr-start 3124 '<FieldAccess for derefed_base_subtype at ast.py:5937>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5937
      if Operand_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.derefed_base_subtype
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Derefed_Base_Subtype (Node => Operand_Type.Node, Origin => Origin, E_Info => Operand_Type.Info);
--# end
--# expr-done 3124
   If_Result_2 := Fld_3;
else
   If_Result_2 := No_Entity_Base_Type_Decl;
end if;
   If_Result_3 := If_Result_2;
end if;
--# expr-done 3125
Let_Result := If_Result_3; 
--# end
--# expr-done 3126
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Expected_Array_Concat_Operand_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.access_def' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Access_Def
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Access_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Access_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.access_def
                  Property_Result := Base_Type_Decl_P_Access_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.access_def
                  Property_Result := Base_Subtype_Decl_P_Access_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.access_def
                  Property_Result := Type_Decl_P_Access_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Access_Def;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_char_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Char_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_char_type
                  Property_Result := Base_Type_Decl_P_Is_Char_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_char_type
                  Property_Result := Base_Subtype_Decl_P_Is_Char_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_char_type
                  Property_Result := Type_Decl_P_Is_Char_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Char_Type;
--# end
--# property-start BaseTypeDecl.is_non_null_char_type /tmp/lal-23.0.0/ada/ast.py:5951
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Non_Null_Char_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 3128 '<Not at ast.py:5952>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5952
--# expr-start 3127 '<IsNull at ast.py:5952>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5952
Is_Null := Self = null; 
--# expr-done 3127
Not_Val := not (Is_Null); 
--# expr-done 3128
if Not_Val then
   --# expr-start 3129 '<FieldAccess for is_char_type at ast.py:5952>' Fld /tmp/lal-23.0.0/ada/ast.py:5952
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_char_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Char_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3129
   If_Result := Fld;
else
   If_Result := False;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Non_Null_Char_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.classwide_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Classwide_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Classwide_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Classwide_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl | Ada_Incomplete_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.classwide_type
                  Property_Result := Base_Type_Decl_P_Classwide_Type
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.classwide_type
                  Property_Result := Classwide_Type_Decl_P_Classwide_Type
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Classwide_Type;
--# end
--# property-start BaseTypeDecl.scalar_base_type /tmp/lal-23.0.0/ada/ast.py:5963
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Scalar_Base_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Discrete_Base_Subtype_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Discrete_Base_Subtype_Decl;
      Fld : Bare_Discrete_Base_Subtype_Decl;
As_Entity : Internal_Entity_Discrete_Base_Subtype_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Discrete_Base_Subtype_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3131 '<as_entity at ast.py:5963>' If_Result /tmp/lal-23.0.0/ada/ast.py:5963
--# expr-start 3130 '<FieldAccess for scalar_base_subtype_node at ast.py:5963>' Fld /tmp/lal-23.0.0/ada/ast.py:5963
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.scalar_base_subtype_node
Fld := Libadalang.Implementation.Base_Type_Decl_P_Scalar_Base_Subtype_Node (Node => Self);
--# end
--# expr-done 3130
Is_Null := Fld = null; 
if Is_Null then
   If_Result := No_Entity_Discrete_Base_Subtype_Decl;
else
As_Entity := (Info => E_Info, Node => Fld); 
   If_Result := As_Entity;
end if;
--# expr-done 3131
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Scalar_Base_Type;
--# end
--# property-start BaseTypeDecl.is_universal_type /tmp/lal-23.0.0/ada/ast.py:5966
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Universal_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Internal_Entity;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Is_Equiv : Boolean;
Fld_1 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv_1 : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3138 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3133 '<Not at ast.py:5974>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5974
--# expr-start 3132 '<IsNull at ast.py:5974>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5974
Is_Null := Ent.Node = null; 
--# expr-done 3132
Not_Val := not (Is_Null); 
--# expr-done 3133
if Not_Val then
--# expr-start 3135 '<Eq at ast.py:5975>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:5975
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 3134 '<FieldAccess for universal_int_type at ast.py:5975>' Fld /tmp/lal-23.0.0/ada/ast.py:5975
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 3134
Is_Equiv := Equivalent (Cast_Result, Fld); 
--# expr-done 3135
if Is_Equiv then
   If_Result := True;
else
   --# expr-start 3137 '<Eq at ast.py:5976>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:5976
Cast_Expr_1 := Ent; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
--# expr-start 3136 '<FieldAccess for universal_real_type at ast.py:5976>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5976
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 3136
Is_Equiv_1 := Equivalent (Cast_Result_1, Fld_1); 
--# expr-done 3137
   If_Result := Is_Equiv_1;
end if;
   If_Result_1 := If_Result;
else
   If_Result_1 := False;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 3138
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Universal_Type;
--# end
--# property-start BaseTypeDecl.is_not_universal_type /tmp/lal-23.0.0/ada/ast.py:5980
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Not_Universal_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3143 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3140 '<Not at ast.py:5988>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5988
--# expr-start 3139 '<IsNull at ast.py:5988>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5988
Is_Null := Ent.Node = null; 
--# expr-done 3139
Not_Val := not (Is_Null); 
--# expr-done 3140
if Not_Val then
   --# expr-start 3142 '<Not at ast.py:5988>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:5988
--# expr-start 3141 '<FieldAccess for is_universal_type at ast.py:5988>' Fld /tmp/lal-23.0.0/ada/ast.py:5988
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_universal_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Is_Universal_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3141
Not_Val_1 := not (Fld); 
--# expr-done 3142
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3143
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Not_Universal_Type;
--# end
--# property-start BaseTypeDecl.is_access_type_predicate /tmp/lal-23.0.0/ada/ast.py:5991
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Access_Type_Predicate
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3145 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr := Ent;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3144 '<FieldAccess for is_access_type at ast.py:5997>' Fld /tmp/lal-23.0.0/ada/ast.py:5997
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3144
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 3145
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Access_Type_Predicate;
--# end
--# property-start BaseTypeDecl.array_ndims /tmp/lal-23.0.0/ada/ast.py:6000
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Array_Ndims
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Integer;
      Let_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3146 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := 0; 
--# end
--# expr-done 3146
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Array_Ndims;
--# end
--# property-start '[dispatcher]BaseTypeDecl.discrete_range' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Discrete_Range
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl | Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.discrete_range
                  Property_Result := Base_Type_Decl_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Decl =>
                  --# property-call-start SubtypeDecl.discrete_range
                  Property_Result := Subtype_Decl_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.discrete_range
                  Property_Result := Type_Decl_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Discrete_Range;
--# end
--# property-start BaseTypeDecl.static_predicate /tmp/lal-23.0.0/ada/ast.py:6012
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Static_Predicate
  (Node : Bare_Base_Type_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Expr;
      Var_Expr : Internal_Entity_Expr;
Sym : Symbol_Type;
Fld : Internal_Aspect;
Fld_1 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Sym_1 : Symbol_Type;
Fld_2 : Internal_Aspect;
Fld_3 : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Let_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3153 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3149 '<FieldAccess for value at ast.py:6017>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6017
--# expr-start 3148 '<FieldAccess for get_aspect at ast.py:6017>' Fld /tmp/lal-23.0.0/ada/ast.py:6017
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3147 '<Symbol Static_Predicate at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Static_Predicate); 
--# expr-done 3147
--# property-call-start BasicDecl.get_aspect
Fld := Libadalang.Implementation.Basic_Decl_P_Get_Aspect (Node => Ent.Node, Name => Sym, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3148
Fld_1 := Fld.Value;
--# expr-done 3149
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr
Scope_Result := Var_Expr;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 3152 '<FieldAccess for value at ast.py:6018>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6018
--# expr-start 3151 '<FieldAccess for get_aspect at ast.py:6018>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6018
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3150 '<Symbol Predicate at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Predicate); 
--# expr-done 3150
--# property-call-start BasicDecl.get_aspect
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect (Node => Ent.Node, Name => Sym_1, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3151
Fld_3 := Fld_2.Value;
--# expr-done 3152
   Result_Var := Fld_3;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 3153
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Static_Predicate;
--# end
--# property-start BaseTypeDecl.satisfies_type_predicates /tmp/lal-23.0.0/ada/ast.py:6024
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Satisfies_Type_Predicates
  (Node : Bare_Base_Type_Decl
      ; Value : Big_Integer_Type
      ; Imprecise_Fallback : Boolean
         := False
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind value Value
   --# bind imprecise_fallback Imprecise_Fallback
   --# bind origin Origin
   Property_Result : Boolean;
            procedure Finalizer_Scope_456 with Inline_Always;
            procedure Finalizer_Scope_2229 with Inline_Always;
      Block_Var : Big_Integer_Type;
Block_Var_1 : Boolean;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Block_Var_3 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Base_Subtype_Decl;
Big_Int : Big_Integer_Type;
Fld : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Basic_Decl;
New_Struct : Internal_Substitution := No_Substitution;
Singleton : Internal_Substitution_Array_Access;
Fld_1 : Big_Integer_Type;
Is_Equal : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Subtype_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_4 : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
Fld_5 : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_456 is
            begin
                     Dec_Ref (Big_Int);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_456;
            procedure Finalizer_Scope_2229 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (Singleton);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2229;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3169 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3154 '<BigInteger 1 at ast.py:6031>' Big_Int /tmp/lal-23.0.0/ada/ast.py:6031
Big_Int := Create_Big_Integer ("1"); 
--# expr-done 3154
Block_Var := Big_Int; Inc_Ref (Block_Var);
--# bind true_val Block_Var
--# expr-start 3155 '<FieldAccess for static_predicate at ast.py:6034>' Fld /tmp/lal-23.0.0/ada/ast.py:6034
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.static_predicate
Fld := Libadalang.Implementation.Base_Type_Decl_P_Static_Predicate (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3155
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind pred Var_Expr
--# expr-start 3158 '<Eq at ast.py:6035>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:6035
--# expr-start 3157 '<FieldAccess for eval_as_int_in_env at ast.py:6035>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6035
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3156 '<New Substitution at ast.py:6036>' New_Struct /tmp/lal-23.0.0/ada/ast.py:6036
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Inc_Ref (Value);
New_Struct := (From_Decl => Cast_Result, To_Value => Value, Value_Type => Ent); 
--# expr-done 3156
                Singleton := Create_Internal_Substitution_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
                Inc_Ref (Singleton.Items (1));
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Eval_As_Int_In_Env (Node => Var_Expr.Node, Env => Singleton, E_Info => Var_Expr.Info);
--# expr-done 3157
Is_Equal := Equivalent (Block_Var, Fld_1); 
--# expr-done 3158
Scope_Result := Is_Equal;
   --# end
      Finalizer_Scope_2229;
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
Block_Var_1 := Result_Var; 
--# bind satisfies_own_predicate Block_Var_1
--# expr-start 3159 '<Cast to BaseSubtypeDecl at ast.py:6046>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:6046
Cast_Expr_1 := Ent; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Base_Subtype_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Subtype_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Base_Subtype_Decl;
   end if;
--# expr-done 3159
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Base_Subtype_Decl then
   --# scope-start
--# expr-start 3160 '<FieldAccess for get_type at ast.py:6046>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6046
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 3160
Scope_Result_1 := Fld_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Block_Var_2 := Result_Var_1; 
--# bind from_type Block_Var_2
--# expr-start 3161 '<FieldAccess for base_type at ast.py:6047>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6047
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3161
Block_Var_3 := Fld_3; 
--# bind base_type Block_Var_3
if Block_Var_1 then
   --# expr-start 3168 '<Cond at ast.py:6049>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:6049
--# expr-start 3163 '<Not at ast.py:6050>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6050
--# expr-start 3162 '<IsNull at ast.py:6050>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6050
Is_Null := Block_Var_2.Node = null; 
--# expr-done 3162
Not_Val := not (Is_Null); 
--# expr-done 3163
if Not_Val then
   --# expr-start 3164 '<FieldAccess for satisfies_type_predicates at ast.py:6051>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6051
      if Block_Var_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.satisfies_type_predicates
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Satisfies_Type_Predicates (Node => Block_Var_2.Node, Value => Value, Imprecise_Fallback => Imprecise_Fallback, Origin => Origin, E_Info => Block_Var_2.Info);
--# end
--# expr-done 3164
   If_Result_1 := Fld_4;
else
--# expr-start 3166 '<Not at ast.py:6053>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6053
--# expr-start 3165 '<IsNull at ast.py:6053>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6053
Is_Null_1 := Block_Var_3.Node = null; 
--# expr-done 3165
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3166
if Not_Val_1 then
   --# expr-start 3167 '<FieldAccess for satisfies_type_predicates at ast.py:6054>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6054
      if Block_Var_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.satisfies_type_predicates
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Satisfies_Type_Predicates (Node => Block_Var_3.Node, Value => Value, Imprecise_Fallback => Imprecise_Fallback, Origin => Origin, E_Info => Block_Var_3.Info);
--# end
--# expr-done 3167
   If_Result := Fld_5;
else
   If_Result := True;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 3168
   If_Result_2 := If_Result_1;
else
   If_Result_2 := False;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 3169
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_456;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_456;
               Finalizer_Scope_2229;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Satisfies_Type_Predicates;
--# end
--# property-start BaseTypeDecl.is_iterator_type /tmp/lal-23.0.0/ada/ast.py:6060
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Iterator_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
            procedure Finalizer_Scope_457 with Inline_Always;
      Block_Var : Bare_Basic_Decl;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Classwide_Type_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Classwide_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity;
Fld_3 : Internal_Entity;
Fld_4 : Bare_Ada_Node;
Cast_Expr_1 : Bare_Basic_Decl;
Cast_Result_1 : Bare_Ada_Node;
Is_Equal : Boolean;
Fld_5 : Internal_Entity_Basic_Decl;
Sym_2 : Symbol_Type;
Fld_6 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_457 is
            begin
                     Dec_Ref (Array_Lit);
            end Finalizer_Scope_457;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Is_Iterator_Type,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 3183 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3173 '<FieldAccess for get_unit_root_decl at ast.py:6061>' Fld /tmp/lal-23.0.0/ada/ast.py:6061
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3172 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 3170 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 3170
--# expr-start 3171 '<Symbol Iterator_Interfaces at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterator_Interfaces); 
--# expr-done 3171
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 3172
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 3173
Block_Var := Fld; 
--# bind iifcs Block_Var
--# expr-start 3174 '<Cast to ClasswideTypeDecl at ast.py:6064>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6064
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Classwide_Type_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Classwide_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Classwide_Type_Decl;
   end if;
--# expr-done 3174
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Classwide_Type_Decl then
   --# scope-start
   --# bind cw Var_Expr
--# expr-start 3175 '<FieldAccess for typedecl at ast.py:6065>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6065
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld_1 := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3175
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := Ent;
end if;
Block_Var_1 := Result_Var; 
--# bind typ Block_Var_1
--# expr-start 3179 '<Eq at ast.py:6068>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:6068
--# expr-start 3178 '<FieldAccess for node at ast.py:6068>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6068
--# expr-start 3177 '<FieldAccess for semantic_parent at ast.py:6068>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6068
--# expr-start 3176 '<FieldAccess for semantic_parent at ast.py:6068>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6068
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_2 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 3176
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_3 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 3177
Fld_4 := Fld_3.Node;
--# expr-done 3178
Cast_Expr_1 := Block_Var; 
      Cast_Result_1 := Cast_Expr_1;
Is_Equal := Fld_4 = Cast_Result_1; 
--# expr-done 3179
if Is_Equal then
   If_Result := True;
else
   --# expr-start 3182 '<FieldAccess for has_aspect at ast.py:6069>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6069
--# expr-start 3180 '<FieldAccess for canonical_part at ast.py:6069>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6069
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 3180
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3181 '<Symbol Iterable at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterable); 
--# expr-done 3181
--# property-call-start BasicDecl.has_aspect
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Has_Aspect (Node => Fld_5.Node, Name => Sym_2, Imprecise_Fallback => False, E_Info => Fld_5.Info);
--# end
--# expr-done 3182
   If_Result := Fld_6;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3183
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_457;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_457;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Iterator_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_discrete_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Discrete_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_discrete_type
                  Property_Result := Base_Type_Decl_P_Is_Discrete_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_discrete_type
                  Property_Result := Base_Subtype_Decl_P_Is_Discrete_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_discrete_type
                  Property_Result := Type_Decl_P_Is_Discrete_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Discrete_Type;
--# end
--# property-start BaseTypeDecl.is_not_root_int_type /tmp/lal-23.0.0/ada/ast.py:6080
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Not_Root_Int_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3189 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3185 '<Not at ast.py:6081>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6081
--# expr-start 3184 '<IsNull at ast.py:6081>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6081
Is_Null := Self = null; 
--# expr-done 3184
Not_Val := not (Is_Null); 
--# expr-done 3185
if Not_Val then
   --# expr-start 3188 '<Not at ast.py:6081>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6081
--# expr-start 3187 '<Eq at ast.py:6081>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:6081
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 3186 '<FieldAccess for root_int_type at ast.py:6081>' Fld /tmp/lal-23.0.0/ada/ast.py:6081
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_int_type
Fld := Libadalang.Implementation.Ada_Node_P_Root_Int_Type (Node => Self);
--# end
--# expr-done 3186
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld.Node,
         Info => Fld.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 3187
Not_Val_1 := not (Is_Equiv); 
--# expr-done 3188
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3189
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Not_Root_Int_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_int_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Int_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_int_type
                  Property_Result := Base_Type_Decl_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_int_type
                  Property_Result := Base_Subtype_Decl_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_int_type
                  Property_Result := Type_Decl_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Int_Type;
--# end
--# property-start BaseTypeDecl.allows_universal_int /tmp/lal-23.0.0/ada/ast.py:6089
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Allows_Universal_Int
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Sym : Symbol_Type;
Fld_2 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3196 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3190 '<FieldAccess for is_int_type at ast.py:6095>' Fld /tmp/lal-23.0.0/ada/ast.py:6095
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_int_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Int_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3190
if Fld then
   If_Result := True;
else
--# expr-start 3191 '<FieldAccess for base_subtype at ast.py:6095>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6095
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3191
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 3195 '<Not at ast.py:6098>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6098
--# expr-start 3194 '<IsNull at ast.py:6098>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6098
--# expr-start 3193 '<FieldAccess for get_aspect_spec_expr at ast.py:6098>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6098
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3192 '<Symbol Integer_Literal at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Integer_Literal); 
--# expr-done 3192
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Var_Expr.Node, Name => Sym, E_Info => Var_Expr.Info);
--# end
--# expr-done 3193
Is_Null := Fld_2.Node = null; 
--# expr-done 3194
Not_Val := not (Is_Null); 
--# expr-done 3195
Scope_Result := Not_Val;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3196
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Allows_Universal_Int;
--# end
--# property-start BaseTypeDecl.allows_universal_real /tmp/lal-23.0.0/ada/ast.py:6103
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Allows_Universal_Real
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Sym : Symbol_Type;
Fld_2 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3203 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3197 '<FieldAccess for is_real_type at ast.py:6109>' Fld /tmp/lal-23.0.0/ada/ast.py:6109
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_real_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Real_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3197
if Fld then
   If_Result := True;
else
--# expr-start 3198 '<FieldAccess for base_subtype at ast.py:6109>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6109
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3198
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 3202 '<Not at ast.py:6112>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6112
--# expr-start 3201 '<IsNull at ast.py:6112>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6112
--# expr-start 3200 '<FieldAccess for get_aspect_spec_expr at ast.py:6112>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6112
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3199 '<Symbol Real_Literal at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Real_Literal); 
--# expr-done 3199
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Var_Expr.Node, Name => Sym, E_Info => Var_Expr.Info);
--# end
--# expr-done 3200
Is_Null := Fld_2.Node = null; 
--# expr-done 3201
Not_Val := not (Is_Null); 
--# expr-done 3202
Scope_Result := Not_Val;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3203
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Allows_Universal_Real;
--# end
--# property-start BaseTypeDecl.allows_string_literal /tmp/lal-23.0.0/ada/ast.py:6117
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Allows_String_Literal
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Sym : Symbol_Type;
Fld_2 : Internal_Entity_Expr;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3212 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3205 '<Not at ast.py:6128>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6128
--# expr-start 3204 '<IsNull at ast.py:6128>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6128
Is_Null := Self = null; 
--# expr-done 3204
Not_Val := not (Is_Null); 
--# expr-done 3205
if Not_Val then
--# expr-start 3206 '<FieldAccess for is_str_type at ast.py:6129>' Fld /tmp/lal-23.0.0/ada/ast.py:6129
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_str_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Is_Str_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3206
if Fld then
   If_Result := True;
else
--# expr-start 3207 '<FieldAccess for base_subtype at ast.py:6129>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6129
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3207
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 3211 '<Not at ast.py:6133>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6133
--# expr-start 3210 '<IsNull at ast.py:6133>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6133
--# expr-start 3209 '<FieldAccess for get_aspect_spec_expr at ast.py:6133>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6133
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3208 '<Symbol String_Literal at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String_Literal); 
--# expr-done 3208
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Var_Expr.Node, Name => Sym, E_Info => Var_Expr.Info);
--# end
--# expr-done 3209
Is_Null_1 := Fld_2.Node = null; 
--# expr-done 3210
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3211
Scope_Result := Not_Val_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
   If_Result_1 := If_Result;
else
   If_Result_1 := False;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 3212
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Allows_String_Literal;
--# end
--# property-start BaseTypeDecl.is_str_type /tmp/lal-23.0.0/ada/ast.py:6139
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Str_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Integer;
Is_Equal : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3217 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3214 '<Eq at ast.py:6143>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:6143
--# expr-start 3213 '<FieldAccess for array_ndims at ast.py:6143>' Fld /tmp/lal-23.0.0/ada/ast.py:6143
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3213
Is_Equal := Fld = 1; 
--# expr-done 3214
if Is_Equal then
--# expr-start 3215 '<FieldAccess for comp_type at ast.py:6143>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6143
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.comp_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3215
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3216 '<FieldAccess for is_char_type at ast.py:6143>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6143
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_char_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Char_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3216
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3217
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Str_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.accessed_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Accessed_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.accessed_type
                  Property_Result := Base_Type_Decl_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.accessed_type
                  Property_Result := Base_Subtype_Decl_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.accessed_type
                  Property_Result := Type_Decl_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Accessed_Type;
--# end
--# property-start BaseTypeDecl.accessed_type_no_call /tmp/lal-23.0.0/ada/ast.py:6154
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Accessed_Type_No_Call
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Fld_1 : Internal_Entity_Access_Def;
Is_A : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3223 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3222 '<If at ast.py:6159>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:6159
--# expr-start 3218 '<IsNull at ast.py:6160>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6160
Is_Null := Ent.Node = null; 
--# expr-done 3218
if Is_Null then
   If_Result := True;
else
   --# expr-start 3220 '<IsA AccessToSubpDef at ast.py:6160>' Is_A /tmp/lal-23.0.0/ada/ast.py:6160
--# expr-start 3219 '<FieldAccess for access_def at ast.py:6160>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6160
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3219
Is_A := Fld_1.Node /= null 
and then Fld_1.Node.Kind in Ada_Access_To_Subp_Def_Range; 
--# expr-done 3220
   If_Result := Is_A;
end if;
if If_Result then
   If_Result_1 := No_Entity_Base_Type_Decl;
else
   --# expr-start 3221 '<FieldAccess for accessed_type at ast.py:6162>' Fld /tmp/lal-23.0.0/ada/ast.py:6162
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3221
   If_Result_1 := Fld;
end if;
--# expr-done 3222
Let_Result := If_Result_1; 
--# end
--# expr-done 3223
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Accessed_Type_No_Call;
--# end
--# property-start BaseTypeDecl.final_accessed_type /tmp/lal-23.0.0/ada/ast.py:6166
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Final_Accessed_Type
  (Node : Bare_Base_Type_Decl
      ; First_Call : Boolean
         := True
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind first_call First_Call
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
If_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3227 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3224 '<FieldAccess for accessed_type at ast.py:6177>' Fld /tmp/lal-23.0.0/ada/ast.py:6177
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3224
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind at Var_Expr
--# expr-start 3225 '<FieldAccess for final_accessed_type at ast.py:6178>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6178
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.final_accessed_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Final_Accessed_Type (Node => Var_Expr.Node, First_Call => False, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3225
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 3226 '<If at ast.py:6179>' If_Result /tmp/lal-23.0.0/ada/ast.py:6179
if First_Call then
   If_Result := No_Entity_Base_Type_Decl;
else
   If_Result := Ent;
end if;
--# expr-done 3226
   Result_Var := If_Result;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 3227
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Final_Accessed_Type;
--# end
--# property-start BaseTypeDecl.is_access_to /tmp/lal-23.0.0/ada/ast.py:6183
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Access_To
  (Node : Bare_Base_Type_Decl
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3230 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Ent; 
--# bind access_type Block_Var
--# expr-start 3229 '<FieldAccess for matching_formal_type at ast.py:6185>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6185
--# expr-start 3228 '<FieldAccess for accessed_type at ast.py:6185>' Fld /tmp/lal-23.0.0/ada/ast.py:6185
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3228
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Fld.Node, Formal_Type => Typ, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3229
Let_Result := Fld_1; 
--# end
--# expr-done 3230
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Access_To;
--# end
--# property-start BaseTypeDecl.is_subp_access_of /tmp/lal-23.0.0/ada/ast.py:6188
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Subp_Access_Of
  (Node : Bare_Base_Type_Decl
      ; Entity : Internal_Entity_Basic_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind entity Entity
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Access_To_Subp_Def;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Access_Def;
Cast_Result : Internal_Entity_Access_To_Subp_Def;
Fld_1 : Internal_Entity_Base_Subp_Spec;
Fld_2 : Internal_Entity_Subp_Spec;
Fld_3 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3236 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Ent; 
--# bind access_type Block_Var
--# expr-start 3232 '<Cast to AccessToSubpDef at ast.py:6194>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6194
--# expr-start 3231 '<FieldAccess for access_def at ast.py:6194>' Fld /tmp/lal-23.0.0/ada/ast.py:6194
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3231
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Access_To_Subp_Def_Range
   then
      Cast_Result := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Access_To_Subp_Def;
   end if;
--# expr-done 3232
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Access_To_Subp_Def then
   --# scope-start
   --# bind sa Var_Expr
--# expr-start 3233 '<FieldAccess for subp_spec_or_null at ast.py:6195>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6195
      if Entity.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Entity.Node, E_Info => Entity.Info);
--# end
--# expr-done 3233
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind se Var_Expr_1
--# expr-start 3235 '<FieldAccess for match_signature at ast.py:6196>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6196
--# expr-start 3234 '<FieldAccess for subp_spec at ast.py:6196>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6196
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Var_Expr.Info);
--# expr-done 3234
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.match_signature
Fld_3 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld_2.Node, Other => Var_Expr_1, Match_Name => False, E_Info => Fld_2.Info);
--# end
--# expr-done 3235
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 3236
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Subp_Access_Of;
--# end
--# property-start BaseTypeDecl.is_generic_formal /tmp/lal-23.0.0/ada/ast.py:6201
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Generic_Formal
  (Node : Bare_Base_Type_Decl
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Base_Type_Decl;
Fld : Bare_Ada_Node;
Is_A : Boolean;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Base_Type_Decl;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3242 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3238 '<IsA GenericFormalTypeDecl at ast.py:6206>' Is_A /tmp/lal-23.0.0/ada/ast.py:6206
--# expr-start 3237 '<parent at ast.py:6206>' Fld /tmp/lal-23.0.0/ada/ast.py:6206
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 3237
Is_A := Fld /= null 
and then Fld.Kind in Ada_Generic_Formal_Type_Decl_Range; 
--# expr-done 3238
if Is_A then
   If_Result := True;
else
--# expr-start 3240 '<Cast to BaseTypeDecl at ast.py:6207>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6207
--# expr-start 3239 '<parent at ast.py:6207>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6207
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Parent; 
--# expr-done 3239
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 3240
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3241 '<FieldAccess for is_generic_formal at ast.py:6207>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6207
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_generic_formal
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Is_Generic_Formal (Node => Var_Expr);
--# end
--# expr-done 3241
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3242
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Generic_Formal;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_tagged_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Tagged_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl | Ada_Protected_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_tagged_type
                  Property_Result := Base_Type_Decl_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_tagged_type
                  Property_Result := Base_Subtype_Decl_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.is_tagged_type
                  Property_Result := Classwide_Type_Decl_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Incomplete_Formal_Type_Decl =>
                  --# property-call-start IncompleteFormalTypeDecl.is_tagged_type
                  Property_Result := Incomplete_Formal_Type_Decl_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Incomplete_Tagged_Type_Decl =>
                  --# property-call-start IncompleteTaggedTypeDecl.is_tagged_type
                  Property_Result := Incomplete_Tagged_Type_Decl_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_tagged_type
                  Property_Result := Type_Decl_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Tagged_Type;
--# end
--# property-start BaseTypeDecl.is_tagged_type_with_deref /tmp/lal-23.0.0/ada/ast.py:6216
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Tagged_Type_With_Deref
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3249 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3248 '<FieldAccess for is_tagged_type at ast.py:6225>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6225
--# expr-start 3247 '<If at ast.py:6221>' If_Result /tmp/lal-23.0.0/ada/ast.py:6221
--# expr-start 3245 '<Not at ast.py:6222>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6222
--# expr-start 3244 '<IsNull at ast.py:6222>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6222
--# expr-start 3243 '<FieldAccess for get_imp_deref at ast.py:6222>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6222
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3243
Is_Null := Fld_1.Node = null; 
--# expr-done 3244
Not_Val := not (Is_Null); 
--# expr-done 3245
if Not_Val then
   --# expr-start 3246 '<FieldAccess for accessed_type at ast.py:6223>' Fld /tmp/lal-23.0.0/ada/ast.py:6223
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3246
   If_Result := Fld;
else
   If_Result := Ent;
end if;
--# expr-done 3247
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => If_Result.Node, Origin => Origin, E_Info => If_Result.Info);
--# end
--# expr-done 3248
Let_Result := Fld_2; 
--# end
--# expr-done 3249
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Tagged_Type_With_Deref;
--# end
--# property-start '[dispatcher]BaseTypeDecl.base_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Base_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.base_type
                  Property_Result := Base_Type_Decl_P_Base_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.base_type
                  Property_Result := Base_Subtype_Decl_P_Base_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.base_type
                  Property_Result := Classwide_Type_Decl_P_Base_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.base_type
                  Property_Result := Type_Decl_P_Base_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Base_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.base_types' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Base_Types
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.base_types
                  Property_Result := Base_Type_Decl_P_Base_Types
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.base_types
                  Property_Result := Base_Subtype_Decl_P_Base_Types
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Base_Types;
--# end
--# property-start '[dispatcher]BaseTypeDecl.base_interfaces' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Base_Interfaces
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
                  --# property-call-start BaseTypeDecl.base_interfaces
                  Property_Result := Base_Type_Decl_P_Base_Interfaces
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.base_interfaces
                  Property_Result := Base_Subtype_Decl_P_Base_Interfaces
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.base_interfaces
                  Property_Result := Classwide_Type_Decl_P_Base_Interfaces
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.base_interfaces
                  Property_Result := Protected_Type_Decl_P_Base_Interfaces
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.base_interfaces
                  Property_Result := Task_Type_Decl_P_Base_Interfaces
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.base_interfaces
                  Property_Result := Type_Decl_P_Base_Interfaces
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Base_Interfaces;
--# end
--# property-start BaseTypeDecl.find_all_derived_types /tmp/lal-23.0.0/ada/ast.py:6247
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Find_All_Derived_Types
  (Node : Bare_Base_Type_Decl
      ; Units : Internal_Unit_Array_Access
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind units Units
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Type_Decl_Array_Access;
            procedure Finalizer_Scope_476 with Inline_Always;
            procedure Finalizer_Scope_2240 with Inline_Always;
            procedure Finalizer_Scope_2241 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Base_Type_Decl;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Unit_Array_Access;
Fld_2 : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_3 : Internal_Entity_Type_Decl_Array_Access;
Scope_Result : Internal_Entity_Type_Decl_Array_Access;
Result_Var : Internal_Entity_Type_Decl_Array_Access;
Map_Result : Internal_Entity_Type_Decl_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Type_Decl_Array_Access;
Let_Result : Internal_Entity_Type_Decl_Array_Access;
            procedure Finalizer_Scope_476 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_476;
            procedure Finalizer_Scope_2240 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2240;
            procedure Finalizer_Scope_2241 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2241;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3257 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3256 '<bind at ast.py:6252>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:6252
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 3255 '<Mapcat at ast.py:6255>' Map_Result /tmp/lal-23.0.0/ada/ast.py:6255
   --# expr-start 3251 '<FieldAccess for filter_is_imported_by at ast.py:6254>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6254
--# expr-start 3250 '<FieldAccess for canonical_type at ast.py:6254>' Fld /tmp/lal-23.0.0/ada/ast.py:6254
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 3250
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Ada_Node_P_Filter_Is_Imported_By (Node => Fld.Node, Units => Units, Transitive => True);
--# expr-done 3251
      declare
         Map_Result_Vec : Internal_Entity_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Unit_Array_Access := Fld_1;
      begin
         for Item_132 of
               Collection.Items
         loop
   --# scope-start
               --# bind u Item_132
--# expr-start 3252 '<FieldAccess for root at ast.py:6255>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6255
      if Item_132 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Item_132.Ast_Root;
--# expr-done 3252
Var_Expr := Fld_2;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 3254 '<FieldAccess for find_derived_types at ast.py:6256>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6256
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3253 '<as_bare_entity at ast.py:6256>' If_Result /tmp/lal-23.0.0/ada/ast.py:6256
Is_Null := Var_Expr = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Var_Expr); 
   If_Result := As_Entity;
end if;
--# expr-done 3253
--# property-call-start BaseTypeDecl.find_derived_types
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Find_Derived_Types (Node => Ent.Node, Root => If_Result, Origin => Bound_Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3254
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2241;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
         for Item_To_Append of
               Result_Var.Items
         loop
            Internal_Entity_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2240;
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3255
Dyn_Var_Bind_Result := Map_Result; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 3256
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 3257
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_476;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_476;
               Finalizer_Scope_2240;
               Finalizer_Scope_2241;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Find_All_Derived_Types;
--# end
--# property-start '[dispatcher]BaseTypeDecl.record_def' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Record_Def
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Record_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Record_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.record_def
                  Property_Result := Base_Type_Decl_P_Record_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.record_def
                  Property_Result := Base_Subtype_Decl_P_Record_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.record_def
                  Property_Result := Classwide_Type_Decl_P_Record_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.record_def
                  Property_Result := Type_Decl_P_Record_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Record_Def;
--# end
--# property-start '[dispatcher]BaseTypeDecl.array_def' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Array_Def
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Type_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Type_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.array_def
                  Property_Result := Base_Type_Decl_P_Array_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.array_def
                  Property_Result := Base_Subtype_Decl_P_Array_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.array_def
                  Property_Result := Type_Decl_P_Array_Def
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Array_Def;
--# end
--# property-start BaseTypeDecl.array_def_with_deref /tmp/lal-23.0.0/ada/ast.py:6264
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Array_Def_With_Deref
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Type_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Type_Def;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
Fld_1 : Internal_Entity_Array_Type_Def;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Result_Var : Internal_Entity_Array_Type_Def;
If_Result : Internal_Entity_Array_Type_Def;
If_Result_1 : Internal_Entity_Array_Type_Def;
Let_Result : Internal_Entity_Array_Type_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3264 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3263 '<Cond at ast.py:6270>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:6270
--# expr-start 3258 '<FieldAccess for is_array at ast.py:6271>' Fld /tmp/lal-23.0.0/ada/ast.py:6271
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_array
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Array (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3258
if Fld then
   --# expr-start 3259 '<FieldAccess for array_def at ast.py:6271>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6271
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3259
   If_Result_1 := Fld_1;
else
--# expr-start 3260 '<FieldAccess for is_implicit_deref at ast.py:6273>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6273
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_implicit_deref
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Is_Implicit_Deref (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3260
if Fld_2 then
--# expr-start 3261 '<FieldAccess for accessed_type at ast.py:6274>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6274
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3261
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 3262 '<FieldAccess for array_def at ast.py:6274>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6274
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3262
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Array_Type_Def;
end if;
   If_Result := Result_Var;
else
   If_Result := No_Entity_Array_Type_Def;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 3263
Let_Result := If_Result_1; 
--# end
--# expr-done 3264
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Array_Def_With_Deref;
--# end
--# property-start BaseTypeDecl.is_array_def_with_deref /tmp/lal-23.0.0/ada/ast.py:6279
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Array_Def_With_Deref
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Internal_Entity_Array_Type_Def;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 3266 '<Not at ast.py:6280>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6280
--# expr-start 3265 '<IsNull at ast.py:6280>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6280
Is_Null := Self = null; 
--# expr-done 3265
Not_Val := not (Is_Null); 
--# expr-done 3266
if Not_Val then
   --# expr-start 3269 '<Not at ast.py:6280>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6280
--# expr-start 3268 '<IsNull at ast.py:6280>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6280
--# expr-start 3267 '<FieldAccess for array_def_with_deref at ast.py:6280>' Fld /tmp/lal-23.0.0/ada/ast.py:6280
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3267
Is_Null_1 := Fld.Node = null; 
--# expr-done 3268
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3269
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Array_Def_With_Deref;
--# end
--# property-start BaseTypeDecl.is_array_def_with_deref_or_null /tmp/lal-23.0.0/ada/ast.py:6284
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Is_Null : Boolean;
Fld : Internal_Entity_Array_Type_Def;
Is_Null_1 : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 3270 '<IsNull at ast.py:6285>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6285
Is_Null := Self = null; 
--# expr-done 3270
if Is_Null then
   If_Result := True;
else
   --# expr-start 3273 '<Not at ast.py:6285>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6285
--# expr-start 3272 '<IsNull at ast.py:6285>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6285
--# expr-start 3271 '<FieldAccess for array_def_with_deref at ast.py:6285>' Fld /tmp/lal-23.0.0/ada/ast.py:6285
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3271
Is_Null_1 := Fld.Node = null; 
--# expr-done 3272
Not_Val := not (Is_Null_1); 
--# expr-done 3273
   If_Result := Not_Val;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null;
--# end
--# property-start BaseTypeDecl.comp_type /tmp/lal-23.0.0/ada/ast.py:6291
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Comp_Type
  (Node : Bare_Base_Type_Decl
      ; Is_Subscript : Boolean
         := False
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind is_subscript Is_Subscript
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Ad : Internal_Entity_Array_Type_Def;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Array_Type_Def;
Var_Expr_3 : Internal_Entity_Access_Def;
Match_0 : Internal_Entity_Access_To_Subp_Def;
Match_1 : Internal_Entity_Base_Type_Access_Def;
Fld : Internal_Entity_Array_Type_Def;
Fld_1 : Internal_Entity_Array_Type_Def;
If_Result : Internal_Entity_Array_Type_Def;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Access_Def;
Fld_4 : Internal_Entity_Subp_Spec;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Access_Def;
Cast_Result : Internal_Entity_Access_To_Subp_Def;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Access_Def;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_5 : Internal_Entity_Base_Type_Decl;
Result_Var_3 : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3284 '<Block at ???>' Let_Result_3 None
--# scope-start
Var_Expr := Ent;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 3283 '<Let at ast.py:6301>' Let_Result_2 /tmp/lal-23.0.0/ada/ast.py:6301
--# scope-start
--# expr-start 3276 '<If at ast.py:6302>' If_Result /tmp/lal-23.0.0/ada/ast.py:6302
if Is_Subscript then
   --# expr-start 3274 '<FieldAccess for array_def_with_deref at ast.py:6303>' Fld /tmp/lal-23.0.0/ada/ast.py:6303
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3274
   If_Result := Fld;
else
   --# expr-start 3275 '<FieldAccess for array_def at ast.py:6304>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6304
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3275
   If_Result := Fld_1;
end if;
--# expr-done 3276
Ad := If_Result; 
--# bind ad Ad
Var_Expr_2 := Ad;
if Var_Expr_2 /= No_Entity_Array_Type_Def then
   --# scope-start
   --# bind ad Var_Expr_2
--# expr-start 3277 '<FieldAccess for comp_type at ast.py:6305>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6305
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ArrayTypeDef.comp_type
Fld_2 := Libadalang.Implementation.Array_Type_Def_P_Comp_Type (Node => Var_Expr_2.Node, Origin => Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 3277
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result_1 := Var_Expr_1;
   --# end
   Result_Var_2 := Scope_Result_1;
else
--# expr-start 3278 '<FieldAccess for access_def at ast.py:6306>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6306
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3278
Var_Expr_3 := Fld_3;
if Var_Expr_3 /= No_Entity_Access_Def then
   --# scope-start
--# expr-start 3282 '<Match at ast.py:6306>' Match_Result /tmp/lal-23.0.0/ada/ast.py:6306
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr_3; 
case Ada_Access_Def (Match_Prefix.Node.Kind) is
         when Ada_Access_To_Subp_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind asd Match_0
--# expr-start 3280 '<FieldAccess for return_type at ast.py:6308>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6308
--# expr-start 3279 '<FieldAccess for subp_spec at ast.py:6308>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6308
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Subp_Spec (Node => Match_0.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Match_0.Info);
--# expr-done 3279
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_5 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld_4.Node, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 3280
Let_Result := Fld_5; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Anonymous_Type_Access_Def .. Ada_Type_Access_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Access_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind tad Match_1
--# expr-start 3281 '<FieldAccess for accessed_type at ast.py:6309>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6309
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.accessed_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Type_Def_P_Accessed_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 3281
Let_Result_1 := Fld_6; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 3282
Scope_Result_4 := Match_Result;
   --# end
   Result_Var_1 := Scope_Result_4;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
   Result_Var_2 := Result_Var_1;
end if;
Let_Result_2 := Result_Var_2; 
--# end
--# expr-done 3283
Scope_Result_5 := Let_Result_2;
   --# end
   Result_Var_3 := Scope_Result_5;
else
   Result_Var_3 := No_Entity_Base_Type_Decl;
end if;
Let_Result_3 := Result_Var_3; 
--# end
--# expr-done 3284
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Comp_Type;
--# end
--# property-start BaseTypeDecl.index_type /tmp/lal-23.0.0/ada/ast.py:6316
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Index_Type
  (Node : Bare_Base_Type_Decl
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Array_Type_Def;
Fld : Internal_Entity_Array_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3287 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3285 '<FieldAccess for array_def_with_deref at ast.py:6324>' Fld /tmp/lal-23.0.0/ada/ast.py:6324
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3285
Var_Expr := Fld;
if Var_Expr /= No_Entity_Array_Type_Def then
   --# scope-start
   --# bind ad Var_Expr
--# expr-start 3286 '<FieldAccess for index_type at ast.py:6324>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6324
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ArrayTypeDef.index_type
Fld_1 := Libadalang.Implementation.Array_Type_Def_P_Index_Type (Node => Var_Expr.Node, Dim => Dim, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3286
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 3287
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Index_Type;
--# end
--# property-start BaseTypeDecl.expr_type /tmp/lal-23.0.0/ada/ast.py:6328
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Expr_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Ent;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Expr_Type;
--# end
--# property-start BaseTypeDecl.is_derived_type /tmp/lal-23.0.0/ada/ast.py:6332
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Derived_Type
  (Node : Bare_Base_Type_Decl
      ; Other_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other_type Other_Type
   --# bind origin Origin
   Property_Result : Boolean;
            procedure Finalizer_Scope_485 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Fld_2 : Internal_Entity_Classwide_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_3 : Internal_Entity_Classwide_Type_Decl;
Fld_4 : Internal_Entity_Classwide_Type_Decl;
Cast_Result_2 : Internal_Entity;
Cast_Result_3 : Internal_Entity;
Is_Equiv_1 : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Fld_5 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_6 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Quantifier_Result : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_485 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_485;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3300 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3288 '<FieldAccess for canonical_type at ast.py:6336>' Fld /tmp/lal-23.0.0/ada/ast.py:6336
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3288
Block_Var := Fld; 
--# bind entity_can Block_Var
--# expr-start 3289 '<FieldAccess for canonical_type at ast.py:6337>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6337
      if Other_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Other_Type.Node, Origin => Origin, E_Info => Other_Type.Info);
--# end
--# expr-done 3289
Block_Var_1 := Fld_1; 
--# bind other_can Block_Var_1
--# expr-start 3290 '<Eq at ast.py:6339>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:6339
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Block_Var_1; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 3290
if Is_Equiv then
   If_Result_1 := True;
else
--# expr-start 3293 '<Not at ast.py:6340>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6340
--# expr-start 3292 '<IsNull at ast.py:6340>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6340
--# expr-start 3291 '<FieldAccess for classwide_type at ast.py:6340>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6340
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 3291
Is_Null := Fld_2.Node = null; 
--# expr-done 3292
Not_Val := not (Is_Null); 
--# expr-done 3293
if Not_Val then
   --# expr-start 3296 '<Eq at ast.py:6341>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:6341
--# expr-start 3294 '<FieldAccess for classwide_type at ast.py:6341>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6341
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 3294
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
--# expr-start 3295 '<FieldAccess for classwide_type at ast.py:6341>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6341
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 3295
      Cast_Result_3 := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Is_Equiv_1 := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 3296
   If_Result := Is_Equiv_1;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 3299 '<AnyQuantifier at ast.py:6342>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:6342
   --# expr-start 3297 '<FieldAccess for base_types at ast.py:6342>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6342
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_types'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Types (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3297
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_5;
      begin
         for Item_133 of
               Collection.Items
         loop
   --# scope-start
               --# bind bt Item_133
Var_Expr := Item_133;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3298 '<FieldAccess for is_derived_type at ast.py:6342>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6342
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_derived_type
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Is_Derived_Type (Node => Var_Expr.Node, Other_Type => Other_Type, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3298
Scope_Result := Fld_6;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      Quantifier_Result := Result_Var;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 3299
   If_Result_2 := Quantifier_Result;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 3300
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_485;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_485;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Derived_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_iterable_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Iterable_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_iterable_type
                  Property_Result := Base_Type_Decl_P_Is_Iterable_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_iterable_type
                  Property_Result := Base_Subtype_Decl_P_Is_Iterable_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.is_iterable_type
                  Property_Result := Classwide_Type_Decl_P_Is_Iterable_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_iterable_type
                  Property_Result := Type_Decl_P_Is_Iterable_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Iterable_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_interface_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Interface_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl | Ada_Incomplete_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_interface_type
                  Property_Result := Base_Type_Decl_P_Is_Interface_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.is_interface_type
                  Property_Result := Classwide_Type_Decl_P_Is_Interface_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Interface_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.iterable_comp_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.iterable_comp_type
                  Property_Result := Base_Type_Decl_P_Iterable_Comp_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.iterable_comp_type
                  Property_Result := Base_Subtype_Decl_P_Iterable_Comp_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.iterable_comp_type
                  Property_Result := Classwide_Type_Decl_P_Iterable_Comp_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.iterable_comp_type
                  Property_Result := Type_Decl_P_Iterable_Comp_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type;
--# end
--# property-start BaseTypeDecl.matching_prefix_type /tmp/lal-23.0.0/ada/ast.py:6370
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Prefix_Type
  (Node : Bare_Base_Type_Decl
      ; Container_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind container_type Container_Type
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result_1 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3310 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Container_Type; 
--# bind cont_type Block_Var
--# expr-start 3302 '<Not at ast.py:6377>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6377
--# expr-start 3301 '<IsNull at ast.py:6377>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6377
Is_Null := Self = null; 
--# expr-done 3301
Not_Val := not (Is_Null); 
--# expr-done 3302
if Not_Val then
   --# expr-start 3304 '<Not at ast.py:6377>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6377
--# expr-start 3303 '<IsNull at ast.py:6377>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6377
Is_Null_1 := Container_Type.Node = null; 
--# expr-done 3303
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3304
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
--# expr-start 3305 '<FieldAccess for matching_formal_prim_type at ast.py:6379>' Fld /tmp/lal-23.0.0/ada/ast.py:6379
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_prim_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Prim_Type (Node => Ent.Node, Formal_Type => Block_Var, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3305
if Fld then
   If_Result_1 := True;
else
--# expr-start 3306 '<FieldAccess for final_accessed_type at ast.py:6382>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6382
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.final_accessed_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Final_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3306
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3307 '<FieldAccess for matching_formal_prim_type at ast.py:6382>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6382
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_prim_type
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Prim_Type (Node => Var_Expr.Node, Formal_Type => Block_Var, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3307
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result_1 := Result_Var;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
--# expr-start 3308 '<FieldAccess for accessed_type at ast.py:6386>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6386
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3308
Var_Expr_1 := Fld_3;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind at Var_Expr_1
--# expr-start 3309 '<FieldAccess for matching_formal_prim_type at ast.py:6387>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6387
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_prim_type
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Prim_Type (Node => Ent.Node, Formal_Type => Var_Expr_1, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3309
Scope_Result_1 := Fld_4;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_2 := Result_Var_1;
end if;
   If_Result_3 := If_Result_2;
else
   If_Result_3 := False;
end if;
Let_Result := If_Result_3; 
--# end
--# expr-done 3310
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Prefix_Type;
--# end
--# property-start BaseTypeDecl.matching_access_type /tmp/lal-23.0.0/ada/ast.py:6392
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Access_Type
  (Node : Bare_Base_Type_Decl
      ; Expected_Type : Internal_Entity_Base_Type_Decl
      ; For_Assignment : Boolean
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind expected_type Expected_Type
   --# bind for_assignment For_Assignment
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Match_0 : Internal_Entity_Anonymous_Type_Decl;
Match_1 : Internal_Entity_Base_Type_Decl;
Match_0_1 : Internal_Entity_Anonymous_Type_Decl;
Match_1_1 : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
Fld_1 : Boolean;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Anonymous_Type_Decl;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Match_Result : Boolean;
Match_Prefix_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Anonymous_Type_Decl;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Boolean;
Scope_Result_3 : Boolean;
Match_Result_1 : Boolean;
Let_Result_4 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3315 '<Block at ???>' Let_Result_4 None
--# scope-start
Block_Var := Ent; 
--# bind actual_type Block_Var
--# expr-start 3314 '<Match at ast.py:6398>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:6398
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Expected_Type; 
case Ada_Base_Type_Decl (Match_Prefix_1.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Synth_Anonymous_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Anonymous_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_0 := Cast_Result_2; 
--# bind atd Match_0
--# expr-start 3311 '<FieldAccess for access_def_matches at ast.py:6400>' Fld /tmp/lal-23.0.0/ada/ast.py:6400
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AnonymousTypeDecl.access_def_matches
Fld := Libadalang.Implementation.Anonymous_Type_Decl_P_Access_Def_Matches (Node => Match_0.Node, Other => Block_Var, For_Assignment => For_Assignment, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 3311
Let_Result_2 := Fld; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result_1 := Scope_Result_2; 
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Single_Task_Type_Decl | Ada_Concrete_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_1 := Cast_Result_3; 
--# bind _ Match_1
--# expr-start 3313 '<Match at ast.py:6401>' Match_Result /tmp/lal-23.0.0/ada/ast.py:6401
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Block_Var; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Synth_Anonymous_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Anonymous_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0_1 := Cast_Result; 
--# bind atd2 Match_0_1
--# expr-start 3312 '<FieldAccess for access_def_matches at ast.py:6403>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6403
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AnonymousTypeDecl.access_def_matches
Fld_1 := Libadalang.Implementation.Anonymous_Type_Decl_P_Access_Def_Matches (Node => Match_0_1.Node, Other => Expected_Type, For_Assignment => For_Assignment, Origin => Origin, E_Info => Match_0_1.Info);
--# end
--# expr-done 3312
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Single_Task_Type_Decl | Ada_Concrete_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1_1 := Cast_Result_1; 
--# bind _ Match_1_1
Let_Result_1 := False; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 3313
Let_Result_3 := Match_Result; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result_1 := Scope_Result_3; 
end case;
--# expr-done 3314
Let_Result_4 := Match_Result_1; 
--# end
--# expr-done 3315
      Property_Result := Let_Result_4;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Access_Type;
--# end
--# property-start BaseTypeDecl.matching_formal_prim_type /tmp/lal-23.0.0/ada/ast.py:6409
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Formal_Prim_Type
  (Node : Bare_Base_Type_Decl
      ; Formal_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind formal_type Formal_Type
   --# bind origin Origin
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3321 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3317 '<Not at ast.py:6411>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6411
--# expr-start 3316 '<IsNull at ast.py:6411>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6411
Is_Null := Formal_Type.Node = null; 
--# expr-done 3316
Not_Val := not (Is_Null); 
--# expr-done 3317
if Not_Val then
   --# expr-start 3319 '<Not at ast.py:6412>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6412
--# expr-start 3318 '<IsNull at ast.py:6412>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6412
Is_Null_1 := Self = null; 
--# expr-done 3318
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3319
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 3320 '<FieldAccess for matching_formal_type_impl at ast.py:6413>' Fld /tmp/lal-23.0.0/ada/ast.py:6413
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type_impl
Fld := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type_Impl (Node => Ent.Node, Formal_Type => Formal_Type, Accept_Derived => True, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3320
   If_Result_1 := Fld;
else
   If_Result_1 := False;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 3321
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Formal_Prim_Type;
--# end
--# property-start BaseTypeDecl.matching_formal_type /tmp/lal-23.0.0/ada/ast.py:6417
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Formal_Type
  (Node : Bare_Base_Type_Decl
      ; Formal_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind formal_type Formal_Type
   --# bind origin Origin
   Property_Result : Boolean;
      Is_Null : Boolean;
Not_Val : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3327 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3323 '<Not at ast.py:6419>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6419
--# expr-start 3322 '<IsNull at ast.py:6419>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6419
Is_Null := Formal_Type.Node = null; 
--# expr-done 3322
Not_Val := not (Is_Null); 
--# expr-done 3323
if Not_Val then
   --# expr-start 3325 '<Not at ast.py:6420>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6420
--# expr-start 3324 '<IsNull at ast.py:6420>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6420
Is_Null_1 := Self = null; 
--# expr-done 3324
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3325
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 3326 '<FieldAccess for matching_formal_type_impl at ast.py:6421>' Fld /tmp/lal-23.0.0/ada/ast.py:6421
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type_impl
Fld := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type_Impl (Node => Ent.Node, Formal_Type => Formal_Type, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3326
   If_Result_1 := Fld;
else
   If_Result_1 := False;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 3327
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Formal_Type;
--# end
--# property-start BaseTypeDecl.matching_formal_type_impl /tmp/lal-23.0.0/ada/ast.py:6425
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Formal_Type_Impl
  (Node : Bare_Base_Type_Decl
      ; Formal_Type : Internal_Entity_Base_Type_Decl
      ; Accept_Derived : Boolean
         := False
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind formal_type Formal_Type
   --# bind accept_derived Accept_Derived
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
If_Result : Boolean;
Fld_1 : Boolean;
If_Result_1 : Boolean;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Boolean;
If_Result_4 : Boolean;
Fld_8 : Boolean;
If_Result_5 : Boolean;
Fld_9 : Boolean;
Fld_10 : Internal_Entity_Base_Type_Decl;
Fld_11 : Boolean;
If_Result_6 : Boolean;
If_Result_7 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_8 : Boolean;
Fld_12 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_13 : Internal_Entity_Base_Type_Decl;
Fld_14 : Boolean;
If_Result_9 : Boolean;
If_Result_10 : Boolean;
Fld_15 : Boolean;
If_Result_11 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3346 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Ent; 
--# bind actual_type Block_Var
--# expr-start 3328 '<FieldAccess for is_classwide at ast.py:6429>' Fld /tmp/lal-23.0.0/ada/ast.py:6429
      if Formal_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Formal_Type.Node, E_Info => Formal_Type.Info);
--# end
--# expr-done 3328
if Fld then
   If_Result := True;
else
   If_Result := Accept_Derived;
end if;
if If_Result then
   --# expr-start 3329 '<FieldAccess for is_derived_type at ast.py:6430>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6430
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_derived_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Is_Derived_Type (Node => Block_Var.Node, Other_Type => Formal_Type, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3329
   If_Result_1 := Fld_1;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_3 := True;
else
--# expr-start 3330 '<FieldAccess for is_classwide at ast.py:6432>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6432
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 3330
if Fld_2 then
   --# expr-start 3332 '<FieldAccess for matching_type at ast.py:6433>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6433
--# expr-start 3331 '<FieldAccess for specific_type at ast.py:6433>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6433
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.specific_type
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Specific_Type (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 3331
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Fld_3.Node, Expected_Type => Formal_Type, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 3332
   If_Result_2 := Fld_4;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
if If_Result_3 then
   If_Result_8 := True;
else
--# expr-start 3333 '<FieldAccess for accessed_type at ast.py:6436>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6436
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3333
Var_Expr := Fld_5;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind actual_access Var_Expr
--# expr-start 3334 '<FieldAccess for accessed_type at ast.py:6438>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6438
      if Formal_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Formal_Type.Node, Origin => Origin, E_Info => Formal_Type.Info);
--# end
--# expr-done 3334
Var_Expr_1 := Fld_6;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind formal_access Var_Expr_1
--# expr-start 3335 '<FieldAccess for is_classwide at ast.py:6440>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6440
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 3335
if Fld_7 then
   If_Result_4 := True;
else
   If_Result_4 := Accept_Derived;
end if;
if If_Result_4 then
   --# expr-start 3336 '<FieldAccess for is_derived_type at ast.py:6441>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6441
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_derived_type
Fld_8 := Libadalang.Implementation.Base_Type_Decl_P_Is_Derived_Type (Node => Var_Expr.Node, Other_Type => Var_Expr_1, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3336
   If_Result_5 := Fld_8;
else
   If_Result_5 := False;
end if;
if If_Result_5 then
   If_Result_7 := True;
else
--# expr-start 3337 '<FieldAccess for is_classwide at ast.py:6443>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6443
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3337
if Fld_9 then
   --# expr-start 3339 '<FieldAccess for matching_type at ast.py:6444>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:6444
--# expr-start 3338 '<FieldAccess for specific_type at ast.py:6444>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:6444
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.specific_type
Fld_10 := Libadalang.Implementation.Base_Type_Decl_P_Specific_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3338
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_11 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Fld_10.Node, Expected_Type => Var_Expr_1, Origin => Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 3339
   If_Result_6 := Fld_11;
else
   If_Result_6 := False;
end if;
   If_Result_7 := If_Result_6;
end if;
Scope_Result := If_Result_7;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_8 := Result_Var_1;
end if;
if If_Result_8 then
   If_Result_10 := True;
else
--# expr-start 3342 '<Not at ast.py:6450>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6450
--# expr-start 3341 '<IsNull at ast.py:6450>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6450
--# expr-start 3340 '<FieldAccess for get_imp_deref at ast.py:6450>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:6450
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_12 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 3340
Is_Null := Fld_12.Node = null; 
--# expr-done 3341
Not_Val := not (Is_Null); 
--# expr-done 3342
if Not_Val then
   --# expr-start 3344 '<FieldAccess for matching_formal_type at ast.py:6452>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:6452
--# expr-start 3343 '<FieldAccess for accessed_type at ast.py:6452>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:6452
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_13 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3343
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_14 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Fld_13.Node, Formal_Type => Formal_Type, Origin => Origin, E_Info => Fld_13.Info);
--# end
--# expr-done 3344
   If_Result_9 := Fld_14;
else
   If_Result_9 := False;
end if;
   If_Result_10 := If_Result_9;
end if;
if If_Result_10 then
   If_Result_11 := True;
else
   --# expr-start 3345 '<FieldAccess for matching_type at ast.py:6454>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:6454
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_15 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Block_Var.Node, Expected_Type => Formal_Type, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3345
   If_Result_11 := Fld_15;
end if;
Let_Result := If_Result_11; 
--# end
--# expr-done 3346
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Formal_Type_Impl;
--# end
--# property-start BaseTypeDecl.matching_assign_type /tmp/lal-23.0.0/ada/ast.py:6458
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Assign_Type
  (Node : Bare_Base_Type_Decl
      ; Expected_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind expected_type Expected_Type
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld : Boolean;
Fld_1 : Boolean;
Fld_2 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Fld_3 : Internal_Entity_Expr;
Is_Null_2 : Boolean;
Not_Val_2 : Boolean;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Boolean;
Fld_6 : Internal_Entity_Expr;
Is_Null_3 : Boolean;
Not_Val_3 : Boolean;
Fld_7 : Internal_Entity_Base_Type_Decl;
Fld_8 : Boolean;
If_Result_5 : Boolean;
If_Result_6 : Boolean;
Fld_9 : Boolean;
If_Result_7 : Boolean;
If_Result_8 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3365 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Ent; 
--# bind actual_type Block_Var
--# expr-start 3348 '<Not at ast.py:6460>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6460
--# expr-start 3347 '<IsNull at ast.py:6460>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6460
Is_Null := Self = null; 
--# expr-done 3347
Not_Val := not (Is_Null); 
--# expr-done 3348
if Not_Val then
   --# expr-start 3350 '<Not at ast.py:6460>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6460
--# expr-start 3349 '<IsNull at ast.py:6460>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6460
Is_Null_1 := Expected_Type.Node = null; 
--# expr-done 3349
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3350
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
--# expr-start 3351 '<FieldAccess for matching_type at ast.py:6461>' Fld /tmp/lal-23.0.0/ada/ast.py:6461
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Ent.Node, Expected_Type => Expected_Type, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3351
if Fld then
   If_Result_2 := True;
else
--# expr-start 3352 '<FieldAccess for is_classwide at ast.py:6464>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6464
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Expected_Type.Node, E_Info => Expected_Type.Info);
--# end
--# expr-done 3352
if Fld_1 then
   --# expr-start 3353 '<FieldAccess for matching_formal_prim_type at ast.py:6465>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6465
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_formal_prim_type
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Prim_Type (Node => Block_Var.Node, Formal_Type => Expected_Type, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3353
   If_Result_1 := Fld_2;
else
   If_Result_1 := False;
end if;
   If_Result_2 := If_Result_1;
end if;
if If_Result_2 then
   If_Result_4 := True;
else
--# expr-start 3356 '<Not at ast.py:6469>' Not_Val_2 /tmp/lal-23.0.0/ada/ast.py:6469
--# expr-start 3355 '<IsNull at ast.py:6469>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:6469
--# expr-start 3354 '<FieldAccess for get_imp_deref at ast.py:6469>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6469
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 3354
Is_Null_2 := Fld_3.Node = null; 
--# expr-done 3355
Not_Val_2 := not (Is_Null_2); 
--# expr-done 3356
if Not_Val_2 then
   --# expr-start 3358 '<FieldAccess for matching_assign_type at ast.py:6471>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6471
--# expr-start 3357 '<FieldAccess for accessed_type at ast.py:6471>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6471
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3357
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_assign_type
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Assign_Type (Node => Fld_4.Node, Expected_Type => Expected_Type, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 3358
   If_Result_3 := Fld_5;
else
   If_Result_3 := False;
end if;
   If_Result_4 := If_Result_3;
end if;
if If_Result_4 then
   If_Result_6 := True;
else
--# expr-start 3361 '<Not at ast.py:6475>' Not_Val_3 /tmp/lal-23.0.0/ada/ast.py:6475
--# expr-start 3360 '<IsNull at ast.py:6475>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:6475
--# expr-start 3359 '<FieldAccess for get_imp_deref at ast.py:6475>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6475
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Expected_Type.Node, E_Info => Expected_Type.Info);
--# end
--# expr-done 3359
Is_Null_3 := Fld_6.Node = null; 
--# expr-done 3360
Not_Val_3 := not (Is_Null_3); 
--# expr-done 3361
if Not_Val_3 then
   --# expr-start 3363 '<FieldAccess for matching_assign_type at ast.py:6477>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6477
--# expr-start 3362 '<FieldAccess for accessed_type at ast.py:6477>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6477
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Expected_Type.Node, Origin => Origin, E_Info => Expected_Type.Info);
--# end
--# expr-done 3362
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_assign_type
Fld_8 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Assign_Type (Node => Fld_7.Node, Expected_Type => Block_Var, Origin => Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 3363
   If_Result_5 := Fld_8;
else
   If_Result_5 := False;
end if;
   If_Result_6 := If_Result_5;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 3364 '<FieldAccess for matching_access_type at ast.py:6480>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6480
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_access_type
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Access_Type (Node => Ent.Node, Expected_Type => Expected_Type, For_Assignment => True, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3364
   If_Result_7 := Fld_9;
end if;
   If_Result_8 := If_Result_7;
else
   If_Result_8 := False;
end if;
Let_Result := If_Result_8; 
--# end
--# expr-done 3365
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Assign_Type;
--# end
--# property-start BaseTypeDecl.matching_type /tmp/lal-23.0.0/ada/ast.py:6485
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Type
  (Node : Bare_Base_Type_Decl
      ; Expected_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind expected_type Expected_Type
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld : Internal_Entity;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Is_Equiv : Boolean;
Fld_1 : Boolean;
If_Result_1 : Boolean;
Fld_2 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv_1 : Boolean;
Fld_3 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Fld_4 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Is_Equiv_2 : Boolean;
Fld_5 : Boolean;
If_Result_4 : Boolean;
If_Result_5 : Boolean;
Fld_6 : Internal_Entity;
Cast_Expr_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Is_Equiv_3 : Boolean;
Fld_7 : Boolean;
If_Result_6 : Boolean;
If_Result_7 : Boolean;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Cast_Result_5 : Internal_Entity;
Is_Equiv_4 : Boolean;
If_Result_8 : Boolean;
Fld_10 : Boolean;
If_Result_9 : Boolean;
If_Result_10 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3386 '<Block at ???>' Let_Result None
--# scope-start
Block_Var := Ent; 
--# bind actual_type Block_Var
--# expr-start 3367 '<Not at ast.py:6491>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6491
--# expr-start 3366 '<IsNull at ast.py:6491>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6491
Is_Null := Expected_Type.Node = null; 
--# expr-done 3366
Not_Val := not (Is_Null); 
--# expr-done 3367
if Not_Val then
   --# expr-start 3369 '<Not at ast.py:6492>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6492
--# expr-start 3368 '<IsNull at ast.py:6492>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6492
Is_Null_1 := Block_Var.Node = null; 
--# expr-done 3368
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3369
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
--# expr-start 3371 '<Eq at ast.py:6494>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:6494
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 3370 '<FieldAccess for universal_int_type at ast.py:6494>' Fld /tmp/lal-23.0.0/ada/ast.py:6494
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 3370
Is_Equiv := Equivalent (Cast_Result, Fld); 
--# expr-done 3371
if Is_Equiv then
   --# expr-start 3372 '<FieldAccess for allows_universal_int at ast.py:6495>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6495
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.allows_universal_int
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Allows_Universal_Int (Node => Expected_Type.Node, Origin => Origin, E_Info => Expected_Type.Info);
--# end
--# expr-done 3372
   If_Result_1 := Fld_1;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_3 := True;
else
--# expr-start 3374 '<Eq at ast.py:6497>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:6497
Cast_Expr_1 := Expected_Type; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
--# expr-start 3373 '<FieldAccess for universal_int_type at ast.py:6497>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6497
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 3373
Is_Equiv_1 := Equivalent (Cast_Result_1, Fld_2); 
--# expr-done 3374
if Is_Equiv_1 then
   --# expr-start 3375 '<FieldAccess for is_int_type at ast.py:6498>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6498
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_int_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Int_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3375
   If_Result_2 := Fld_3;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
if If_Result_3 then
   If_Result_5 := True;
else
--# expr-start 3377 '<Eq at ast.py:6500>' Is_Equiv_2 /tmp/lal-23.0.0/ada/ast.py:6500
Cast_Expr_2 := Block_Var; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
--# expr-start 3376 '<FieldAccess for universal_real_type at ast.py:6500>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6500
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld_4 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 3376
Is_Equiv_2 := Equivalent (Cast_Result_2, Fld_4); 
--# expr-done 3377
if Is_Equiv_2 then
   --# expr-start 3378 '<FieldAccess for allows_universal_real at ast.py:6501>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6501
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.allows_universal_real
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Allows_Universal_Real (Node => Expected_Type.Node, Origin => Origin, E_Info => Expected_Type.Info);
--# end
--# expr-done 3378
   If_Result_4 := Fld_5;
else
   If_Result_4 := False;
end if;
   If_Result_5 := If_Result_4;
end if;
if If_Result_5 then
   If_Result_7 := True;
else
--# expr-start 3380 '<Eq at ast.py:6503>' Is_Equiv_3 /tmp/lal-23.0.0/ada/ast.py:6503
Cast_Expr_3 := Expected_Type; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
--# expr-start 3379 '<FieldAccess for universal_real_type at ast.py:6503>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6503
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld_6 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 3379
Is_Equiv_3 := Equivalent (Cast_Result_3, Fld_6); 
--# expr-done 3380
if Is_Equiv_3 then
   --# expr-start 3381 '<FieldAccess for is_real_type at ast.py:6504>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6504
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_real_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Real_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3381
   If_Result_6 := Fld_7;
else
   If_Result_6 := False;
end if;
   If_Result_7 := If_Result_6;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 3384 '<Eq at ast.py:6506>' Is_Equiv_4 /tmp/lal-23.0.0/ada/ast.py:6506
--# expr-start 3382 '<FieldAccess for canonical_type at ast.py:6506>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6506
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_8 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3382
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
--# expr-start 3383 '<FieldAccess for canonical_type at ast.py:6506>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6506
      if Expected_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Expected_Type.Node, Origin => Origin, E_Info => Expected_Type.Info);
--# end
--# expr-done 3383
      Cast_Result_5 := Create_Internal_Entity
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
Is_Equiv_4 := Equivalent (Cast_Result_4, Cast_Result_5); 
--# expr-done 3384
   If_Result_8 := Is_Equiv_4;
end if;
if If_Result_8 then
   If_Result_9 := True;
else
   --# expr-start 3385 '<FieldAccess for matching_access_type at ast.py:6508>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:6508
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_access_type
Fld_10 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Access_Type (Node => Block_Var.Node, Expected_Type => Expected_Type, For_Assignment => False, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 3385
   If_Result_9 := Fld_10;
end if;
   If_Result_10 := If_Result_9;
else
   If_Result_10 := False;
end if;
Let_Result := If_Result_10; 
--# end
--# expr-done 3386
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Type;
--# end
--# property-start BaseTypeDecl.matching_allocator_type /tmp/lal-23.0.0/ada/ast.py:6513
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Matching_Allocator_Type
  (Node : Bare_Base_Type_Decl
      ; Allocated_Type : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind allocated_type Allocated_Type
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3390 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3387 '<FieldAccess for is_access_type at ast.py:6515>' Fld /tmp/lal-23.0.0/ada/ast.py:6515
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3387
if Fld then
   --# expr-start 3389 '<FieldAccess for matching_formal_type at ast.py:6516>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6516
      if Allocated_Type.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3388 '<FieldAccess for accessed_type at ast.py:6516>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6516
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3388
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Allocated_Type.Node, Formal_Type => Fld_1, Origin => Origin, E_Info => Allocated_Type.Info);
--# end
--# expr-done 3389
   If_Result := Fld_2;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3390
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Matching_Allocator_Type;
--# end
--# property-start '[dispatcher]BaseTypeDecl.canonical_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Canonical_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.canonical_type
                  Property_Result := Base_Type_Decl_P_Canonical_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.canonical_type
                  Property_Result := Base_Subtype_Decl_P_Canonical_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.canonical_type
                  Property_Result := Classwide_Type_Decl_P_Canonical_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Canonical_Type;
--# end
--# property-start BaseTypeDecl.classwide_type_node /tmp/lal-23.0.0/ada/ast.py:6532
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Classwide_Type_Node
  (Node : Bare_Base_Type_Decl
  )
   return Bare_Classwide_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Classwide_Type_Decl;
      Fld : Bare_Defining_Name;
New_Node : Bare_Classwide_Type_Decl;
Let_Result : Bare_Classwide_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Classwide_Type_Node,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Bare_Classwide_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
      end if;
   --# scope-start
      --# expr-start 3393 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3392 '<New ClasswideTypeDecl at ???>' New_Node None
--# expr-start 3391 '<FieldAccess for name at ast.py:6533>' Fld /tmp/lal-23.0.0/ada/ast.py:6533
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Base_Type_Decl_F_Name;
--# expr-done 3391
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Classwide_Type_Decl);
Initialize
  (Self => New_Node,
   Kind => Ada_Classwide_Type_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Classwide_Type_Decl
     (Self => New_Node,
      Base_Type_Decl_F_Name => Fld);
--# expr-done 3392
Let_Result := New_Node; 
--# end
--# expr-done 3393
      Property_Result := Let_Result;
   --# end
      if Self /= null then
            Mmz_Val := (Kind => Mmz_Bare_Classwide_Type_Decl,
                        As_Bare_Classwide_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Classwide_Type_Node;
--# end
--# property-start BaseTypeDecl.scalar_base_subtype_node /tmp/lal-23.0.0/ada/ast.py:6538
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Scalar_Base_Subtype_Node
  (Node : Bare_Base_Type_Decl
  )
   return Bare_Discrete_Base_Subtype_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Discrete_Base_Subtype_Decl;
      Fld : Bare_Defining_Name;
New_Node : Bare_Discrete_Base_Subtype_Decl;
Let_Result : Bare_Discrete_Base_Subtype_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Scalar_Base_Subtype_Node,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Bare_Discrete_Base_Subtype_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
      end if;
   --# scope-start
      --# expr-start 3396 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3395 '<New DiscreteBaseSubtypeDecl at ast.py:6543>' New_Node /tmp/lal-23.0.0/ada/ast.py:6543
--# expr-start 3394 '<FieldAccess for name at ast.py:6543>' Fld /tmp/lal-23.0.0/ada/ast.py:6543
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Base_Type_Decl_F_Name;
--# expr-done 3394
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Discrete_Base_Subtype_Decl);
Initialize
  (Self => New_Node,
   Kind => Ada_Discrete_Base_Subtype_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Discrete_Base_Subtype_Decl
     (Self => New_Node,
      Base_Type_Decl_F_Name => Fld);
--# expr-done 3395
Let_Result := New_Node; 
--# end
--# expr-done 3396
      Property_Result := Let_Result;
   --# end
      if Self /= null then
            Mmz_Val := (Kind => Mmz_Bare_Discrete_Base_Subtype_Decl,
                        As_Bare_Discrete_Base_Subtype_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Scalar_Base_Subtype_Node;
--# end
--# property-start BaseTypeDecl.scalar_base_subtype /tmp/lal-23.0.0/ada/ast.py:6546
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Scalar_Base_Subtype
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Discrete_Base_Subtype_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Discrete_Base_Subtype_Decl;
      Fld : Bare_Discrete_Base_Subtype_Decl;
As_Entity : Internal_Entity_Discrete_Base_Subtype_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Discrete_Base_Subtype_Decl;
Let_Result : Internal_Entity_Discrete_Base_Subtype_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3399 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3398 '<as_entity at ast.py:6551>' If_Result /tmp/lal-23.0.0/ada/ast.py:6551
--# expr-start 3397 '<FieldAccess for scalar_base_subtype_node at ast.py:6551>' Fld /tmp/lal-23.0.0/ada/ast.py:6551
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.scalar_base_subtype_node
Fld := Libadalang.Implementation.Base_Type_Decl_P_Scalar_Base_Subtype_Node (Node => Self);
--# end
--# expr-done 3397
Is_Null := Fld = null; 
if Is_Null then
   If_Result := No_Entity_Discrete_Base_Subtype_Decl;
else
As_Entity := (Info => E_Info, Node => Fld); 
   If_Result := As_Entity;
end if;
--# expr-done 3398
Let_Result := If_Result; 
--# end
--# expr-done 3399
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Scalar_Base_Subtype;
--# end
--# property-start '[dispatcher]BaseTypeDecl.previous_part' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Previous_Part
  (Node : Bare_Base_Type_Decl
      ; Go_To_Incomplete : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind go_to_incomplete Go_To_Incomplete
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl | Ada_Incomplete_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start BaseTypeDecl.previous_part
                  Property_Result := Base_Type_Decl_P_Previous_Part
                    (Self
                        , Go_To_Incomplete
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.previous_part
                  Property_Result := Classwide_Type_Decl_P_Previous_Part
                    (Self
                        , Go_To_Incomplete
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Previous_Part;
--# end
--# property-start BaseTypeDecl.next_part /tmp/lal-23.0.0/ada/ast.py:6586
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Next_Part
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Incomplete_Type_Decl;
Match_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Bare_Declarative_Part;
Var_Expr_2 : Boolean;
Var_Expr_3 : Internal_Entity_Package_Body;
Fld : Bare_Declarative_Part;
As_Entity : Internal_Entity_Declarative_Part;
Is_Null : Boolean;
If_Result : Internal_Entity_Declarative_Part;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
Fld_3 : Bare_Declarative_Part;
Fld_4 : Bare_Ada_Node;
Cast_Result : Bare_Base_Package_Decl;
As_Entity_1 : Internal_Entity_Base_Package_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Base_Package_Decl;
Fld_5 : Internal_Entity_Package_Body;
Fld_6 : Internal_Entity_Declarative_Part;
Fld_7 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Result_Var_3 : Internal_Entity_Base_Type_Decl;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Boolean;
Fld_10 : Boolean;
Not_Val : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Incomplete_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_5 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Next_Part,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 3417 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 3416 '<Match at ast.py:6596>' Match_Result /tmp/lal-23.0.0/ada/ast.py:6596
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Incomplete_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind itd Match_0
--# expr-start 3400 '<FieldAccess for declarative_scope at ast.py:6600>' Fld /tmp/lal-23.0.0/ada/ast.py:6600
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Match_0.Node);
--# end
--# expr-done 3400
Var_Expr_1 := Fld;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind s Var_Expr_1
--# expr-start 3402 '<FieldAccess for find_next_part_in at ast.py:6601>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6601
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3401 '<as_entity at ast.py:6601>' If_Result /tmp/lal-23.0.0/ada/ast.py:6601
Is_Null := Var_Expr_1 = null; 
if Is_Null then
   If_Result := No_Entity_Declarative_Part;
else
As_Entity := (Info => E_Info, Node => Var_Expr_1); 
   If_Result := As_Entity;
end if;
--# expr-done 3401
--# property-call-start IncompleteTypeDecl.find_next_part_in
Fld_1 := Libadalang.Implementation.Incomplete_Type_Decl_P_Find_Next_Part_In (Node => Match_0.Node, Decl_Part => If_Result, E_Info => Match_0.Info);
--# end
--# expr-done 3402
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_1 := Var_Expr;
   --# end
   Result_Var_3 := Scope_Result_1;
else
--# expr-start 3403 '<FieldAccess for is_in_private_part at ast.py:6607>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6607
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3403
Var_Expr_2 := Fld_2;
if Var_Expr_2 /= False then
   --# scope-start
   --# bind _ Var_Expr_2
--# expr-start 3408 '<FieldAccess for body_part at ast.py:6610>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6610
--# expr-start 3407 '<as_entity at ast.py:6610>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:6610
--# expr-start 3406 '<Cast to BasePackageDecl at ast.py:6610>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6610
--# expr-start 3405 '<parent at ast.py:6609>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6609
--# expr-start 3404 '<FieldAccess for declarative_scope at ast.py:6609>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6609
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld_3 := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 3404
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Fld_3.Parent; 
--# expr-done 3405
   if Fld_4 = null
      or else Fld_4.Kind in Ada_Base_Package_Decl
   then
      Cast_Result := Fld_4;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 3406
Is_Null_1 := Cast_Result = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Base_Package_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Cast_Result); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 3407
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasePackageDecl.body_part
Fld_5 := Libadalang.Implementation.Base_Package_Decl_P_Body_Part (Node => If_Result_1.Node, E_Info => If_Result_1.Info);
--# end
--# expr-done 3408
Var_Expr_3 := Fld_5;
if Var_Expr_3 /= No_Entity_Package_Body then
   --# scope-start
   --# bind p Var_Expr_3
--# expr-start 3410 '<FieldAccess for find_next_part_in at ast.py:6611>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6611
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3409 '<FieldAccess for decls at ast.py:6611>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6611
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Declarative_Part (Node => Var_Expr_3.Node.Package_Body_F_Decls, Info => Var_Expr_3.Info);
--# expr-done 3409
--# property-call-start IncompleteTypeDecl.find_next_part_in
Fld_7 := Libadalang.Implementation.Incomplete_Type_Decl_P_Find_Next_Part_In (Node => Match_0.Node, Decl_Part => Fld_6, E_Info => Match_0.Info);
--# end
--# expr-done 3410
Scope_Result_2 := Fld_7;
   --# end
   Result_Var_1 := Scope_Result_2;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Scope_Result_3 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_3;
else
   Result_Var_2 := No_Entity_Base_Type_Decl;
end if;
   Result_Var_3 := Result_Var_2;
end if;
Let_Result := Result_Var_3; 
--# end
Scope_Result_4 := Let_Result;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Classwide_Type_Decl | Ada_Protected_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind _ Match_1
--# expr-start 3415 '<If at ast.py:6615>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:6615
--# expr-start 3411 '<FieldAccess for is_private at ast.py:6616>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6616
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_private'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Private (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3411
if Fld_9 then
   --# expr-start 3413 '<Not at ast.py:6617>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6617
--# expr-start 3412 '<FieldAccess for is_generic_formal at ast.py:6617>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:6617
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_generic_formal
Fld_10 := Libadalang.Implementation.Base_Type_Decl_P_Is_Generic_Formal (Node => Ent.Node);
--# end
--# expr-done 3412
Not_Val := not (Fld_10); 
--# expr-done 3413
   If_Result_2 := Not_Val;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   --# expr-start 3414 '<FieldAccess for private_completion at ast.py:6618>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6618
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.private_completion
Fld_8 := Libadalang.Implementation.Base_Type_Decl_P_Private_Completion (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3414
   If_Result_3 := Fld_8;
else
   If_Result_3 := No_Entity_Base_Type_Decl;
end if;
--# expr-done 3415
Let_Result_1 := If_Result_3; 
--# end
Scope_Result_5 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_5; 
end case;
--# expr-done 3416
Let_Result_2 := Match_Result; 
--# end
--# expr-done 3417
      Property_Result := Let_Result_2;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Next_Part;
--# end
--# property-start BaseTypeDecl.full_view /tmp/lal-23.0.0/ada/ast.py:6625
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Full_View
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3420 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3418 '<FieldAccess for next_part at ast.py:6629>' Fld /tmp/lal-23.0.0/ada/ast.py:6629
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.next_part
Fld := Libadalang.Implementation.Base_Type_Decl_P_Next_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3418
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind np Var_Expr
--# expr-start 3419 '<FieldAccess for full_view at ast.py:6630>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6630
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3419
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := Ent;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 3420
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Full_View;
--# end
--# property-start BaseTypeDecl.is_definite_subtype /tmp/lal-23.0.0/ada/ast.py:6636
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Definite_Subtype
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Incomplete_Type_Decl;
Match_1 : Internal_Entity_Type_Decl;
Match_2 : Internal_Entity_Subtype_Decl;
Match_3 : Internal_Entity_Classwide_Type_Decl;
Match_4 : Internal_Entity_Task_Type_Decl;
Match_5 : Internal_Entity_Protected_Type_Decl;
Match_6 : Internal_Entity_Base_Type_Decl;
Match_0_1 : Internal_Entity_Derived_Type_Def;
Match_1_1 : Internal_Entity_Array_Type_Def;
Match_2_1 : Internal_Entity_Type_Def;
Fld : Internal_Entity_Discriminant_Part;
Is_Null : Boolean;
Fld_1 : Internal_Entity_Type_Def;
Fld_2 : Internal_Entity_Subtype_Indication;
Fld_3 : Internal_Entity_Constraint;
Is_Null_1 : Boolean;
Not_Val : Boolean;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
If_Result : Boolean;
Fld_6 : Internal_Entity_Array_Indices;
Is_A : Boolean;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Derived_Type_Def;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Internal_Entity_Array_Type_Def;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_2 : Internal_Entity_Type_Def;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
If_Result_1 : Boolean;
Fld_7 : Internal_Entity_Subtype_Indication;
Fld_8 : Internal_Entity_Constraint;
Is_Null_2 : Boolean;
Not_Val_1 : Boolean;
Fld_9 : Internal_Entity_Base_Type_Decl;
Fld_10 : Boolean;
If_Result_2 : Boolean;
Fld_11 : Internal_Entity_Discriminant_Part;
Is_Null_3 : Boolean;
Fld_12 : Internal_Entity_Discriminant_Part;
Is_Null_4 : Boolean;
Match_Prefix_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity_Incomplete_Type_Decl;
Let_Result_3 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_4 : Internal_Entity_Type_Decl;
Let_Result_4 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_5 : Internal_Entity_Subtype_Decl;
Let_Result_5 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_6 : Internal_Entity_Classwide_Type_Decl;
Let_Result_6 : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_7 : Internal_Entity_Task_Type_Decl;
Let_Result_7 : Boolean;
Scope_Result_7 : Boolean;
Cast_Result_8 : Internal_Entity_Protected_Type_Decl;
Let_Result_8 : Boolean;
Scope_Result_8 : Boolean;
Cast_Result_9 : Internal_Entity_Base_Type_Decl;
Let_Result_9 : Boolean;
Scope_Result_9 : Boolean;
Match_Result_1 : Boolean;
Let_Result_10 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3444 '<Block at ???>' Let_Result_10 None
--# scope-start
--# expr-start 3443 '<Match at ast.py:6643>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:6643
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Ent; 
case Ada_Base_Type_Decl (Match_Prefix_1.Node.Kind) is
         when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Incomplete_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_0 := Cast_Result_3; 
--# bind _ Match_0
Let_Result_3 := False; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result_1 := Scope_Result_3; 
         when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_1 := Cast_Result_4; 
--# bind td Match_1
--# expr-start 3422 '<IsNull at ast.py:6645>' Is_Null /tmp/lal-23.0.0/ada/ast.py:6645
--# expr-start 3421 '<FieldAccess for discriminants at ast.py:6645>' Fld /tmp/lal-23.0.0/ada/ast.py:6645
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Discriminant_Part (Node => Match_1.Node.Type_Decl_F_Discriminants, Info => Match_1.Info);
--# expr-done 3421
Is_Null := Fld.Node = null; 
--# expr-done 3422
if Is_Null then
   --# expr-start 3432 '<Match at ast.py:6645>' Match_Result /tmp/lal-23.0.0/ada/ast.py:6645
--# expr-start 3423 '<FieldAccess for type_def at ast.py:6645>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6645
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Def (Node => Match_1.Node.Type_Decl_F_Type_Def, Info => Match_1.Info);
--# expr-done 3423
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_1; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0_1 := Cast_Result; 
--# bind dtd Match_0_1
--# expr-start 3427 '<Not at ast.py:6647>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6647
--# expr-start 3426 '<IsNull at ast.py:6647>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:6647
--# expr-start 3425 '<FieldAccess for constraint at ast.py:6647>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6647
--# expr-start 3424 '<FieldAccess for subtype_indication at ast.py:6647>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6647
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Subtype_Indication (Node => Match_0_1.Node.Derived_Type_Def_F_Subtype_Indication, Info => Match_0_1.Info);
--# expr-done 3424
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Constraint (Node => Fld_2.Node.Subtype_Indication_F_Constraint, Info => Fld_2.Info);
--# expr-done 3425
Is_Null_1 := Fld_3.Node = null; 
--# expr-done 3426
Not_Val := not (Is_Null_1); 
--# expr-done 3427
if Not_Val then
   If_Result := True;
else
   --# expr-start 3429 '<FieldAccess for is_definite_subtype at ast.py:6648>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6648
--# expr-start 3428 '<FieldAccess for base_type at ast.py:6648>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6648
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_0_1.Node, Origin => Origin, E_Info => Match_0_1.Info);
--# end
--# expr-done 3428
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_definite_subtype
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Is_Definite_Subtype (Node => Fld_4.Node, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 3429
   If_Result := Fld_5;
end if;
Let_Result := If_Result; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Array_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Array_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1_1 := Cast_Result_1; 
--# bind atd Match_1_1
--# expr-start 3431 '<IsA ConstrainedArrayIndices at ast.py:6651>' Is_A /tmp/lal-23.0.0/ada/ast.py:6651
--# expr-start 3430 '<FieldAccess for indices at ast.py:6651>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6651
      if Match_1_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Array_Indices (Node => Match_1_1.Node.Array_Type_Def_F_Indices, Info => Match_1_1.Info);
--# expr-done 3430
Is_A := Fld_6.Node /= null 
and then Fld_6.Node.Kind in Ada_Constrained_Array_Indices_Range; 
--# expr-done 3431
Let_Result_1 := Is_A; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2_1 := Cast_Result_2; 
--# bind _ Match_2_1
Let_Result_2 := True; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3432
   If_Result_1 := Match_Result;
else
   If_Result_1 := False;
end if;
Let_Result_4 := If_Result_1; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result_1 := Scope_Result_4; 
         when Ada_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Subtype_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_2 := Cast_Result_5; 
--# bind st Match_2
--# expr-start 3436 '<Not at ast.py:6655>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:6655
--# expr-start 3435 '<IsNull at ast.py:6655>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:6655
--# expr-start 3434 '<FieldAccess for constraint at ast.py:6655>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6655
--# expr-start 3433 '<FieldAccess for subtype at ast.py:6655>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6655
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Subtype_Indication (Node => Match_2.Node.Subtype_Decl_F_Subtype, Info => Match_2.Info);
--# expr-done 3433
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Constraint (Node => Fld_7.Node.Subtype_Indication_F_Constraint, Info => Fld_7.Info);
--# expr-done 3434
Is_Null_2 := Fld_8.Node = null; 
--# expr-done 3435
Not_Val_1 := not (Is_Null_2); 
--# expr-done 3436
if Not_Val_1 then
   If_Result_2 := True;
else
   --# expr-start 3438 '<FieldAccess for is_definite_subtype at ast.py:6656>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:6656
--# expr-start 3437 '<FieldAccess for get_type at ast.py:6656>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6656
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Match_2.Node, Origin => Origin, E_Info => Match_2.Info);
--# end
--# expr-done 3437
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_definite_subtype
Fld_10 := Libadalang.Implementation.Base_Type_Decl_P_Is_Definite_Subtype (Node => Fld_9.Node, Origin => Origin, E_Info => Fld_9.Info);
--# end
--# expr-done 3438
   If_Result_2 := Fld_10;
end if;
Let_Result_5 := If_Result_2; 
--# end
Scope_Result_5 := Let_Result_5;
   --# end
            Match_Result_1 := Scope_Result_5; 
         when Ada_Classwide_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Classwide_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_3 := Cast_Result_6; 
--# bind _ Match_3
Let_Result_6 := False; 
--# end
Scope_Result_6 := Let_Result_6;
   --# end
            Match_Result_1 := Scope_Result_6; 
         when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Task_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_4 := Cast_Result_7; 
--# bind ttd Match_4
--# expr-start 3440 '<IsNull at ast.py:6658>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:6658
--# expr-start 3439 '<FieldAccess for discriminants at ast.py:6658>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:6658
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Discriminant_Part (Node => Match_4.Node.Task_Type_Decl_F_Discriminants, Info => Match_4.Info);
--# expr-done 3439
Is_Null_3 := Fld_11.Node = null; 
--# expr-done 3440
Let_Result_7 := Is_Null_3; 
--# end
Scope_Result_7 := Let_Result_7;
   --# end
            Match_Result_1 := Scope_Result_7; 
         when Ada_Protected_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Protected_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_5 := Cast_Result_8; 
--# bind ptd Match_5
--# expr-start 3442 '<IsNull at ast.py:6659>' Is_Null_4 /tmp/lal-23.0.0/ada/ast.py:6659
--# expr-start 3441 '<FieldAccess for discriminants at ast.py:6659>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:6659
      if Match_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Discriminant_Part (Node => Match_5.Node.Protected_Type_Decl_F_Discriminants, Info => Match_5.Info);
--# expr-done 3441
Is_Null_4 := Fld_12.Node = null; 
--# expr-done 3442
Let_Result_8 := Is_Null_4; 
--# end
Scope_Result_8 := Let_Result_8;
   --# end
            Match_Result_1 := Scope_Result_8; 
         when Ada_Discrete_Base_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_6 := Cast_Result_9; 
--# bind _ Match_6
Let_Result_9 := True; 
--# end
Scope_Result_9 := Let_Result_9;
   --# end
            Match_Result_1 := Scope_Result_9; 
end case;
--# expr-done 3443
Let_Result_10 := Match_Result_1; 
--# end
--# expr-done 3444
      Property_Result := Let_Result_10;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Definite_Subtype;
--# end
--# property-start '[dispatcher]BaseTypeDecl.is_private' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Is_Private
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Incomplete_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.is_private
                  Property_Result := Base_Type_Decl_P_Is_Private
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.is_private
                  Property_Result := Base_Subtype_Decl_P_Is_Private
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.is_private
                  Property_Result := Classwide_Type_Decl_P_Is_Private
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.is_private
                  Property_Result := Type_Decl_P_Is_Private
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Is_Private;
--# end
--# property-start '[dispatcher]BaseTypeDecl.discriminants_list' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Discriminants_List
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.discriminants_list
                  Property_Result := Base_Subtype_Decl_P_Discriminants_List
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Classwide_Type_Decl =>
                  --# property-call-start ClasswideTypeDecl.discriminants_list
                  Property_Result := Classwide_Type_Decl_P_Discriminants_List
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Incomplete_Type_Decl .. Ada_Incomplete_Tagged_Type_Decl =>
                  --# property-call-start IncompleteTypeDecl.discriminants_list
                  Property_Result := Incomplete_Type_Decl_P_Discriminants_List
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Protected_Type_Decl =>
                  --# property-call-start ProtectedTypeDecl.discriminants_list
                  Property_Result := Protected_Type_Decl_P_Discriminants_List
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start TaskTypeDecl.discriminants_list
                  Property_Result := Task_Type_Decl_P_Discriminants_List
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.discriminants_list
                  Property_Result := Type_Decl_P_Discriminants_List
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Discriminants_List;
--# end
--# property-start BaseTypeDecl.corresponding_char_literal /tmp/lal-23.0.0/ada/ast.py:6683
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Corresponding_Char_Literal
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Basic_Decl;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Enum_Type_Def;
Block_Var_2 : Symbol_Type;
Block_Var_3 : Internal_Entity_Enum_Literal_Decl;
Var_Expr : Internal_Entity_Type_Decl;
Var_Expr_1 : Bare_Char_Literal;
Var_Expr_2 : Internal_Entity_Enum_Type_Def;
Fld : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Type_Decl;
Fld_1 : Internal_Entity_Type_Def;
Scope_Result : Internal_Entity_Type_Def;
Result_Var : Internal_Entity_Type_Def;
Cast_Result_1 : Internal_Entity_Enum_Type_Def;
Cast_Expr_1 : Bare_Ada_Node;
Cast_Result_2 : Bare_Char_Literal;
Sym : Symbol_Type;
Scope_Result_1 : Symbol_Type;
Result_Var_1 : Symbol_Type;
Fld_2 : Internal_Entity_Enum_Literal_Decl_List;
Scope_Result_2 : Internal_Entity_Enum_Literal_Decl_List;
Result_Var_2 : Internal_Entity_Enum_Literal_Decl_List;
Fld_3 : Bare_Enum_Literal_Decl_List;
Fld_4 : Internal_Entity_Info;
As_Entity : Internal_Entity_Enum_Literal_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Enum_Literal_Decl;
Fld_5 : Internal_Entity_Defining_Name;
Fld_6 : Boolean;
Item_135 : Internal_Entity_Enum_Literal_Decl;
Bare_Item_135 : Bare_Enum_Literal_Decl;
Find_Result : Internal_Entity_Enum_Literal_Decl;
Fld_7 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Type_Decl;
New_Node : Bare_Synthetic_Char_Enum_Lit;
As_Entity_1 : Internal_Entity_Synthetic_Char_Enum_Lit;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Synthetic_Char_Enum_Lit;
Cast_Result_4 : Internal_Entity_Enum_Literal_Decl;
Is_Null_2 : Boolean;
Fld_8 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Internal_Entity_Enum_Literal_Decl;
Let_Result : Internal_Entity_Enum_Literal_Decl;
Cast_Result_5 : Internal_Entity_Basic_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Corresponding_Char_Literal,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
--# expr-start 3462 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3445 '<FieldAccess for root_type at ast.py:6693>' Fld /tmp/lal-23.0.0/ada/ast.py:6693
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.root_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Root_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3445
Block_Var := Fld; 
--# bind root Block_Var
--# expr-start 3448 '<Cast to EnumTypeDef at ast.py:6694>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:6694
--# expr-start 3446 '<Cast to TypeDecl at ast.py:6694>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6694
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Type_Decl;
   end if;
--# expr-done 3446
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Type_Decl then
   --# scope-start
--# expr-start 3447 '<FieldAccess for type_def at ast.py:6694>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6694
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Def (Node => Var_Expr.Node.Type_Decl_F_Type_Def, Info => Var_Expr.Info);
--# expr-done 3447
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Type_Def;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Enum_Type_Def_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Enum_Type_Def
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result_1 := No_Entity_Enum_Type_Def;
   end if;
--# expr-done 3448
Block_Var_1 := Cast_Result_1; 
--# bind enum_type Block_Var_1
--# expr-start 3449 '<Cast to CharLiteral at ast.py:6695>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:6695
Cast_Expr_1 := Origin; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Char_Literal_Range
   then
      Cast_Result_2 := Cast_Expr_1;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 3449
Var_Expr_1 := Cast_Result_2;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind l Var_Expr_1
--# expr-start 3450 '<GetSymbol at ast.py:6695>' Sym /tmp/lal-23.0.0/ada/ast.py:6695
Sym := Get_Symbol (Var_Expr_1); 
--# expr-done 3450
Scope_Result_1 := Sym;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := null;
end if;
Block_Var_2 := Result_Var_1; 
--# bind sym Block_Var_2
--# expr-start 3454 '<Find at ast.py:6697>' Find_Result /tmp/lal-23.0.0/ada/ast.py:6697
Var_Expr_2 := Block_Var_1;
if Var_Expr_2 /= No_Entity_Enum_Type_Def then
   --# scope-start
--# expr-start 3451 '<FieldAccess for enum_literals at ast.py:6697>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6697
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Enum_Literal_Decl_List (Node => Var_Expr_2.Node.Enum_Type_Def_F_Enum_Literals, Info => Var_Expr_2.Info);
--# expr-done 3451
Scope_Result_2 := Fld_2;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Enum_Literal_Decl_List;
end if;
Fld_3 := Result_Var_2.Node;
      Find_Result := No_Entity_Enum_Literal_Decl;
      if Fld_3 = null then
      Find_Result := No_Entity_Enum_Literal_Decl;
      else
      declare
         Collection : constant Bare_Enum_Literal_Decl_List := Fld_3;
      begin
         for Untyped_Item_135 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_135 := Untyped_Item_135; 
Is_Null := Bare_Item_135 = null; 
if Is_Null then
   If_Result := No_Entity_Enum_Literal_Decl;
else
Fld_4 := Result_Var_2.Info;
As_Entity := (Info => Fld_4, Node => Bare_Item_135); 
   If_Result := As_Entity;
end if;
                  Item_135 := If_Result; 
   --# scope-start
               --# bind lit_decl Item_135
      --# expr-start 3453 '<FieldAccess for name_is at ast.py:6698>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6698
--# expr-start 3452 '<FieldAccess for name at ast.py:6698>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6698
      if Item_135.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Defining_Name (Node => Item_135.Node.Enum_Literal_Decl_F_Name, Info => Item_135.Info);
--# expr-done 3452
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_6 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_5.Node, Sym => Block_Var_2);
--# end
--# expr-done 3453
      if Fld_6 then
         Find_Result := Item_135;
      end if;
   --# end
               exit when Fld_6;
         end loop;
      end;
      end if;
--# expr-done 3454
Block_Var_3 := Find_Result; 
--# bind char_lit Block_Var_3
--# expr-start 3461 '<If at ast.py:6701>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:6701
--# expr-start 3455 '<IsNull at ast.py:6705>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:6705
Is_Null_2 := Block_Var_3.Node = null; 
--# expr-done 3455
if Is_Null_2 then
   --# expr-start 3456 '<FieldAccess for is_std_char_type at ast.py:6705>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6705
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EnumTypeDef.is_std_char_type
Fld_8 := Libadalang.Implementation.Enum_Type_Def_P_Is_Std_Char_Type (Node => Block_Var_1.Node);
--# end
--# expr-done 3456
   If_Result_2 := Fld_8;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
--# expr-start 3460 '<as_entity at ast.py:6718>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:6718
--# expr-start 3459 '<New SyntheticCharEnumLit at ast.py:6707>' New_Node /tmp/lal-23.0.0/ada/ast.py:6707
--# expr-start 3458 '<Cast to TypeDecl at ast.py:6717>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:6717
--# expr-start 3457 '<parent at ast.py:6717>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6717
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Parent (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# expr-done 3457
   if Fld_7.Node = null
      or else Fld_7.Node.Kind in Ada_Type_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Type_Decl
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
   else
         Cast_Result_3 := No_Entity_Type_Decl;
   end if;
--# expr-done 3458
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Char_Enum_Lit);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Char_Enum_Lit,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Char_Enum_Lit
     (Self => New_Node,
      Enum_Literal_Decl_F_Name => No_Bare_Ada_Node);
      New_Node.Synthetic_Char_Enum_Lit_Char_Symbol :=
         Block_Var_2;
      New_Node.Synthetic_Char_Enum_Lit_Enum_Type_Decl :=
         Cast_Result_3;
--# expr-done 3459
Is_Null_1 := New_Node = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Synthetic_Char_Enum_Lit;
else
As_Entity_1 := (Info => E_Info, Node => New_Node); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 3460
      Cast_Result_4 := Create_Internal_Entity_Enum_Literal_Decl
        (Node => If_Result_1.Node,
         Info => If_Result_1.Info);
   If_Result_3 := Cast_Result_4;
else
   If_Result_3 := Block_Var_3;
end if;
--# expr-done 3461
Let_Result := If_Result_3; 
--# end
--# expr-done 3462
      Cast_Result_5 := Create_Internal_Entity_Basic_Decl
        (Node => Let_Result.Node,
         Info => Let_Result.Info);
      Property_Result := Cast_Result_5;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl,
                        As_Internal_Entity_Basic_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Corresponding_Char_Literal;
--# end
--# property-start '[dispatcher]BaseTypeDecl.root_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Type_Decl_P_Root_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Type_Decl (Self.Kind) is
               when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
                  --# property-call-start BaseTypeDecl.root_type
                  Property_Result := Base_Type_Decl_P_Root_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
                  --# property-call-start BaseSubtypeDecl.root_type
                  Property_Result := Base_Subtype_Decl_P_Root_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
                  --# property-call-start TypeDecl.root_type
                  Property_Result := Type_Decl_P_Root_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Type_Decl_P_Root_Type;
--# end
--# property-start BaseTypeDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:6734
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Next_Part_For_Decl
  (Node : Bare_Base_Type_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Match_0 : Internal_Entity_Single_Task_Type_Decl;
Match_1 : Internal_Entity_Task_Type_Decl;
Match_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Basic_Decl;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Single_Task_Type_Decl;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Task_Type_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3469 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 3468 '<Match at ast.py:6735>' Match_Result /tmp/lal-23.0.0/ada/ast.py:6735
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Single_Task_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind sttd Match_0
--# expr-start 3464 '<FieldAccess for basic_decl_next_part_for_decl at ast.py:6739>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6739
--# expr-start 3463 '<FieldAccess for parent_basic_decl at ast.py:6739>' Fld /tmp/lal-23.0.0/ada/ast.py:6739
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 3463
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.basic_decl_next_part_for_decl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Next_Part_For_Decl (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 3464
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Task_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind ttd Match_1
--# expr-start 3465 '<FieldAccess for basic_decl_next_part_for_decl at ast.py:6740>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6740
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.basic_decl_next_part_for_decl
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Next_Part_For_Decl (Node => Match_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_1.Info);
--# end
--# expr-done 3465
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Protected_Type_Decl | Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
--# expr-start 3467 '<Cast to BasicDecl.entity at ast.py:6741>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6741
--# expr-start 3466 '<FieldAccess for next_part at ast.py:6741>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6741
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.next_part
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Next_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3466
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
--# expr-done 3467
Let_Result_2 := Cast_Result; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3468
Let_Result_3 := Match_Result; 
--# end
--# expr-done 3469
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Next_Part_For_Decl;
--# end
--# property-start BaseTypeDecl.shapes /tmp/lal-23.0.0/ada/ast.py:6746
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Shapes
  (Node : Bare_Base_Type_Decl
      ; Include_Discriminants : Boolean
         := True
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Shape_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind include_discriminants Include_Discriminants
   --# bind origin Origin
   Property_Result : Internal_Shape_Array_Access;
            procedure Finalizer_Scope_510 with Inline_Always;
            procedure Finalizer_Scope_2294 with Inline_Always;
            procedure Finalizer_Scope_2295 with Inline_Always;
            procedure Finalizer_Scope_2296 with Inline_Always;
            procedure Finalizer_Scope_2297 with Inline_Always;
      Block_Var : Internal_Entity_Base_Record_Def;
Block_Var_1 : Internal_Entity_Component_List;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Block_Var_3 : Internal_Entity_Base_Record_Def;
Block_Var_4 : Internal_Shape_Array_Access;
Block_Var_5 : Internal_Shape_Array_Access;
Block_Var_6 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Var_Expr : Internal_Entity_Derived_Type_Def;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Base_Record_Def;
Fld : Internal_Entity_Base_Record_Def;
Fld_1 : Internal_Entity_Component_List;
Fld_2 : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Derived_Type_Def;
Fld_3 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Record_Def;
Scope_Result_1 : Internal_Entity_Base_Record_Def;
Result_Var_1 : Internal_Entity_Base_Record_Def;
Fld_5 : Internal_Shape_Array_Access;
Fld_6 : Internal_Shape_Array_Access;
Fld_7 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_8 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_9 : Internal_Discriminant_Values_Array_Access;
Fld_10 : Internal_Discriminant_Values_Array_Access;
Concat_Result_1 : Internal_Discriminant_Values_Array_Access;
New_Struct : Internal_Shape := No_Shape;
Map_Result : Internal_Shape_Array_Access;
Map_Result_1 : Internal_Shape_Array_Access;
Scope_Result_2 : Internal_Shape_Array_Access;
Result_Var_2 : Internal_Shape_Array_Access;
Fld_11 : Internal_Entity_Type_Decl;
Fld_12 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_13 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Concat_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_14 : Internal_Discriminant_Values_Array_Access;
New_Struct_1 : Internal_Shape := No_Shape;
Map_Result_2 : Internal_Shape_Array_Access;
If_Result : Internal_Shape_Array_Access;
Let_Result : Internal_Shape_Array_Access;
            procedure Finalizer_Scope_510 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Block_Var_4);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Block_Var_5);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Block_Var_6);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_510;
            procedure Finalizer_Scope_2294 is
            begin
                     Dec_Ref (Fld_6);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_2294;
            procedure Finalizer_Scope_2295 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2295;
            procedure Finalizer_Scope_2296 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2296;
            procedure Finalizer_Scope_2297 is
            begin
                     Dec_Ref (Fld_13);
                     Dec_Ref (Concat_Result_2);
                     Dec_Ref (Fld_14);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_2297;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3495 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3470 '<FieldAccess for record_def at ast.py:6800>' Fld /tmp/lal-23.0.0/ada/ast.py:6800
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3470
Block_Var := Fld; 
--# bind rdef Block_Var
--# expr-start 3471 '<FieldAccess for components at ast.py:6801>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6801
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Component_List (Node => Block_Var.Node.Base_Record_Def_F_Components, Info => Block_Var.Info);
--# expr-done 3471
Block_Var_1 := Fld_1; 
--# bind comps Block_Var_1
--# expr-start 3473 '<Cast to DerivedTypeDef at ast.py:6803>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6803
--# expr-start 3472 '<FieldAccess for type_def at ast.py:6803>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6803
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_def
Fld_2 := Libadalang.Implementation.Component_List_P_Type_Def (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 3472
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Derived_Type_Def_Range
   then
      Cast_Result := Create_Internal_Entity_Derived_Type_Def
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result := No_Entity_Derived_Type_Def;
   end if;
--# expr-done 3473
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Derived_Type_Def then
   --# scope-start
--# expr-start 3474 '<FieldAccess for base_type at ast.py:6803>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6803
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3474
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Block_Var_2 := Result_Var; 
--# bind parent_type Block_Var_2
Var_Expr_1 := Block_Var_2;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3475 '<FieldAccess for record_def at ast.py:6805>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6805
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 3475
Scope_Result_1 := Fld_4;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Record_Def;
end if;
Block_Var_3 := Result_Var_1; 
--# bind parent_record Block_Var_3
--# expr-start 3476 '<FieldAccess for shapes at ast.py:6807>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6807
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.shapes
Fld_5 := Libadalang.Implementation.Component_List_P_Shapes (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 3476
Block_Var_4 := Fld_5; Inc_Ref (Block_Var_4);
--# bind own_shapes Block_Var_4
Var_Expr_2 := Block_Var_3;
if Var_Expr_2 /= No_Entity_Base_Record_Def then
   --# scope-start
   --# bind _ Var_Expr_2
--# expr-start 3486 '<Mapcat at ast.py:6812>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:6812
   --# expr-start 3477 '<FieldAccess for shapes at ast.py:6812>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6812
      if Block_Var_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.shapes
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Shapes (Node => Block_Var_2.Node, Include_Discriminants => False, Origin => Origin, E_Info => Block_Var_2.Info);
--# end
--# expr-done 3477
      declare
         Map_Result_1_Vec : Internal_Shape_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Shape_Array_Access := Fld_6;
      begin
         for Item_136 of
               Collection.Items
         loop
   --# scope-start
               --# bind parent_shape Item_136
      --# expr-start 3485 '<Map at ast.py:6813>' Map_Result /tmp/lal-23.0.0/ada/ast.py:6813
      declare
         Map_Result_Vec : Internal_Shape_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Shape_Array_Access := Block_Var_4;
      begin
         for Item_137 of
               Collection.Items
         loop
   --# scope-start
               --# bind own_shape Item_137
      --# expr-start 3484 '<New Shape at ast.py:6814>' New_Struct /tmp/lal-23.0.0/ada/ast.py:6814
--# expr-start 3480 '<Concat at ast.py:6815>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:6815
--# expr-start 3478 '<FieldAccess for components at ast.py:6815>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6815
Fld_7 := Item_136.Components;
Inc_Ref (Fld_7);
--# expr-done 3478
--# expr-start 3479 '<FieldAccess for components at ast.py:6816>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6816
Fld_8 := Item_137.Components;
Inc_Ref (Fld_8);
--# expr-done 3479
Concat_Result := Concat (Fld_7, Fld_8); 
--# expr-done 3480
--# expr-start 3483 '<Concat at ast.py:6819>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:6819
--# expr-start 3481 '<FieldAccess for discriminants_values at ast.py:6818>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6818
Fld_9 := Item_136.Discriminants_Values;
Inc_Ref (Fld_9);
--# expr-done 3481
--# expr-start 3482 '<FieldAccess for discriminants_values at ast.py:6820>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:6820
Fld_10 := Item_137.Discriminants_Values;
Inc_Ref (Fld_10);
--# expr-done 3482
Concat_Result_1 := Concat (Fld_9, Fld_10); 
--# expr-done 3483
Inc_Ref (Concat_Result);
Inc_Ref (Concat_Result_1);
New_Struct := (Components => Concat_Result, Discriminants_Values => Concat_Result_1); 
--# expr-done 3484
         declare
            Item_To_Append : constant Internal_Shape := New_Struct;
         begin
               Inc_Ref (Item_To_Append);
            Internal_Shape_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2296;
         end loop;
      end;
         Map_Result := Create_Internal_Shape_Array
           (Items_Count => Natural (Internal_Shape_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Shape_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Shape_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Shape_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3485
         for Item_To_Append of
               Map_Result.Items
         loop
               Inc_Ref (Item_To_Append);
            Internal_Shape_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2295;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Shape_Array
           (Items_Count => Natural (Internal_Shape_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Shape_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Shape_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Shape_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 3486
Scope_Result_2 := Map_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2294;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Block_Var_4;
end if;
      Inc_Ref (Result_Var_2);
Block_Var_5 := Result_Var_2; Inc_Ref (Block_Var_5);
--# bind all_shapes Block_Var_5
--# expr-start 3488 '<FieldAccess for discriminants_list at ast.py:6828>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:6828
--# expr-start 3487 '<FieldAccess for type_decl at ast.py:6828>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:6828
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_decl
Fld_11 := Libadalang.Implementation.Component_List_P_Type_Decl (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 3487
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_12 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Fld_11.Node, Origin => Origin, E_Info => Fld_11.Info);
--# end
--# expr-done 3488
Block_Var_6 := Fld_12; Inc_Ref (Block_Var_6);
--# bind discrs Block_Var_6
--# expr-start 3494 '<If at ast.py:6829>' If_Result /tmp/lal-23.0.0/ada/ast.py:6829
if Include_Discriminants then
   --# expr-start 3493 '<Map at ast.py:6831>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:6831
      declare
         Map_Result_2_Vec : Internal_Shape_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Shape_Array_Access := Block_Var_5;
      begin
         for Item_138 of
               Collection.Items
         loop
   --# scope-start
               --# bind s Item_138
      --# expr-start 3492 '<New Shape at ast.py:6832>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:6832
--# expr-start 3490 '<Concat at ast.py:6833>' Concat_Result_2 /tmp/lal-23.0.0/ada/ast.py:6833
--# expr-start 3489 '<FieldAccess for components at ast.py:6833>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:6833
Fld_13 := Item_138.Components;
Inc_Ref (Fld_13);
--# expr-done 3489
Concat_Result_2 := Concat (Block_Var_6, Fld_13); 
--# expr-done 3490
--# expr-start 3491 '<FieldAccess for discriminants_values at ast.py:6834>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:6834
Fld_14 := Item_138.Discriminants_Values;
Inc_Ref (Fld_14);
--# expr-done 3491
Inc_Ref (Concat_Result_2);
Inc_Ref (Fld_14);
New_Struct_1 := (Components => Concat_Result_2, Discriminants_Values => Fld_14); 
--# expr-done 3492
         declare
            Item_To_Append : constant Internal_Shape := New_Struct_1;
         begin
               Inc_Ref (Item_To_Append);
            Internal_Shape_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2297;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Shape_Array
           (Items_Count => Natural (Internal_Shape_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Shape_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Shape_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Shape_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 3493
   If_Result := Map_Result_2;
else
   If_Result := Block_Var_5;
end if;
      Inc_Ref (If_Result);
--# expr-done 3494
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 3495
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_510;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_510;
               Finalizer_Scope_2294;
               Finalizer_Scope_2295;
               Finalizer_Scope_2296;
               Finalizer_Scope_2297;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Shapes;
--# end
--# property-start BaseTypeDecl.dottable_subps_env /tmp/lal-23.0.0/ada/ast.py:6841
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_F_Dottable_Subps_Env
  (Node : Bare_Base_Type_Decl
  )
   return Lexical_Env
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_511 with Inline_Always;
      Dyn_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_511 is
            begin
                     Dec_Ref (Dyn_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_511;
begin
   --# property-body-start
      if Self.Lf_Present_Dottable_Subps_Env then
         Property_Result := Self.Lf_Stg_Dottable_Subps_Env;
            Inc_Ref (Property_Result);
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3497 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3496 '<DynamicLexicalEnv at ast.py:6846>' Dyn_Env /tmp/lal-23.0.0/ada/ast.py:6846
Dyn_Env := Create_Dynamic_Lexical_Env (Self, Base_Type_Decl_P_Dottable_Subps'Access, null, False); 
--# expr-done 3496
Let_Result := Dyn_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 3497
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_511;
      Self.Lf_Present_Dottable_Subps_Env := True;
      Self.Lf_Stg_Dottable_Subps_Env := Property_Result;
         Inc_Ref (Property_Result);
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_511;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_F_Dottable_Subps_Env;
--# end
--# property-start BaseTypeDecl.dottable_subps /tmp/lal-23.0.0/ada/ast.py:6852
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Dottable_Subps
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Inner_Env_Assoc_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_513 with Inline_Always;
            procedure Finalizer_Scope_2302 with Inline_Always;
      Block_Var : Bare_Declarative_Part;
Block_Var_1 : Internal_Entity_Base_Package_Decl;
Var_Expr : Bare_Package_Body;
Var_Expr_1 : Bare_Declarative_Part;
Var_Expr_2 : Bare_Declarative_Part;
Var_Expr_3 : Internal_Entity_Package_Body;
Var_Expr_4 : Internal_Entity_Declarative_Part;
Bd : Internal_Entity_Basic_Decl;
Var_Expr_5 : Internal_Entity_Base_Subp_Spec;
Var_Expr_6 : Internal_Entity_Basic_Decl;
Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node;
Scope_Result : Bare_Ada_Node;
Result_Var : Bare_Ada_Node;
Cast_Result : Bare_Package_Body;
Bound_Imprecise_Fallback : Boolean;
As_Entity : Internal_Entity_Package_Body;
Is_Null : Boolean;
If_Result : Internal_Entity_Package_Body;
Fld_2 : Internal_Entity_Basic_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Base_Package_Decl;
Scope_Result_1 : Internal_Entity_Base_Package_Decl;
Fld_3 : Bare_Ada_Node;
Scope_Result_2 : Bare_Ada_Node;
Result_Var_1 : Bare_Ada_Node;
Cast_Result_2 : Bare_Base_Package_Decl;
As_Entity_1 : Internal_Entity_Base_Package_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Base_Package_Decl;
Result_Var_2 : Internal_Entity_Base_Package_Decl;
Fld_4 : Boolean;
Not_Val : Boolean;
Is_Null_2 : Boolean;
Fld_5 : Internal_Entity_Public_Part;
Cast_Result_3 : Internal_Entity_Declarative_Part;
Fld_6 : Internal_Entity_Private_Part;
Cast_Result_4 : Internal_Entity_Declarative_Part;
Fld_7 : Internal_Entity_Package_Body;
Fld_8 : Internal_Entity_Declarative_Part;
Scope_Result_3 : Internal_Entity_Declarative_Part;
Result_Var_3 : Internal_Entity_Declarative_Part;
Array_Lit : Internal_Entity_Declarative_Part_Array_Access;
Fld_9 : Internal_Entity_Ada_Node_List;
Scope_Result_4 : Internal_Entity_Ada_Node_List;
Result_Var_4 : Internal_Entity_Ada_Node_List;
Fld_10 : Bare_Ada_Node_List;
Fld_11 : Internal_Entity_Info;
As_Entity_2 : Internal_Entity;
Is_Null_3 : Boolean;
If_Result_2 : Internal_Entity;
Item_359 : Internal_Entity;
Bare_Item_359 : Bare_Ada_Node;
Map_Result : Internal_Entity_Array_Access;
Map_Result_1 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result_5 : Internal_Entity_Basic_Decl;
Fld_12 : Internal_Entity_Defining_Name;
Fld_13 : Symbol_Type;
Fld_14 : Bare_Basic_Decl;
New_Struct : Internal_Metadata;
Cast_Result_6 : Bare_Ada_Node;
New_Struct_1 : Internal_Inner_Env_Assoc;
Let_Result : Internal_Inner_Env_Assoc;
Cast_Expr_1 : Internal_Entity;
Cast_Result_7 : Internal_Entity_Basic_Decl;
Fld_15 : Internal_Entity_Base_Subp_Spec;
Scope_Result_5 : Internal_Entity_Base_Subp_Spec;
Result_Var_5 : Internal_Entity_Base_Subp_Spec;
Fld_16 : Internal_Entity_Base_Type_Decl;
Scope_Result_6 : Internal_Entity_Base_Type_Decl;
Result_Var_6 : Internal_Entity_Base_Type_Decl;
Cast_Result_8 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_9 : Internal_Entity;
Is_Equiv : Boolean;
Map_Result_2 : Internal_Inner_Env_Assoc_Array_Access;
If_Result_3 : Internal_Inner_Env_Assoc_Array_Access;
If_Result_4 : Internal_Inner_Env_Assoc_Array_Access;
Let_Result_1 : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_513 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_513;
            procedure Finalizer_Scope_2302 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2302;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Dottable_Subps,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Inner_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 3534 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 3498 '<FieldAccess for declarative_scope at ast.py:6858>' Fld /tmp/lal-23.0.0/ada/ast.py:6858
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 3498
Block_Var := Fld; 
--# bind scope Block_Var
--# expr-start 3500 '<Cast to PackageBody at ast.py:6860>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6860
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3499 '<parent at ast.py:6860>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6860
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr_1.Parent; 
--# expr-done 3499
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
   if Result_Var = null
      or else Result_Var.Kind in Ada_Package_Body_Range
   then
      Cast_Result := Result_Var;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 3500
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind body Var_Expr
--# expr-start 3504 '<Cast to BasePackageDecl at ast.py:6864>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:6864
--# expr-start 3503 '<bind at ast.py:6861>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:6861
Bound_Imprecise_Fallback := False; 
--# expr-start 3502 '<FieldAccess for previous_part at ast.py:6863>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6863
--# expr-start 3501 '<as_entity at ast.py:6863>' If_Result /tmp/lal-23.0.0/ada/ast.py:6863
Is_Null := Var_Expr = null; 
if Is_Null then
   If_Result := No_Entity_Package_Body;
else
As_Entity := (Info => E_Info, Node => Var_Expr); 
   If_Result := As_Entity;
end if;
--# expr-done 3501
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.previous_part
Fld_2 := Libadalang.Implementation.Body_Node_P_Previous_Part (Node => If_Result.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => If_Result.Info);
--# end
--# expr-done 3502
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 3503
   if Dyn_Var_Bind_Result.Node = null
      or else Dyn_Var_Bind_Result.Node.Kind in Ada_Base_Package_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Package_Decl
        (Node => Dyn_Var_Bind_Result.Node,
         Info => Dyn_Var_Bind_Result.Info);
   else
         Cast_Result_1 := No_Entity_Base_Package_Decl;
   end if;
--# expr-done 3504
Scope_Result_1 := Cast_Result_1;
   --# end
   Result_Var_2 := Scope_Result_1;
else
   --# expr-start 3507 '<as_entity at ast.py:6865>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:6865
--# expr-start 3506 '<Cast to BasePackageDecl at ast.py:6865>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:6865
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3505 '<parent at ast.py:6865>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6865
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Var_Expr_2.Parent; 
--# expr-done 3505
Scope_Result_2 := Fld_3;
   --# end
   Result_Var_1 := Scope_Result_2;
else
   Result_Var_1 := No_Bare_Ada_Node;
end if;
   if Result_Var_1 = null
      or else Result_Var_1.Kind in Ada_Base_Package_Decl
   then
      Cast_Result_2 := Result_Var_1;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 3506
Is_Null_1 := Cast_Result_2 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Base_Package_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Cast_Result_2); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 3507
   Result_Var_2 := If_Result_1;
end if;
Block_Var_1 := Result_Var_2; 
--# bind pkg Block_Var_1
--# expr-start 3533 '<Cond at ast.py:6868>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:6868
--# expr-start 3509 '<Not at ast.py:6869>' Not_Val /tmp/lal-23.0.0/ada/ast.py:6869
--# expr-start 3508 '<FieldAccess for is_tagged_type at ast.py:6869>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6869
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Ent.Node, Origin => No_Bare_Ada_Node, E_Info => Ent.Info);
--# end
--# expr-done 3508
Not_Val := not (Fld_4); 
--# expr-done 3509
if Not_Val then
   If_Result_4 := No_Internal_Inner_Env_Assoc_Array_Type;
else
--# expr-start 3510 '<IsNull at ast.py:6872>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:6872
Is_Null_2 := Block_Var_1.Node = null; 
--# expr-done 3510
if Is_Null_2 then
   If_Result_3 := No_Internal_Inner_Env_Assoc_Array_Type;
else
   --# expr-start 3532 '<FilterMap at ast.py:6881>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:6881
   --# expr-start 3520 '<Mapcat at ast.py:6879>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:6879
   --# expr-start 3517 '<ArrayLiteral at ast.py:6875>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:6875
--# expr-start 3512 '<Cast to DeclarativePart at ast.py:6876>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:6876
--# expr-start 3511 '<FieldAccess for public_part at ast.py:6876>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6876
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Public_Part (Node => Block_Var_1.Node.Base_Package_Decl_F_Public_Part, Info => Block_Var_1.Info);
--# expr-done 3511
      Cast_Result_3 := Create_Internal_Entity_Declarative_Part
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
--# expr-done 3512
--# expr-start 3514 '<Cast to DeclarativePart at ast.py:6877>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:6877
--# expr-start 3513 '<FieldAccess for private_part at ast.py:6877>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6877
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Private_Part (Node => Block_Var_1.Node.Base_Package_Decl_F_Private_Part, Info => Block_Var_1.Info);
--# expr-done 3513
      Cast_Result_4 := Create_Internal_Entity_Declarative_Part
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
--# expr-done 3514
--# expr-start 3515 '<FieldAccess for body_part at ast.py:6878>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:6878
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasePackageDecl.body_part
Fld_7 := Libadalang.Implementation.Base_Package_Decl_P_Body_Part (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 3515
Var_Expr_3 := Fld_7;
if Var_Expr_3 /= No_Entity_Package_Body then
   --# scope-start
--# expr-start 3516 '<FieldAccess for decls at ast.py:6878>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:6878
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Declarative_Part (Node => Var_Expr_3.Node.Package_Body_F_Decls, Info => Var_Expr_3.Info);
--# expr-done 3516
Scope_Result_3 := Fld_8;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Entity_Declarative_Part;
end if;
Array_Lit := Create_Internal_Entity_Declarative_Part_Array (Internal_Internal_Entity_Declarative_Part_Array'(1 => Cast_Result_3, 2 => Cast_Result_4, 3 => Result_Var_3)); 
--# expr-done 3517
      declare
         Map_Result_1_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Declarative_Part_Array_Access := Array_Lit;
      begin
         for Item_140 of
               Collection.Items
         loop
   --# scope-start
               --# bind dp Item_140
      --# expr-start 3519 '<TakeWhile at ???>' Map_Result None
Var_Expr_4 := Item_140;
if Var_Expr_4 /= No_Entity_Declarative_Part then
   --# scope-start
--# expr-start 3518 '<FieldAccess for decls at ast.py:6880>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:6880
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Ada_Node_List (Node => Var_Expr_4.Node.Declarative_Part_F_Decls, Info => Var_Expr_4.Info);
--# expr-done 3518
Scope_Result_4 := Fld_9;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Ada_Node_List;
end if;
Fld_10 := Result_Var_4.Node;
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      if Fld_10 = null then
      Map_Result := Create_Internal_Entity_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_10;
      begin
         for Untyped_Item_359 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_359 := Untyped_Item_359; 
Is_Null_3 := Bare_Item_359 = null; 
if Is_Null_3 then
   If_Result_2 := No_Entity;
else
Fld_11 := Result_Var_4.Info;
As_Entity_2 := (Info => Fld_11, Node => Bare_Item_359); 
   If_Result_2 := As_Entity_2;
end if;
                  Item_359 := If_Result_2; 
   --# scope-start
         declare
            Item_To_Append : constant Internal_Entity := Item_359;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3519
         for Item_To_Append of
               Map_Result.Items
         loop
            Internal_Entity_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2302;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 3520
      declare
         Map_Result_2_Vec : Internal_Inner_Env_Assoc_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result_1;
      begin
         for Item_139 of
               Collection.Items
         loop
   --# scope-start
               --# bind decl Item_139
         --# expr-start 3524 '<Eq at ast.py:6891>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:6891
--# expr-start 3521 '<Cast to BasicDecl at ast.py:6891>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:6891
Cast_Expr_1 := Item_139; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_7 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_7 := No_Entity_Basic_Decl;
   end if;
--# expr-done 3521
Var_Expr_6 := Cast_Result_7;
if Var_Expr_6 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 3522 '<FieldAccess for subp_spec_or_null at ast.py:6892>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:6892
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_15 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 3522
Scope_Result_5 := Fld_15;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := No_Entity_Base_Subp_Spec;
end if;
Var_Expr_5 := Result_Var_5;
if Var_Expr_5 /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 3523 '<FieldAccess for dottable_subp_of at ast.py:6892>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:6892
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.dottable_subp_of
Fld_16 := Libadalang.Implementation.Base_Subp_Spec_P_Dottable_Subp_Of (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 3523
Scope_Result_6 := Fld_16;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Base_Type_Decl;
end if;
      Cast_Result_8 := Create_Internal_Entity
        (Node => Result_Var_6.Node,
         Info => Result_Var_6.Info);
Cast_Expr_2 := Ent; 
      Cast_Result_9 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv := Equivalent (Cast_Result_8, Cast_Result_9); 
--# expr-done 3524
         if Is_Equiv then
      --# expr-start 3531 '<Let at ast.py:6882>' Let_Result /tmp/lal-23.0.0/ada/ast.py:6882
--# scope-start
--# expr-start 3525 '<Cast to BasicDecl at ast.py:6883>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:6883
Cast_Expr := Item_139; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_5 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_5 := No_Entity_Basic_Decl;
   end if;
--# expr-done 3525
Bd := Cast_Result_5; 
--# bind bd Bd
--# expr-start 3530 '<New InnerEnvAssoc at ast.py:6883>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:6883
--# expr-start 3527 '<FieldAccess for name_symbol at ast.py:6884>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:6884
--# expr-start 3526 '<FieldAccess for defining_name at ast.py:6884>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:6884
      if Bd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_12 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Bd.Node, E_Info => Bd.Info);
--# end
--# expr-done 3526
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_13 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_12.Node);
--# end
--# expr-done 3527
--# expr-start 3528 '<New Metadata at ast.py:6886>' New_Struct /tmp/lal-23.0.0/ada/ast.py:6886
New_Struct := (Dottable_Subp => True, Primitive => No_Bare_Ada_Node, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 3528
--# expr-start 3529 '<FieldAccess for node at ast.py:6885>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:6885
Fld_14 := Bd.Node;
--# expr-done 3529
      Cast_Result_6 := Fld_14;
New_Struct_1 := (Key => Fld_13, Metadata => New_Struct, Value => Cast_Result_6); 
--# expr-done 3530
Let_Result := New_Struct_1; 
--# end
--# expr-done 3531
         declare
            Item_To_Append : constant Internal_Inner_Env_Assoc := Let_Result;
         begin
            Internal_Inner_Env_Assoc_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Inner_Env_Assoc_Array
           (Items_Count => Natural (Internal_Inner_Env_Assoc_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Inner_Env_Assoc_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Inner_Env_Assoc_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Inner_Env_Assoc_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 3532
   If_Result_3 := Map_Result_2;
end if;
      Inc_Ref (If_Result_3);
   If_Result_4 := If_Result_3;
end if;
      Inc_Ref (If_Result_4);
--# expr-done 3533
Let_Result_1 := If_Result_4; Inc_Ref (Let_Result_1);
--# end
--# expr-done 3534
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_513;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Inner_Env_Assoc_Array_Access,
                        As_Internal_Inner_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_513;
               Finalizer_Scope_2302;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Dottable_Subps;
--# end
--# property-start BaseTypeDecl.find_base_type_rebindings /tmp/lal-23.0.0/ada/ast.py:6898
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Find_Base_Type_Rebindings
  (Node : Bare_Base_Type_Decl
      ; Target : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Env_Rebindings
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind target Target
   --# bind origin Origin
   Property_Result : Env_Rebindings;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Info;
Fld_1 : Env_Rebindings;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Env_Rebindings;
Scope_Result : Env_Rebindings;
Result_Var : Env_Rebindings;
Cast_Expr : Bare_Base_Type_Decl;
Cast_Result : Bare_Base_Type_Decl;
Is_Equal : Boolean;
If_Result : Env_Rebindings;
Let_Result : Env_Rebindings;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Type_Decl_Base_Type_Decl_P_Find_Base_Type_Rebindings,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Type_Decl,
                                As_Bare_Base_Type_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Base_Type_Decl,
                                      As_Bare_Base_Type_Decl => Target);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (4) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Env_Rebindings;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 3541 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3540 '<If at ast.py:6915>' If_Result /tmp/lal-23.0.0/ada/ast.py:6915
--# expr-start 3535 '<Eq at ast.py:6916>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:6916
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Is_Equal := Cast_Result = Target; 
--# expr-done 3535
if Is_Equal then
   --# expr-start 3537 '<FieldAccess for rebindings at ast.py:6917>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6917
--# expr-start 3536 '<FieldAccess for info at ast.py:6917>' Fld /tmp/lal-23.0.0/ada/ast.py:6917
Fld := Ent.Info;
--# expr-done 3536
Fld_1 := Fld.Rebindings;
--# expr-done 3537
   If_Result := Fld_1;
else
--# expr-start 3538 '<FieldAccess for base_type at ast.py:6918>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6918
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3538
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 3539 '<FieldAccess for find_base_type_rebindings at ast.py:6919>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6919
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.find_base_type_rebindings
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Find_Base_Type_Rebindings (Node => Var_Expr.Node, Target => Target, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3539
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := null;
end if;
   If_Result := Result_Var;
end if;
--# expr-done 3540
Let_Result := If_Result; 
--# end
--# expr-done 3541
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Env_Rebindings,
                        As_Env_Rebindings => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Find_Base_Type_Rebindings;
--# end
--# property-start BaseTypeDecl.has_base_type_impl /tmp/lal-23.0.0/ada/ast.py:6924
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Has_Base_Type_Impl
  (Node : Bare_Base_Type_Decl
      ; Target : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind target Target
   Property_Result : Boolean;
            procedure Finalizer_Scope_515 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Bare_Base_Type_Decl;
Cast_Result : Bare_Base_Type_Decl;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_3 : Boolean;
Quantifier_Result : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_515 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_515;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3548 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3544 '<Eq at ast.py:6930>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:6930
--# expr-start 3543 '<FieldAccess for node at ast.py:6930>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6930
--# expr-start 3542 '<FieldAccess for canonical_type at ast.py:6930>' Fld /tmp/lal-23.0.0/ada/ast.py:6930
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Ent.Node, Origin => No_Bare_Ada_Node, E_Info => Ent.Info);
--# end
--# expr-done 3542
Fld_1 := Fld.Node;
--# expr-done 3543
      Cast_Result := Fld_1;
Is_Equal := Cast_Result = Target; 
--# expr-done 3544
if Is_Equal then
   If_Result := True;
else
   --# expr-start 3547 '<AnyQuantifier at ast.py:6931>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:6931
   --# expr-start 3545 '<FieldAccess for base_types at ast.py:6931>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6931
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_types'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Types (Node => Ent.Node, Origin => No_Bare_Ada_Node, E_Info => Ent.Info);
--# end
--# expr-done 3545
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_2;
      begin
         for Item_141 of
               Collection.Items
         loop
   --# scope-start
               --# bind bt Item_141
      --# expr-start 3546 '<FieldAccess for has_base_type_impl at ast.py:6932>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6932
      if Item_141.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.has_base_type_impl
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Has_Base_Type_Impl (Node => Item_141.Node, Target => Target, E_Info => Item_141.Info);
--# end
--# expr-done 3546
      Quantifier_Result := Fld_3;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 3547
   If_Result := Quantifier_Result;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 3548
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_515;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_515;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Has_Base_Type_Impl;
--# end
--# property-start BaseTypeDecl.has_base_type /tmp/lal-23.0.0/ada/ast.py:6937
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Has_Base_Type
  (Node : Bare_Base_Type_Decl
      ; Target : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind target Target
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3554 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3553 '<FieldAccess for has_base_type_impl at ast.py:6946>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6946
--# expr-start 3549 '<FieldAccess for full_view at ast.py:6946>' Fld /tmp/lal-23.0.0/ada/ast.py:6946
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3549
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3552 '<FieldAccess for node at ast.py:6947>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6947
--# expr-start 3551 '<FieldAccess for canonical_type at ast.py:6947>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6947
--# expr-start 3550 '<as_bare_entity at ast.py:6947>' If_Result /tmp/lal-23.0.0/ada/ast.py:6947
Is_Null := Target = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Target); 
   If_Result := As_Entity;
end if;
--# expr-done 3550
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => If_Result.Node, Origin => No_Bare_Ada_Node, E_Info => If_Result.Info);
--# end
--# expr-done 3551
Fld_2 := Fld_1.Node;
--# expr-done 3552
--# property-call-start BaseTypeDecl.has_base_type_impl
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Has_Base_Type_Impl (Node => Fld.Node, Target => Fld_2, E_Info => Fld.Info);
--# end
--# expr-done 3553
Let_Result := Fld_3; 
--# end
--# expr-done 3554
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Has_Base_Type;
--# end
--# property-start BaseTypeDecl._env_mappings_2 /tmp/lal-23.0.0/ada/ast.py:5612
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_2
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1470 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Base_Type_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1470 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1470;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3557 '<New EnvAssoc at ast.py:5612>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:5612
--# expr-start 3555 '<New DesignatedEnv at ast.py:5612>' New_Struct /tmp/lal-23.0.0/ada/ast.py:5612
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 3555
--# expr-start 3556 '<FieldAccess for name_symbol at ast.py:5612>' Fld /tmp/lal-23.0.0/ada/ast.py:5612
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 3556
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 3557
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1470;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1470;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_2;
--# end
--# property-start BaseTypeDecl.primitives_env /tmp/lal-23.0.0/ada/ast.py:5720
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Primitives_Env
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_422 with Inline_Always;
      Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_422 is
            begin
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_422;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3558 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := Empty_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 3558
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_422;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_422;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Primitives_Env;
--# end
--# property-start BaseTypeDecl.is_record_type /tmp/lal-23.0.0/ada/ast.py:5724
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Record_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Record_Def;
Is_Null : Boolean;
Not_Val : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3562 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3561 '<Not at ast.py:5731>' Not_Val /tmp/lal-23.0.0/ada/ast.py:5731
--# expr-start 3560 '<IsNull at ast.py:5731>' Is_Null /tmp/lal-23.0.0/ada/ast.py:5731
--# expr-start 3559 '<FieldAccess for record_def at ast.py:5731>' Fld /tmp/lal-23.0.0/ada/ast.py:5731
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3559
Is_Null := Fld.Node = null; 
--# expr-done 3560
Not_Val := not (Is_Null); 
--# expr-done 3561
Let_Result := Not_Val; 
--# end
--# expr-done 3562
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Record_Type;
--# end
--# property-start BaseTypeDecl.is_task_type /tmp/lal-23.0.0/ada/ast.py:5756
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Task_Type
  (Node : Bare_Base_Type_Decl
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Task_Type;
--# end
--# property-start BaseTypeDecl.is_real_type /tmp/lal-23.0.0/ada/ast.py:5758
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Real_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Real_Type;
--# end
--# property-start BaseTypeDecl.is_float_type /tmp/lal-23.0.0/ada/ast.py:5762
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Float_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Float_Type;
--# end
--# property-start BaseTypeDecl.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:5766
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Fixed_Point
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Fixed_Point;
--# end
--# property-start BaseTypeDecl.is_enum_type /tmp/lal-23.0.0/ada/ast.py:5771
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Enum_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Enum_Type;
--# end
--# property-start BaseTypeDecl.is_classwide /tmp/lal-23.0.0/ada/ast.py:5776
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Classwide
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Classwide;
--# end
--# property-start BaseTypeDecl.is_access_type /tmp/lal-23.0.0/ada/ast.py:5778
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Access_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Access_Type;
--# end
--# property-start BaseTypeDecl.has_ud_indexing /tmp/lal-23.0.0/ada/ast.py:5790
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Has_Ud_Indexing
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Has_Ud_Indexing;
--# end
--# property-start BaseTypeDecl.constant_indexing_fns /tmp/lal-23.0.0/ada/ast.py:5794
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Constant_Indexing_Fns
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Basic_Decl_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Constant_Indexing_Fns;
--# end
--# property-start BaseTypeDecl.variable_indexing_fns /tmp/lal-23.0.0/ada/ast.py:5801
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Variable_Indexing_Fns
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Basic_Decl_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Variable_Indexing_Fns;
--# end
--# property-start BaseTypeDecl.get_imp_deref /tmp/lal-23.0.0/ada/ast.py:5809
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Get_Imp_Deref
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Expr;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Get_Imp_Deref;
--# end
--# property-start BaseTypeDecl.access_def /tmp/lal-23.0.0/ada/ast.py:5942
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Access_Def
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Access_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Access_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Access_Def;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Access_Def;
--# end
--# property-start BaseTypeDecl.is_char_type /tmp/lal-23.0.0/ada/ast.py:5944
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Char_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Char_Type;
--# end
--# property-start BaseTypeDecl.classwide_type /tmp/lal-23.0.0/ada/ast.py:5957
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Classwide_Type
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Classwide_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Classwide_Type_Decl;
      Cast_Expr : Bare_Base_Type_Decl;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Bare_Classwide_Type_Decl;
As_Entity : Internal_Entity_Classwide_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Classwide_Type_Decl;
Fld_1 : Boolean;
If_Result_1 : Internal_Entity_Classwide_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Classwide_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3567 '<bind at ast.py:5957>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:5957
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 3566 '<If at ast.py:5957>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:5957
--# expr-start 3563 '<FieldAccess for is_tagged_type at ast.py:5958>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5958
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 3563
if Fld_1 then
   --# expr-start 3565 '<as_entity at ast.py:5959>' If_Result /tmp/lal-23.0.0/ada/ast.py:5959
--# expr-start 3564 '<FieldAccess for classwide_type_node at ast.py:5959>' Fld /tmp/lal-23.0.0/ada/ast.py:5959
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.classwide_type_node
Fld := Libadalang.Implementation.Base_Type_Decl_P_Classwide_Type_Node (Node => Self);
--# end
--# expr-done 3564
Is_Null := Fld = null; 
if Is_Null then
   If_Result := No_Entity_Classwide_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Fld); 
   If_Result := As_Entity;
end if;
--# expr-done 3565
   If_Result_1 := If_Result;
else
   If_Result_1 := No_Entity_Classwide_Type_Decl;
end if;
--# expr-done 3566
Dyn_Var_Bind_Result := If_Result_1; 
--# expr-done 3567
      Property_Result := Dyn_Var_Bind_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Classwide_Type;
--# end
--# property-start BaseTypeDecl.discrete_range /tmp/lal-23.0.0/ada/ast.py:6004
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Discrete_Range
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Discrete_Range;
      Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3568 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Discrete_Range; 
--# end
--# expr-done 3568
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Discrete_Range;
--# end
--# property-start BaseTypeDecl.is_discrete_type /tmp/lal-23.0.0/ada/ast.py:6073
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Discrete_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
Fld_2 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3572 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3569 '<FieldAccess for is_int_type at ast.py:6077>' Fld /tmp/lal-23.0.0/ada/ast.py:6077
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_int_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Int_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3569
if Fld then
   If_Result := True;
else
   --# expr-start 3570 '<FieldAccess for is_enum_type at ast.py:6077>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6077
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_enum_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Enum_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3570
   If_Result := Fld_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 3571 '<FieldAccess for is_char_type at ast.py:6077>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6077
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_char_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Char_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3571
   If_Result_1 := Fld_2;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 3572
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Discrete_Type;
--# end
--# property-start BaseTypeDecl.is_int_type /tmp/lal-23.0.0/ada/ast.py:6084
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Int_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3573 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 3573
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Int_Type;
--# end
--# property-start BaseTypeDecl.accessed_type /tmp/lal-23.0.0/ada/ast.py:6146
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Accessed_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3574 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Base_Type_Decl; 
--# end
--# expr-done 3574
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Accessed_Type;
--# end
--# property-start BaseTypeDecl.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:6210
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Tagged_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Tagged_Type;
--# end
--# property-start BaseTypeDecl.base_type /tmp/lal-23.0.0/ada/ast.py:6227
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Base_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Base_Type_Decl;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Base_Type;
--# end
--# property-start BaseTypeDecl.base_types /tmp/lal-23.0.0/ada/ast.py:6233
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Base_Types
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_474 with Inline_Always;
            procedure Finalizer_Scope_2098 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Singleton : Internal_Entity_Base_Type_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Concat_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_474 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_474;
            procedure Finalizer_Scope_2098 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2098;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3577 '<Concat at ast.py:6235>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:6235
--# expr-start 3575 '<FieldAccess for base_type at ast.py:6234>' Fld /tmp/lal-23.0.0/ada/ast.py:6234
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3575
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
                Singleton := Create_Internal_Entity_Base_Type_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2098;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# expr-start 3576 '<FieldAccess for base_interfaces at ast.py:6235>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6235
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_interfaces'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Interfaces (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3576
Concat_Result := Concat (Result_Var, Fld_1); 
--# expr-done 3577
      Property_Result := Concat_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_474;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_474;
               Finalizer_Scope_2098;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Base_Types;
--# end
--# property-start BaseTypeDecl.base_interfaces /tmp/lal-23.0.0/ada/ast.py:6241
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Base_Interfaces
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Base_Type_Decl_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Base_Interfaces;
--# end
--# property-start BaseTypeDecl.record_def /tmp/lal-23.0.0/ada/ast.py:6260
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Record_Def
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Record_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Record_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Base_Record_Def;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Record_Def;
--# end
--# property-start BaseTypeDecl.array_def /tmp/lal-23.0.0/ada/ast.py:6261
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Array_Def
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Type_Def
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Type_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Array_Type_Def;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Array_Def;
--# end
--# property-start BaseTypeDecl.is_iterable_type /tmp/lal-23.0.0/ada/ast.py:6345
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Iterable_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Iterable_Type;
--# end
--# property-start BaseTypeDecl.is_interface_type /tmp/lal-23.0.0/ada/ast.py:6355
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Interface_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Match_0 : Internal_Entity_Type_Decl;
Match_1 : Internal_Entity_Subtype_Decl;
Match_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Type_Def;
Is_A : Boolean;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Boolean;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Type_Decl;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Internal_Entity_Subtype_Decl;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
Scope_Result_3 : Boolean;
Result_Var : Boolean;
Let_Result_3 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3584 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 3578 '<FieldAccess for full_view at ast.py:6359>' Fld /tmp/lal-23.0.0/ada/ast.py:6359
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3578
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3583 '<Match at ast.py:6359>' Match_Result /tmp/lal-23.0.0/ada/ast.py:6359
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind td Match_0
--# expr-start 3580 '<IsA InterfaceTypeDef at ast.py:6360>' Is_A /tmp/lal-23.0.0/ada/ast.py:6360
--# expr-start 3579 '<FieldAccess for type_def at ast.py:6360>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6360
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Def (Node => Match_0.Node.Type_Decl_F_Type_Def, Info => Match_0.Info);
--# expr-done 3579
Is_A := Fld_1.Node /= null 
and then Fld_1.Node.Kind in Ada_Interface_Type_Def_Range; 
--# expr-done 3580
Let_Result := Is_A; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subtype_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind sb Match_1
--# expr-start 3582 '<FieldAccess for is_interface_type at ast.py:6361>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6361
--# expr-start 3581 '<FieldAccess for get_type at ast.py:6361>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6361
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 3581
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_interface_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Interface_Type (Node => Fld_2.Node, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 3582
Let_Result_1 := Fld_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Discrete_Base_Subtype_Decl | Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := False; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3583
Scope_Result_3 := Match_Result;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := False;
end if;
Let_Result_3 := Result_Var; 
--# end
--# expr-done 3584
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Interface_Type;
--# end
--# property-start BaseTypeDecl.iterable_comp_type /tmp/lal-23.0.0/ada/ast.py:6366
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Iterable_Comp_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3585 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Base_Type_Decl; 
--# end
--# expr-done 3585
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Iterable_Comp_Type;
--# end
--# property-start BaseTypeDecl.canonical_type /tmp/lal-23.0.0/ada/ast.py:6521
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Canonical_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Bound_Imprecise_Fallback : Boolean;
Fld : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3589 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3588 '<bind at ast.py:6526>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:6526
Bound_Imprecise_Fallback := False; 
--# expr-start 3587 '<Cast to BaseTypeDecl at ast.py:6527>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6527
--# expr-start 3586 '<FieldAccess for canonical_part at ast.py:6527>' Fld /tmp/lal-23.0.0/ada/ast.py:6527
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Ent.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3586
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 3587
Dyn_Var_Bind_Result := Cast_Result; 
--# expr-done 3588
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 3589
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Canonical_Type;
--# end
--# property-start BaseTypeDecl.previous_part /tmp/lal-23.0.0/ada/ast.py:6556
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Previous_Part
  (Node : Bare_Base_Type_Decl
      ; Go_To_Incomplete : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind go_to_incomplete Go_To_Incomplete
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_2264 with Inline_Always;
            procedure Finalizer_Scope_2265 with Inline_Always;
      Var_Expr : Bare_Defining_Name;
Var_Expr_1 : Internal_Entity_Array_Access;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Fld : Bare_Defining_Name;
Fld_1 : Internal_Entity;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Symbol_Type;
Cast_Expr : Bare_Base_Type_Decl;
Cast_Result : Bare_Ada_Node;
Env_Get_Result : Internal_Entity_Array_Access;
Fld_4 : Boolean;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Is_A : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Find_Result : Internal_Entity;
Scope_Result_1 : Internal_Entity;
Result_Var_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Fld_6 : Boolean;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_2264 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_2264;
            procedure Finalizer_Scope_2265 is
            begin
                     Dec_Ref (Var_Expr_1);
            end Finalizer_Scope_2265;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3603 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3602 '<If at ast.py:6560>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:6560
--# expr-start 3590 '<FieldAccess for is_generic_formal at ast.py:6561>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:6561
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_generic_formal
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Is_Generic_Formal (Node => Self);
--# end
--# expr-done 3590
if Fld_6 then
   If_Result_3 := No_Entity_Base_Type_Decl;
else
--# expr-start 3591 '<FieldAccess for name at ast.py:6568>' Fld /tmp/lal-23.0.0/ada/ast.py:6568
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Base_Type_Decl_F_Name;
--# expr-done 3591
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind type_name Var_Expr
--# expr-start 3601 '<Cast to BaseTypeDecl at ast.py:6580>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:6580
--# expr-start 3595 '<EnvGet at ast.py:6571>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:6571
--# expr-start 3593 '<FieldAccess for immediate_declarative_region at ast.py:6571>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6571
--# expr-start 3592 '<FieldAccess for semantic_parent at ast.py:6571>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6571
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_1 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3592
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.immediate_declarative_region'
Fld_2 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Immediate_Declarative_Region (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 3593
--# expr-start 3594 '<FieldAccess for name_symbol at ast.py:6572>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:6572
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Var_Expr);
--# end
--# expr-done 3594
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_2, Key => Fld_3, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => True, Nocat => True), From => Cast_Result)); 
--# expr-done 3595
Var_Expr_1 := Env_Get_Result;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= No_Internal_Entity_Array_Type then
   --# scope-start
   --# bind pp Var_Expr_1
--# expr-start 3600 '<Find at ast.py:6575>' Find_Result /tmp/lal-23.0.0/ada/ast.py:6575
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Var_Expr_1;
      begin
         for Item_134 of
               Collection.Items
         loop
   --# scope-start
               --# bind pp Item_134
--# expr-start 3596 '<FieldAccess for is_in_private_part at ast.py:6576>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:6576
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3596
if Fld_4 then
--# expr-start 3597 '<Cast to BaseTypeDecl at ast.py:6577>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:6577
Cast_Expr_1 := Item_134; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 3597
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 3598 '<FieldAccess for is_private at ast.py:6577>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:6577
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_private'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Private (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 3598
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_2 := True;
else
if Go_To_Incomplete then
   --# expr-start 3599 '<IsA IncompleteTypeDecl at ast.py:6579>' Is_A /tmp/lal-23.0.0/ada/ast.py:6579
Is_A := Item_134.Node /= null 
and then Item_134.Node.Kind in Ada_Incomplete_Type_Decl_Range; 
--# expr-done 3599
   If_Result_1 := Is_A;
else
   If_Result_1 := False;
end if;
   If_Result_2 := If_Result_1;
end if;
      if If_Result_2 then
         Find_Result := Item_134;
      end if;
   --# end
               exit when If_Result_2;
         end loop;
      end;
--# expr-done 3600
Scope_Result_1 := Find_Result;
   --# end
      Finalizer_Scope_2265;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity;
end if;
   if Result_Var_1.Node = null
      or else Result_Var_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Result_Var_1.Node,
         Info => Result_Var_1.Info);
   else
         Cast_Result_2 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 3601
Scope_Result_2 := Cast_Result_2;
   --# end
      Finalizer_Scope_2264;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Base_Type_Decl;
end if;
   If_Result_3 := Result_Var_2;
end if;
--# expr-done 3602
Let_Result := If_Result_3; 
--# end
--# expr-done 3603
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2264;
               Finalizer_Scope_2265;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Previous_Part;
--# end
--# property-start BaseTypeDecl.is_private /tmp/lal-23.0.0/ada/ast.py:6663
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Is_Private
  (Node : Bare_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Is_Private;
--# end
--# property-start BaseTypeDecl.root_type /tmp/lal-23.0.0/ada/ast.py:6723
pragma Warnings (Off, "is not referenced");
 function Base_Type_Decl_P_Root_Type
  (Node : Bare_Base_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Type_Decl := Bare_Base_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Type_Decl :=
     Internal_Entity_Base_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Ent;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Type_Decl_P_Root_Type;
--# end
function Base_Type_Decl_P_Dottable_Subps
  (E : Entity
  ) return Internal_Inner_Env_Assoc_Array_Access
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Internal_Inner_Env_Assoc_Array_Access :=
      Base_Type_Decl_P_Dottable_Subps (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Base_Subtype_Decl
   --
      procedure Initialize_Fields_For_Base_Subtype_Decl
        (Self : Bare_Base_Subtype_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Initialize_Fields_For_Base_Type_Decl
              (Self, Base_Type_Decl_F_Name);
      end Initialize_Fields_For_Base_Subtype_Decl;
--# property-start BaseSubtypeDecl.from_type_bound /tmp/lal-23.0.0/ada/ast.py:8490
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_From_Type_Bound
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3607 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3606 '<bind at ast.py:8495>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:8495
--# expr-start 3604 '<FieldAccess for origin_node at ast.py:8495>' Fld /tmp/lal-23.0.0/ada/ast.py:8495
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 3604
Bound_Origin := Fld; 
--# expr-start 3605 '<FieldAccess for get_type at ast.py:8495>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8495
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 3605
Dyn_Var_Bind_Result := Fld_1; 
--# expr-done 3606
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 3607
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_From_Type_Bound;
--# end
--# property-start '[dispatcher]BaseSubtypeDecl.get_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Base_Subtype_Decl_P_Get_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Base_Subtype_Decl (Self.Kind) is
               when Ada_Discrete_Base_Subtype_Decl =>
                  --# property-call-start DiscreteBaseSubtypeDecl.get_type
                  Property_Result := Discrete_Base_Subtype_Decl_P_Get_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Decl =>
                  --# property-call-start SubtypeDecl.get_type
                  Property_Result := Subtype_Decl_P_Get_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Base_Subtype_Decl_P_Get_Type;
--# end
--# property-start BaseSubtypeDecl.primitives_env /tmp/lal-23.0.0/ada/ast.py:8507
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Primitives_Env
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_661 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_661 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_661;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3609 '<FieldAccess for primitives_env at ast.py:8507>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8507
--# expr-start 3608 '<FieldAccess for from_type_bound at ast.py:8507>' Fld /tmp/lal-23.0.0/ada/ast.py:8507
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubtypeDecl.from_type_bound
Fld := Libadalang.Implementation.Base_Subtype_Decl_P_From_Type_Bound (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3608
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3609
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_661;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_661;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Primitives_Env;
--# end
--# property-start BaseSubtypeDecl.array_ndims /tmp/lal-23.0.0/ada/ast.py:8509
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Array_Ndims
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Integer;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3611 '<FieldAccess for array_ndims at ast.py:8509>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8509
--# expr-start 3610 '<FieldAccess for get_type at ast.py:8509>' Fld /tmp/lal-23.0.0/ada/ast.py:8509
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3610
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3611
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Array_Ndims;
--# end
--# property-start BaseSubtypeDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:8510
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Defining_Env
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_663 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_663 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_663;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3613 '<FieldAccess for defining_env at ast.py:8510>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8510
--# expr-start 3612 '<FieldAccess for get_type at ast.py:8510>' Fld /tmp/lal-23.0.0/ada/ast.py:8510
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3612
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 3613
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_663;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_663;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Defining_Env;
--# end
--# property-start BaseSubtypeDecl.canonical_type /tmp/lal-23.0.0/ada/ast.py:8512
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Canonical_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3615 '<FieldAccess for canonical_type at ast.py:8512>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8512
--# expr-start 3614 '<FieldAccess for get_type at ast.py:8512>' Fld /tmp/lal-23.0.0/ada/ast.py:8512
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3614
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3615
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Canonical_Type;
--# end
--# property-start BaseSubtypeDecl.record_def /tmp/lal-23.0.0/ada/ast.py:8513
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Record_Def
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Record_Def
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Record_Def;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Record_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3617 '<FieldAccess for record_def at ast.py:8513>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8513
--# expr-start 3616 '<FieldAccess for get_type at ast.py:8513>' Fld /tmp/lal-23.0.0/ada/ast.py:8513
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3616
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3617
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Record_Def;
--# end
--# property-start BaseSubtypeDecl.accessed_type /tmp/lal-23.0.0/ada/ast.py:8514
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Accessed_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3619 '<FieldAccess for accessed_type at ast.py:8514>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8514
--# expr-start 3618 '<FieldAccess for get_type at ast.py:8514>' Fld /tmp/lal-23.0.0/ada/ast.py:8514
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3618
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3619
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Accessed_Type;
--# end
--# property-start BaseSubtypeDecl.is_int_type /tmp/lal-23.0.0/ada/ast.py:8515
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Int_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3621 '<FieldAccess for is_int_type at ast.py:8515>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8515
--# expr-start 3620 '<FieldAccess for get_type at ast.py:8515>' Fld /tmp/lal-23.0.0/ada/ast.py:8515
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3620
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_int_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Int_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3621
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Int_Type;
--# end
--# property-start BaseSubtypeDecl.is_discrete_type /tmp/lal-23.0.0/ada/ast.py:8516
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Discrete_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3623 '<FieldAccess for is_discrete_type at ast.py:8516>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8516
--# expr-start 3622 '<FieldAccess for get_type at ast.py:8516>' Fld /tmp/lal-23.0.0/ada/ast.py:8516
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3622
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_discrete_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Discrete_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3623
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Discrete_Type;
--# end
--# property-start BaseSubtypeDecl.is_real_type /tmp/lal-23.0.0/ada/ast.py:8518
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Real_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3625 '<FieldAccess for is_real_type at ast.py:8518>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8518
--# expr-start 3624 '<FieldAccess for get_type at ast.py:8518>' Fld /tmp/lal-23.0.0/ada/ast.py:8518
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3624
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_real_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Real_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3625
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Real_Type;
--# end
--# property-start BaseSubtypeDecl.is_float_type /tmp/lal-23.0.0/ada/ast.py:8519
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Float_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3627 '<FieldAccess for is_float_type at ast.py:8519>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8519
--# expr-start 3626 '<FieldAccess for get_type at ast.py:8519>' Fld /tmp/lal-23.0.0/ada/ast.py:8519
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3626
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_float_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Float_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3627
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Float_Type;
--# end
--# property-start BaseSubtypeDecl.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:8520
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Fixed_Point
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3629 '<FieldAccess for is_fixed_point at ast.py:8520>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8520
--# expr-start 3628 '<FieldAccess for get_type at ast.py:8520>' Fld /tmp/lal-23.0.0/ada/ast.py:8520
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3628
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_fixed_point'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Fixed_Point (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3629
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Fixed_Point;
--# end
--# property-start BaseSubtypeDecl.is_enum_type /tmp/lal-23.0.0/ada/ast.py:8521
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Enum_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3631 '<FieldAccess for is_enum_type at ast.py:8521>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8521
--# expr-start 3630 '<FieldAccess for get_type at ast.py:8521>' Fld /tmp/lal-23.0.0/ada/ast.py:8521
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3630
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_enum_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Enum_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3631
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Enum_Type;
--# end
--# property-start BaseSubtypeDecl.is_access_type /tmp/lal-23.0.0/ada/ast.py:8522
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Access_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3633 '<FieldAccess for is_access_type at ast.py:8522>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8522
--# expr-start 3632 '<FieldAccess for get_type at ast.py:8522>' Fld /tmp/lal-23.0.0/ada/ast.py:8522
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3632
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3633
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Access_Type;
--# end
--# property-start BaseSubtypeDecl.access_def /tmp/lal-23.0.0/ada/ast.py:8523
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Access_Def
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Access_Def
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Access_Def;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Access_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3635 '<FieldAccess for access_def at ast.py:8523>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8523
--# expr-start 3634 '<FieldAccess for get_type at ast.py:8523>' Fld /tmp/lal-23.0.0/ada/ast.py:8523
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3634
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3635
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Access_Def;
--# end
--# property-start BaseSubtypeDecl.is_char_type /tmp/lal-23.0.0/ada/ast.py:8524
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Char_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3637 '<FieldAccess for is_char_type at ast.py:8524>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8524
--# expr-start 3636 '<FieldAccess for get_type at ast.py:8524>' Fld /tmp/lal-23.0.0/ada/ast.py:8524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3636
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_char_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Char_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3637
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Char_Type;
--# end
--# property-start BaseSubtypeDecl.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:8525
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Tagged_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3639 '<FieldAccess for is_tagged_type at ast.py:8525>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8525
--# expr-start 3638 '<FieldAccess for get_type at ast.py:8525>' Fld /tmp/lal-23.0.0/ada/ast.py:8525
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3638
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3639
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Tagged_Type;
--# end
--# property-start BaseSubtypeDecl.base_type /tmp/lal-23.0.0/ada/ast.py:8526
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Base_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3641 '<FieldAccess for base_type at ast.py:8526>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8526
--# expr-start 3640 '<FieldAccess for get_type at ast.py:8526>' Fld /tmp/lal-23.0.0/ada/ast.py:8526
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3640
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3641
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Base_Type;
--# end
--# property-start BaseSubtypeDecl.base_interfaces /tmp/lal-23.0.0/ada/ast.py:8527
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Base_Interfaces
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_678 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_678 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_678;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3643 '<FieldAccess for base_interfaces at ast.py:8527>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8527
--# expr-start 3642 '<FieldAccess for get_type at ast.py:8527>' Fld /tmp/lal-23.0.0/ada/ast.py:8527
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3642
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_interfaces'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Interfaces (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3643
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_678;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_678;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Base_Interfaces;
--# end
--# property-start BaseSubtypeDecl.base_types /tmp/lal-23.0.0/ada/ast.py:8528
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Base_Types
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_679 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_679 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_679;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3645 '<FieldAccess for base_types at ast.py:8528>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8528
--# expr-start 3644 '<FieldAccess for get_type at ast.py:8528>' Fld /tmp/lal-23.0.0/ada/ast.py:8528
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3644
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_types'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Types (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3645
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_679;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_679;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Base_Types;
--# end
--# property-start BaseSubtypeDecl.array_def /tmp/lal-23.0.0/ada/ast.py:8529
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Array_Def
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Type_Def
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Type_Def;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Array_Type_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3647 '<FieldAccess for array_def at ast.py:8529>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8529
--# expr-start 3646 '<FieldAccess for get_type at ast.py:8529>' Fld /tmp/lal-23.0.0/ada/ast.py:8529
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3646
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3647
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Array_Def;
--# end
--# property-start BaseSubtypeDecl.is_classwide /tmp/lal-23.0.0/ada/ast.py:8530
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Classwide
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3649 '<FieldAccess for is_classwide at ast.py:8530>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8530
--# expr-start 3648 '<FieldAccess for from_type_bound at ast.py:8530>' Fld /tmp/lal-23.0.0/ada/ast.py:8530
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubtypeDecl.from_type_bound
Fld := Libadalang.Implementation.Base_Subtype_Decl_P_From_Type_Bound (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3648
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3649
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Classwide;
--# end
--# property-start BaseSubtypeDecl.discriminants_list /tmp/lal-23.0.0/ada/ast.py:8531
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Discriminants_List
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_682 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_682 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_682;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3651 '<FieldAccess for discriminants_list at ast.py:8531>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8531
--# expr-start 3650 '<FieldAccess for get_type at ast.py:8531>' Fld /tmp/lal-23.0.0/ada/ast.py:8531
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3650
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3651
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_682;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_682;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Discriminants_List;
--# end
--# property-start BaseSubtypeDecl.is_iterable_type /tmp/lal-23.0.0/ada/ast.py:8532
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Iterable_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3653 '<FieldAccess for is_iterable_type at ast.py:8532>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8532
--# expr-start 3652 '<FieldAccess for get_type at ast.py:8532>' Fld /tmp/lal-23.0.0/ada/ast.py:8532
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3652
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3653
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Iterable_Type;
--# end
--# property-start BaseSubtypeDecl.iterable_comp_type /tmp/lal-23.0.0/ada/ast.py:8533
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Iterable_Comp_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3655 '<FieldAccess for iterable_comp_type at ast.py:8533>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8533
--# expr-start 3654 '<FieldAccess for get_type at ast.py:8533>' Fld /tmp/lal-23.0.0/ada/ast.py:8533
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3654
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3655
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Iterable_Comp_Type;
--# end
--# property-start BaseSubtypeDecl.is_record_type /tmp/lal-23.0.0/ada/ast.py:8534
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Record_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3657 '<FieldAccess for is_record_type at ast.py:8534>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8534
--# expr-start 3656 '<FieldAccess for get_type at ast.py:8534>' Fld /tmp/lal-23.0.0/ada/ast.py:8534
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3656
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_record_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Record_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3657
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Record_Type;
--# end
--# property-start BaseSubtypeDecl.is_private /tmp/lal-23.0.0/ada/ast.py:8535
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Is_Private
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3659 '<FieldAccess for is_private at ast.py:8535>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8535
--# expr-start 3658 '<FieldAccess for from_type_bound at ast.py:8535>' Fld /tmp/lal-23.0.0/ada/ast.py:8535
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubtypeDecl.from_type_bound
Fld := Libadalang.Implementation.Base_Subtype_Decl_P_From_Type_Bound (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3658
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_private'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Private (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3659
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Is_Private;
--# end
--# property-start BaseSubtypeDecl.root_type /tmp/lal-23.0.0/ada/ast.py:8536
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Root_Type
  (Node : Bare_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3661 '<FieldAccess for root_type at ast.py:8536>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8536
--# expr-start 3660 '<FieldAccess for get_type at ast.py:8536>' Fld /tmp/lal-23.0.0/ada/ast.py:8536
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3660
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.root_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Root_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3661
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Root_Type;
--# end
--# property-start BaseSubtypeDecl.has_ud_indexing /tmp/lal-23.0.0/ada/ast.py:8538
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Has_Ud_Indexing
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3663 '<FieldAccess for has_ud_indexing at ast.py:8539>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8539
--# expr-start 3662 '<FieldAccess for from_type_bound at ast.py:8539>' Fld /tmp/lal-23.0.0/ada/ast.py:8539
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubtypeDecl.from_type_bound
Fld := Libadalang.Implementation.Base_Subtype_Decl_P_From_Type_Bound (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3662
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.has_ud_indexing'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Has_Ud_Indexing (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3663
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Has_Ud_Indexing;
--# end
--# property-start BaseSubtypeDecl.constant_indexing_fns /tmp/lal-23.0.0/ada/ast.py:8541
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Constant_Indexing_Fns
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_689 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_689 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_689;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3665 '<FieldAccess for constant_indexing_fns at ast.py:8542>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8542
--# expr-start 3664 '<FieldAccess for from_type_bound at ast.py:8542>' Fld /tmp/lal-23.0.0/ada/ast.py:8542
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubtypeDecl.from_type_bound
Fld := Libadalang.Implementation.Base_Subtype_Decl_P_From_Type_Bound (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3664
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.constant_indexing_fns'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Constant_Indexing_Fns (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3665
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_689;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_689;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Constant_Indexing_Fns;
--# end
--# property-start BaseSubtypeDecl.variable_indexing_fns /tmp/lal-23.0.0/ada/ast.py:8544
pragma Warnings (Off, "is not referenced");
 function Base_Subtype_Decl_P_Variable_Indexing_Fns
  (Node : Bare_Base_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Base_Subtype_Decl := Bare_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subtype_Decl :=
     Internal_Entity_Base_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_690 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_690 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_690;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3667 '<FieldAccess for variable_indexing_fns at ast.py:8545>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8545
--# expr-start 3666 '<FieldAccess for from_type_bound at ast.py:8545>' Fld /tmp/lal-23.0.0/ada/ast.py:8545
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubtypeDecl.from_type_bound
Fld := Libadalang.Implementation.Base_Subtype_Decl_P_From_Type_Bound (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3666
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.variable_indexing_fns'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Variable_Indexing_Fns (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3667
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_690;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_690;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subtype_Decl_P_Variable_Indexing_Fns;
--# end
   --
   --  Primitives for Bare_Discrete_Base_Subtype_Decl
   --
      procedure Initialize_Fields_For_Discrete_Base_Subtype_Decl
        (Self : Bare_Discrete_Base_Subtype_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Initialize_Fields_For_Base_Subtype_Decl
              (Self, Base_Type_Decl_F_Name);
      end Initialize_Fields_For_Discrete_Base_Subtype_Decl;
--# property-start DiscreteBaseSubtypeDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:8583
pragma Warnings (Off, "is not referenced");
 function Discrete_Base_Subtype_Decl_P_Is_Static_Decl
  (Node : Bare_Discrete_Base_Subtype_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Discrete_Base_Subtype_Decl := Bare_Discrete_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discrete_Base_Subtype_Decl_P_Is_Static_Decl;
--# end
--# property-start DiscreteBaseSubtypeDecl.get_type /tmp/lal-23.0.0/ada/ast.py:8587
pragma Warnings (Off, "is not referenced");
 function Discrete_Base_Subtype_Decl_P_Get_Type
  (Node : Bare_Discrete_Base_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Discrete_Base_Subtype_Decl := Bare_Discrete_Base_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Cast_Result : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3670 '<as_entity at ast.py:8588>' If_Result /tmp/lal-23.0.0/ada/ast.py:8588
--# expr-start 3669 '<Cast to BaseTypeDecl at ast.py:8588>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8588
--# expr-start 3668 '<parent at ast.py:8588>' Fld /tmp/lal-23.0.0/ada/ast.py:8588
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 3668
   if Fld = null
      or else Fld.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Fld;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 3669
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 3670
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Discrete_Base_Subtype_Decl_P_Get_Type;
--# end
   --
   --  Primitives for Bare_Subtype_Decl
   --
      procedure Initialize_Fields_For_Subtype_Decl
        (Self : Bare_Subtype_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Subtype_Decl_F_Subtype : Bare_Subtype_Indication
         ; Subtype_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Base_Subtype_Decl
              (Self, Base_Type_Decl_F_Name);
            Self.Subtype_Decl_F_Subtype := Subtype_Decl_F_Subtype;
            Self.Subtype_Decl_F_Aspects := Subtype_Decl_F_Aspects;
      end Initialize_Fields_For_Subtype_Decl;
   function Subtype_Decl_F_Subtype
     (Node : Bare_Subtype_Decl) return Bare_Subtype_Indication
   is
   begin
         return Node.Subtype_Decl_F_Subtype;
   end;
--# property-start SubtypeDecl.get_type /tmp/lal-23.0.0/ada/ast.py:8557
pragma Warnings (Off, "is not referenced");
 function Subtype_Decl_P_Get_Type
  (Node : Bare_Subtype_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Subtype_Decl := Bare_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Decl :=
     Internal_Entity_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Subtype_Decl;
Match_1 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Subtype_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3675 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 3674 '<Match at ast.py:8558>' Match_Result /tmp/lal-23.0.0/ada/ast.py:8558
--# expr-start 3672 '<FieldAccess for designated_type at ast.py:8558>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8558
--# expr-start 3671 '<FieldAccess for subtype at ast.py:8558>' Fld /tmp/lal-23.0.0/ada/ast.py:8558
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Subtype_Decl_F_Subtype, Info => Ent.Info);
--# expr-done 3671
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3672
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_1; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Subtype_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind st Match_0
--# expr-start 3673 '<FieldAccess for get_type at ast.py:8559>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8559
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 3673
Let_Result := Fld_2; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Discrete_Base_Subtype_Decl | Ada_Classwide_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind t Match_1
Let_Result_1 := Match_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 3674
Let_Result_2 := Match_Result; 
--# end
--# expr-done 3675
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Decl_P_Get_Type;
--# end
--# property-start SubtypeDecl.discrete_range /tmp/lal-23.0.0/ada/ast.py:8564
pragma Warnings (Off, "is not referenced");
 function Subtype_Decl_P_Discrete_Range
  (Node : Bare_Subtype_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Subtype_Decl := Bare_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Decl :=
     Internal_Entity_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Internal_Discrete_Range;
Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3678 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3677 '<FieldAccess for discrete_range at ast.py:8565>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8565
--# expr-start 3676 '<FieldAccess for subtype at ast.py:8565>' Fld /tmp/lal-23.0.0/ada/ast.py:8565
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Subtype_Decl_F_Subtype, Info => Ent.Info);
--# expr-done 3676
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.discrete_range
Fld_1 := Libadalang.Implementation.Subtype_Indication_P_Discrete_Range (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3677
Let_Result := Fld_1; 
--# end
--# expr-done 3678
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Decl_P_Discrete_Range;
--# end
--# property-start SubtypeDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:8568
pragma Warnings (Off, "is not referenced");
 function Subtype_Decl_P_Xref_Equation
  (Node : Bare_Subtype_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Subtype_Decl := Bare_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Decl :=
     Internal_Entity_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_693 with Inline_Always;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_693 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_693;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3681 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3680 '<FieldAccess for sub_equation at ast.py:8569>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8569
--# expr-start 3679 '<FieldAccess for subtype at ast.py:8569>' Fld /tmp/lal-23.0.0/ada/ast.py:8569
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Subtype_Decl_F_Subtype, Info => Ent.Info);
--# expr-done 3679
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3680
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 3681
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_693;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_693;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Decl_P_Xref_Equation;
--# end
--# property-start SubtypeDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:8571
pragma Warnings (Off, "is not referenced");
 function Subtype_Decl_P_Is_Static_Decl
  (Node : Bare_Subtype_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Subtype_Decl := Bare_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Decl :=
     Internal_Entity_Subtype_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3683 '<FieldAccess for is_static_subtype at ast.py:8571>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8571
--# expr-start 3682 '<FieldAccess for subtype at ast.py:8571>' Fld /tmp/lal-23.0.0/ada/ast.py:8571
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Subtype_Decl_F_Subtype, Info => Ent.Info);
--# expr-done 3682
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.is_static_subtype
Fld_1 := Libadalang.Implementation.Subtype_Indication_P_Is_Static_Subtype (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 3683
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Decl_P_Is_Static_Decl;
--# end
--# property-start SubtypeDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:8572
pragma Warnings (Off, "is not referenced");
 function Subtype_Decl_P_Xref_Entry_Point
  (Node : Bare_Subtype_Decl
  )
   return Boolean
is
   Self : Bare_Subtype_Decl := Bare_Subtype_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Decl_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_Classwide_Type_Decl
   --
      procedure Initialize_Fields_For_Classwide_Type_Decl
        (Self : Bare_Classwide_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Initialize_Fields_For_Base_Type_Decl
              (Self, Base_Type_Decl_F_Name);
      end Initialize_Fields_For_Classwide_Type_Decl;
--# property-start ClasswideTypeDecl.typedecl /tmp/lal-23.0.0/ada/ast.py:6962
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Typedecl
  (Node : Bare_Classwide_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Cast_Result : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3686 '<as_entity at ast.py:6962>' If_Result /tmp/lal-23.0.0/ada/ast.py:6962
--# expr-start 3685 '<Cast to BaseTypeDecl at ast.py:6962>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:6962
--# expr-start 3684 '<parent at ast.py:6962>' Fld /tmp/lal-23.0.0/ada/ast.py:6962
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 3684
   if Fld = null
      or else Fld.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 3685
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 3686
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Typedecl;
--# end
--# property-start ClasswideTypeDecl.is_classwide /tmp/lal-23.0.0/ada/ast.py:6964
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Is_Classwide
  (Node : Bare_Classwide_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Is_Classwide;
--# end
--# property-start ClasswideTypeDecl.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:6966
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Is_Tagged_Type
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Is_Tagged_Type;
--# end
--# property-start ClasswideTypeDecl.base_type /tmp/lal-23.0.0/ada/ast.py:6967
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Base_Type
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3688 '<FieldAccess for base_type at ast.py:6967>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6967
--# expr-start 3687 '<FieldAccess for typedecl at ast.py:6967>' Fld /tmp/lal-23.0.0/ada/ast.py:6967
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3687
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3688
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Base_Type;
--# end
--# property-start ClasswideTypeDecl.base_interfaces /tmp/lal-23.0.0/ada/ast.py:6968
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Base_Interfaces
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_521 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_521 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_521;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3690 '<FieldAccess for base_interfaces at ast.py:6968>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6968
--# expr-start 3689 '<FieldAccess for typedecl at ast.py:6968>' Fld /tmp/lal-23.0.0/ada/ast.py:6968
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3689
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_interfaces'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Interfaces (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3690
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_521;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_521;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Base_Interfaces;
--# end
--# property-start ClasswideTypeDecl.record_def /tmp/lal-23.0.0/ada/ast.py:6969
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Record_Def
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Record_Def
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Record_Def;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Record_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3692 '<FieldAccess for record_def at ast.py:6969>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6969
--# expr-start 3691 '<FieldAccess for typedecl at ast.py:6969>' Fld /tmp/lal-23.0.0/ada/ast.py:6969
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3691
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3692
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Record_Def;
--# end
--# property-start ClasswideTypeDecl.classwide_type /tmp/lal-23.0.0/ada/ast.py:6970
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Classwide_Type
  (Node : Bare_Classwide_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Classwide_Type_Decl
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Classwide_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Ent;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Classwide_Type;
--# end
--# property-start ClasswideTypeDecl.is_iterable_type /tmp/lal-23.0.0/ada/ast.py:6971
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Is_Iterable_Type
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3694 '<FieldAccess for is_iterable_type at ast.py:6971>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6971
--# expr-start 3693 '<FieldAccess for typedecl at ast.py:6971>' Fld /tmp/lal-23.0.0/ada/ast.py:6971
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3693
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3694
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Is_Iterable_Type;
--# end
--# property-start ClasswideTypeDecl.iterable_comp_type /tmp/lal-23.0.0/ada/ast.py:6972
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Iterable_Comp_Type
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3696 '<FieldAccess for iterable_comp_type at ast.py:6972>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6972
--# expr-start 3695 '<FieldAccess for typedecl at ast.py:6972>' Fld /tmp/lal-23.0.0/ada/ast.py:6972
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3695
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3696
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Iterable_Comp_Type;
--# end
--# property-start ClasswideTypeDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:6973
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Defining_Env
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_526 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_526 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_526;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3698 '<FieldAccess for defining_env at ast.py:6973>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6973
--# expr-start 3697 '<FieldAccess for typedecl at ast.py:6973>' Fld /tmp/lal-23.0.0/ada/ast.py:6973
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3697
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 3698
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_526;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_526;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Defining_Env;
--# end
--# property-start ClasswideTypeDecl.is_private /tmp/lal-23.0.0/ada/ast.py:6974
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Is_Private
  (Node : Bare_Classwide_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3700 '<FieldAccess for is_private at ast.py:6974>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6974
--# expr-start 3699 '<FieldAccess for typedecl at ast.py:6974>' Fld /tmp/lal-23.0.0/ada/ast.py:6974
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3699
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_private'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Private (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3700
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Is_Private;
--# end
--# property-start ClasswideTypeDecl.is_in_private_part /tmp/lal-23.0.0/ada/ast.py:6975
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Is_In_Private_Part
  (Node : Bare_Classwide_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3702 '<FieldAccess for is_in_private_part at ast.py:6975>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6975
--# expr-start 3701 '<FieldAccess for typedecl at ast.py:6975>' Fld /tmp/lal-23.0.0/ada/ast.py:6975
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3701
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3702
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Is_In_Private_Part;
--# end
--# property-start ClasswideTypeDecl.get_aspect_assoc /tmp/lal-23.0.0/ada/ast.py:6978
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Get_Aspect_Assoc
  (Node : Bare_Classwide_Type_Decl
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Aspect_Assoc
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Aspect_Assoc;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Aspect_Assoc;
Let_Result : Internal_Entity_Aspect_Assoc;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3705 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3704 '<FieldAccess for get_aspect_assoc at ast.py:6979>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6979
--# expr-start 3703 '<FieldAccess for typedecl at ast.py:6979>' Fld /tmp/lal-23.0.0/ada/ast.py:6979
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3703
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.get_aspect_assoc'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Get_Aspect_Assoc (Node => Fld.Node, Name => Name, E_Info => Fld.Info);
--# end
--# expr-done 3704
Let_Result := Fld_1; 
--# end
--# expr-done 3705
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Get_Aspect_Assoc;
--# end
--# property-start ClasswideTypeDecl.is_interface_type /tmp/lal-23.0.0/ada/ast.py:6981
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Is_Interface_Type
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3707 '<FieldAccess for is_interface_type at ast.py:6981>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6981
--# expr-start 3706 '<FieldAccess for typedecl at ast.py:6981>' Fld /tmp/lal-23.0.0/ada/ast.py:6981
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3706
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_interface_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Interface_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3707
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Is_Interface_Type;
--# end
--# property-start ClasswideTypeDecl.discriminants_list /tmp/lal-23.0.0/ada/ast.py:6983
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Discriminants_List
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_531 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_531 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_531;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3709 '<FieldAccess for discriminants_list at ast.py:6983>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6983
--# expr-start 3708 '<FieldAccess for typedecl at ast.py:6983>' Fld /tmp/lal-23.0.0/ada/ast.py:6983
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3708
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3709
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_531;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_531;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Discriminants_List;
--# end
--# property-start ClasswideTypeDecl.previous_part /tmp/lal-23.0.0/ada/ast.py:6987
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Previous_Part
  (Node : Bare_Classwide_Type_Decl
      ; Go_To_Incomplete : Boolean
         := True
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind go_to_incomplete Go_To_Incomplete
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Classwide_Type_Decl;
Scope_Result : Internal_Entity_Classwide_Type_Decl;
Result_Var : Internal_Entity_Classwide_Type_Decl;
Let_Result : Internal_Entity_Classwide_Type_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Classwide_Type_Decl_Classwide_Type_Decl_P_Previous_Part,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Classwide_Type_Decl,
                                As_Bare_Classwide_Type_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Go_To_Incomplete);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
--# expr-start 3713 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3711 '<FieldAccess for previous_part at ast.py:6988>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6988
--# expr-start 3710 '<FieldAccess for typedecl at ast.py:6988>' Fld /tmp/lal-23.0.0/ada/ast.py:6988
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3710
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Fld.Node, Go_To_Incomplete => Go_To_Incomplete, E_Info => Fld.Info);
--# end
--# expr-done 3711
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind pp Var_Expr
--# expr-start 3712 '<FieldAccess for classwide_type at ast.py:6989>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6989
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3712
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Classwide_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 3713
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Let_Result.Node,
         Info => Let_Result.Info);
      Property_Result := Cast_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Previous_Part;
--# end
--# property-start ClasswideTypeDecl.canonical_type /tmp/lal-23.0.0/ada/ast.py:6992
pragma Warnings (Off, "is not referenced");
 function Classwide_Type_Decl_P_Canonical_Type
  (Node : Bare_Classwide_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Classwide_Type_Decl := Bare_Classwide_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classwide_Type_Decl :=
     Internal_Entity_Classwide_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Classwide_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Classwide_Type_Decl;
Scope_Result : Internal_Entity_Classwide_Type_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 3715 '<FieldAccess for canonical_type at ast.py:6992>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:6992
--# expr-start 3714 '<FieldAccess for typedecl at ast.py:6992>' Fld /tmp/lal-23.0.0/ada/ast.py:6992
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3714
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3715
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 3716 '<FieldAccess for classwide_type at ast.py:6996>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:6996
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3716
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity_Classwide_Type_Decl then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result := Var_Expr_1;
   --# end
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Scope_Result.Node,
         Info => Scope_Result.Info);
   Result_Var := Cast_Result;
else
   Result_Var := Var_Expr;
end if;
Scope_Result_1 := Result_Var;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
      Property_Result := Result_Var_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classwide_Type_Decl_P_Canonical_Type;
--# end
   --
   --  Primitives for Bare_Incomplete_Type_Decl
   --
      procedure Incomplete_Type_Decl_Pre_Env_Actions
        (Self            : Bare_Incomplete_Type_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_231 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20765");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_232 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Incomplete_Type_Decl
        (Self : Bare_Incomplete_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Incomplete_Type_Decl_F_Discriminants : Bare_Discriminant_Part
        ) is
      begin
            Initialize_Fields_For_Base_Type_Decl
              (Self, Base_Type_Decl_F_Name);
            Self.Incomplete_Type_Decl_F_Discriminants := Incomplete_Type_Decl_F_Discriminants;
      end Initialize_Fields_For_Incomplete_Type_Decl;
   function Incomplete_Type_Decl_F_Discriminants
     (Node : Bare_Incomplete_Type_Decl) return Bare_Discriminant_Part
   is
   begin
         return Node.Incomplete_Type_Decl_F_Discriminants;
   end;
--# property-start IncompleteTypeDecl.find_next_part_in /tmp/lal-23.0.0/ada/ast.py:20751
pragma Warnings (Off, "is not referenced");
 function Incomplete_Type_Decl_P_Find_Next_Part_In
  (Node : Bare_Incomplete_Type_Decl
      ; Decl_Part : Internal_Entity_Declarative_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Incomplete_Type_Decl := Bare_Incomplete_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Incomplete_Type_Decl :=
     Internal_Entity_Incomplete_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind decl_part Decl_Part
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Defining_Name;
Fld_4 : Symbol_Type;
Fld_5 : Boolean;
Cast_Expr_1 : Internal_Entity_Incomplete_Type_Decl;
Cast_Result_1 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Not_Val : Boolean;
If_Result_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Item_142 : Internal_Entity;
Bare_Item_142 : Bare_Ada_Node;
Find_Result : Internal_Entity;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3726 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3725 '<Cast to BaseTypeDecl at ast.py:20762>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:20762
--# expr-start 3724 '<Find at ast.py:20757>' Find_Result /tmp/lal-23.0.0/ada/ast.py:20757
   --# expr-start 3717 '<FieldAccess for decls at ast.py:20757>' Fld /tmp/lal-23.0.0/ada/ast.py:20757
      if Decl_Part.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Decl_Part.Node.Declarative_Part_F_Decls, Info => Decl_Part.Info);
--# expr-done 3717
Fld_1 := Fld.Node;
      Find_Result := No_Entity;
      if Fld_1 = null then
      Find_Result := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_142 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_142 := Untyped_Item_142; 
Is_Null := Bare_Item_142 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_142); 
   If_Result := As_Entity;
end if;
                  Item_142 := If_Result; 
   --# scope-start
               --# bind t Item_142
--# expr-start 3718 '<Cast to BaseTypeDecl at ast.py:20758>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20758
Cast_Expr := Item_142; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 3718
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind btd Var_Expr
--# expr-start 3721 '<FieldAccess for name_is at ast.py:20760>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:20760
--# expr-start 3719 '<FieldAccess for name at ast.py:20760>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20760
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Defining_Name (Node => Var_Expr.Node.Base_Type_Decl_F_Name, Info => Var_Expr.Info);
--# expr-done 3719
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3720 '<FieldAccess for name_symbol at ast.py:20760>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20760
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 3720
--# property-call-start Name.name_is
Fld_5 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_3.Node, Sym => Fld_4);
--# end
--# expr-done 3721
if Fld_5 then
   --# expr-start 3723 '<Not at ast.py:20760>' Not_Val /tmp/lal-23.0.0/ada/ast.py:20760
--# expr-start 3722 '<Eq at ast.py:20760>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:20760
Cast_Expr_1 := Ent; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Cast_Expr_2 := Var_Expr; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 3722
Not_Val := not (Is_Equiv); 
--# expr-done 3723
   If_Result_1 := Not_Val;
else
   If_Result_1 := False;
end if;
Scope_Result := If_Result_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      if Result_Var then
         Find_Result := Item_142;
      end if;
   --# end
               exit when Result_Var;
         end loop;
      end;
      end if;
--# expr-done 3724
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_3 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 3725
Let_Result := Cast_Result_3; 
--# end
--# expr-done 3726
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Incomplete_Type_Decl_P_Find_Next_Part_In;
--# end
--# property-start IncompleteTypeDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:20769
pragma Warnings (Off, "is not referenced");
 function Incomplete_Type_Decl_P_Defining_Env
  (Node : Bare_Incomplete_Type_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Incomplete_Type_Decl := Bare_Incomplete_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1458 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1458 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
            end Finalizer_Scope_1458;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3730 '<env_group at ast.py:20770>' Group_Env /tmp/lal-23.0.0/ada/ast.py:20770
--# expr-start 3729 '<ArrayLiteral at ast.py:20770>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:20770
--# expr-start 3727 '<FieldAccess for children_env at ast.py:20770>' Fld /tmp/lal-23.0.0/ada/ast.py:20770
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Self);
--# expr-done 3727
--# expr-start 3728 '<FieldAccess for dottable_subps_env at ast.py:20770>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20770
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.dottable_subps_env
Fld_1 := Libadalang.Implementation.Base_Type_Decl_F_Dottable_Subps_Env (Node => Self);
--# end
--# expr-done 3728
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld, 2 => Fld_1)); 
--# expr-done 3729
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 3730
      Property_Result := Group_Env;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1458;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1458;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Incomplete_Type_Decl_P_Defining_Env;
--# end
--# property-start IncompleteTypeDecl.discriminants_list /tmp/lal-23.0.0/ada/ast.py:20774
pragma Warnings (Off, "is not referenced");
 function Incomplete_Type_Decl_P_Discriminants_List
  (Node : Bare_Incomplete_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Incomplete_Type_Decl := Bare_Incomplete_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Incomplete_Type_Decl :=
     Internal_Entity_Incomplete_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1459 with Inline_Always;
      Fld : Internal_Entity_Discriminant_Part;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_1459 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1459;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3732 '<FieldAccess for abstract_formal_params at ast.py:20774>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20774
--# expr-start 3731 '<FieldAccess for discriminants at ast.py:20774>' Fld /tmp/lal-23.0.0/ada/ast.py:20774
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Discriminant_Part (Node => Ent.Node.Incomplete_Type_Decl_F_Discriminants, Info => Ent.Info);
--# expr-done 3731
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3732
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1459;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1459;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Incomplete_Type_Decl_P_Discriminants_List;
--# end
--# property-start IncompleteTypeDecl._env_mappings_231 /tmp/lal-23.0.0/ada/ast.py:20765
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_231
  (Node : Bare_Incomplete_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Incomplete_Type_Decl := Bare_Incomplete_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Incomplete_Type_Decl :=
     Internal_Entity_Incomplete_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1700 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Incomplete_Type_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1700 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1700;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3735 '<New EnvAssoc at ast.py:20765>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:20765
--# expr-start 3733 '<New DesignatedEnv at ast.py:20765>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20765
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 3733
--# expr-start 3734 '<FieldAccess for name_symbol at ast.py:20765>' Fld /tmp/lal-23.0.0/ada/ast.py:20765
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 3734
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 3735
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1700;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1700;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_231;
--# end
--# property-start IncompleteTypeDecl._env_trans_parent_232 /tmp/lal-23.0.0/ada/ast.py:20764
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_232
  (Node : Bare_Incomplete_Type_Decl
  )
   return Boolean
is
   Self : Bare_Incomplete_Type_Decl := Bare_Incomplete_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_232;
--# end
   --
   --  Primitives for Bare_Incomplete_Formal_Type_Decl
   --
      procedure Initialize_Fields_For_Incomplete_Formal_Type_Decl
        (Self : Bare_Incomplete_Formal_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Incomplete_Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Incomplete_Formal_Type_Decl_F_Is_Tagged : Bare_Tagged_Node
         ; Incomplete_Formal_Type_Decl_F_Default_Type : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Incomplete_Type_Decl
              (Self, Base_Type_Decl_F_Name, Incomplete_Type_Decl_F_Discriminants);
            Self.Incomplete_Formal_Type_Decl_F_Is_Tagged := Incomplete_Formal_Type_Decl_F_Is_Tagged;
            Self.Incomplete_Formal_Type_Decl_F_Default_Type := Incomplete_Formal_Type_Decl_F_Default_Type;
      end Initialize_Fields_For_Incomplete_Formal_Type_Decl;
   function Incomplete_Formal_Type_Decl_F_Is_Tagged
     (Node : Bare_Incomplete_Formal_Type_Decl) return Bare_Tagged_Node
   is
   begin
         return Node.Incomplete_Formal_Type_Decl_F_Is_Tagged;
   end;
   function Incomplete_Formal_Type_Decl_F_Default_Type
     (Node : Bare_Incomplete_Formal_Type_Decl) return Bare_Name
   is
   begin
         return Node.Incomplete_Formal_Type_Decl_F_Default_Type;
   end;
--# property-start IncompleteFormalTypeDecl.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:20794
pragma Warnings (Off, "is not referenced");
 function Incomplete_Formal_Type_Decl_P_Is_Tagged_Type
  (Node : Bare_Incomplete_Formal_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Incomplete_Formal_Type_Decl := Bare_Incomplete_Formal_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Bare_Tagged_Node;
Is_Null : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3738 '<Not at ast.py:20794>' Not_Val /tmp/lal-23.0.0/ada/ast.py:20794
--# expr-start 3737 '<IsNull at ast.py:20794>' Is_Null /tmp/lal-23.0.0/ada/ast.py:20794
--# expr-start 3736 '<FieldAccess for is_tagged at ast.py:20794>' Fld /tmp/lal-23.0.0/ada/ast.py:20794
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Incomplete_Formal_Type_Decl_F_Is_Tagged;
--# expr-done 3736
Is_Null := Fld = null; 
--# expr-done 3737
Not_Val := not (Is_Null); 
--# expr-done 3738
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Incomplete_Formal_Type_Decl_P_Is_Tagged_Type;
--# end
   --
   --  Primitives for Bare_Incomplete_Tagged_Type_Decl
   --
      procedure Initialize_Fields_For_Incomplete_Tagged_Type_Decl
        (Self : Bare_Incomplete_Tagged_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Incomplete_Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Incomplete_Tagged_Type_Decl_F_Has_Abstract : Bare_Abstract_Node
        ) is
      begin
            Initialize_Fields_For_Incomplete_Type_Decl
              (Self, Base_Type_Decl_F_Name, Incomplete_Type_Decl_F_Discriminants);
            Self.Incomplete_Tagged_Type_Decl_F_Has_Abstract := Incomplete_Tagged_Type_Decl_F_Has_Abstract;
      end Initialize_Fields_For_Incomplete_Tagged_Type_Decl;
   function Incomplete_Tagged_Type_Decl_F_Has_Abstract
     (Node : Bare_Incomplete_Tagged_Type_Decl) return Bare_Abstract_Node
   is
   begin
         return Node.Incomplete_Tagged_Type_Decl_F_Has_Abstract;
   end;
--# property-start IncompleteTaggedTypeDecl.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:20784
pragma Warnings (Off, "is not referenced");
 function Incomplete_Tagged_Type_Decl_P_Is_Tagged_Type
  (Node : Bare_Incomplete_Tagged_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Incomplete_Tagged_Type_Decl := Bare_Incomplete_Tagged_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Incomplete_Tagged_Type_Decl_P_Is_Tagged_Type;
--# end
   --
   --  Primitives for Bare_Protected_Type_Decl
   --
      procedure Protected_Type_Decl_Pre_Env_Actions
        (Self            : Bare_Protected_Type_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_13 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:8715");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_14 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_15 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Protected_Type_Decl
        (Self : Bare_Protected_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Protected_Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Protected_Type_Decl_F_Aspects : Bare_Aspect_Spec
         ; Protected_Type_Decl_F_Interfaces : Bare_Parent_List
         ; Protected_Type_Decl_F_Definition : Bare_Protected_Def
        ) is
      begin
            Initialize_Fields_For_Base_Type_Decl
              (Self, Base_Type_Decl_F_Name);
            Self.Protected_Type_Decl_F_Discriminants := Protected_Type_Decl_F_Discriminants;
            Self.Protected_Type_Decl_F_Aspects := Protected_Type_Decl_F_Aspects;
            Self.Protected_Type_Decl_F_Interfaces := Protected_Type_Decl_F_Interfaces;
            Self.Protected_Type_Decl_F_Definition := Protected_Type_Decl_F_Definition;
      end Initialize_Fields_For_Protected_Type_Decl;
   function Protected_Type_Decl_F_Discriminants
     (Node : Bare_Protected_Type_Decl) return Bare_Discriminant_Part
   is
   begin
         return Node.Protected_Type_Decl_F_Discriminants;
   end;
   function Protected_Type_Decl_F_Interfaces
     (Node : Bare_Protected_Type_Decl) return Bare_Parent_List
   is
   begin
         return Node.Protected_Type_Decl_F_Interfaces;
   end;
   function Protected_Type_Decl_F_Definition
     (Node : Bare_Protected_Type_Decl) return Bare_Protected_Def
   is
   begin
         return Node.Protected_Type_Decl_F_Definition;
   end;
--# property-start ProtectedTypeDecl.discriminants_list /tmp/lal-23.0.0/ada/ast.py:8683
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Discriminants_List
  (Node : Bare_Protected_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_707 with Inline_Always;
      Fld : Internal_Entity_Discriminant_Part;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_707 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_707;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3740 '<FieldAccess for abstract_formal_params at ast.py:8683>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8683
--# expr-start 3739 '<FieldAccess for discriminants at ast.py:8683>' Fld /tmp/lal-23.0.0/ada/ast.py:8683
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Discriminant_Part (Node => Ent.Node.Protected_Type_Decl_F_Discriminants, Info => Ent.Info);
--# expr-done 3739
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3740
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_707;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_707;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Discriminants_List;
--# end
--# property-start ProtectedTypeDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:8685
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Defining_Env
  (Node : Bare_Protected_Type_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_708 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_708 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_708;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3741 '<FieldAccess for children_env at ast.py:8685>' Fld /tmp/lal-23.0.0/ada/ast.py:8685
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 3741
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_708;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_708;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Defining_Env;
--# end
--# property-start ProtectedTypeDecl.base_interfaces /tmp/lal-23.0.0/ada/ast.py:8687
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Base_Interfaces
  (Node : Bare_Protected_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_709 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Item_143 : Internal_Entity_Name;
Bare_Item_143 : Bare_Name;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_709 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_709;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3744 '<Map at ast.py:8688>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8688
   --# expr-start 3742 '<FieldAccess for interfaces at ast.py:8688>' Fld /tmp/lal-23.0.0/ada/ast.py:8688
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Protected_Type_Decl_F_Interfaces, Info => Ent.Info);
--# expr-done 3742
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Type_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_143 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_143 := Untyped_Item_143; 
Is_Null := Bare_Item_143 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_143); 
   If_Result := As_Entity;
end if;
                  Item_143 := If_Result; 
   --# scope-start
               --# bind i Item_143
      --# expr-start 3743 '<FieldAccess for name_designated_type at ast.py:8688>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8688
      if Item_143.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Item_143.Node, E_Info => Item_143.Info);
--# end
--# expr-done 3743
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Fld_3;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3744
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_709;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_709;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Base_Interfaces;
--# end
--# property-start ProtectedTypeDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:8692
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Next_Part_For_Decl
  (Node : Bare_Protected_Type_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3746 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3745 '<FieldAccess for basic_decl_next_part_for_decl at ast.py:8693>' Fld /tmp/lal-23.0.0/ada/ast.py:8693
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.basic_decl_next_part_for_decl
Fld := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Next_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 3745
Let_Result := Fld; 
--# end
--# expr-done 3746
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Next_Part_For_Decl;
--# end
--# property-start ProtectedTypeDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:8695
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Xref_Entry_Point
  (Node : Bare_Protected_Type_Decl
  )
   return Boolean
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Xref_Entry_Point;
--# end
--# property-start ProtectedTypeDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:8698
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Xref_Equation
  (Node : Bare_Protected_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_712 with Inline_Always;
            procedure Finalizer_Scope_2318 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Item_144 : Internal_Entity_Name;
Bare_Item_144 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_712 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_712;
            procedure Finalizer_Scope_2318 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2318;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3751 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3750 '<LogicAll at ast.py:8699>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8699
--# expr-start 3749 '<Map at ast.py:8699>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8699
   --# expr-start 3747 '<FieldAccess for interfaces at ast.py:8699>' Fld /tmp/lal-23.0.0/ada/ast.py:8699
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Protected_Type_Decl_F_Interfaces, Info => Ent.Info);
--# expr-done 3747
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_144 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_144 := Untyped_Item_144; 
Is_Null := Bare_Item_144 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_144); 
   If_Result := As_Entity;
end if;
                  Item_144 := If_Result; 
   --# scope-start
               --# bind ifc Item_144
      --# expr-start 3748 '<FieldAccess for xref_equation at ast.py:8699>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8699
      if Item_144.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Item_144.Node, Env => Env, Origin => Origin, E_Info => Item_144.Info);
--# end
--# expr-done 3748
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2318;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3749
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8699") else null)); 
--# expr-done 3750
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 3751
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_712;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_712;
               Finalizer_Scope_2318;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Xref_Equation;
--# end
--# property-start ProtectedTypeDecl.declarative_parts /tmp/lal-23.0.0/ada/ast.py:8702
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Declarative_Parts
  (Node : Bare_Protected_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_713 with Inline_Always;
            procedure Finalizer_Scope_2319 with Inline_Always;
      Block_Var : Internal_Entity_Protected_Def;
Var_Expr : Internal_Entity_Declarative_Part;
Fld : Internal_Entity_Protected_Def;
Fld_1 : Internal_Entity_Public_Part;
Cast_Result : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
Fld_2 : Internal_Entity_Private_Part;
Cast_Result_1 : Internal_Entity_Declarative_Part;
Singleton_1 : Internal_Entity_Declarative_Part_Array_Access;
Scope_Result : Internal_Entity_Declarative_Part_Array_Access;
Result_Var : Internal_Entity_Declarative_Part_Array_Access;
Concat_Result : Internal_Entity_Declarative_Part_Array_Access;
Let_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_713 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_713;
            procedure Finalizer_Scope_2319 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2319;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3758 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3752 '<FieldAccess for definition at ast.py:8703>' Fld /tmp/lal-23.0.0/ada/ast.py:8703
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Protected_Def (Node => Ent.Node.Protected_Type_Decl_F_Definition, Info => Ent.Info);
--# expr-done 3752
Block_Var := Fld; 
--# bind pdef Block_Var
--# expr-start 3757 '<Concat at ast.py:8704>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:8704
--# expr-start 3754 '<Cast to DeclarativePart at ast.py:8704>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8704
--# expr-start 3753 '<FieldAccess for public_part at ast.py:8704>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8704
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Public_Part (Node => Block_Var.Node.Protected_Def_F_Public_Part, Info => Block_Var.Info);
--# expr-done 3753
      Cast_Result := Create_Internal_Entity_Declarative_Part
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
--# expr-done 3754
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
--# expr-start 3756 '<Cast to DeclarativePart at ast.py:8705>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:8705
--# expr-start 3755 '<FieldAccess for private_part at ast.py:8705>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8705
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Private_Part (Node => Block_Var.Node.Protected_Def_F_Private_Part, Info => Block_Var.Info);
--# expr-done 3755
      Cast_Result_1 := Create_Internal_Entity_Declarative_Part
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# expr-done 3756
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Declarative_Part then
   --# scope-start
                Singleton_1 := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton_1.Items (1) := Var_Expr;
Scope_Result := Singleton_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2319;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Declarative_Part_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result := Concat (Singleton, Result_Var); 
--# expr-done 3757
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 3758
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_713;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_713;
               Finalizer_Scope_2319;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Declarative_Parts;
--# end
--# property-start ProtectedTypeDecl.env_names /tmp/lal-23.0.0/ada/ast.py:8709
pragma Warnings (Off, "is not referenced");
 function Protected_Type_Decl_P_Env_Names
  (Node : Bare_Protected_Type_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_714 with Inline_Always;
            procedure Finalizer_Scope_2320 with Inline_Always;
      Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_714 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_714;
            procedure Finalizer_Scope_2320 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2320;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3761 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3759 '<FieldAccess for top_level_env_name at ast.py:8710>' Fld /tmp/lal-23.0.0/ada/ast.py:8710
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 3759
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 3760 '<to_symbol at ast.py:8711>' Sym /tmp/lal-23.0.0/ada/ast.py:8711
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 3760
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Sym;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2320;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 3761
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_714;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_714;
               Finalizer_Scope_2320;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Type_Decl_P_Env_Names;
--# end
--# property-start ProtectedTypeDecl._env_mappings_13 /tmp/lal-23.0.0/ada/ast.py:8715
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_13
  (Node : Bare_Protected_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Type_Decl :=
     Internal_Entity_Protected_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1482 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Protected_Type_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1482 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1482;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3764 '<New EnvAssoc at ast.py:8715>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:8715
--# expr-start 3762 '<New DesignatedEnv at ast.py:8715>' New_Struct /tmp/lal-23.0.0/ada/ast.py:8715
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 3762
--# expr-start 3763 '<FieldAccess for name_symbol at ast.py:8715>' Fld /tmp/lal-23.0.0/ada/ast.py:8715
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 3763
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 3764
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1482;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1482;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_13;
--# end
--# property-start ProtectedTypeDecl._env_trans_parent_14 /tmp/lal-23.0.0/ada/ast.py:8714
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_14
  (Node : Bare_Protected_Type_Decl
  )
   return Boolean
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_14;
--# end
--# property-start ProtectedTypeDecl._env_names_15 /tmp/lal-23.0.0/ada/ast.py:8716
pragma Warnings (Off, "is not referenced");
 function Env_Names_15
  (Node : Bare_Protected_Type_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Protected_Type_Decl := Bare_Protected_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1484 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1484 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1484;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3765 '<FieldAccess for env_names at ast.py:8716>' Fld /tmp/lal-23.0.0/ada/ast.py:8716
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ProtectedTypeDecl.env_names
Fld := Libadalang.Implementation.Protected_Type_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 3765
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1484;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1484;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_15;
--# end
   --
   --  Primitives for Bare_Task_Type_Decl
   --
      procedure Task_Type_Decl_Pre_Env_Actions
        (Self            : Bare_Task_Type_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_9 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:8635");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_10 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_11 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Task_Type_Decl
        (Self : Bare_Task_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Task_Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Task_Type_Decl_F_Aspects : Bare_Aspect_Spec
         ; Task_Type_Decl_F_Definition : Bare_Task_Def
        ) is
      begin
            Initialize_Fields_For_Base_Type_Decl
              (Self, Base_Type_Decl_F_Name);
            Self.Task_Type_Decl_F_Discriminants := Task_Type_Decl_F_Discriminants;
            Self.Task_Type_Decl_F_Aspects := Task_Type_Decl_F_Aspects;
            Self.Task_Type_Decl_F_Definition := Task_Type_Decl_F_Definition;
      end Initialize_Fields_For_Task_Type_Decl;
   function Task_Type_Decl_F_Discriminants
     (Node : Bare_Task_Type_Decl) return Bare_Discriminant_Part
   is
   begin
         return Node.Task_Type_Decl_F_Discriminants;
   end;
   function Task_Type_Decl_F_Definition
     (Node : Bare_Task_Type_Decl) return Bare_Task_Def
   is
   begin
         return Node.Task_Type_Decl_F_Definition;
   end;
--# property-start TaskTypeDecl.is_task_type /tmp/lal-23.0.0/ada/ast.py:8622
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Is_Task_Type
  (Node : Bare_Task_Type_Decl
  )
   return Boolean
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Is_Task_Type;
--# end
--# property-start TaskTypeDecl.base_interfaces /tmp/lal-23.0.0/ada/ast.py:8624
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Base_Interfaces
  (Node : Bare_Task_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Type_Decl :=
     Internal_Entity_Task_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_700 with Inline_Always;
      Fld : Internal_Entity_Task_Def;
Fld_1 : Internal_Entity_Parent_List;
Fld_2 : Bare_Parent_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_4 : Internal_Entity_Base_Type_Decl;
Item_145 : Internal_Entity_Name;
Bare_Item_145 : Bare_Name;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_700 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_700;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3769 '<Map at ast.py:8625>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8625
   --# expr-start 3767 '<FieldAccess for interfaces at ast.py:8625>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8625
--# expr-start 3766 '<FieldAccess for definition at ast.py:8625>' Fld /tmp/lal-23.0.0/ada/ast.py:8625
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Task_Def (Node => Ent.Node.Task_Type_Decl_F_Definition, Info => Ent.Info);
--# expr-done 3766
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Parent_List (Node => Fld.Node.Task_Def_F_Interfaces, Info => Fld.Info);
--# expr-done 3767
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Base_Type_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_2;
      begin
         for Untyped_Item_145 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_145 := Untyped_Item_145; 
Is_Null := Bare_Item_145 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_145); 
   If_Result := As_Entity;
end if;
                  Item_145 := If_Result; 
   --# scope-start
               --# bind i Item_145
      --# expr-start 3768 '<FieldAccess for name_designated_type at ast.py:8625>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8625
      if Item_145.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_4 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Item_145.Node, E_Info => Item_145.Info);
--# end
--# expr-done 3768
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Fld_4;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3769
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_700;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_700;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Base_Interfaces;
--# end
--# property-start TaskTypeDecl.env_names /tmp/lal-23.0.0/ada/ast.py:8629
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Env_Names
  (Node : Bare_Task_Type_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_701 with Inline_Always;
            procedure Finalizer_Scope_2322 with Inline_Always;
      Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_701 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_701;
            procedure Finalizer_Scope_2322 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2322;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3772 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3770 '<FieldAccess for top_level_env_name at ast.py:8630>' Fld /tmp/lal-23.0.0/ada/ast.py:8630
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 3770
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 3771 '<to_symbol at ast.py:8631>' Sym /tmp/lal-23.0.0/ada/ast.py:8631
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 3771
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Sym;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2322;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 3772
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_701;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_701;
               Finalizer_Scope_2322;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Env_Names;
--# end
--# property-start TaskTypeDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:8639
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Defining_Env
  (Node : Bare_Task_Type_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Type_Decl :=
     Internal_Entity_Task_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_702 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_702 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_702;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3773 '<FieldAccess for children_env at ast.py:8639>' Fld /tmp/lal-23.0.0/ada/ast.py:8639
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 3773
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_702;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_702;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Defining_Env;
--# end
--# property-start TaskTypeDecl.discriminants_list /tmp/lal-23.0.0/ada/ast.py:8641
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Discriminants_List
  (Node : Bare_Task_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Type_Decl :=
     Internal_Entity_Task_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_703 with Inline_Always;
      Fld : Internal_Entity_Discriminant_Part;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_703 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_703;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3775 '<FieldAccess for abstract_formal_params at ast.py:8641>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8641
--# expr-start 3774 '<FieldAccess for discriminants at ast.py:8641>' Fld /tmp/lal-23.0.0/ada/ast.py:8641
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Discriminant_Part (Node => Ent.Node.Task_Type_Decl_F_Discriminants, Info => Ent.Info);
--# expr-done 3774
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3775
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_703;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_703;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Discriminants_List;
--# end
--# property-start TaskTypeDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:8643
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Xref_Entry_Point
  (Node : Bare_Task_Type_Decl
  )
   return Boolean
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Xref_Entry_Point;
--# end
--# property-start TaskTypeDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:8646
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Xref_Equation
  (Node : Bare_Task_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Type_Decl :=
     Internal_Entity_Task_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_705 with Inline_Always;
            procedure Finalizer_Scope_2323 with Inline_Always;
      Var_Expr : Internal_Entity_Task_Def;
Fld : Internal_Entity_Task_Def;
Fld_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_705 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_705;
            procedure Finalizer_Scope_2323 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2323;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3778 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3776 '<FieldAccess for definition at ast.py:8647>' Fld /tmp/lal-23.0.0/ada/ast.py:8647
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Task_Def (Node => Ent.Node.Task_Type_Decl_F_Definition, Info => Ent.Info);
--# expr-done 3776
Var_Expr := Fld;
if Var_Expr /= No_Entity_Task_Def then
   --# scope-start
   --# bind d Var_Expr
--# expr-start 3777 '<FieldAccess for xref_equation at ast.py:8648>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8648
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3777
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2323;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8649") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 3778
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_705;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_705;
               Finalizer_Scope_2323;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Xref_Equation;
--# end
--# property-start TaskTypeDecl.declarative_parts /tmp/lal-23.0.0/ada/ast.py:8653
pragma Warnings (Off, "is not referenced");
 function Task_Type_Decl_P_Declarative_Parts
  (Node : Bare_Task_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Type_Decl :=
     Internal_Entity_Task_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_706 with Inline_Always;
            procedure Finalizer_Scope_2324 with Inline_Always;
            procedure Finalizer_Scope_2325 with Inline_Always;
      Var_Expr : Internal_Entity_Task_Def;
Var_Expr_1 : Internal_Entity_Declarative_Part;
Fld : Internal_Entity_Task_Def;
Fld_1 : Internal_Entity_Public_Part;
Cast_Result : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
Fld_2 : Internal_Entity_Private_Part;
Cast_Result_1 : Internal_Entity_Declarative_Part;
Singleton_1 : Internal_Entity_Declarative_Part_Array_Access;
Scope_Result : Internal_Entity_Declarative_Part_Array_Access;
Result_Var : Internal_Entity_Declarative_Part_Array_Access;
Concat_Result : Internal_Entity_Declarative_Part_Array_Access;
Scope_Result_1 : Internal_Entity_Declarative_Part_Array_Access;
Result_Var_1 : Internal_Entity_Declarative_Part_Array_Access;
Let_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_706 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_706;
            procedure Finalizer_Scope_2324 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_2324;
            procedure Finalizer_Scope_2325 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2325;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3785 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3779 '<FieldAccess for definition at ast.py:8654>' Fld /tmp/lal-23.0.0/ada/ast.py:8654
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Task_Def (Node => Ent.Node.Task_Type_Decl_F_Definition, Info => Ent.Info);
--# expr-done 3779
Var_Expr := Fld;
if Var_Expr /= No_Entity_Task_Def then
   --# scope-start
   --# bind tdef Var_Expr
--# expr-start 3784 '<Concat at ast.py:8656>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:8656
--# expr-start 3781 '<Cast to DeclarativePart at ast.py:8656>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8656
--# expr-start 3780 '<FieldAccess for public_part at ast.py:8656>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8656
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Public_Part (Node => Var_Expr.Node.Task_Def_F_Public_Part, Info => Var_Expr.Info);
--# expr-done 3780
      Cast_Result := Create_Internal_Entity_Declarative_Part
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
--# expr-done 3781
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
--# expr-start 3783 '<Cast to DeclarativePart at ast.py:8657>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:8657
--# expr-start 3782 '<FieldAccess for private_part at ast.py:8657>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8657
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Private_Part (Node => Var_Expr.Node.Task_Def_F_Private_Part, Info => Var_Expr.Info);
--# expr-done 3782
      Cast_Result_1 := Create_Internal_Entity_Declarative_Part
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# expr-done 3783
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Declarative_Part then
   --# scope-start
                Singleton_1 := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton_1.Items (1) := Var_Expr_1;
Scope_Result := Singleton_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2325;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Declarative_Part_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result := Concat (Singleton, Result_Var); 
--# expr-done 3784
Scope_Result_1 := Concat_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2324;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Declarative_Part_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
--# expr-done 3785
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_706;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_706;
               Finalizer_Scope_2324;
               Finalizer_Scope_2325;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Type_Decl_P_Declarative_Parts;
--# end
--# property-start TaskTypeDecl._env_mappings_9 /tmp/lal-23.0.0/ada/ast.py:8635
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_9
  (Node : Bare_Task_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Type_Decl :=
     Internal_Entity_Task_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1478 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Task_Type_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1478 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1478;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3788 '<New EnvAssoc at ast.py:8635>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:8635
--# expr-start 3786 '<New DesignatedEnv at ast.py:8635>' New_Struct /tmp/lal-23.0.0/ada/ast.py:8635
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 3786
--# expr-start 3787 '<FieldAccess for name_symbol at ast.py:8635>' Fld /tmp/lal-23.0.0/ada/ast.py:8635
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 3787
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 3788
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1478;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1478;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_9;
--# end
--# property-start TaskTypeDecl._env_trans_parent_10 /tmp/lal-23.0.0/ada/ast.py:8634
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_10
  (Node : Bare_Task_Type_Decl
  )
   return Boolean
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_10;
--# end
--# property-start TaskTypeDecl._env_names_11 /tmp/lal-23.0.0/ada/ast.py:8636
pragma Warnings (Off, "is not referenced");
 function Env_Names_11
  (Node : Bare_Task_Type_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Task_Type_Decl := Bare_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1480 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1480 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1480;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3789 '<FieldAccess for env_names at ast.py:8636>' Fld /tmp/lal-23.0.0/ada/ast.py:8636
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TaskTypeDecl.env_names
Fld := Libadalang.Implementation.Task_Type_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 3789
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1480;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1480;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_11;
--# end
   --
   --  Primitives for Bare_Single_Task_Type_Decl
   --
      procedure Single_Task_Type_Decl_Pre_Env_Actions
        (Self            : Bare_Single_Task_Type_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_12 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Single_Task_Type_Decl
        (Self : Bare_Single_Task_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Task_Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Task_Type_Decl_F_Aspects : Bare_Aspect_Spec
         ; Task_Type_Decl_F_Definition : Bare_Task_Def
        ) is
      begin
            Initialize_Fields_For_Task_Type_Decl
              (Self, Base_Type_Decl_F_Name, Task_Type_Decl_F_Discriminants, Task_Type_Decl_F_Aspects, Task_Type_Decl_F_Definition);
      end Initialize_Fields_For_Single_Task_Type_Decl;
--# property-start SingleTaskTypeDecl._env_trans_parent_12 /tmp/lal-23.0.0/ada/ast.py:8666
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_12
  (Node : Bare_Single_Task_Type_Decl
  )
   return Boolean
is
   Self : Bare_Single_Task_Type_Decl := Bare_Single_Task_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_12;
--# end
   --
   --  Primitives for Bare_Type_Decl
   --
      procedure Type_Decl_Pre_Env_Actions
        (Self            : Bare_Type_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_3 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:7285");
         Dec_Ref (Mapping.Dest_Env);
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_4 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:7286");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_5 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Type_Decl_Post_Env_Actions
        (Self : Bare_Type_Decl; State : in out PLE_Node_State) is
      begin
      if Libadalang.Implementation.Ref_Cond_8 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_6 (Node => 
Self);
            Env : Lexical_Env :=
              Libadalang.Implementation.Env_Dest_7 (Node => 
Self);
         begin
               if Is_Foreign_Strict (Env, Self) then
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "unsound foreign environment in RefEnvs ("
                     & "ast.py:7289)");
               end if;
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Type_Decl_P_Refined_Parent_Primitives_Env'Access,
               Transitive,
               (Inherited_Primitives => True, others => False),
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Type_Decl
        (Self : Bare_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Type_Decl_F_Type_Def : Bare_Type_Def
        ) is
      begin
            Initialize_Fields_For_Base_Type_Decl
              (Self, Base_Type_Decl_F_Name);
            Self.Type_Decl_F_Discriminants := Type_Decl_F_Discriminants;
            Self.Type_Decl_F_Type_Def := Type_Decl_F_Type_Def;
      Self.Lf_Present_Direct_Primitives_Env := False;
      Self.Lf_Stg_Direct_Primitives_Env := Empty_Env;
      Self.Lf_Present_Direct_Primitive_Subps := False;
      Self.Lf_Stg_Direct_Primitive_Subps := No_Internal_Inner_Env_Assoc_Array_Type;
      end Initialize_Fields_For_Type_Decl;
   function Type_Decl_F_Discriminants
     (Node : Bare_Type_Decl) return Bare_Discriminant_Part
   is
   begin
         return Node.Type_Decl_F_Discriminants;
   end;
   function Type_Decl_F_Type_Def
     (Node : Bare_Type_Decl) return Bare_Type_Def
   is
   begin
         return Node.Type_Decl_F_Type_Def;
   end;
--# property-start TypeDecl.is_iterable_type /tmp/lal-23.0.0/ada/ast.py:7009
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Iterable_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Derived_Type_Def;
Match_1 : Internal_Entity_Type_Def;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Fld : Boolean;
Sym : Symbol_Type;
Fld_1 : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
Sym_1 : Symbol_Type;
Fld_2 : Internal_Entity_Expr;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result_1 : Boolean;
Fld_3 : Internal_Entity_Type_Def;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Derived_Type_Def;
Let_Result : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_1 : Internal_Entity_Type_Def;
Let_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
If_Result_2 : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_1 : Boolean;
If_Result_3 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 3790 '<FieldAccess for is_array at ast.py:7014>' Fld /tmp/lal-23.0.0/ada/ast.py:7014
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_array
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Array (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3790
if Fld then
   If_Result := True;
else
   --# expr-start 3794 '<Not at ast.py:7015>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7015
--# expr-start 3793 '<IsNull at ast.py:7015>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7015
--# expr-start 3792 '<FieldAccess for get_aspect_spec_expr at ast.py:7015>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7015
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3791 '<Symbol Iterator_Element at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterator_Element); 
--# expr-done 3791
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym, E_Info => Ent.Info);
--# end
--# expr-done 3792
Is_Null := Fld_1.Node = null; 
--# expr-done 3793
Not_Val := not (Is_Null); 
--# expr-done 3794
   If_Result := Not_Val;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 3798 '<Not at ast.py:7016>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:7016
--# expr-start 3797 '<IsNull at ast.py:7016>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:7016
--# expr-start 3796 '<FieldAccess for get_aspect_spec_expr at ast.py:7016>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7016
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3795 '<Symbol Iterable at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterable); 
--# expr-done 3795
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym_1, E_Info => Ent.Info);
--# end
--# expr-done 3796
Is_Null_1 := Fld_2.Node = null; 
--# expr-done 3797
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3798
   If_Result_1 := Not_Val_1;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 3802 '<Match at ast.py:7017>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7017
--# expr-start 3799 '<FieldAccess for type_def at ast.py:7017>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7017
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3799
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_3; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind dtd Match_0
--# expr-start 3800 '<FieldAccess for base_type at ast.py:7019>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7019
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 3800
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 3801 '<FieldAccess for is_iterable_type at ast.py:7019>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7019
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 3801
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
Let_Result_1 := False; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3802
   If_Result_2 := Match_Result;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
--# expr-start 3803 '<FieldAccess for previous_part at ast.py:7022>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7022
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Ent.Node, Go_To_Incomplete => False, E_Info => Ent.Info);
--# end
--# expr-done 3803
Var_Expr_1 := Fld_6;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind pp Var_Expr_1
--# expr-start 3804 '<FieldAccess for is_iterable_type at ast.py:7022>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7022
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 3804
Scope_Result_3 := Fld_7;
   --# end
   Result_Var_1 := Scope_Result_3;
else
   Result_Var_1 := False;
end if;
   If_Result_3 := Result_Var_1;
end if;
      Property_Result := If_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Iterable_Type;
--# end
--# property-start TypeDecl.iterable_comp_type /tmp/lal-23.0.0/ada/ast.py:7031
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Iterable_Comp_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_535 with Inline_Always;
            procedure Finalizer_Scope_2330 with Inline_Always;
      Block_Var : Internal_Entity_Expr;
Block_Var_1 : Internal_Entity_Expr;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Name;
Match_0 : Internal_Entity_Derived_Type_Def;
Match_1 : Internal_Entity_Type_Def;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Var_Expr_3 : Internal_Entity_Base_Type_Decl;
Sym : Symbol_Type;
Fld : Internal_Entity_Expr;
Sym_1 : Symbol_Type;
Fld_1 : Internal_Entity_Expr;
Bound_Imprecise_Fallback : Boolean;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_4 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_5 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
Cast_Expr_1 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Aggregate;
Fld_6 : Internal_Entity_Assoc_List;
Fld_7 : Internal_Single_Actual_Array_Access;
Fld_8 : Bare_Base_Id;
Sym_2 : Symbol_Type;
Fld_9 : Boolean;
Find_Result : Internal_Single_Actual;
Fld_10 : Internal_Entity_Basic_Assoc;
Fld_11 : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity_Name;
Fld_12 : Internal_Entity_Basic_Decl;
Fld_13 : Internal_Entity_Base_Type_Decl;
Fld_14 : Internal_Entity_Type_Def;
Fld_15 : Internal_Entity_Base_Type_Decl;
Fld_16 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result_3 : Internal_Entity_Derived_Type_Def;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity_Type_Def;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
If_Result : Internal_Entity_Base_Type_Decl;
If_Result_1 : Internal_Entity_Base_Type_Decl;
If_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Fld_17 : Internal_Entity_Base_Type_Decl;
Fld_18 : Internal_Entity_Base_Type_Decl;
Scope_Result_5 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Result_Var_3 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_535 is
            begin
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_535;
            procedure Finalizer_Scope_2330 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_2330;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3839 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 3806 '<FieldAccess for get_aspect_spec_expr at ast.py:7032>' Fld /tmp/lal-23.0.0/ada/ast.py:7032
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3805 '<Symbol Iterator_Element at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterator_Element); 
--# expr-done 3805
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym, E_Info => Ent.Info);
--# end
--# expr-done 3806
Block_Var := Fld; 
--# bind ie Block_Var
--# expr-start 3808 '<FieldAccess for get_aspect_spec_expr at ast.py:7033>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7033
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3807 '<Symbol Iterable at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Iterable); 
--# expr-done 3807
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym_1, E_Info => Ent.Info);
--# end
--# expr-done 3808
Block_Var_1 := Fld_1; 
--# bind it Block_Var_1
--# expr-start 3838 '<bind at ast.py:7035>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:7035
Bound_Imprecise_Fallback := False; 
--# expr-start 3835 '<Cond at ast.py:7035>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:7035
--# expr-start 3809 '<FieldAccess for is_array at ast.py:7036>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7036
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_array
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Is_Array (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3809
if Fld_2 then
   --# expr-start 3810 '<FieldAccess for comp_type at ast.py:7036>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7036
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.comp_type
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3810
   If_Result_2 := Fld_3;
else
--# expr-start 3812 '<Not at ast.py:7038>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7038
--# expr-start 3811 '<IsNull at ast.py:7038>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7038
Is_Null := Block_Var.Node = null; 
--# expr-done 3811
Not_Val := not (Is_Null); 
--# expr-done 3812
if Not_Val then
--# expr-start 3813 '<Cast to Name at ast.py:7038>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7038
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 3813
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Name then
   --# scope-start
   --# bind name Var_Expr_1
--# expr-start 3816 '<bind at ast.py:7039>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7039
--# expr-start 3814 '<FieldAccess for node_env at ast.py:7039>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7039
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Node_Env (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# expr-done 3814
Bound_Env := Fld_4; Inc_Ref (Bound_Env);
--# expr-start 3815 '<FieldAccess for designated_type_impl at ast.py:7039>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7039
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Var_Expr_1.Node, Env => Bound_Env, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 3815
Dyn_Var_Bind_Result := Fld_5; 
--# expr-done 3816
Scope_Result := Dyn_Var_Bind_Result;
   --# end
      Finalizer_Scope_2330;
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
   If_Result_1 := Result_Var;
else
--# expr-start 3818 '<Not at ast.py:7042>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:7042
--# expr-start 3817 '<IsNull at ast.py:7042>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:7042
Is_Null_1 := Block_Var_1.Node = null; 
--# expr-done 3817
Not_Val_1 := not (Is_Null_1); 
--# expr-done 3818
if Not_Val_1 then
   --# expr-start 3830 '<FieldAccess for expr_type at ast.py:7046>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7046
--# expr-start 3829 '<FieldAccess for referenced_decl at ast.py:7046>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7046
--# expr-start 3828 '<Cast to Name at ast.py:7045>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:7045
--# expr-start 3827 '<FieldAccess for expr at ast.py:7045>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7045
--# expr-start 3826 '<FieldAccess for assoc at ast.py:7045>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7045
--# expr-start 3825 '<Find at ast.py:7043>' Find_Result /tmp/lal-23.0.0/ada/ast.py:7043
   --# expr-start 3821 '<FieldAccess for unpacked_params at ast.py:7043>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7043
--# expr-start 3820 '<FieldAccess for assocs at ast.py:7043>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7043
--# expr-start 3819 '<Cast to Aggregate at ast.py:7043>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7043
Cast_Expr_1 := Block_Var_1; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Aggregate_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Aggregate
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Aggregate;
   end if;
--# expr-done 3819
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Assoc_List (Node => Cast_Result_1.Node.Base_Aggregate_F_Assocs, Info => Cast_Result_1.Info);
--# expr-done 3820
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.unpacked_params
Fld_7 := Libadalang.Implementation.Assoc_List_P_Unpacked_Params (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 3821
      Find_Result := No_Single_Actual;
      declare
         Collection : constant Internal_Single_Actual_Array_Access := Fld_7;
      begin
         for Item_146 of
               Collection.Items
         loop
   --# scope-start
               --# bind sa Item_146
      --# expr-start 3824 '<FieldAccess for name_is at ast.py:7044>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7044
--# expr-start 3822 '<FieldAccess for name at ast.py:7044>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7044
Fld_8 := Item_146.Name;
--# expr-done 3822
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3823 '<Symbol Element at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Element); 
--# expr-done 3823
--# property-call-start Name.name_is
Fld_9 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_8, Sym => Sym_2);
--# end
--# expr-done 3824
      if Fld_9 then
         Find_Result := Item_146;
      end if;
   --# end
               exit when Fld_9;
         end loop;
      end;
--# expr-done 3825
Fld_10 := Find_Result.Assoc;
--# expr-done 3826
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_11 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_10.Node, E_Info => Fld_10.Info);
--# end
--# expr-done 3827
   if Fld_11.Node = null
      or else Fld_11.Node.Kind in Ada_Name
   then
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Fld_11.Node,
         Info => Fld_11.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 3828
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_12 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Cast_Result_2.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 3829
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_13 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Fld_12.Node, Origin => Origin, E_Info => Fld_12.Info);
--# end
--# expr-done 3830
   If_Result := Fld_13;
else
   --# expr-start 3834 '<Match at ast.py:7048>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7048
--# expr-start 3831 '<FieldAccess for type_def at ast.py:7048>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7048
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3831
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_14; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_3; 
--# bind dtd Match_0
--# expr-start 3832 '<FieldAccess for base_type at ast.py:7050>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:7050
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_15 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 3832
Var_Expr_2 := Fld_15;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr_2
--# expr-start 3833 '<FieldAccess for iterable_comp_type at ast.py:7050>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7050
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_16 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => Var_Expr_2.Node, Origin => Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 3833
Scope_Result_1 := Fld_16;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_4; 
--# bind _ Match_1
Let_Result_1 := No_Entity_Base_Type_Decl; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 3834
   If_Result := Match_Result;
end if;
   If_Result_1 := If_Result;
end if;
   If_Result_2 := If_Result_1;
end if;
--# expr-done 3835
Var_Expr := If_Result_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_4 := Var_Expr;
   --# end
   Result_Var_3 := Scope_Result_4;
else
--# expr-start 3836 '<FieldAccess for previous_part at ast.py:7053>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7053
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld_17 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Ent.Node, Go_To_Incomplete => False, E_Info => Ent.Info);
--# end
--# expr-done 3836
Var_Expr_3 := Fld_17;
if Var_Expr_3 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind pp Var_Expr_3
--# expr-start 3837 '<FieldAccess for iterable_comp_type at ast.py:7054>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7054
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_18 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => Var_Expr_3.Node, Origin => Origin, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 3837
Scope_Result_5 := Fld_18;
   --# end
   Result_Var_2 := Scope_Result_5;
else
   Result_Var_2 := No_Entity_Base_Type_Decl;
end if;
   Result_Var_3 := Result_Var_2;
end if;
Dyn_Var_Bind_Result_1 := Result_Var_3; 
--# expr-done 3838
Let_Result_2 := Dyn_Var_Bind_Result_1; 
--# end
--# expr-done 3839
      Property_Result := Let_Result_2;
   --# end
      Finalizer_Scope_535;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_535;
               Finalizer_Scope_2330;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Iterable_Comp_Type;
--# end
--# property-start TypeDecl.discrete_range /tmp/lal-23.0.0/ada/ast.py:7057
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Discrete_Range
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Discrete_Range;
Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3842 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3841 '<FieldAccess for discrete_range at ast.py:7058>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7058
--# expr-start 3840 '<FieldAccess for type_def at ast.py:7058>' Fld /tmp/lal-23.0.0/ada/ast.py:7058
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3840
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.discrete_range'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Discrete_Range (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3841
Let_Result := Fld_1; 
--# end
--# expr-done 3842
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Discrete_Range;
--# end
--# property-start TypeDecl.discriminants_list /tmp/lal-23.0.0/ada/ast.py:7061
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Discriminants_List
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_537 with Inline_Always;
            procedure Finalizer_Scope_2337 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Var_Expr : Internal_Entity_Discriminant_Part;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Discriminant_Part;
Fld_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_3 : Boolean;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Len : Integer;
Comp_Result : Boolean;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
If_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
If_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
If_Result_2 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_537 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_7);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_537;
            procedure Finalizer_Scope_2337 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2337;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3855 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3843 '<FieldAccess for base_type at ast.py:7063>' Fld /tmp/lal-23.0.0/ada/ast.py:7063
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3843
Block_Var := Fld; 
--# bind base_type Block_Var
--# expr-start 3844 '<FieldAccess for discriminants at ast.py:7064>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7064
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Discriminant_Part (Node => Ent.Node.Type_Decl_F_Discriminants, Info => Ent.Info);
--# expr-done 3844
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Discriminant_Part then
   --# scope-start
   --# bind d Var_Expr
--# expr-start 3845 '<FieldAccess for abstract_formal_params at ast.py:7065>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7065
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 3845
Scope_Result := Fld_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2337;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
Block_Var_1 := Result_Var; Inc_Ref (Block_Var_1);
--# bind self_discs Block_Var_1
--# expr-start 3854 '<Cond at ast.py:7068>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:7068
--# expr-start 3846 '<FieldAccess for is_access_type at ast.py:7069>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7069
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3846
if Fld_3 then
   --# expr-start 3848 '<FieldAccess for discriminants_list at ast.py:7070>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7070
--# expr-start 3847 '<FieldAccess for accessed_type at ast.py:7070>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7070
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3847
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Fld_4.Node, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 3848
   If_Result_2 := Fld_5;
else
--# expr-start 3849 '<length at ast.py:7072>' Len /tmp/lal-23.0.0/ada/ast.py:7072
Len := Length (Block_Var_1); 
--# expr-done 3849
Comp_Result := Len > 0; 
if Comp_Result then
   If_Result_1 := Block_Var_1;
else
--# expr-start 3851 '<Not at ast.py:7073>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7073
--# expr-start 3850 '<IsNull at ast.py:7073>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7073
Is_Null := Block_Var.Node = null; 
--# expr-done 3850
Not_Val := not (Is_Null); 
--# expr-done 3851
if Not_Val then
   --# expr-start 3853 '<FieldAccess for discriminants_list at ast.py:7073>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7073
--# expr-start 3852 '<FieldAccess for base_type at ast.py:7073>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7073
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 3852
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Fld_6.Node, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 3853
   If_Result := Fld_7;
else
   If_Result := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
   If_Result_2 := If_Result_1;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 3854
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 3855
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_537;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_537;
               Finalizer_Scope_2337;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Discriminants_List;
--# end
--# property-start TypeDecl.direct_primitives_env /tmp/lal-23.0.0/ada/ast.py:7078
pragma Warnings (Off, "is not referenced");
 function Type_Decl_F_Direct_Primitives_Env
  (Node : Bare_Type_Decl
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_538 with Inline_Always;
      Dyn_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_538 is
            begin
                     Dec_Ref (Dyn_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_538;
begin
   --# property-body-start
      if Self.Lf_Present_Direct_Primitives_Env then
         Property_Result := Self.Lf_Stg_Direct_Primitives_Env;
            Inc_Ref (Property_Result);
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3857 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3856 '<DynamicLexicalEnv at ast.py:7083>' Dyn_Env /tmp/lal-23.0.0/ada/ast.py:7083
Dyn_Env := Create_Dynamic_Lexical_Env (Self, Type_Decl_F_Direct_Primitive_Subps'Access, null, False); 
--# expr-done 3856
Let_Result := Dyn_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 3857
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_538;
      Self.Lf_Present_Direct_Primitives_Env := True;
      Self.Lf_Stg_Direct_Primitives_Env := Property_Result;
         Inc_Ref (Property_Result);
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_538;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_F_Direct_Primitives_Env;
--# end
--# property-start TypeDecl.direct_primitive_subps /tmp/lal-23.0.0/ada/ast.py:7089
pragma Warnings (Off, "is not referenced");
 function Type_Decl_F_Direct_Primitive_Subps
  (Node : Bare_Type_Decl
  )
   return Internal_Inner_Env_Assoc_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_539 with Inline_Always;
            procedure Finalizer_Scope_2339 with Inline_Always;
            procedure Finalizer_Scope_2340 with Inline_Always;
            procedure Finalizer_Scope_2344 with Inline_Always;
            procedure Finalizer_Scope_2345 with Inline_Always;
            procedure Finalizer_Scope_2347 with Inline_Always;
            procedure Finalizer_Scope_2351 with Inline_Always;
            procedure Finalizer_Scope_2354 with Inline_Always;
      Block_Var : Bare_Declarative_Part;
Block_Var_1 : Boolean;
Block_Var_2 : Internal_Entity_Array_Access;
Block_Var_3 : Internal_Inner_Env_Assoc_Array_Access;
Block_Var_4 : Internal_Inner_Env_Assoc_Array_Access;
Block_Var_5 : Internal_Inner_Env_Assoc_Array_Access;
Var_Expr : Internal_Entity;
Var_Expr_1 : Bare_Declarative_Part;
Match_0 : Internal_Entity_Base_Package_Decl;
Match_1 : Internal_Entity;
Var_Expr_2 : Internal_Entity_Private_Part;
Var_Expr_3 : Bare_Declarative_Part;
Var_Expr_4 : Bare_Enum_Type_Def;
Var_Expr_5 : Internal_Entity_Base_Subp_Spec;
Var_Expr_6 : Internal_Entity_Basic_Decl;
Bd : Internal_Entity_Basic_Decl;
Fld : Bare_Declarative_Part;
As_Entity : Internal_Entity_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Type_Decl;
Fld_1 : Boolean;
Fld_2 : Bare_Ada_Node;
Scope_Result : Bare_Ada_Node;
Result_Var : Bare_Ada_Node;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Fld_3 : Internal_Entity_Public_Part;
Fld_4 : Internal_Entity_Ada_Node_List;
Fld_5 : Bare_Ada_Node_List;
Fld_6 : Internal_Entity_Info;
As_Entity_2 : Internal_Entity;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity;
Item_360 : Internal_Entity;
Bare_Item_360 : Bare_Ada_Node;
Map_Result : Internal_Entity_Array_Access;
Fld_7 : Internal_Entity_Private_Part;
Fld_8 : Internal_Entity_Ada_Node_List;
Scope_Result_1 : Internal_Entity_Ada_Node_List;
Result_Var_1 : Internal_Entity_Ada_Node_List;
Fld_9 : Bare_Ada_Node_List;
Fld_10 : Internal_Entity_Info;
As_Entity_3 : Internal_Entity;
Is_Null_3 : Boolean;
If_Result_3 : Internal_Entity;
Item_361 : Internal_Entity;
Bare_Item_361 : Bare_Ada_Node;
Map_Result_1 : Internal_Entity_Array_Access;
Concat_Result : Internal_Entity_Array_Access;
Fld_11 : Bare_Ada_Node;
Fld_12 : Bare_Ada_Node;
Cast_Result : Bare_Declarative_Part;
As_Entity_4 : Internal_Entity_Declarative_Part;
Is_Null_4 : Boolean;
If_Result_4 : Internal_Entity_Declarative_Part;
Fld_13 : Internal_Entity_Ada_Node_List;
Fld_14 : Bare_Ada_Node_List;
Fld_15 : Internal_Entity_Info;
As_Entity_5 : Internal_Entity;
Is_Null_5 : Boolean;
If_Result_5 : Internal_Entity;
Item_362 : Internal_Entity;
Bare_Item_362 : Bare_Ada_Node;
Map_Result_2 : Internal_Entity_Array_Access;
Scope_Result_2 : Internal_Entity_Array_Access;
Result_Var_2 : Internal_Entity_Array_Access;
If_Result_6 : Internal_Entity_Array_Access;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Package_Decl;
Let_Result : Internal_Entity_Array_Access;
Scope_Result_3 : Internal_Entity_Array_Access;
Cast_Result_2 : Internal_Entity;
Let_Result_1 : Internal_Entity_Array_Access;
Scope_Result_4 : Internal_Entity_Array_Access;
Match_Result : Internal_Entity_Array_Access;
Scope_Result_5 : Internal_Entity_Array_Access;
Result_Var_3 : Internal_Entity_Array_Access;
Fld_16 : Bare_Type_Def;
Cast_Result_3 : Bare_Enum_Type_Def;
Fld_17 : Bare_Enum_Literal_Decl_List;
Fld_18 : Bare_Defining_Name;
Fld_19 : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_4 : Bare_Ada_Node;
New_Struct : Internal_Metadata;
Cast_Expr_1 : Bare_Enum_Literal_Decl;
Cast_Result_5 : Bare_Ada_Node;
New_Struct_1 : Internal_Inner_Env_Assoc;
Item_147 : Bare_Enum_Literal_Decl;
Map_Result_3 : Internal_Inner_Env_Assoc_Array_Access;
Scope_Result_6 : Internal_Inner_Env_Assoc_Array_Access;
Result_Var_4 : Internal_Inner_Env_Assoc_Array_Access;
Cast_Expr_2 : Internal_Entity;
Cast_Result_6 : Internal_Entity_Basic_Decl;
Fld_20 : Internal_Entity_Base_Subp_Spec;
Scope_Result_7 : Internal_Entity_Base_Subp_Spec;
Result_Var_5 : Internal_Entity_Base_Subp_Spec;
Fld_21 : Internal_Entity_Base_Type_Decl_Array_Access;
As_Entity_6 : Internal_Entity_Type_Decl;
Is_Null_6 : Boolean;
If_Result_7 : Internal_Entity_Type_Decl;
Cast_Expr_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_7 : Internal_Entity;
Cast_Result_8 : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result : Boolean;
As_Entity_7 : Internal_Entity_Type_Decl;
Is_Null_7 : Boolean;
If_Result_8 : Internal_Entity_Type_Decl;
Fld_22 : Lexical_Env := Empty_Env;
Fld_23 : Internal_Entity_Defining_Name;
Fld_24 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr_4 : Internal_Entity;
Cast_Result_9 : Internal_Entity_Basic_Decl;
Fld_25 : Internal_Entity_Base_Subp_Spec;
Fld_26 : Boolean;
Quantifier_Result_1 : Boolean;
Fld_27 : Bare_Ada_Node;
Is_A : Boolean;
Not_Val : Boolean;
If_Result_9 : Boolean;
If_Result_10 : Boolean;
Scope_Result_8 : Boolean;
Result_Var_6 : Boolean;
Map_Result_4 : Internal_Entity_Array_Access;
Cast_Expr_5 : Internal_Entity;
Cast_Result_10 : Internal_Entity_Basic_Decl;
Fld_28 : Internal_Entity_Defining_Name;
Fld_29 : Symbol_Type;
Fld_30 : Bare_Basic_Decl;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_11 : Bare_Ada_Node;
New_Struct_2 : Internal_Metadata;
Cast_Result_12 : Bare_Ada_Node;
New_Struct_3 : Internal_Inner_Env_Assoc;
Singleton : Internal_Inner_Env_Assoc_Array_Access;
Sym : Symbol_Type;
Fld_31 : Bare_Basic_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_13 : Bare_Ada_Node;
New_Struct_4 : Internal_Metadata;
Cast_Result_14 : Bare_Ada_Node;
New_Struct_5 : Internal_Inner_Env_Assoc;
Singleton_1 : Internal_Inner_Env_Assoc_Array_Access;
Fld_32 : Internal_Entity_Defining_Name;
Sym_1 : Symbol_Type;
Fld_33 : Boolean;
If_Result_11 : Internal_Inner_Env_Assoc_Array_Access;
Concat_Result_1 : Internal_Inner_Env_Assoc_Array_Access;
Let_Result_2 : Internal_Inner_Env_Assoc_Array_Access;
Map_Result_5 : Internal_Inner_Env_Assoc_Array_Access;
Fld_34 : Internal_Env_Assoc_Array_Access;
Fld_35 : Symbol_Type;
Fld_36 : Bare_Ada_Node;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_15 : Bare_Ada_Node;
New_Struct_6 : Internal_Metadata;
New_Struct_7 : Internal_Inner_Env_Assoc;
Map_Result_6 : Internal_Inner_Env_Assoc_Array_Access;
Concat_Result_2 : Internal_Inner_Env_Assoc_Array_Access;
Concat_Result_3 : Internal_Inner_Env_Assoc_Array_Access;
Let_Result_3 : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_539 is
            begin
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Result_Var_4);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Map_Result_4);
                     Dec_Ref (Map_Result_5);
                     Dec_Ref (Block_Var_4);
                     Dec_Ref (Fld_34);
                     Dec_Ref (Map_Result_6);
                     Dec_Ref (Block_Var_5);
                     Dec_Ref (Concat_Result_2);
                     Dec_Ref (Concat_Result_3);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_539;
            procedure Finalizer_Scope_2339 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_2339;
            procedure Finalizer_Scope_2340 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_2340;
            procedure Finalizer_Scope_2344 is
            begin
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (If_Result_6);
            end Finalizer_Scope_2344;
            procedure Finalizer_Scope_2345 is
            begin
                     Dec_Ref (Map_Result_2);
            end Finalizer_Scope_2345;
            procedure Finalizer_Scope_2347 is
            begin
                     Dec_Ref (Map_Result_3);
            end Finalizer_Scope_2347;
            procedure Finalizer_Scope_2351 is
            begin
                     Dec_Ref (Fld_21);
                     Dec_Ref (Fld_22);
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_2351;
            procedure Finalizer_Scope_2354 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Singleton_1);
                     Dec_Ref (If_Result_11);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_2354;
begin
   --# property-body-start
      if Self.Lf_Present_Direct_Primitive_Subps then
         Property_Result := Self.Lf_Stg_Direct_Primitive_Subps;
            Inc_Ref (Property_Result);
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3931 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 3858 '<FieldAccess for declarative_scope at ast.py:7095>' Fld /tmp/lal-23.0.0/ada/ast.py:7095
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Self);
--# end
--# expr-done 3858
Block_Var := Fld; 
--# bind scope Block_Var
--# expr-start 3860 '<FieldAccess for is_derived_tagged_type at ast.py:7096>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7096
--# expr-start 3859 '<as_bare_entity at ast.py:7096>' If_Result /tmp/lal-23.0.0/ada/ast.py:7096
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Type_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 3859
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.is_derived_tagged_type
Fld_1 := Libadalang.Implementation.Type_Decl_P_Is_Derived_Tagged_Type (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 3860
Block_Var_1 := Fld_1; 
--# bind is_derived_tagged Block_Var_1
--# expr-start 3862 '<as_bare_entity at ast.py:7097>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:7097
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 3861 '<parent at ast.py:7097>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7097
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr_1.Parent; 
--# expr-done 3861
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_Null_1 := Result_Var = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
As_Entity_1 := (Info => No_Entity_Info, Node => Result_Var); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 3862
Var_Expr := If_Result_1;
if Var_Expr /= No_Entity then
   --# scope-start
--# expr-start 3877 '<Match at ast.py:7097>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7097
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Generic_Package_Internal .. Ada_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Base_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind pkg_decl Match_0
--# expr-start 3869 '<Concat at ast.py:7101>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:7101
--# expr-start 3865 '<TakeWhile at ???>' Map_Result None
   --# expr-start 3864 '<FieldAccess for decls at ast.py:7101>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7101
--# expr-start 3863 '<FieldAccess for public_part at ast.py:7101>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7101
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Public_Part (Node => Match_0.Node.Base_Package_Decl_F_Public_Part, Info => Match_0.Info);
--# expr-done 3863
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Ada_Node_List (Node => Fld_3.Node.Declarative_Part_F_Decls, Info => Fld_3.Info);
--# expr-done 3864
Fld_5 := Fld_4.Node;
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      if Fld_5 = null then
      Map_Result := Create_Internal_Entity_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_5;
      begin
         for Untyped_Item_360 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_360 := Untyped_Item_360; 
Is_Null_2 := Bare_Item_360 = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity;
else
Fld_6 := Fld_4.Info;
As_Entity_2 := (Info => Fld_6, Node => Bare_Item_360); 
   If_Result_2 := As_Entity_2;
end if;
                  Item_360 := If_Result_2; 
   --# scope-start
         declare
            Item_To_Append : constant Internal_Entity := Item_360;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 3865
--# expr-start 3868 '<TakeWhile at ???>' Map_Result_1 None
--# expr-start 3866 '<FieldAccess for private_part at ast.py:7102>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7102
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Private_Part (Node => Match_0.Node.Base_Package_Decl_F_Private_Part, Info => Match_0.Info);
--# expr-done 3866
Var_Expr_2 := Fld_7;
if Var_Expr_2 /= No_Entity_Private_Part then
   --# scope-start
--# expr-start 3867 '<FieldAccess for decls at ast.py:7102>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7102
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Ada_Node_List (Node => Var_Expr_2.Node.Declarative_Part_F_Decls, Info => Var_Expr_2.Info);
--# expr-done 3867
Scope_Result_1 := Fld_8;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Ada_Node_List;
end if;
Fld_9 := Result_Var_1.Node;
      declare
         Map_Result_1_Vec : Internal_Entity_Vectors.Vector;
      begin
      if Fld_9 = null then
      Map_Result_1 := Create_Internal_Entity_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_9;
      begin
         for Untyped_Item_361 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_361 := Untyped_Item_361; 
Is_Null_3 := Bare_Item_361 = null; 
if Is_Null_3 then
   If_Result_3 := No_Entity;
else
Fld_10 := Result_Var_1.Info;
As_Entity_3 := (Info => Fld_10, Node => Bare_Item_361); 
   If_Result_3 := As_Entity_3;
end if;
                  Item_361 := If_Result_3; 
   --# scope-start
         declare
            Item_To_Append : constant Internal_Entity := Item_361;
         begin
            Internal_Entity_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 3868
Concat_Result := Concat (Map_Result, Map_Result_1); 
--# expr-done 3869
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
Scope_Result_3 := Let_Result;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2340;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Synthetic_Formal_Param_Decl | Ada_Discrete_Base_Subtype_Decl .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind _ Match_1
--# expr-start 3876 '<If at ast.py:7108>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:7108
if Block_Var_1 then
--# expr-start 3872 '<Cast to DeclarativePart at ast.py:7110>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7110
--# expr-start 3871 '<parent at ast.py:7110>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7110
--# expr-start 3870 '<parent at ast.py:7110>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7110
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Self.Parent; 
--# expr-done 3870
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Fld_11.Parent; 
--# expr-done 3871
   if Fld_12 = null
      or else Fld_12.Kind in Ada_Declarative_Part_Range
   then
      Cast_Result := Fld_12;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 3872
Var_Expr_3 := Cast_Result;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind dp Var_Expr_3
--# expr-start 3875 '<TakeWhile at ???>' Map_Result_2 None
   --# expr-start 3874 '<FieldAccess for decls at ast.py:7111>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7111
--# expr-start 3873 '<as_bare_entity at ast.py:7111>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:7111
Is_Null_4 := Var_Expr_3 = null; 
if Is_Null_4 then
   If_Result_4 := No_Entity_Declarative_Part;
else
As_Entity_4 := (Info => No_Entity_Info, Node => Var_Expr_3); 
   If_Result_4 := As_Entity_4;
end if;
--# expr-done 3873
      if If_Result_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Ada_Node_List (Node => If_Result_4.Node.Declarative_Part_F_Decls, Info => If_Result_4.Info);
--# expr-done 3874
Fld_14 := Fld_13.Node;
      declare
         Map_Result_2_Vec : Internal_Entity_Vectors.Vector;
      begin
      if Fld_14 = null then
      Map_Result_2 := Create_Internal_Entity_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_14;
      begin
         for Untyped_Item_362 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_362 := Untyped_Item_362; 
Is_Null_5 := Bare_Item_362 = null; 
if Is_Null_5 then
   If_Result_5 := No_Entity;
else
Fld_15 := Fld_13.Info;
As_Entity_5 := (Info => Fld_15, Node => Bare_Item_362); 
   If_Result_5 := As_Entity_5;
end if;
                  Item_362 := If_Result_5; 
   --# scope-start
         declare
            Item_To_Append : constant Internal_Entity := Item_362;
         begin
            Internal_Entity_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result_2 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 3875
Scope_Result_2 := Map_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2345;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var_2);
   If_Result_6 := Result_Var_2;
else
   If_Result_6 := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 3876
Let_Result_1 := If_Result_6; Inc_Ref (Let_Result_1);
--# end
Scope_Result_4 := Let_Result_1;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2344;
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
end case;
--# expr-done 3877
Scope_Result_5 := Match_Result;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2339;
   Result_Var_3 := Scope_Result_5;
else
   Result_Var_3 := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
Block_Var_2 := Result_Var_3; Inc_Ref (Block_Var_2);
--# bind decl_parts Block_Var_2
--# expr-start 3879 '<Cast to EnumTypeDef at ast.py:7116>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:7116
--# expr-start 3878 '<FieldAccess for type_def at ast.py:7116>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7116
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Self.Type_Decl_F_Type_Def;
--# expr-done 3878
   if Fld_16 = null
      or else Fld_16.Kind in Ada_Enum_Type_Def_Range
   then
      Cast_Result_3 := Fld_16;
   else
         Cast_Result_3 := No_Bare_Ada_Node;
   end if;
--# expr-done 3879
Var_Expr_4 := Cast_Result_3;
if Var_Expr_4 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind etf Var_Expr_4
--# expr-start 3885 '<Map at ast.py:7117>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:7117
   --# expr-start 3880 '<FieldAccess for enum_literals at ast.py:7117>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7117
      if Var_Expr_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Var_Expr_4.Enum_Type_Def_F_Enum_Literals;
--# expr-done 3880
      declare
         Map_Result_3_Vec : Internal_Inner_Env_Assoc_Vectors.Vector;
      begin
      if Fld_17 = null then
      Map_Result_3 := Create_Internal_Inner_Env_Assoc_Array (0);
      else
      declare
         Collection : constant Bare_Enum_Literal_Decl_List := Fld_17;
      begin
         for Untyped_Item_147 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_147 := Untyped_Item_147; 
   --# scope-start
               --# bind lit Item_147
      --# expr-start 3884 '<New InnerEnvAssoc at ast.py:7118>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:7118
--# expr-start 3882 '<FieldAccess for name_symbol at ast.py:7119>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:7119
--# expr-start 3881 '<FieldAccess for name at ast.py:7119>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7119
      if Item_147 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Item_147.Enum_Literal_Decl_F_Name;
--# expr-done 3881
      if Fld_18 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_19 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_18);
--# end
--# expr-done 3882
--# expr-start 3883 '<New Metadata at ast.py:7121>' New_Struct /tmp/lal-23.0.0/ada/ast.py:7121
Cast_Expr := Self; 
      Cast_Result_4 := Cast_Expr;
New_Struct := (Dottable_Subp => False, Primitive => Cast_Result_4, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 3883
Cast_Expr_1 := Item_147; 
      Cast_Result_5 := Cast_Expr_1;
New_Struct_1 := (Key => Fld_19, Metadata => New_Struct, Value => Cast_Result_5); 
--# expr-done 3884
         declare
            Item_To_Append : constant Internal_Inner_Env_Assoc := New_Struct_1;
         begin
            Internal_Inner_Env_Assoc_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result_3 := Create_Internal_Inner_Env_Assoc_Array
           (Items_Count => Natural (Internal_Inner_Env_Assoc_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Internal_Inner_Env_Assoc_Vectors.Get
              (Map_Result_3_Vec,
               I + Internal_Inner_Env_Assoc_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Internal_Inner_Env_Assoc_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 3885
Scope_Result_6 := Map_Result_3;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_2347;
   Result_Var_4 := Scope_Result_6;
else
   Result_Var_4 := No_Internal_Inner_Env_Assoc_Array_Type;
end if;
      Inc_Ref (Result_Var_4);
Block_Var_3 := Result_Var_4; Inc_Ref (Block_Var_3);
--# bind enum_lits Block_Var_3
--# expr-start 3922 '<Mapcat at ast.py:7148>' Map_Result_5 /tmp/lal-23.0.0/ada/ast.py:7148
   --# expr-start 3905 '<Filter at ast.py:7125>' Map_Result_4 /tmp/lal-23.0.0/ada/ast.py:7125
      declare
         Map_Result_4_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var_2;
      begin
         for Item_149 of
               Collection.Items
         loop
   --# scope-start
               --# bind decl Item_149
--# expr-start 3886 '<Cast to BasicDecl at ast.py:7126>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:7126
Cast_Expr_2 := Item_149; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_6 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_6 := No_Entity_Basic_Decl;
   end if;
--# expr-done 3886
Var_Expr_6 := Cast_Result_6;
if Var_Expr_6 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 3887 '<FieldAccess for subp_spec_or_null at ast.py:7126>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:7126
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_20 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 3887
Scope_Result_7 := Fld_20;
   --# end
   Result_Var_5 := Scope_Result_7;
else
   Result_Var_5 := No_Entity_Base_Subp_Spec;
end if;
Var_Expr_5 := Result_Var_5;
if Var_Expr_5 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr_5
--# expr-start 3891 '<Contains at ast.py:7127>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:7127
   --# expr-start 3888 '<FieldAccess for candidate_primitive_subp_types at ast.py:7127>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:7127
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.candidate_primitive_subp_types
Fld_21 := Libadalang.Implementation.Base_Subp_Spec_P_Candidate_Primitive_Subp_Types (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 3888
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_21;
      begin
         for Item_150 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_150
      --# expr-start 3890 '<Eq at ???>' Is_Equiv None
Cast_Expr_3 := Item_150; 
      Cast_Result_7 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
--# expr-start 3889 '<as_bare_entity at ast.py:7128>' If_Result_7 /tmp/lal-23.0.0/ada/ast.py:7128
Is_Null_6 := Self = null; 
if Is_Null_6 then
   If_Result_7 := No_Entity_Type_Decl;
else
As_Entity_6 := (Info => No_Entity_Info, Node => Self); 
   If_Result_7 := As_Entity_6;
end if;
--# expr-done 3889
      Cast_Result_8 := Create_Internal_Entity
        (Node => If_Result_7.Node,
         Info => If_Result_7.Info);
Is_Equiv := Equivalent (Cast_Result_7, Cast_Result_8); 
--# expr-done 3890
      Quantifier_Result := Is_Equiv;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 3891
if Quantifier_Result then
   --# expr-start 3904 '<If at ast.py:7129>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:7129
--# expr-start 3894 '<Not at ast.py:7136>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7136
--# expr-start 3893 '<IsA BasePackageDecl at ast.py:7136>' Is_A /tmp/lal-23.0.0/ada/ast.py:7136
--# expr-start 3892 '<parent at ast.py:7136>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:7136
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Block_Var.Parent; 
--# expr-done 3892
Is_A := Fld_27 /= null 
and then Fld_27.Kind in Ada_Base_Package_Decl; 
--# expr-done 3893
Not_Val := not (Is_A); 
--# expr-done 3894
if Not_Val then
   --# expr-start 3903 '<AnyQuantifier at ast.py:7139>' Quantifier_Result_1 /tmp/lal-23.0.0/ada/ast.py:7139
   --# expr-start 3899 '<EnvGet at ast.py:7137>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:7137
--# expr-start 3896 '<FieldAccess for parent_primitives_env at ast.py:7137>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:7137
--# expr-start 3895 '<as_bare_entity at ast.py:7137>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:7137
Is_Null_7 := Self = null; 
if Is_Null_7 then
   If_Result_8 := No_Entity_Type_Decl;
else
As_Entity_7 := (Info => No_Entity_Info, Node => Self); 
   If_Result_8 := As_Entity_7;
end if;
--# expr-done 3895
      if If_Result_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.parent_primitives_env
Fld_22 := Libadalang.Implementation.Type_Decl_P_Parent_Primitives_Env (Node => If_Result_8.Node, E_Info => If_Result_8.Info);
--# end
--# expr-done 3896
--# expr-start 3898 '<FieldAccess for name_symbol at ast.py:7138>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:7138
--# expr-start 3897 '<FieldAccess for name at ast.py:7138>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:7138
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_23 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 3897
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_24 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_23.Node);
--# end
--# expr-done 3898
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_22, Key => Fld_24, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 3899
      Quantifier_Result_1 := False;
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_151 of
               Collection.Items
         loop
   --# scope-start
               --# bind x Item_151
      --# expr-start 3902 '<FieldAccess for match_signature at ast.py:7141>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:7141
--# expr-start 3901 '<FieldAccess for subp_spec_or_null at ast.py:7141>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:7141
--# expr-start 3900 '<Cast to BasicDecl at ast.py:7141>' Cast_Result_9 /tmp/lal-23.0.0/ada/ast.py:7141
Cast_Expr_4 := Item_151; 
   if Cast_Expr_4.Node = null
      or else Cast_Expr_4.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_9 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_4.Node,
         Info => Cast_Expr_4.Info);
   else
         Cast_Result_9 := No_Entity_Basic_Decl;
   end if;
--# expr-done 3900
      if Cast_Result_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_25 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result_9.Node, E_Info => Cast_Result_9.Info);
--# end
--# expr-done 3901
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.match_signature
Fld_26 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld_25.Node, Other => Var_Expr_5, Match_Name => False, Use_Entity_Info => True, E_Info => Fld_25.Info);
--# end
--# expr-done 3902
      Quantifier_Result_1 := Fld_26;
   --# end
               exit when Quantifier_Result_1;
         end loop;
      end;
--# expr-done 3903
   If_Result_9 := Quantifier_Result_1;
else
   If_Result_9 := True;
end if;
--# expr-done 3904
   If_Result_10 := If_Result_9;
else
   If_Result_10 := False;
end if;
Scope_Result_8 := If_Result_10;
   --# end
      Finalizer_Scope_2351;
   Result_Var_6 := Scope_Result_8;
else
   Result_Var_6 := False;
end if;
         if Result_Var_6 then
         declare
            Item_To_Append : constant Internal_Entity := Item_149;
         begin
            Internal_Entity_Vectors.Append (Map_Result_4_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_4 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_4_Vec)));
         for I in Map_Result_4.Items'Range loop
            Map_Result_4.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_4_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_4.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_4_Vec);
      end;
--# expr-done 3905
      declare
         Map_Result_5_Vec : Internal_Inner_Env_Assoc_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result_4;
      begin
         for Item_148 of
               Collection.Items
         loop
   --# scope-start
               --# bind decl Item_148
      --# expr-start 3921 '<Let at ast.py:7149>' Let_Result_2 /tmp/lal-23.0.0/ada/ast.py:7149
--# scope-start
--# expr-start 3906 '<Cast to BasicDecl at ast.py:7150>' Cast_Result_10 /tmp/lal-23.0.0/ada/ast.py:7150
Cast_Expr_5 := Item_148; 
   if Cast_Expr_5.Node = null
      or else Cast_Expr_5.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_10 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_5.Node,
         Info => Cast_Expr_5.Info);
   else
         Cast_Result_10 := No_Entity_Basic_Decl;
   end if;
--# expr-done 3906
Bd := Cast_Result_10; 
--# bind bd Bd
--# expr-start 3920 '<Concat at ast.py:7154>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:7154
--# expr-start 3911 '<New InnerEnvAssoc at ast.py:7150>' New_Struct_3 /tmp/lal-23.0.0/ada/ast.py:7150
--# expr-start 3908 '<FieldAccess for name_symbol at ast.py:7151>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:7151
--# expr-start 3907 '<FieldAccess for defining_name at ast.py:7151>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:7151
      if Bd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_28 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Bd.Node, E_Info => Bd.Info);
--# end
--# expr-done 3907
      if Fld_28.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_29 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_28.Node);
--# end
--# expr-done 3908
--# expr-start 3909 '<New Metadata at ast.py:7153>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:7153
Cast_Expr_6 := Self; 
      Cast_Result_11 := Cast_Expr_6;
New_Struct_2 := (Dottable_Subp => False, Primitive => Cast_Result_11, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 3909
--# expr-start 3910 '<FieldAccess for node at ast.py:7152>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:7152
Fld_30 := Bd.Node;
--# expr-done 3910
      Cast_Result_12 := Fld_30;
New_Struct_3 := (Key => Fld_29, Metadata => New_Struct_2, Value => Cast_Result_12); 
--# expr-done 3911
                Singleton := Create_Internal_Inner_Env_Assoc_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct_3;
--# expr-start 3919 '<If at ast.py:7154>' If_Result_11 /tmp/lal-23.0.0/ada/ast.py:7154
--# expr-start 3914 '<FieldAccess for name_is at ast.py:7155>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:7155
--# expr-start 3912 '<FieldAccess for defining_name at ast.py:7155>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:7155
      if Bd.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_32 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Bd.Node, E_Info => Bd.Info);
--# end
--# expr-done 3912
      if Fld_32.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 3913 '<Symbol "=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 3913
--# property-call-start Name.name_is
Fld_33 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_32.Node, Sym => Sym_1);
--# end
--# expr-done 3914
if Fld_33 then
   --# expr-start 3918 '<New InnerEnvAssoc at ast.py:7156>' New_Struct_5 /tmp/lal-23.0.0/ada/ast.py:7156
--# expr-start 3915 '<Symbol "/=" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 3915
--# expr-start 3916 '<New Metadata at ast.py:7159>' New_Struct_4 /tmp/lal-23.0.0/ada/ast.py:7159
Cast_Expr_7 := Self; 
      Cast_Result_13 := Cast_Expr_7;
New_Struct_4 := (Dottable_Subp => False, Primitive => Cast_Result_13, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 3916
--# expr-start 3917 '<FieldAccess for node at ast.py:7158>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:7158
Fld_31 := Bd.Node;
--# expr-done 3917
      Cast_Result_14 := Fld_31;
New_Struct_5 := (Key => Sym, Metadata => New_Struct_4, Value => Cast_Result_14); 
--# expr-done 3918
                Singleton_1 := Create_Internal_Inner_Env_Assoc_Array (Items_Count => 1);
                Singleton_1.Items (1) := New_Struct_5;
   If_Result_11 := Singleton_1;
else
   If_Result_11 := No_Internal_Inner_Env_Assoc_Array_Type;
end if;
      Inc_Ref (If_Result_11);
--# expr-done 3919
Concat_Result_1 := Concat (Singleton, If_Result_11); 
--# expr-done 3920
Let_Result_2 := Concat_Result_1; Inc_Ref (Let_Result_2);
--# end
--# expr-done 3921
         for Item_To_Append of
               Let_Result_2.Items
         loop
            Internal_Inner_Env_Assoc_Vectors.Append (Map_Result_5_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2354;
         end loop;
      end;
         Map_Result_5 := Create_Internal_Inner_Env_Assoc_Array
           (Items_Count => Natural (Internal_Inner_Env_Assoc_Vectors.Length (Map_Result_5_Vec)));
         for I in Map_Result_5.Items'Range loop
            Map_Result_5.Items (I) := Internal_Inner_Env_Assoc_Vectors.Get
              (Map_Result_5_Vec,
               I + Internal_Inner_Env_Assoc_Vectors.Index_Type'First - Map_Result_5.Items'First);
         end loop;
         Internal_Inner_Env_Assoc_Vectors.Destroy (Map_Result_5_Vec);
      end;
--# expr-done 3922
Block_Var_4 := Map_Result_5; Inc_Ref (Block_Var_4);
--# bind prim_subps Block_Var_4
--# expr-start 3928 '<Map at ast.py:7167>' Map_Result_6 /tmp/lal-23.0.0/ada/ast.py:7167
   --# expr-start 3923 '<FieldAccess for predefined_operators at ast.py:7167>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:7167
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.predefined_operators
Fld_34 := Libadalang.Implementation.Type_Decl_P_Predefined_Operators (Node => Self);
--# end
--# expr-done 3923
      declare
         Map_Result_6_Vec : Internal_Inner_Env_Assoc_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Env_Assoc_Array_Access := Fld_34;
      begin
         for Item_152 of
               Collection.Items
         loop
   --# scope-start
               --# bind assoc Item_152
      --# expr-start 3927 '<New InnerEnvAssoc at ast.py:7168>' New_Struct_7 /tmp/lal-23.0.0/ada/ast.py:7168
--# expr-start 3924 '<FieldAccess for key at ast.py:7169>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:7169
Fld_35 := Item_152.Key;
--# expr-done 3924
--# expr-start 3925 '<New Metadata at ast.py:7171>' New_Struct_6 /tmp/lal-23.0.0/ada/ast.py:7171
Cast_Expr_8 := Self; 
      Cast_Result_15 := Cast_Expr_8;
New_Struct_6 := (Dottable_Subp => False, Primitive => Cast_Result_15, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 3925
--# expr-start 3926 '<FieldAccess for value at ast.py:7170>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:7170
Fld_36 := Item_152.Value;
--# expr-done 3926
New_Struct_7 := (Key => Fld_35, Metadata => New_Struct_6, Value => Fld_36); 
--# expr-done 3927
         declare
            Item_To_Append : constant Internal_Inner_Env_Assoc := New_Struct_7;
         begin
            Internal_Inner_Env_Assoc_Vectors.Append (Map_Result_6_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_6 := Create_Internal_Inner_Env_Assoc_Array
           (Items_Count => Natural (Internal_Inner_Env_Assoc_Vectors.Length (Map_Result_6_Vec)));
         for I in Map_Result_6.Items'Range loop
            Map_Result_6.Items (I) := Internal_Inner_Env_Assoc_Vectors.Get
              (Map_Result_6_Vec,
               I + Internal_Inner_Env_Assoc_Vectors.Index_Type'First - Map_Result_6.Items'First);
         end loop;
         Internal_Inner_Env_Assoc_Vectors.Destroy (Map_Result_6_Vec);
      end;
--# expr-done 3928
Block_Var_5 := Map_Result_6; Inc_Ref (Block_Var_5);
--# bind predefined_ops Block_Var_5
--# expr-start 3930 '<Concat at ast.py:7175>' Concat_Result_3 /tmp/lal-23.0.0/ada/ast.py:7175
--# expr-start 3929 '<Concat at ast.py:7175>' Concat_Result_2 /tmp/lal-23.0.0/ada/ast.py:7175
Concat_Result_2 := Concat (Block_Var_3, Block_Var_4); 
--# expr-done 3929
Concat_Result_3 := Concat (Concat_Result_2, Block_Var_5); 
--# expr-done 3930
Let_Result_3 := Concat_Result_3; Inc_Ref (Let_Result_3);
--# end
--# expr-done 3931
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_539;
      Self.Lf_Present_Direct_Primitive_Subps := True;
      Self.Lf_Stg_Direct_Primitive_Subps := Property_Result;
         Inc_Ref (Property_Result);
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_539;
               Finalizer_Scope_2339;
               Finalizer_Scope_2340;
               Finalizer_Scope_2344;
               Finalizer_Scope_2345;
               Finalizer_Scope_2347;
               Finalizer_Scope_2351;
               Finalizer_Scope_2354;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_F_Direct_Primitive_Subps;
--# end
--# property-start TypeDecl.array_ndims /tmp/lal-23.0.0/ada/ast.py:7177
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Array_Ndims
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Integer;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3933 '<FieldAccess for array_ndims at ast.py:7177>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7177
--# expr-start 3932 '<FieldAccess for type_def at ast.py:7177>' Fld /tmp/lal-23.0.0/ada/ast.py:7177
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3932
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3933
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Array_Ndims;
--# end
--# property-start TypeDecl.is_real_type /tmp/lal-23.0.0/ada/ast.py:7179
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Real_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3935 '<FieldAccess for is_real_type at ast.py:7179>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7179
--# expr-start 3934 '<FieldAccess for type_def at ast.py:7179>' Fld /tmp/lal-23.0.0/ada/ast.py:7179
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3934
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.is_real_type
Fld_1 := Libadalang.Implementation.Type_Def_P_Is_Real_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3935
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Real_Type;
--# end
--# property-start TypeDecl.is_float_type /tmp/lal-23.0.0/ada/ast.py:7180
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Float_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3937 '<FieldAccess for is_float_type at ast.py:7180>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7180
--# expr-start 3936 '<FieldAccess for type_def at ast.py:7180>' Fld /tmp/lal-23.0.0/ada/ast.py:7180
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3936
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_float_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Float_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3937
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Float_Type;
--# end
--# property-start TypeDecl.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:7181
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Fixed_Point
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3939 '<FieldAccess for is_fixed_point at ast.py:7181>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7181
--# expr-start 3938 '<FieldAccess for type_def at ast.py:7181>' Fld /tmp/lal-23.0.0/ada/ast.py:7181
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3938
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_fixed_point'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Fixed_Point (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3939
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Fixed_Point;
--# end
--# property-start TypeDecl.is_int_type /tmp/lal-23.0.0/ada/ast.py:7182
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Int_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3941 '<FieldAccess for is_int_type at ast.py:7182>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7182
--# expr-start 3940 '<FieldAccess for type_def at ast.py:7182>' Fld /tmp/lal-23.0.0/ada/ast.py:7182
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3940
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_int_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Int_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3941
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Int_Type;
--# end
--# property-start TypeDecl.is_access_type /tmp/lal-23.0.0/ada/ast.py:7183
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Access_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      As_Entity : Internal_Entity_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Type_Decl;
Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3944 '<FieldAccess for is_access_type at ast.py:7183>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7183
--# expr-start 3943 '<FieldAccess for type_def at ast.py:7183>' Fld /tmp/lal-23.0.0/ada/ast.py:7183
--# expr-start 3942 '<as_bare_entity at ast.py:7183>' If_Result /tmp/lal-23.0.0/ada/ast.py:7183
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Type_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 3942
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => If_Result.Node.Type_Decl_F_Type_Def, Info => If_Result.Info);
--# expr-done 3943
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_access_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Access_Type (Node => Fld.Node, Origin => Origin);
--# end
--# expr-done 3944
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Access_Type;
--# end
--# property-start TypeDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:7184
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Static_Decl
  (Node : Bare_Type_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      As_Entity : Internal_Entity_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Type_Decl;
Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3947 '<FieldAccess for is_static at ast.py:7184>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7184
--# expr-start 3946 '<FieldAccess for type_def at ast.py:7184>' Fld /tmp/lal-23.0.0/ada/ast.py:7184
--# expr-start 3945 '<as_bare_entity at ast.py:7184>' If_Result /tmp/lal-23.0.0/ada/ast.py:7184
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Type_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 3945
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => If_Result.Node.Type_Decl_F_Type_Def, Info => If_Result.Info);
--# expr-done 3946
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_static'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Static (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 3947
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Static_Decl;
--# end
--# property-start TypeDecl.accessed_type /tmp/lal-23.0.0/ada/ast.py:7187
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Accessed_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_547 with Inline_Always;
      Block_Var : Internal_Entity_Expr;
Fld : Internal_Entity_Expr;
Fld_1 : Internal_Entity_Type_Def;
Fld_2 : Internal_Entity_Base_Type_Decl;
Bound_Include_Ud_Indexing : Boolean;
Fld_3 : Internal_Entity_Type_Def;
Fld_4 : Lexical_Env := Empty_Env;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_5 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Dyn_Var_Bind_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_547 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_547;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3962 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3948 '<FieldAccess for get_imp_deref at ast.py:7188>' Fld /tmp/lal-23.0.0/ada/ast.py:7188
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3948
Block_Var := Fld; 
--# bind imp_deref Block_Var
--# expr-start 3961 '<If at ast.py:7190>' If_Result /tmp/lal-23.0.0/ada/ast.py:7190
--# expr-start 3949 '<IsNull at ast.py:7191>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7191
Is_Null := Block_Var.Node = null; 
--# expr-done 3949
if Is_Null then
   --# expr-start 3951 '<FieldAccess for accessed_type at ast.py:7192>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7192
--# expr-start 3950 '<FieldAccess for type_def at ast.py:7192>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7192
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3950
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.accessed_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Def_P_Accessed_Type (Node => Fld_1.Node, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 3951
   If_Result := Fld_2;
else
   --# expr-start 3960 '<FieldAccess for accessed_type at ast.py:7206>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7206
--# expr-start 3959 '<FieldAccess for formal_type at ast.py:7206>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7206
--# expr-start 3958 '<Cast to BaseFormalParamDecl at ast.py:7206>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7206
--# expr-start 3957 '<bind at ast.py:7196>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7196
Bound_Include_Ud_Indexing := False; 
--# expr-start 3956 '<EnvGet at ast.py:7198>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:7198
--# expr-start 3953 '<FieldAccess for defining_env at ast.py:7198>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7198
--# expr-start 3952 '<FieldAccess for type_def at ast.py:7198>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7198
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3952
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.defining_env
Fld_4 := Libadalang.Implementation.Type_Def_P_Defining_Env (Node => Fld_3.Node, Origin => Origin, Include_Ud_Indexing => Bound_Include_Ud_Indexing, Dottable_Type => No_Bare_Ada_Node, E_Info => Fld_3.Info);
--# end
--# expr-done 3953
--# expr-start 3955 '<FieldAccess for name_symbol at ast.py:7199>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7199
--# expr-start 3954 '<Cast to Name at ast.py:7199>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7199
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 3954
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Cast_Result.Node);
--# end
--# expr-done 3955
Env_Get_Result := AST_Envs.Get_First (Self => Fld_4, Key => Fld_5, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 3956
Dyn_Var_Bind_Result := Env_Get_Result; 
--# expr-done 3957
   if Dyn_Var_Bind_Result.Node = null
      or else Dyn_Var_Bind_Result.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Dyn_Var_Bind_Result.Node,
         Info => Dyn_Var_Bind_Result.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 3958
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Cast_Result_1.Node, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 3959
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Fld_6.Node, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 3960
   If_Result := Fld_7;
end if;
--# expr-done 3961
Let_Result := If_Result; 
--# end
--# expr-done 3962
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_547;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_547;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Accessed_Type;
--# end
--# property-start TypeDecl.access_def /tmp/lal-23.0.0/ada/ast.py:7209
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Access_Def
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Access_Def
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Access_Def;
      Match_0 : Internal_Entity_Access_Def;
Match_1 : Internal_Entity_Derived_Type_Def;
Match_2 : Internal_Entity_Type_Def;
Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Access_Def;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Access_Def;
Let_Result : Internal_Entity_Access_Def;
Scope_Result : Internal_Entity_Access_Def;
Cast_Result_1 : Internal_Entity_Derived_Type_Def;
Let_Result_1 : Internal_Entity_Access_Def;
Scope_Result_1 : Internal_Entity_Access_Def;
Cast_Result_2 : Internal_Entity_Type_Def;
Let_Result_2 : Internal_Entity_Access_Def;
Scope_Result_2 : Internal_Entity_Access_Def;
Match_Result : Internal_Entity_Access_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3966 '<Match at ast.py:7209>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7209
--# expr-start 3963 '<FieldAccess for type_def at ast.py:7209>' Fld /tmp/lal-23.0.0/ada/ast.py:7209
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3963
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Access_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind ad Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind dtd Match_1
--# expr-start 3965 '<FieldAccess for access_def at ast.py:7211>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7211
--# expr-start 3964 '<FieldAccess for base_type at ast.py:7211>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7211
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 3964
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Fld_1.Node, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 3965
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Access_Def; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3966
      Property_Result := Match_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Access_Def;
--# end
--# property-start TypeDecl.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:7215
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Tagged_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 3968 '<FieldAccess for is_tagged_type at ast.py:7215>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7215
--# expr-start 3967 '<FieldAccess for type_def at ast.py:7215>' Fld /tmp/lal-23.0.0/ada/ast.py:7215
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3967
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_tagged_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Tagged_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3968
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Tagged_Type;
--# end
--# property-start TypeDecl.base_type /tmp/lal-23.0.0/ada/ast.py:7216
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Base_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3970 '<FieldAccess for base_type at ast.py:7216>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7216
--# expr-start 3969 '<FieldAccess for type_def at ast.py:7216>' Fld /tmp/lal-23.0.0/ada/ast.py:7216
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3969
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3970
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Base_Type;
--# end
--# property-start TypeDecl.base_interfaces /tmp/lal-23.0.0/ada/ast.py:7217
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Base_Interfaces
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_551 with Inline_Always;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_551 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_551;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3972 '<FieldAccess for base_interfaces at ast.py:7217>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7217
--# expr-start 3971 '<FieldAccess for type_def at ast.py:7217>' Fld /tmp/lal-23.0.0/ada/ast.py:7217
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3971
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_interfaces'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Interfaces (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 3972
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_551;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_551;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Base_Interfaces;
--# end
--# property-start TypeDecl.is_char_type /tmp/lal-23.0.0/ada/ast.py:7218
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Char_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3974 '<FieldAccess for is_char_type at ast.py:7218>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7218
--# expr-start 3973 '<FieldAccess for type_def at ast.py:7218>' Fld /tmp/lal-23.0.0/ada/ast.py:7218
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3973
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_char_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Char_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3974
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Char_Type;
--# end
--# property-start TypeDecl.is_enum_type /tmp/lal-23.0.0/ada/ast.py:7219
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Enum_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3976 '<FieldAccess for is_enum_type at ast.py:7219>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7219
--# expr-start 3975 '<FieldAccess for type_def at ast.py:7219>' Fld /tmp/lal-23.0.0/ada/ast.py:7219
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3975
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_enum_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Enum_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 3976
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Enum_Type;
--# end
--# property-start TypeDecl.is_private /tmp/lal-23.0.0/ada/ast.py:7220
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Private
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Derived_Type_Def;
Fld : Bare_Type_Def;
Is_A : Boolean;
Fld_1 : Bare_Type_Def;
Cast_Result : Bare_Derived_Type_Def;
Fld_2 : Bare_With_Private;
Fld_3 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 3978 '<IsA PrivateTypeDef at ast.py:7221>' Is_A /tmp/lal-23.0.0/ada/ast.py:7221
--# expr-start 3977 '<FieldAccess for type_def at ast.py:7221>' Fld /tmp/lal-23.0.0/ada/ast.py:7221
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Type_Decl_F_Type_Def;
--# expr-done 3977
Is_A := Fld /= null 
and then Fld.Kind in Ada_Private_Type_Def_Range; 
--# expr-done 3978
if Is_A then
   If_Result := True;
else
--# expr-start 3980 '<Cast to DerivedTypeDef at ast.py:7222>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7222
--# expr-start 3979 '<FieldAccess for type_def at ast.py:7222>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7222
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Type_Decl_F_Type_Def;
--# expr-done 3979
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Derived_Type_Def_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 3980
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind dtd Var_Expr
--# expr-start 3982 '<FieldAccess for as_bool at ast.py:7223>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7223
--# expr-start 3981 '<FieldAccess for has_with_private at ast.py:7223>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7223
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr.Derived_Type_Def_F_Has_With_Private;
--# expr-done 3981
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]WithPrivate.as_bool'
Fld_3 := Libadalang.Implementation.Dispatcher_With_Private_P_As_Bool (Node => Fld_2);
--# end
--# expr-done 3982
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Private;
--# end
--# property-start TypeDecl.is_derived_tagged_type /tmp/lal-23.0.0/ada/ast.py:7227
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Derived_Tagged_Type
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Type_Def;
Is_A : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 3984 '<FieldAccess for is_tagged_type at ast.py:7228>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7228
--# expr-start 3983 '<FieldAccess for type_def at ast.py:7228>' Fld /tmp/lal-23.0.0/ada/ast.py:7228
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3983
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_tagged_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Tagged_Type (Node => Fld.Node, Origin => No_Bare_Ada_Node, E_Info => Fld.Info);
--# end
--# expr-done 3984
if Fld_1 then
   --# expr-start 3986 '<IsA DerivedTypeDef, InterfaceTypeDef at ast.py:7229>' Is_A /tmp/lal-23.0.0/ada/ast.py:7229
--# expr-start 3985 '<FieldAccess for type_def at ast.py:7229>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7229
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3985
Is_A := Fld_2.Node /= null 
and then Fld_2.Node.Kind in Ada_Derived_Type_Def_Range | Ada_Interface_Type_Def_Range; 
--# expr-done 3986
   If_Result := Is_A;
else
   If_Result := False;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Derived_Tagged_Type;
--# end
--# property-start TypeDecl.array_def /tmp/lal-23.0.0/ada/ast.py:7232
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Array_Def
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Type_Def
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Type_Def;
      Match_0 : Internal_Entity_Array_Type_Def;
Match_1 : Internal_Entity_Derived_Type_Def;
Match_2 : Internal_Entity_Type_Def;
Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Array_Type_Def;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Array_Type_Def;
Let_Result : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Cast_Result_1 : Internal_Entity_Derived_Type_Def;
Let_Result_1 : Internal_Entity_Array_Type_Def;
Scope_Result_1 : Internal_Entity_Array_Type_Def;
Cast_Result_2 : Internal_Entity_Type_Def;
Let_Result_2 : Internal_Entity_Array_Type_Def;
Scope_Result_2 : Internal_Entity_Array_Type_Def;
Match_Result : Internal_Entity_Array_Type_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3990 '<Match at ast.py:7232>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7232
--# expr-start 3987 '<FieldAccess for type_def at ast.py:7232>' Fld /tmp/lal-23.0.0/ada/ast.py:7232
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3987
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Array_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Array_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind atd Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind dtd Match_1
--# expr-start 3989 '<FieldAccess for array_def at ast.py:7234>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7234
--# expr-start 3988 '<FieldAccess for base_type at ast.py:7234>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7234
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 3988
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.array_def'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Array_Def (Node => Fld_1.Node, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 3989
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Array_Type_Def; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 3990
      Property_Result := Match_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Array_Def;
--# end
--# property-start TypeDecl.root_type /tmp/lal-23.0.0/ada/ast.py:7238
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Root_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Derived_Type_Def;
Match_1 : Internal_Entity_Type_Def;
Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Derived_Type_Def;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Type_Def;
Cast_Expr : Internal_Entity_Type_Decl;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 3994 '<Match at ast.py:7238>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7238
--# expr-start 3991 '<FieldAccess for type_def at ast.py:7238>' Fld /tmp/lal-23.0.0/ada/ast.py:7238
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3991
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind dtd Match_0
--# expr-start 3993 '<FieldAccess for root_type at ast.py:7239>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7239
--# expr-start 3992 '<FieldAccess for base_type at ast.py:7239>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7239
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 3992
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.root_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Root_Type (Node => Fld_1.Node, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 3993
Let_Result := Fld_2; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
Cast_Expr := Ent; 
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Let_Result_1 := Cast_Result_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 3994
      Property_Result := Match_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Root_Type;
--# end
--# property-start TypeDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:7244
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Defining_Env
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_558 with Inline_Always;
            procedure Finalizer_Scope_2375 with Inline_Always;
      Block_Var : Internal_Entity_Expr;
Block_Var_1 : Lexical_Env := Empty_Env;
Fld : Internal_Entity_Expr;
Fld_1 : Internal_Entity_Type_Def;
Fld_2 : Lexical_Env := Empty_Env;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Fld_5 : Boolean;
If_Result : Boolean;
Bound_Include_Ud_Indexing : Boolean;
Fld_6 : Internal_Entity_Basic_Decl_Array_Access;
Fld_7 : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Fld_8 : Lexical_Env := Empty_Env;
Map_Result : Lexical_Env_Array_Access;
Array_Lit_1 : Lexical_Env_Array_Access;
Concat_Result_1 : Lexical_Env_Array_Access;
Group_Env_1 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
If_Result_1 : Lexical_Env := Empty_Env;
If_Result_2 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_558 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Group_Env_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_558;
            procedure Finalizer_Scope_2375 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_2375;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4015 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 3995 '<FieldAccess for get_imp_deref at ast.py:7245>' Fld /tmp/lal-23.0.0/ada/ast.py:7245
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.get_imp_deref'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Get_Imp_Deref (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 3995
Block_Var := Fld; 
--# bind imp_deref Block_Var
--# expr-start 3997 '<FieldAccess for defining_env at ast.py:7249>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7249
--# expr-start 3996 '<FieldAccess for type_def at ast.py:7249>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7249
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 3996
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.defining_env
Fld_2 := Libadalang.Implementation.Type_Def_P_Defining_Env (Node => Fld_1.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld_1.Info);
--# end
--# expr-done 3997
Block_Var_1 := Fld_2; Inc_Ref (Block_Var_1);
--# bind self_env Block_Var_1
--# expr-start 4014 '<Cond at ast.py:7251>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:7251
--# expr-start 3999 '<Not at ast.py:7252>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7252
--# expr-start 3998 '<IsNull at ast.py:7252>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7252
Is_Null := Block_Var.Node = null; 
--# expr-done 3998
Not_Val := not (Is_Null); 
--# expr-done 3999
if Not_Val then
   --# expr-start 4003 '<env_group at ast.py:7253>' Group_Env /tmp/lal-23.0.0/ada/ast.py:7253
--# expr-start 4002 '<ArrayLiteral at ast.py:7253>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:7253
--# expr-start 4001 '<FieldAccess for defining_env at ast.py:7253>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7253
--# expr-start 4000 '<FieldAccess for accessed_type at ast.py:7253>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7253
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 4000
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld_3.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld_3.Info);
--# end
--# expr-done 4001
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Block_Var_1, 2 => Fld_4)); 
--# expr-done 4002
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 4003
   If_Result_2 := Group_Env;
else
if Include_Ud_Indexing then
   --# expr-start 4004 '<FieldAccess for has_ud_indexing at ast.py:7255>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7255
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.has_ud_indexing'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Has_Ud_Indexing (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4004
   If_Result := Fld_5;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 4013 '<bind at ast.py:7256>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7256
Bound_Include_Ud_Indexing := False; 
--# expr-start 4012 '<env_group at ast.py:7261>' Group_Env_1 /tmp/lal-23.0.0/ada/ast.py:7261
--# expr-start 4011 '<Concat at ast.py:7261>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:7261
--# expr-start 4009 '<Map at ast.py:7260>' Map_Result /tmp/lal-23.0.0/ada/ast.py:7260
   --# expr-start 4007 '<Concat at ast.py:7259>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:7259
--# expr-start 4005 '<FieldAccess for constant_indexing_fns at ast.py:7258>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7258
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.constant_indexing_fns'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Constant_Indexing_Fns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4005
--# expr-start 4006 '<FieldAccess for variable_indexing_fns at ast.py:7259>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7259
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.variable_indexing_fns'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Variable_Indexing_Fns (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4006
Concat_Result := Concat (Fld_6, Fld_7); 
--# expr-done 4007
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Concat_Result;
      begin
         for Item_153 of
               Collection.Items
         loop
   --# scope-start
               --# bind fn Item_153
      --# expr-start 4008 '<FieldAccess for defining_env at ast.py:7260>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7260
      if Item_153.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_8 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Item_153.Node, Origin => Origin, Include_Ud_Indexing => Bound_Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Item_153.Info);
--# end
--# expr-done 4008
         declare
            Item_To_Append : constant Lexical_Env := Fld_8;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2375;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4009
--# expr-start 4010 '<ArrayLiteral at ???>' Array_Lit_1 None
Array_Lit_1 := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Block_Var_1)); 
--# expr-done 4010
Concat_Result_1 := Concat (Map_Result, Array_Lit_1); 
--# expr-done 4011
Group_Env_1 := Group (Concat_Result_1, No_Metadata); 
--# expr-done 4012
Dyn_Var_Bind_Result := Group_Env_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4013
   If_Result_1 := Dyn_Var_Bind_Result;
else
   If_Result_1 := Block_Var_1;
end if;
      Inc_Ref (If_Result_1);
   If_Result_2 := If_Result_1;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 4014
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 4015
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_558;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_558;
               Finalizer_Scope_2375;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Defining_Env;
--# end
--# property-start TypeDecl.predefined_operators /tmp/lal-23.0.0/ada/ast.py:7268
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Predefined_Operators
  (Node : Bare_Type_Decl
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_559 with Inline_Always;
      Fld : Bare_Type_Def;
Fld_1 : Internal_Env_Assoc_Array_Access;
Fld_2 : Internal_Entity;
Fld_3 : Bare_Ada_Node;
Cast_Expr : Bare_Type_Decl;
Cast_Result : Bare_Ada_Node;
Is_Equal : Boolean;
Fld_4 : Internal_Entity;
Fld_5 : Bare_Ada_Node;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_1 : Bare_Ada_Node;
Is_Equal_1 : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_559 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_559;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Type_Decl_Type_Decl_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Type_Decl,
                                As_Bare_Type_Decl => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 4025 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4024 '<If at ast.py:7277>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:7277
--# expr-start 4018 '<Eq at ast.py:7278>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:7278
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-start 4017 '<FieldAccess for node at ast.py:7278>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7278
--# expr-start 4016 '<FieldAccess for universal_int_type at ast.py:7278>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7278
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 4016
Fld_3 := Fld_2.Node;
--# expr-done 4017
Is_Equal := Cast_Result = Fld_3; 
--# expr-done 4018
if Is_Equal then
   If_Result := True;
else
   --# expr-start 4021 '<Eq at ast.py:7278>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:7278
Cast_Expr_1 := Self; 
      Cast_Result_1 := Cast_Expr_1;
--# expr-start 4020 '<FieldAccess for node at ast.py:7279>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7279
--# expr-start 4019 '<FieldAccess for universal_real_type at ast.py:7279>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7279
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld_4 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 4019
Fld_5 := Fld_4.Node;
--# expr-done 4020
Is_Equal_1 := Cast_Result_1 = Fld_5; 
--# expr-done 4021
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := No_Internal_Env_Assoc_Array_Type;
else
   --# expr-start 4023 '<FieldAccess for predefined_operators at ast.py:7281>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7281
--# expr-start 4022 '<FieldAccess for type_def at ast.py:7281>' Fld /tmp/lal-23.0.0/ada/ast.py:7281
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Type_Decl_F_Type_Def;
--# expr-done 4022
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.predefined_operators'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Predefined_Operators (Node => Fld);
--# end
--# expr-done 4023
   If_Result_1 := Fld_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 4024
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 4025
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_559;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_559;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Predefined_Operators;
--# end
--# property-start TypeDecl.record_def /tmp/lal-23.0.0/ada/ast.py:7299
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Record_Def
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Record_Def
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Record_Def;
      Match_0 : Internal_Entity_Record_Type_Def;
Match_1 : Internal_Entity_Derived_Type_Def;
Match_2 : Internal_Entity_Type_Def;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Type_Def;
Fld_1 : Internal_Entity_Base_Record_Def;
Fld_2 : Internal_Entity_Base_Record_Def;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Record_Def;
Scope_Result : Internal_Entity_Base_Record_Def;
Result_Var : Internal_Entity_Base_Record_Def;
Fld_5 : Boolean;
If_Result : Internal_Entity_Base_Record_Def;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Record_Type_Def;
Let_Result : Internal_Entity_Base_Record_Def;
Scope_Result_1 : Internal_Entity_Base_Record_Def;
Cast_Result_1 : Internal_Entity_Derived_Type_Def;
Let_Result_1 : Internal_Entity_Base_Record_Def;
Scope_Result_2 : Internal_Entity_Base_Record_Def;
Cast_Result_2 : Internal_Entity_Type_Def;
Let_Result_2 : Internal_Entity_Base_Record_Def;
Scope_Result_3 : Internal_Entity_Base_Record_Def;
Match_Result : Internal_Entity_Base_Record_Def;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4033 '<Match at ast.py:7300>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7300
--# expr-start 4026 '<FieldAccess for type_def at ast.py:7300>' Fld /tmp/lal-23.0.0/ada/ast.py:7300
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 4026
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Record_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Record_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind r Match_0
--# expr-start 4027 '<FieldAccess for record_def at ast.py:7301>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7301
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Base_Record_Def (Node => Match_0.Node.Record_Type_Def_F_Record_Def, Info => Match_0.Info);
--# expr-done 4027
Let_Result := Fld_1; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Derived_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Derived_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind d Match_1
--# expr-start 4032 '<If at ast.py:7304>' If_Result /tmp/lal-23.0.0/ada/ast.py:7304
--# expr-start 4028 '<FieldAccess for is_tagged_type at ast.py:7305>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7305
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 4028
if Fld_5 then
   --# expr-start 4029 '<FieldAccess for record_extension at ast.py:7306>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7306
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Record_Def (Node => Match_1.Node.Derived_Type_Def_F_Record_Extension, Info => Match_1.Info);
--# expr-done 4029
   If_Result := Fld_2;
else
--# expr-start 4030 '<FieldAccess for base_type at ast.py:7307>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7307
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 4030
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 4031 '<FieldAccess for record_def at ast.py:7307>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7307
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 4031
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Record_Def;
end if;
   If_Result := Result_Var;
end if;
--# expr-done 4032
Let_Result_1 := If_Result; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Ordinary_Fixed_Point_Def | Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Base_Record_Def; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 4033
      Property_Result := Match_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Record_Def;
--# end
--# property-start TypeDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:7313
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Xref_Entry_Point
  (Node : Bare_Type_Decl
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Xref_Entry_Point;
--# end
--# property-start TypeDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:7316
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Xref_Equation
  (Node : Bare_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_562 with Inline_Always;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_562 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_562;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4036 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4035 '<FieldAccess for sub_equation at ast.py:7318>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7318
--# expr-start 4034 '<FieldAccess for type_def at ast.py:7318>' Fld /tmp/lal-23.0.0/ada/ast.py:7318
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 4034
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 4035
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 4036
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_562;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_562;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Xref_Equation;
--# end
--# property-start TypeDecl.is_discrete_type /tmp/lal-23.0.0/ada/ast.py:7320
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Is_Discrete_Type
  (Node : Bare_Type_Decl
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Type_Def;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4038 '<FieldAccess for is_discrete_type at ast.py:7320>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7320
--# expr-start 4037 '<FieldAccess for type_def at ast.py:7320>' Fld /tmp/lal-23.0.0/ada/ast.py:7320
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 4037
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_discrete_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Discrete_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 4038
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Is_Discrete_Type;
--# end
--# property-start TypeDecl.own_primitives_env /tmp/lal-23.0.0/ada/ast.py:7323
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Own_Primitives_Env
  (Node : Bare_Type_Decl
      ; With_Rebindings : Env_Rebindings
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind with_rebindings With_Rebindings
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_564 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Rebound_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_564 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Rebound_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_564;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4041 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4040 '<rebind_env at ast.py:7328>' Rebound_Env /tmp/lal-23.0.0/ada/ast.py:7328
--# expr-start 4039 '<FieldAccess for direct_primitives_env at ast.py:7328>' Fld /tmp/lal-23.0.0/ada/ast.py:7328
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.direct_primitives_env
Fld := Libadalang.Implementation.Type_Decl_F_Direct_Primitives_Env (Node => Ent.Node);
--# end
--# expr-done 4039
Rebound_Env := Rebind_Env (Fld, With_Rebindings); 
--# expr-done 4040
Let_Result := Rebound_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 4041
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_564;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_564;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Own_Primitives_Env;
--# end
--# property-start TypeDecl.own_primitives_envs /tmp/lal-23.0.0/ada/ast.py:7331
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Own_Primitives_Envs
  (Node : Bare_Type_Decl
      ; With_Rebindings : Env_Rebindings
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind with_rebindings With_Rebindings
   Property_Result : Lexical_Env_Array_Access;
            procedure Finalizer_Scope_565 with Inline_Always;
            procedure Finalizer_Scope_2381 with Inline_Always;
      Var_Expr : Internal_Entity_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Scope_Result : Lexical_Env_Array_Access;
Fld_3 : Lexical_Env := Empty_Env;
Singleton : Lexical_Env_Array_Access;
Result_Var : Lexical_Env_Array_Access;
Let_Result : Lexical_Env_Array_Access;
            procedure Finalizer_Scope_565 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Singleton);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_565;
            procedure Finalizer_Scope_2381 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Array_Lit);
            end Finalizer_Scope_2381;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4048 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4043 '<Cast to TypeDecl at ast.py:7338>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7338
--# expr-start 4042 '<FieldAccess for previous_part at ast.py:7338>' Fld /tmp/lal-23.0.0/ada/ast.py:7338
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Ent.Node, Go_To_Incomplete => False, E_Info => Ent.Info);
--# end
--# expr-done 4042
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Type_Decl;
   end if;
--# expr-done 4043
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Type_Decl then
   --# scope-start
   --# bind pp Var_Expr
--# expr-start 4046 '<ArrayLiteral at ast.py:7339>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:7339
--# expr-start 4044 '<FieldAccess for own_primitives_env at ast.py:7340>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7340
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.own_primitives_env
Fld_1 := Libadalang.Implementation.Type_Decl_P_Own_Primitives_Env (Node => Ent.Node, With_Rebindings => With_Rebindings, E_Info => Ent.Info);
--# end
--# expr-done 4044
--# expr-start 4045 '<FieldAccess for own_primitives_env at ast.py:7341>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7341
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.own_primitives_env
Fld_2 := Libadalang.Implementation.Type_Decl_P_Own_Primitives_Env (Node => Var_Expr.Node, With_Rebindings => With_Rebindings, E_Info => Var_Expr.Info);
--# end
--# expr-done 4045
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld_1, 2 => Fld_2)); 
--# expr-done 4046
Scope_Result := Array_Lit;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2381;
   Result_Var := Scope_Result;
else
   --# expr-start 4047 '<FieldAccess for own_primitives_env at ast.py:7343>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7343
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.own_primitives_env
Fld_3 := Libadalang.Implementation.Type_Decl_P_Own_Primitives_Env (Node => Ent.Node, With_Rebindings => With_Rebindings, E_Info => Ent.Info);
--# end
--# expr-done 4047
                Singleton := Create_Lexical_Env_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_3;
                Inc_Ref (Singleton.Items (1));
   Result_Var := Singleton;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 4048
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_565;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_565;
               Finalizer_Scope_2381;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Own_Primitives_Envs;
--# end
--# property-start TypeDecl.primitives_envs /tmp/lal-23.0.0/ada/ast.py:7347
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Primitives_Envs
  (Node : Bare_Type_Decl
      ; With_Rebindings : Env_Rebindings
      ; Stop_At : Internal_Entity_Base_Type_Decl_Array_Access
      ; Include_Self : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind with_rebindings With_Rebindings
   --# bind stop_at Stop_At
   --# bind include_self Include_Self
   Property_Result : Lexical_Env_Array_Access;
            procedure Finalizer_Scope_566 with Inline_Always;
            procedure Finalizer_Scope_2382 with Inline_Always;
            procedure Finalizer_Scope_2386 with Inline_Always;
      Var_Expr : Internal_Entity_Type_Decl;
Match_0 : Internal_Entity_Type_Decl;
Match_1 : Internal_Entity_Base_Subtype_Decl;
Match_2 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Bare_Type_Decl;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_1 : Bare_Base_Subtype_Decl;
Fld_2 : Bare_Ada_Node;
Bound_Origin_1 : Bare_Ada_Node;
Fld_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Type_Decl;
Match_Prefix : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity_Type_Decl;
Let_Result : Internal_Entity_Type_Decl;
Scope_Result : Internal_Entity_Type_Decl;
Cast_Result_3 : Internal_Entity_Base_Subtype_Decl;
Let_Result_1 : Internal_Entity_Type_Decl;
Scope_Result_1 : Internal_Entity_Type_Decl;
Cast_Result_4 : Internal_Entity_Base_Type_Decl;
Let_Result_2 : Internal_Entity_Type_Decl;
Scope_Result_2 : Internal_Entity_Type_Decl;
Match_Result : Internal_Entity_Type_Decl;
Fld_4 : Lexical_Env_Array_Access;
Fld_5 : Lexical_Env_Array_Access;
Concat_Result : Lexical_Env_Array_Access;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_5 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Type_Decl;
Cast_Result_6 : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result : Boolean;
If_Result : Lexical_Env_Array_Access;
Scope_Result_3 : Lexical_Env_Array_Access;
Result_Var : Lexical_Env_Array_Access;
Map_Result : Lexical_Env_Array_Access;
Fld_6 : Lexical_Env_Array_Access;
If_Result_1 : Lexical_Env_Array_Access;
Concat_Result_1 : Lexical_Env_Array_Access;
Dyn_Var_Bind_Result_1 : Lexical_Env_Array_Access;
Let_Result_3 : Lexical_Env_Array_Access;
            procedure Finalizer_Scope_566 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_566;
            procedure Finalizer_Scope_2382 is
            begin
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2382;
            procedure Finalizer_Scope_2386 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2386;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4067 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4066 '<bind at ast.py:7359>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:7359
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 4065 '<Concat at ast.py:7372>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:7372
--# expr-start 4062 '<Mapcat at ast.py:7359>' Map_Result /tmp/lal-23.0.0/ada/ast.py:7359
   --# expr-start 4049 '<FieldAccess for base_types at ast.py:7359>' Fld /tmp/lal-23.0.0/ada/ast.py:7359
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_types'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Types (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 4049
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld;
      begin
         for Item_154 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_154
--# expr-start 4055 '<Match at ast.py:7359>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7359
      if Item_154.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_154; 
case Ada_Base_Type_Decl (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind td Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Subtype_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Base_Subtype_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind std Match_1
--# expr-start 4054 '<bind at ast.py:7361>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7361
--# expr-start 4051 '<FieldAccess for origin_node at ast.py:7362>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7362
--# expr-start 4050 '<FieldAccess for node at ast.py:7362>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7362
Fld_1 := Match_1.Node;
--# expr-done 4050
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_2 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Fld_1);
--# end
--# expr-done 4051
Bound_Origin_1 := Fld_2; 
--# expr-start 4053 '<Cast to TypeDecl at ast.py:7362>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7362
--# expr-start 4052 '<FieldAccess for get_type at ast.py:7362>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7362
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubtypeDecl.get_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Subtype_Decl_P_Get_Type (Node => Match_1.Node, Origin => Bound_Origin_1, E_Info => Match_1.Info);
--# end
--# expr-done 4052
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Type_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result_1 := No_Entity_Type_Decl;
   end if;
--# expr-done 4053
Dyn_Var_Bind_Result := Cast_Result_1; 
--# expr-done 4054
Let_Result_1 := Dyn_Var_Bind_Result; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Classwide_Type_Decl .. Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Type_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 4055
Var_Expr := Match_Result;
if Var_Expr /= No_Entity_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 4061 '<If at ast.py:7366>' If_Result /tmp/lal-23.0.0/ada/ast.py:7366
--# expr-start 4057 '<Contains at ast.py:7367>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:7367
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Stop_At;
      begin
         for Item_155 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_155
      --# expr-start 4056 '<Eq at ???>' Is_Equiv None
Cast_Expr_1 := Item_155; 
      Cast_Result_5 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Cast_Expr_2 := Var_Expr; 
      Cast_Result_6 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv := Equivalent (Cast_Result_5, Cast_Result_6); 
--# expr-done 4056
      Quantifier_Result := Is_Equiv;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 4057
if Quantifier_Result then
   If_Result := No_Lexical_Env_Array_Type;
else
   --# expr-start 4060 '<Concat at ast.py:7370>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:7370
--# expr-start 4058 '<FieldAccess for own_primitives_envs at ast.py:7369>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7369
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.own_primitives_envs
Fld_4 := Libadalang.Implementation.Type_Decl_P_Own_Primitives_Envs (Node => Var_Expr.Node, With_Rebindings => With_Rebindings, E_Info => Var_Expr.Info);
--# end
--# expr-done 4058
--# expr-start 4059 '<FieldAccess for primitives_envs at ast.py:7370>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7370
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.primitives_envs
Fld_5 := Libadalang.Implementation.Type_Decl_P_Primitives_Envs (Node => Var_Expr.Node, With_Rebindings => With_Rebindings, Stop_At => Stop_At, Include_Self => False, E_Info => Var_Expr.Info);
--# end
--# expr-done 4059
Concat_Result := Concat (Fld_4, Fld_5); 
--# expr-done 4060
   If_Result := Concat_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 4061
Scope_Result_3 := If_Result;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2386;
   Result_Var := Scope_Result_3;
else
   Result_Var := No_Lexical_Env_Array_Type;
end if;
      Inc_Ref (Result_Var);
         for Item_To_Append of
               Result_Var.Items
         loop
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2382;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4062
--# expr-start 4064 '<If at ast.py:7373>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:7373
if Include_Self then
   --# expr-start 4063 '<FieldAccess for own_primitives_envs at ast.py:7374>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7374
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.own_primitives_envs
Fld_6 := Libadalang.Implementation.Type_Decl_P_Own_Primitives_Envs (Node => Ent.Node, With_Rebindings => With_Rebindings, E_Info => Ent.Info);
--# end
--# expr-done 4063
   If_Result_1 := Fld_6;
else
   If_Result_1 := No_Lexical_Env_Array_Type;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 4064
Concat_Result_1 := Concat (Map_Result, If_Result_1); 
--# expr-done 4065
Dyn_Var_Bind_Result_1 := Concat_Result_1; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 4066
Let_Result_3 := Dyn_Var_Bind_Result_1; Inc_Ref (Let_Result_3);
--# end
--# expr-done 4067
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_566;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_566;
               Finalizer_Scope_2382;
               Finalizer_Scope_2386;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Primitives_Envs;
--# end
--# property-start TypeDecl.compute_primitives_env /tmp/lal-23.0.0/ada/ast.py:7379
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Compute_Primitives_Env
  (Node : Bare_Type_Decl
      ; Include_Self : Boolean
         := True
      ; Stop_At : Internal_Entity_Base_Type_Decl_Array_Access
         := No_Internal_Entity_Base_Type_Decl_Array_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind include_self Include_Self
   --# bind stop_at Stop_At
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_567 with Inline_Always;
      Fld : Internal_Entity_Info;
Fld_1 : Env_Rebindings;
Fld_2 : Lexical_Env_Array_Access;
Cast_Expr : Bare_Type_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct : Internal_Metadata;
Group_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_567 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_567;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Type_Decl_Type_Decl_P_Compute_Primitives_Env,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Type_Decl,
                                As_Bare_Type_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Include_Self);
               Mmz_K.Items (3) := (Kind => Mmz_Internal_Entity_Base_Type_Decl_Array_Access,
                                      As_Internal_Entity_Base_Type_Decl_Array_Access => Stop_At);
                  Inc_Ref (Mmz_K.Items (3).As_Internal_Entity_Base_Type_Decl_Array_Access);
               Mmz_K.Items (4) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Lexical_Env;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 4073 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4072 '<env_group at ast.py:7387>' Group_Env /tmp/lal-23.0.0/ada/ast.py:7387
--# expr-start 4070 '<FieldAccess for primitives_envs at ast.py:7387>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7387
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4069 '<FieldAccess for rebindings at ast.py:7388>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7388
--# expr-start 4068 '<FieldAccess for info at ast.py:7388>' Fld /tmp/lal-23.0.0/ada/ast.py:7388
Fld := Ent.Info;
--# expr-done 4068
Fld_1 := Fld.Rebindings;
--# expr-done 4069
--# property-call-start TypeDecl.primitives_envs
Fld_2 := Libadalang.Implementation.Type_Decl_P_Primitives_Envs (Node => Ent.Node, With_Rebindings => Fld_1, Stop_At => Stop_At, Include_Self => Include_Self, E_Info => Ent.Info);
--# end
--# expr-done 4070
--# expr-start 4071 '<New Metadata at ast.py:7392>' New_Struct /tmp/lal-23.0.0/ada/ast.py:7392
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
New_Struct := (Dottable_Subp => False, Primitive => No_Bare_Ada_Node, Primitive_Real_Type => Cast_Result); 
--# expr-done 4071
Group_Env := Group (Fld_2, New_Struct); 
--# expr-done 4072
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 4073
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_567;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Lexical_Env,
                        As_Lexical_Env => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_567;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Compute_Primitives_Env;
--# end
--# property-start TypeDecl.parent_primitives_env /tmp/lal-23.0.0/ada/ast.py:7396
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Parent_Primitives_Env
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_568 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Bare_Type_Def;
Is_A : Boolean;
If_Result : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_568 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_568;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4079 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4078 '<If at ast.py:7397>' If_Result /tmp/lal-23.0.0/ada/ast.py:7397
--# expr-start 4075 '<IsA DerivedTypeDef, InterfaceTypeDef at ast.py:7398>' Is_A /tmp/lal-23.0.0/ada/ast.py:7398
--# expr-start 4074 '<FieldAccess for type_def at ast.py:7398>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7398
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Type_Decl_F_Type_Def;
--# expr-done 4074
Is_A := Fld_2 /= null 
and then Fld_2.Kind in Ada_Derived_Type_Def_Range | Ada_Interface_Type_Def_Range; 
--# expr-done 4075
if Is_A then
   --# expr-start 4076 '<FieldAccess for compute_primitives_env at ast.py:7399>' Fld /tmp/lal-23.0.0/ada/ast.py:7399
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.compute_primitives_env
Fld := Libadalang.Implementation.Type_Decl_P_Compute_Primitives_Env (Node => Ent.Node, Include_Self => False, E_Info => Ent.Info);
--# end
--# expr-done 4076
   If_Result := Fld;
else
   --# expr-start 4077 '<FieldAccess for empty_env at ast.py:7400>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7400
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.empty_env
Fld_1 := Libadalang.Implementation.Ada_Node_P_Empty_Env (Node => Self);
--# end
--# expr-done 4077
   If_Result := Fld_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 4078
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 4079
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_568;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_568;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Parent_Primitives_Env;
--# end
--# property-start TypeDecl.refined_parent_primitives_env /tmp/lal-23.0.0/ada/ast.py:7404
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Refined_Parent_Primitives_Env
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_569 with Inline_Always;
            procedure Finalizer_Scope_2388 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_2 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_569 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_569;
            procedure Finalizer_Scope_2388 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2388;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4083 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4082 '<FieldAccess for compute_primitives_env at ast.py:7425>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7425
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4080 '<FieldAccess for previous_part at ast.py:7427>' Fld /tmp/lal-23.0.0/ada/ast.py:7427
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4080
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 4081 '<FieldAccess for base_types at ast.py:7427>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7427
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.base_types'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Base_Types (Node => Var_Expr.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 4081
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2388;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# property-call-start TypeDecl.compute_primitives_env
Fld_2 := Libadalang.Implementation.Type_Decl_P_Compute_Primitives_Env (Node => Ent.Node, Include_Self => False, Stop_At => Result_Var, E_Info => Ent.Info);
--# end
--# expr-done 4082
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 4083
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_569;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_569;
               Finalizer_Scope_2388;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Refined_Parent_Primitives_Env;
--# end
--# property-start TypeDecl.primitives_env /tmp/lal-23.0.0/ada/ast.py:7431
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Primitives_Env
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_570 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_570 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_570;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4085 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4084 '<FieldAccess for compute_primitives_env at ast.py:7432>' Fld /tmp/lal-23.0.0/ada/ast.py:7432
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.compute_primitives_env
Fld := Libadalang.Implementation.Type_Decl_P_Compute_Primitives_Env (Node => Ent.Node, Include_Self => True, E_Info => Ent.Info);
--# end
--# expr-done 4084
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 4085
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_570;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_570;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Primitives_Env;
--# end
--# property-start TypeDecl.get_primitives /tmp/lal-23.0.0/ada/ast.py:7435
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Get_Primitives
  (Node : Bare_Type_Decl
      ; Only_Inherited : Boolean
         := False
      ; Include_Predefined_Operators : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind only_inherited Only_Inherited
   --# bind include_predefined_operators Include_Predefined_Operators
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_571 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Block_Var_1 : Internal_Entity_Basic_Decl_Array_Access;
Block_Var_2 : Internal_Entity_Basic_Decl_Array_Access;
A_Spec : Internal_Entity_Base_Subp_Spec;
A_Prim : Internal_Entity_Base_Type_Decl;
B_Prim : Bare_Base_Type_Decl;
B_Prim_Ent : Internal_Entity_Base_Type_Decl;
Fld : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
If_Result : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Is_A : Boolean;
Not_Val : Boolean;
Map_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
If_Result_1 : Internal_Entity_Basic_Decl_Array_Access;
Index_159 : Integer;
Fld_2 : Internal_Entity_Base_Subp_Spec;
Fld_3 : Internal_Entity_Info;
Fld_4 : Internal_Metadata;
Fld_5 : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity_Info;
Fld_7 : Internal_Metadata;
Fld_8 : Bare_Ada_Node;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_9 : Internal_Entity_Defining_Name;
Fld_10 : Bare_Defining_Name;
Fld_11 : Internal_Entity_Defining_Name;
Fld_12 : Bare_Defining_Name;
Cast_Result_3 : Bare_Name;
Fld_13 : Boolean;
Not_Val_1 : Boolean;
Fld_14 : Internal_Entity_Base_Subp_Spec;
Fld_15 : Boolean;
Not_Val_2 : Boolean;
If_Result_3 : Boolean;
As_Entity_1 : Internal_Entity_Base_Type_Decl;
Is_Null_1 : Boolean;
If_Result_4 : Internal_Entity_Base_Type_Decl;
Comp_Result : Boolean;
Fld_16 : Bare_Base_Type_Decl;
Fld_17 : Boolean;
Not_Val_3 : Boolean;
If_Result_5 : Boolean;
Comp_Result_1 : Boolean;
Fld_18 : Bare_Base_Type_Decl;
Fld_19 : Boolean;
Not_Val_4 : Boolean;
If_Result_6 : Boolean;
Fld_20 : Bare_Base_Type_Decl;
Fld_21 : Boolean;
If_Result_7 : Boolean;
Let_Result : Boolean;
If_Result_8 : Boolean;
Let_Result_1 : Boolean;
Index_161 : Integer;
Quantifier_Result : Boolean;
Let_Result_2 : Boolean;
Map_Result_2 : Internal_Entity_Basic_Decl_Array_Access;
Let_Result_3 : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_571 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_571;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4130 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4088 '<If at ast.py:7444>' If_Result /tmp/lal-23.0.0/ada/ast.py:7444
if Only_Inherited then
   --# expr-start 4086 '<FieldAccess for parent_primitives_env at ast.py:7446>' Fld /tmp/lal-23.0.0/ada/ast.py:7446
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.parent_primitives_env
Fld := Libadalang.Implementation.Type_Decl_P_Parent_Primitives_Env (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4086
   If_Result := Fld;
else
   --# expr-start 4087 '<FieldAccess for primitives_env at ast.py:7447>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7447
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4087
   If_Result := Fld_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 4088
Block_Var := If_Result; Inc_Ref (Block_Var);
--# bind prim_env Block_Var
--# expr-start 4091 '<Map at ast.py:7450>' Map_Result /tmp/lal-23.0.0/ada/ast.py:7450
   --# expr-start 4089 '<EnvGet at ast.py:7450>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:7450
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Block_Var, Key => null, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 4089
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_156 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_156
      --# expr-start 4090 '<Cast to BasicDecl at ast.py:7451>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7451
Cast_Expr := Item_156; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 4090
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4091
Block_Var_1 := Map_Result; Inc_Ref (Block_Var_1);
--# bind all_prims Block_Var_1
--# expr-start 4095 '<If at ast.py:7454>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:7454
if Include_Predefined_Operators then
   If_Result_1 := Block_Var_1;
else
   --# expr-start 4094 '<Filter at ast.py:7457>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:7457
      declare
         Map_Result_1_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_1;
      begin
         for Item_157 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_157
         --# expr-start 4093 '<Not at ast.py:7457>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7457
--# expr-start 4092 '<IsA SyntheticSubpDecl at ast.py:7457>' Is_A /tmp/lal-23.0.0/ada/ast.py:7457
Is_A := Item_157.Node /= null 
and then Item_157.Node.Kind in Ada_Synthetic_Subp_Decl_Range; 
--# expr-done 4092
Not_Val := not (Is_A); 
--# expr-done 4093
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Item_157;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 4094
   If_Result_1 := Map_Result_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 4095
Block_Var_2 := If_Result_1; Inc_Ref (Block_Var_2);
--# bind bds Block_Var_2
--# expr-start 4129 '<Filter at ast.py:7462>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:7462
      declare
         Map_Result_2_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
         Index_159 := 0;
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_2;
      begin
         for Item_158 of
               Collection.Items
         loop
   --# scope-start
               --# bind a Item_158
               --# bind i Index_159
         --# expr-start 4128 '<Let at ast.py:7462>' Let_Result_2 /tmp/lal-23.0.0/ada/ast.py:7462
--# scope-start
--# expr-start 4096 '<FieldAccess for subp_spec_or_null at ast.py:7464>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7464
      if Item_158.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Item_158.Node, E_Info => Item_158.Info);
--# end
--# expr-done 4096
A_Spec := Fld_2; 
--# bind a_spec A_Spec
--# expr-start 4101 '<Cast to BaseTypeDecl at ast.py:7465>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7465
--# expr-start 4100 '<as_bare_entity at ast.py:7465>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:7465
--# expr-start 4099 '<FieldAccess for primitive at ast.py:7465>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7465
--# expr-start 4098 '<FieldAccess for md at ast.py:7465>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7465
--# expr-start 4097 '<FieldAccess for info at ast.py:7465>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7465
Fld_3 := Item_158.Info;
--# expr-done 4097
Fld_4 := Fld_3.Md;
--# expr-done 4098
Fld_5 := Fld_4.Primitive;
--# expr-done 4099
Is_Null := Fld_5 = null; 
if Is_Null then
   If_Result_2 := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_5); 
   If_Result_2 := As_Entity;
end if;
--# expr-done 4100
   if If_Result_2.Node = null
      or else If_Result_2.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => If_Result_2.Node,
         Info => If_Result_2.Info);
   else
         Cast_Result_1 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 4101
A_Prim := Cast_Result_1; 
--# bind a_prim A_Prim
--# expr-start 4127 '<AllQuantifier at ast.py:7467>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:7467
      Quantifier_Result := True;
         Index_161 := 0;
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_2;
      begin
         for Item_160 of
               Collection.Items
         loop
   --# scope-start
               --# bind b Item_160
               --# bind j Index_161
      --# expr-start 4126 '<Let at ast.py:7467>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:7467
--# scope-start
--# expr-start 4105 '<Cast to BaseTypeDecl at ast.py:7468>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:7468
--# expr-start 4104 '<FieldAccess for primitive at ast.py:7468>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7468
--# expr-start 4103 '<FieldAccess for md at ast.py:7468>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7468
--# expr-start 4102 '<FieldAccess for info at ast.py:7468>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7468
Fld_6 := Item_160.Info;
--# expr-done 4102
Fld_7 := Fld_6.Md;
--# expr-done 4103
Fld_8 := Fld_7.Primitive;
--# expr-done 4104
   if Fld_8 = null
      or else Fld_8.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_2 := Fld_8;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 4105
B_Prim := Cast_Result_2; 
--# bind b_prim B_Prim
--# expr-start 4111 '<Not at ast.py:7475>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:7475
--# expr-start 4110 '<FieldAccess for matches at ast.py:7475>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7475
--# expr-start 4107 '<FieldAccess for node at ast.py:7475>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7475
--# expr-start 4106 '<FieldAccess for defining_name at ast.py:7475>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7475
      if Item_158.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Item_158.Node, E_Info => Item_158.Info);
--# end
--# expr-done 4106
Fld_10 := Fld_9.Node;
--# expr-done 4107
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4109 '<FieldAccess for node at ast.py:7475>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7475
--# expr-start 4108 '<FieldAccess for defining_name at ast.py:7475>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7475
      if Item_160.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Item_160.Node, E_Info => Item_160.Info);
--# end
--# expr-done 4108
Fld_12 := Fld_11.Node;
--# expr-done 4109
      Cast_Result_3 := Fld_12;
--# property-call-start Name.matches
Fld_13 := Libadalang.Implementation.Name_P_Matches (Node => Fld_10, N => Cast_Result_3);
--# end
--# expr-done 4110
Not_Val_1 := not (Fld_13); 
--# expr-done 4111
if Not_Val_1 then
   If_Result_3 := True;
else
   --# expr-start 4114 '<Not at ast.py:7478>' Not_Val_2 /tmp/lal-23.0.0/ada/ast.py:7478
--# expr-start 4113 '<FieldAccess for match_signature at ast.py:7478>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:7478
      if A_Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4112 '<FieldAccess for subp_spec_or_null at ast.py:7479>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7479
      if Item_160.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_14 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Item_160.Node, E_Info => Item_160.Info);
--# end
--# expr-done 4112
--# property-call-start BaseSubpSpec.match_signature
Fld_15 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => A_Spec.Node, Other => Fld_14, Match_Name => False, Use_Entity_Info => True, E_Info => A_Spec.Info);
--# end
--# expr-done 4113
Not_Val_2 := not (Fld_15); 
--# expr-done 4114
   If_Result_3 := Not_Val_2;
end if;
if If_Result_3 then
   If_Result_8 := True;
else
   --# expr-start 4125 '<Let at ast.py:7483>' Let_Result /tmp/lal-23.0.0/ada/ast.py:7483
--# scope-start
--# expr-start 4115 '<as_bare_entity at ast.py:7483>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:7483
Is_Null_1 := B_Prim = null; 
if Is_Null_1 then
   If_Result_4 := No_Entity_Base_Type_Decl;
else
As_Entity_1 := (Info => No_Entity_Info, Node => B_Prim); 
   If_Result_4 := As_Entity_1;
end if;
--# expr-done 4115
B_Prim_Ent := If_Result_4; 
--# bind b_prim_ent B_Prim_Ent
--# expr-start 4124 '<If at ast.py:7483>' If_Result_7 /tmp/lal-23.0.0/ada/ast.py:7483
--# expr-start 4117 '<FieldAccess for has_base_type at ast.py:7486>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:7486
      if A_Prim.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4116 '<FieldAccess for node at ast.py:7486>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:7486
Fld_20 := B_Prim_Ent.Node;
--# expr-done 4116
--# property-call-start BaseTypeDecl.has_base_type
Fld_21 := Libadalang.Implementation.Base_Type_Decl_P_Has_Base_Type (Node => A_Prim.Node, Target => Fld_20, E_Info => A_Prim.Info);
--# end
--# expr-done 4117
if Fld_21 then
Comp_Result := Index_159 >= Index_161; 
if Comp_Result then
   If_Result_5 := True;
else
   --# expr-start 4120 '<Not at ast.py:7498>' Not_Val_3 /tmp/lal-23.0.0/ada/ast.py:7498
--# expr-start 4119 '<FieldAccess for has_base_type at ast.py:7498>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7498
      if B_Prim_Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4118 '<FieldAccess for node at ast.py:7498>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7498
Fld_16 := A_Prim.Node;
--# expr-done 4118
--# property-call-start BaseTypeDecl.has_base_type
Fld_17 := Libadalang.Implementation.Base_Type_Decl_P_Has_Base_Type (Node => B_Prim_Ent.Node, Target => Fld_16, E_Info => B_Prim_Ent.Info);
--# end
--# expr-done 4119
Not_Val_3 := not (Fld_17); 
--# expr-done 4120
   If_Result_5 := Not_Val_3;
end if;
   If_Result_7 := If_Result_5;
else
Comp_Result_1 := Index_159 <= Index_161; 
if Comp_Result_1 then
   --# expr-start 4123 '<Not at ast.py:7510>' Not_Val_4 /tmp/lal-23.0.0/ada/ast.py:7510
--# expr-start 4122 '<FieldAccess for has_base_type at ast.py:7510>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:7510
      if B_Prim_Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4121 '<FieldAccess for node at ast.py:7510>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7510
Fld_18 := A_Prim.Node;
--# expr-done 4121
--# property-call-start BaseTypeDecl.has_base_type
Fld_19 := Libadalang.Implementation.Base_Type_Decl_P_Has_Base_Type (Node => B_Prim_Ent.Node, Target => Fld_18, E_Info => B_Prim_Ent.Info);
--# end
--# expr-done 4122
Not_Val_4 := not (Fld_19); 
--# expr-done 4123
   If_Result_6 := Not_Val_4;
else
   If_Result_6 := False;
end if;
   If_Result_7 := If_Result_6;
end if;
--# expr-done 4124
Let_Result := If_Result_7; 
--# end
--# expr-done 4125
   If_Result_8 := Let_Result;
end if;
Let_Result_1 := If_Result_8; 
--# end
--# expr-done 4126
      Quantifier_Result := Let_Result_1;
   --# end
               exit when not Quantifier_Result;
               Index_161 := Index_161 + 1;
         end loop;
      end;
--# expr-done 4127
Let_Result_2 := Quantifier_Result; 
--# end
--# expr-done 4128
         if Let_Result_2 then
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Item_158;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
               Index_159 := Index_159 + 1;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 4129
Let_Result_3 := Map_Result_2; Inc_Ref (Let_Result_3);
--# end
--# expr-done 4130
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_571;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_571;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Get_Primitives;
--# end
--# property-start TypeDecl.get_imp_deref /tmp/lal-23.0.0/ada/ast.py:7516
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Get_Imp_Deref
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Sym : Symbol_Type;
Fld : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4132 '<FieldAccess for get_aspect_spec_expr at ast.py:7517>' Fld /tmp/lal-23.0.0/ada/ast.py:7517
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4131 '<Symbol Implicit_Dereference at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Implicit_Dereference); 
--# expr-done 4131
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym, E_Info => Ent.Info);
--# end
--# expr-done 4132
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Get_Imp_Deref;
--# end
--# property-start TypeDecl.has_ud_indexing /tmp/lal-23.0.0/ada/ast.py:7520
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Has_Ud_Indexing
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Sym : Symbol_Type;
Fld : Internal_Entity_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
Sym_1 : Symbol_Type;
Fld_1 : Internal_Entity_Expr;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 4136 '<Not at ast.py:7521>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7521
--# expr-start 4135 '<IsNull at ast.py:7521>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7521
--# expr-start 4134 '<FieldAccess for get_aspect_spec_expr at ast.py:7521>' Fld /tmp/lal-23.0.0/ada/ast.py:7521
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4133 '<Symbol Constant_Indexing at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Constant_Indexing); 
--# expr-done 4133
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym, E_Info => Ent.Info);
--# end
--# expr-done 4134
Is_Null := Fld.Node = null; 
--# expr-done 4135
Not_Val := not (Is_Null); 
--# expr-done 4136
if Not_Val then
   If_Result := True;
else
   --# expr-start 4140 '<Not at ast.py:7522>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:7522
--# expr-start 4139 '<IsNull at ast.py:7522>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:7522
--# expr-start 4138 '<FieldAccess for get_aspect_spec_expr at ast.py:7522>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7522
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4137 '<Symbol Variable_Indexing at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Variable_Indexing); 
--# expr-done 4137
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym_1, E_Info => Ent.Info);
--# end
--# expr-done 4138
Is_Null_1 := Fld_1.Node = null; 
--# expr-done 4139
Not_Val_1 := not (Is_Null_1); 
--# expr-done 4140
   If_Result := Not_Val_1;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Has_Ud_Indexing;
--# end
--# property-start TypeDecl.constant_indexing_fns /tmp/lal-23.0.0/ada/ast.py:7526
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Constant_Indexing_Fns
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_574 with Inline_Always;
            procedure Finalizer_Scope_2393 with Inline_Always;
            procedure Finalizer_Scope_2395 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Var_Expr_2 : Internal_Entity_Defining_Name;
Sym : Symbol_Type;
Fld : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
Scope_Result : Internal_Entity_Array_Access;
Result_Var : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Cast_Expr_2 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Base_Subp_Spec;
Fld_3 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_4 : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_5 : Internal_Entity_Base_Formal_Param_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr_3 : Internal_Entity_Type_Decl;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Fld_7 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_574 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_574;
            procedure Finalizer_Scope_2393 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2393;
            procedure Finalizer_Scope_2395 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2395;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4156 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4155 '<FilterMap at ast.py:7530>' Map_Result /tmp/lal-23.0.0/ada/ast.py:7530
--# expr-start 4142 '<FieldAccess for get_aspect_spec_expr at ast.py:7528>' Fld /tmp/lal-23.0.0/ada/ast.py:7528
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4141 '<Symbol Constant_Indexing at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Constant_Indexing); 
--# expr-done 4141
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym, E_Info => Ent.Info);
--# end
--# expr-done 4142
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
--# expr-start 4144 '<FieldAccess for all_env_elements_internal at ast.py:7528>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7528
--# expr-start 4143 '<Cast to Name at ast.py:7529>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7529
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4143
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_env_elements_internal
Fld_1 := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Cast_Result.Node, Seq => False, E_Info => Cast_Result.Info);
--# end
--# expr-done 4144
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2393;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var);
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Result_Var;
      begin
         for Item_162 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_162
--# expr-start 4146 '<FieldAccess for subp_spec_or_null at ast.py:7533>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7533
--# expr-start 4145 '<Cast to BasicDecl at ast.py:7533>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:7533
Cast_Expr_2 := Item_162; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4145
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result_2.Node, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 4146
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr_1
--# expr-start 4153 '<bind at ast.py:7535>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7535
--# expr-start 4147 '<FieldAccess for origin_node at ast.py:7536>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7536
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_3 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 4147
Bound_Origin := Fld_3; 
--# expr-start 4152 '<FieldAccess for matching_formal_type at ast.py:7538>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7538
--# expr-start 4149 '<at at ast.py:7537>' Get_Result /tmp/lal-23.0.0/ada/ast.py:7537
--# expr-start 4148 '<FieldAccess for unpacked_formal_params at ast.py:7537>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7537
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4148
Get_Result := Get (Self, Fld_4, 0, True); 
--# expr-done 4149
Var_Expr_2 := Get_Result;
if Var_Expr_2 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 4151 '<FieldAccess for formal_type at ast.py:7538>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7538
--# expr-start 4150 '<FieldAccess for formal_decl at ast.py:7538>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7538
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_5 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 4150
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_5.Node, Origin => Bound_Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 4151
Scope_Result_1 := Fld_6;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
      if Result_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_3 := Ent; 
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_7 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Result_Var_1.Node, Formal_Type => Cast_Result_3, Origin => Bound_Origin, E_Info => Result_Var_1.Info);
--# end
--# expr-done 4152
Dyn_Var_Bind_Result := Fld_7; 
--# expr-done 4153
Scope_Result_2 := Dyn_Var_Bind_Result;
   --# end
      Finalizer_Scope_2395;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
         if Result_Var_2 then
      --# expr-start 4154 '<Cast to BasicDecl at ast.py:7531>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7531
Cast_Expr_1 := Item_162; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 4154
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result_1;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4155
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 4156
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_574;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_574;
               Finalizer_Scope_2393;
               Finalizer_Scope_2395;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Constant_Indexing_Fns;
--# end
--# property-start TypeDecl.variable_indexing_fns /tmp/lal-23.0.0/ada/ast.py:7545
pragma Warnings (Off, "is not referenced");
 function Type_Decl_P_Variable_Indexing_Fns
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_575 with Inline_Always;
            procedure Finalizer_Scope_2397 with Inline_Always;
            procedure Finalizer_Scope_2399 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Var_Expr_2 : Internal_Entity_Defining_Name;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Sym : Symbol_Type;
Fld_1 : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_2 : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Cast_Expr_2 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Base_Subp_Spec;
Fld_4 : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_5 : Internal_Entity_Base_Formal_Param_Decl;
Fld_6 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Cast_Expr_3 : Internal_Entity_Type_Decl;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Fld_7 : Boolean;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Boolean;
If_Result : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result_2 : Internal_Entity_Basic_Decl_Array_Access;
Result_Var_2 : Internal_Entity_Basic_Decl_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_575 is
            begin
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_575;
            procedure Finalizer_Scope_2397 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2397;
            procedure Finalizer_Scope_2399 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2399;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4174 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4173 '<bind at ast.py:7546>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7546
--# expr-start 4157 '<FieldAccess for origin_node at ast.py:7547>' Fld /tmp/lal-23.0.0/ada/ast.py:7547
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 4157
Bound_Origin := Fld; 
--# expr-start 4159 '<FieldAccess for get_aspect_spec_expr at ast.py:7548>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7548
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4158 '<Symbol Variable_Indexing at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Variable_Indexing); 
--# expr-done 4158
--# property-call-start BasicDecl.get_aspect_spec_expr
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect_Spec_Expr (Node => Ent.Node, Name => Sym, E_Info => Ent.Info);
--# end
--# expr-done 4159
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind a Var_Expr
--# expr-start 4172 '<FilterMap at ast.py:7550>' Map_Result /tmp/lal-23.0.0/ada/ast.py:7550
   --# expr-start 4161 '<FieldAccess for all_env_elements_internal at ast.py:7549>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7549
--# expr-start 4160 '<Cast to Name at ast.py:7549>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7549
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4160
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_env_elements_internal
Fld_2 := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Cast_Result.Node, Seq => False, E_Info => Cast_Result.Info);
--# end
--# expr-done 4161
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_2;
      begin
         for Item_163 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_163
--# expr-start 4163 '<FieldAccess for subp_spec_or_null at ast.py:7553>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7553
--# expr-start 4162 '<Cast to BasicDecl at ast.py:7553>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:7553
Cast_Expr_2 := Item_163; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4162
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result_2.Node, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 4163
Var_Expr_1 := Fld_3;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr_1
--# expr-start 4168 '<FieldAccess for matching_formal_type at ast.py:7556>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7556
--# expr-start 4165 '<at at ast.py:7555>' Get_Result /tmp/lal-23.0.0/ada/ast.py:7555
--# expr-start 4164 '<FieldAccess for unpacked_formal_params at ast.py:7555>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7555
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4164
Get_Result := Get (Self, Fld_4, 0, True); 
--# expr-done 4165
Var_Expr_2 := Get_Result;
if Var_Expr_2 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 4167 '<FieldAccess for formal_type at ast.py:7556>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7556
--# expr-start 4166 '<FieldAccess for formal_decl at ast.py:7556>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7556
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_5 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 4166
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_5.Node, Origin => Bound_Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 4167
Scope_Result := Fld_6;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
      if Result_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_3 := Ent; 
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
--# property-call-start BaseTypeDecl.matching_formal_type
Fld_7 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Formal_Type (Node => Result_Var.Node, Formal_Type => Cast_Result_3, Origin => Bound_Origin, E_Info => Result_Var.Info);
--# end
--# expr-done 4168
if Fld_7 then
   --# expr-start 4170 '<FieldAccess for is_implicit_deref at ast.py:7557>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7557
--# expr-start 4169 '<FieldAccess for return_type at ast.py:7557>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7557
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_8 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4169
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_implicit_deref
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Is_Implicit_Deref (Node => Fld_8.Node, Origin => Bound_Origin, E_Info => Fld_8.Info);
--# end
--# expr-done 4170
   If_Result := Fld_9;
else
   If_Result := False;
end if;
Scope_Result_1 := If_Result;
   --# end
      Finalizer_Scope_2399;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
         if Result_Var_1 then
      --# expr-start 4171 '<Cast to BasicDecl at ast.py:7551>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7551
Cast_Expr_1 := Item_163; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 4171
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result_1;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4172
Scope_Result_2 := Map_Result;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2397;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_2);
Dyn_Var_Bind_Result := Result_Var_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4173
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 4174
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_575;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_575;
               Finalizer_Scope_2397;
               Finalizer_Scope_2399;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Decl_P_Variable_Indexing_Fns;
--# end
--# property-start TypeDecl._env_mappings_3 /tmp/lal-23.0.0/ada/ast.py:7285
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_3
  (Node : Bare_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Decl :=
     Internal_Entity_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1471 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Type_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1471 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1471;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4177 '<New EnvAssoc at ast.py:7285>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:7285
--# expr-start 4175 '<New DesignatedEnv at ast.py:7285>' New_Struct /tmp/lal-23.0.0/ada/ast.py:7285
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4175
--# expr-start 4176 '<FieldAccess for name_symbol at ast.py:7285>' Fld /tmp/lal-23.0.0/ada/ast.py:7285
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4176
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4177
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1471;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1471;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_3;
--# end
--# property-start TypeDecl._env_mappings_4 /tmp/lal-23.0.0/ada/ast.py:7286
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_4
  (Node : Bare_Type_Decl
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1472 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1472 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1472;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4178 '<FieldAccess for predefined_operators at ast.py:7286>' Fld /tmp/lal-23.0.0/ada/ast.py:7286
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.predefined_operators
Fld := Libadalang.Implementation.Type_Decl_P_Predefined_Operators (Node => Self);
--# end
--# expr-done 4178
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1472;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1472;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_4;
--# end
--# property-start TypeDecl._env_trans_parent_5 /tmp/lal-23.0.0/ada/ast.py:7284
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_5
  (Node : Bare_Type_Decl
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_5;
--# end
--# property-start TypeDecl._ref_env_nodes_6 /tmp/lal-23.0.0/ada/ast.py:7290
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_6
  (Node : Bare_Type_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1475 with Inline_Always;
      Cast_Expr : Bare_Type_Decl;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1475 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1475;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4179 '<Cast to AdaNode at ast.py:7290>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7290
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4179
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1475;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1475;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_6;
--# end
--# property-start TypeDecl._env_dest_7 /tmp/lal-23.0.0/ada/ast.py:7293
pragma Warnings (Off, "is not referenced");
 function Env_Dest_7
  (Node : Bare_Type_Decl
  )
   return Lexical_Env
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1476 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1476 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1476;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4180 '<FieldAccess for node_env at ast.py:7293>' Fld /tmp/lal-23.0.0/ada/ast.py:7293
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Self);
--# expr-done 4180
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1476;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1476;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Dest_7;
--# end
--# property-start TypeDecl._ref_cond_8 /tmp/lal-23.0.0/ada/ast.py:7294
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_8
  (Node : Bare_Type_Decl
  )
   return Boolean
is
   Self : Bare_Type_Decl := Bare_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Type_Def;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4182 '<IsA DerivedTypeDef, InterfaceTypeDef at ast.py:7294>' Is_A /tmp/lal-23.0.0/ada/ast.py:7294
--# expr-start 4181 '<FieldAccess for type_def at ast.py:7294>' Fld /tmp/lal-23.0.0/ada/ast.py:7294
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Type_Decl_F_Type_Def;
--# expr-done 4181
Is_A := Fld /= null 
and then Fld.Kind in Ada_Derived_Type_Def_Range | Ada_Interface_Type_Def_Range; 
--# expr-done 4182
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_8;
--# end
function Type_Decl_F_Direct_Primitive_Subps
  (E : Entity
  ) return Internal_Inner_Env_Assoc_Array_Access
is
   Result : constant Internal_Inner_Env_Assoc_Array_Access :=
      Type_Decl_F_Direct_Primitive_Subps (E.Node);
begin
      return Result;
end;
function Type_Decl_P_Refined_Parent_Primitives_Env
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Type_Decl_P_Refined_Parent_Primitives_Env (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Anonymous_Type_Decl
   --
      procedure Initialize_Fields_For_Anonymous_Type_Decl
        (Self : Bare_Anonymous_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Type_Decl_F_Type_Def : Bare_Type_Def
        ) is
      begin
            Initialize_Fields_For_Type_Decl
              (Self, Base_Type_Decl_F_Name, Type_Decl_F_Discriminants, Type_Decl_F_Type_Def);
      end Initialize_Fields_For_Anonymous_Type_Decl;
--# property-start AnonymousTypeDecl.access_def_matches /tmp/lal-23.0.0/ada/ast.py:7595
pragma Warnings (Off, "is not referenced");
 function Anonymous_Type_Decl_P_Access_Def_Matches
  (Node : Bare_Anonymous_Type_Decl
      ; Other : Internal_Entity_Base_Type_Decl
      ; For_Assignment : Boolean
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Anonymous_Type_Decl := Bare_Anonymous_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Type_Decl :=
     Internal_Entity_Anonymous_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind other Other
   --# bind for_assignment For_Assignment
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Access_To_Subp_Def;
Block_Var_1 : Internal_Entity_Access_To_Subp_Def;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Access_Def;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Exp : Internal_Entity_Base_Type_Decl;
Act : Internal_Entity_Base_Type_Decl;
Var_Expr_3 : Internal_Entity_Base_Type_Decl;
Var_Expr_4 : Internal_Entity_Classwide_Type_Decl;
Var_Expr_5 : Internal_Entity_Base_Type_Decl;
Var_Expr_6 : Internal_Entity_Classwide_Type_Decl;
Fld : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Access_To_Subp_Def;
Fld_1 : Internal_Entity_Access_Def;
Cast_Result_1 : Internal_Entity_Access_To_Subp_Def;
Is_Null : Boolean;
Not_Val : Boolean;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld_2 : Internal_Entity_Subp_Spec;
Fld_3 : Internal_Entity_Subp_Spec;
Cast_Result_2 : Internal_Entity_Base_Subp_Spec;
Fld_4 : Boolean;
Is_Null_2 : Boolean;
Is_Null_3 : Boolean;
If_Result_1 : Boolean;
Fld_5 : Internal_Entity_Type_Def;
Cast_Result_3 : Internal_Entity_Access_Def;
Fld_6 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity_Classwide_Type_Decl;
Fld_8 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Result_Var_2 : Internal_Entity_Base_Type_Decl;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_5 : Internal_Entity_Classwide_Type_Decl;
Fld_9 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Result_Var_3 : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_4 : Internal_Entity_Base_Type_Decl;
Fld_10 : Boolean;
Fld_11 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
Scope_Result_6 : Boolean;
Result_Var_6 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Boolean;
Let_Result_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4209 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 4184 '<Cast to AccessToSubpDef at ast.py:7605>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7605
--# expr-start 4183 '<FieldAccess for type_def at ast.py:7605>' Fld /tmp/lal-23.0.0/ada/ast.py:7605
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 4183
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Access_To_Subp_Def_Range
   then
      Cast_Result := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Access_To_Subp_Def;
   end if;
--# expr-done 4184
Block_Var := Cast_Result; 
--# bind self_subp_access Block_Var
--# expr-start 4186 '<Cast to AccessToSubpDef at ast.py:7606>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:7606
--# expr-start 4185 '<FieldAccess for access_def at ast.py:7606>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7606
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Other.Node, Origin => Origin, E_Info => Other.Info);
--# end
--# expr-done 4185
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Access_To_Subp_Def_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result_1 := No_Entity_Access_To_Subp_Def;
   end if;
--# expr-done 4186
Block_Var_1 := Cast_Result_1; 
--# bind other_subp_access Block_Var_1
--# expr-start 4208 '<Cond at ast.py:7610>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:7610
--# expr-start 4188 '<Not at ast.py:7611>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7611
--# expr-start 4187 '<IsNull at ast.py:7611>' Is_Null /tmp/lal-23.0.0/ada/ast.py:7611
Is_Null := Block_Var.Node = null; 
--# expr-done 4187
Not_Val := not (Is_Null); 
--# expr-done 4188
if Not_Val then
   --# expr-start 4190 '<Not at ast.py:7611>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:7611
--# expr-start 4189 '<IsNull at ast.py:7611>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:7611
Is_Null_1 := Block_Var_1.Node = null; 
--# expr-done 4189
Not_Val_1 := not (Is_Null_1); 
--# expr-done 4190
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 4193 '<FieldAccess for match_signature at ast.py:7612>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7612
--# expr-start 4191 '<FieldAccess for subp_spec at ast.py:7612>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7612
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Subp_Spec (Node => Block_Var_1.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Block_Var_1.Info);
--# expr-done 4191
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4192 '<FieldAccess for subp_spec at ast.py:7613>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7613
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Subp_Spec (Node => Block_Var.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Block_Var.Info);
--# expr-done 4192
      Cast_Result_2 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
--# property-call-start BaseSubpSpec.match_signature
Fld_4 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld_2.Node, Other => Cast_Result_2, Match_Name => False, E_Info => Fld_2.Info);
--# end
--# expr-done 4193
   If_Result_4 := Fld_4;
else
--# expr-start 4194 '<IsNull at ast.py:7616>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:7616
Is_Null_2 := Block_Var.Node = null; 
--# expr-done 4194
if Is_Null_2 then
   --# expr-start 4195 '<IsNull at ast.py:7616>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:7616
Is_Null_3 := Block_Var_1.Node = null; 
--# expr-done 4195
   If_Result_1 := Is_Null_3;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
--# expr-start 4197 '<Cast to AccessDef at ast.py:7617>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:7617
--# expr-start 4196 '<FieldAccess for type_def at ast.py:7617>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7617
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Type_Def (Node => Ent.Node.Type_Decl_F_Type_Def, Info => Ent.Info);
--# expr-done 4196
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Access_Def
   then
      Cast_Result_3 := Create_Internal_Entity_Access_Def
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_3 := No_Entity_Access_Def;
   end if;
--# expr-done 4197
Var_Expr_1 := Cast_Result_3;
if Var_Expr_1 /= No_Entity_Access_Def then
   --# scope-start
--# expr-start 4198 '<FieldAccess for accessed_type at ast.py:7617>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7617
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.accessed_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Type_Def_P_Accessed_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4198
Scope_Result := Fld_6;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind ast Var_Expr
--# expr-start 4199 '<FieldAccess for accessed_type at ast.py:7618>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7618
      if Other.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Other.Node, Origin => Origin, E_Info => Other.Info);
--# end
--# expr-done 4199
Var_Expr_2 := Fld_7;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind oat Var_Expr_2
--# expr-start 4207 '<Let at ast.py:7619>' Let_Result /tmp/lal-23.0.0/ada/ast.py:7619
--# scope-start
--# expr-start 4200 '<Cast to ClasswideTypeDecl at ast.py:7624>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:7624
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Classwide_Type_Decl_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Classwide_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_4 := No_Entity_Classwide_Type_Decl;
   end if;
--# expr-done 4200
Var_Expr_4 := Cast_Result_4;
if Var_Expr_4 /= No_Entity_Classwide_Type_Decl then
   --# scope-start
--# expr-start 4201 '<FieldAccess for typedecl at ast.py:7624>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7624
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld_8 := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Var_Expr_4.Node, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 4201
Scope_Result_1 := Fld_8;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Var_Expr_3 := Result_Var_1;
if Var_Expr_3 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr_3
Scope_Result_2 := Var_Expr_3;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Var_Expr;
end if;
Exp := Result_Var_2; 
--# bind exp Exp
--# expr-start 4202 '<Cast to ClasswideTypeDecl at ast.py:7625>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:7625
Cast_Expr_1 := Var_Expr_2; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Classwide_Type_Decl_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Classwide_Type_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_5 := No_Entity_Classwide_Type_Decl;
   end if;
--# expr-done 4202
Var_Expr_6 := Cast_Result_5;
if Var_Expr_6 /= No_Entity_Classwide_Type_Decl then
   --# scope-start
--# expr-start 4203 '<FieldAccess for typedecl at ast.py:7625>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7625
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ClasswideTypeDecl.typedecl
Fld_9 := Libadalang.Implementation.Classwide_Type_Decl_P_Typedecl (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 4203
Scope_Result_3 := Fld_9;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Entity_Base_Type_Decl;
end if;
Var_Expr_5 := Result_Var_3;
if Var_Expr_5 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr_5
Scope_Result_4 := Var_Expr_5;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := Var_Expr_2;
end if;
Act := Result_Var_4; 
--# bind act Act
--# expr-start 4206 '<If at ast.py:7626>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:7626
if For_Assignment then
   --# expr-start 4204 '<FieldAccess for matching_assign_type at ast.py:7632>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7632
      if Act.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_assign_type
Fld_10 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Assign_Type (Node => Act.Node, Expected_Type => Var_Expr, Origin => Origin, E_Info => Act.Info);
--# end
--# expr-done 4204
   If_Result_2 := Fld_10;
else
   --# expr-start 4205 '<FieldAccess for matching_type at ast.py:7634>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7634
      if Act.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_11 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Act.Node, Expected_Type => Exp, Origin => Origin, E_Info => Act.Info);
--# end
--# expr-done 4205
   If_Result_2 := Fld_11;
end if;
--# expr-done 4206
Let_Result := If_Result_2; 
--# end
--# expr-done 4207
Scope_Result_5 := Let_Result;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
Scope_Result_6 := Result_Var_5;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := False;
end if;
   If_Result_3 := Result_Var_6;
else
   If_Result_3 := False;
end if;
   If_Result_4 := If_Result_3;
end if;
--# expr-done 4208
Let_Result_1 := If_Result_4; 
--# end
--# expr-done 4209
      Property_Result := Let_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Type_Decl_P_Access_Def_Matches;
--# end
--# property-start AnonymousTypeDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:7643
pragma Warnings (Off, "is not referenced");
 function Anonymous_Type_Decl_P_Xref_Entry_Point
  (Node : Bare_Anonymous_Type_Decl
  )
   return Boolean
is
   Self : Bare_Anonymous_Type_Decl := Bare_Anonymous_Type_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Type_Decl_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_Synth_Anonymous_Type_Decl
   --
      procedure Initialize_Fields_For_Synth_Anonymous_Type_Decl
        (Self : Bare_Synth_Anonymous_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Type_Decl_F_Type_Def : Bare_Type_Def
        ) is
      begin
            Initialize_Fields_For_Anonymous_Type_Decl
              (Self, Base_Type_Decl_F_Name, Type_Decl_F_Discriminants, Type_Decl_F_Type_Def);
      end Initialize_Fields_For_Synth_Anonymous_Type_Decl;
   --
   --  Primitives for Bare_Concrete_Type_Decl
   --
      procedure Initialize_Fields_For_Concrete_Type_Decl
        (Self : Bare_Concrete_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Type_Decl_F_Type_Def : Bare_Type_Def
         ; Concrete_Type_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Type_Decl
              (Self, Base_Type_Decl_F_Name, Type_Decl_F_Discriminants, Type_Decl_F_Type_Def);
            Self.Concrete_Type_Decl_F_Aspects := Concrete_Type_Decl_F_Aspects;
      end Initialize_Fields_For_Concrete_Type_Decl;
   --
   --  Primitives for Bare_Formal_Type_Decl
   --
      procedure Initialize_Fields_For_Formal_Type_Decl
        (Self : Bare_Formal_Type_Decl
         ; Base_Type_Decl_F_Name : Bare_Defining_Name
         ; Type_Decl_F_Discriminants : Bare_Discriminant_Part
         ; Type_Decl_F_Type_Def : Bare_Type_Def
         ; Formal_Type_Decl_F_Default_Type : Bare_Name
         ; Formal_Type_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Type_Decl
              (Self, Base_Type_Decl_F_Name, Type_Decl_F_Discriminants, Type_Decl_F_Type_Def);
            Self.Formal_Type_Decl_F_Default_Type := Formal_Type_Decl_F_Default_Type;
            Self.Formal_Type_Decl_F_Aspects := Formal_Type_Decl_F_Aspects;
      end Initialize_Fields_For_Formal_Type_Decl;
   function Formal_Type_Decl_F_Default_Type
     (Node : Bare_Formal_Type_Decl) return Bare_Name
   is
   begin
         return Node.Formal_Type_Decl_F_Default_Type;
   end;
--# property-start FormalTypeDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:7579
pragma Warnings (Off, "is not referenced");
 function Formal_Type_Decl_P_Xref_Equation
  (Node : Bare_Formal_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Formal_Type_Decl := Bare_Formal_Type_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Formal_Type_Decl :=
     Internal_Entity_Formal_Type_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_576 with Inline_Always;
            procedure Finalizer_Scope_2408 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Fld : Logic_Equation;
Fld_1 : Internal_Entity_Name;
Fld_2 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_576 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_576;
            procedure Finalizer_Scope_2408 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2408;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4214 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4213 '<And at ast.py:7580>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7580
--# expr-start 4210 '<Super at ast.py:7580>' Fld /tmp/lal-23.0.0/ada/ast.py:7580
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDecl.xref_equation
Fld := Libadalang.Implementation.Type_Decl_P_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 4210
--# expr-start 4211 '<FieldAccess for default_type at ast.py:7580>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7580
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Formal_Type_Decl_F_Default_Type, Info => Ent.Info);
--# expr-done 4211
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind dt Var_Expr
--# expr-start 4212 '<FieldAccess for sub_equation at ast.py:7581>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7581
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_2 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 4212
Scope_Result := Fld_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2408;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7582") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7580") else null)); 
--# expr-done 4213
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 4214
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_576;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_576;
               Finalizer_Scope_2408;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Type_Decl_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Basic_Subp_Decl
   --
      procedure Basic_Subp_Decl_Pre_Env_Actions
        (Self            : Bare_Basic_Subp_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_25 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_26 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:9425");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_27 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:9432");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_28 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_29 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_30 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_32 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_31 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_34 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_33 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Basic_Subp_Decl_Post_Env_Actions
        (Self : Bare_Basic_Subp_Decl; State : in out PLE_Node_State) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_35 (Node => 
Self);
      end;
      end;
--# property-start BasicSubpDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:9316
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Defining_Names
  (Node : Bare_Basic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_764 with Inline_Always;
      Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_764 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_764;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4216 '<FieldAccess for name at ast.py:9316>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9316
--# expr-start 4215 '<FieldAccess for subp_decl_spec at ast.py:9316>' Fld /tmp/lal-23.0.0/ada/ast.py:9316
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4215
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4216
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_1;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_764;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_764;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Defining_Names;
--# end
--# property-start BasicSubpDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:9318
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Defining_Env
  (Node : Bare_Basic_Subp_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_765 with Inline_Always;
      Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_765 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_765;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4218 '<FieldAccess for defining_env at ast.py:9318>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9318
--# expr-start 4217 '<FieldAccess for subp_decl_spec at ast.py:9318>' Fld /tmp/lal-23.0.0/ada/ast.py:9318
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4217
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.defining_env
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Defining_Env (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 4218
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_765;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_765;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Defining_Env;
--# end
--# property-start BasicSubpDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:9320
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Type_Expression
  (Node : Bare_Basic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4220 '<FieldAccess for returns at ast.py:9321>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9321
--# expr-start 4219 '<FieldAccess for subp_decl_spec at ast.py:9321>' Fld /tmp/lal-23.0.0/ada/ast.py:9321
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4219
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4220
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Type_Expression;
--# end
--# property-start BasicSubpDecl.get_body_in_env /tmp/lal-23.0.0/ada/ast.py:9328
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Get_Body_In_Env
  (Node : Bare_Basic_Subp_Decl
      ; Env : Lexical_Env
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Body_Node
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Body_Node;
            procedure Finalizer_Scope_767 with Inline_Always;
      Block_Var : Internal_Entity_Array_Access;
Block_Var_1 : Internal_Entity_Body_Node;
Block_Var_2 : Internal_Entity_Body_Node;
Var_Expr : Internal_Entity_Body_Node;
Var_Expr_1 : Internal_Entity_Body_Node;
Fld : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Fld_1 : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Body_Node;
Fld_2 : Internal_Entity_Base_Formal_Param_Holder;
Fld_3 : Internal_Entity_Base_Subp_Spec;
Fld_4 : Bare_Base_Subp_Spec;
As_Entity_1 : Internal_Entity_Base_Subp_Spec;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Base_Subp_Spec;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_5 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Find_Result : Internal_Entity;
Cast_Result_2 : Internal_Entity_Body_Node;
Is_A : Boolean;
Find_Result_1 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Body_Node;
Is_Null_2 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Internal_Entity_Body_Node;
Fld_6 : Bare_Body_Node;
As_Entity_2 : Internal_Entity_Body_Node;
Is_Null_3 : Boolean;
If_Result_4 : Internal_Entity_Body_Node;
Fld_7 : Internal_Entity;
Scope_Result_1 : Internal_Entity;
Result_Var_1 : Internal_Entity;
Cast_Result_4 : Internal_Entity_Body_Node;
Let_Result : Internal_Entity_Body_Node;
            procedure Finalizer_Scope_767 is
            begin
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_767;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4242 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4222 '<EnvGet at ast.py:9330>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:9330
--# expr-start 4221 '<FieldAccess for name_symbol at ast.py:9330>' Fld /tmp/lal-23.0.0/ada/ast.py:9330
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4221
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Env, Key => Fld, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 4222
Block_Var := Env_Get_Result; Inc_Ref (Block_Var);
--# bind elements Block_Var
--# expr-start 4232 '<Cast to Body at ast.py:9340>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:9340
--# expr-start 4231 '<Find at ast.py:9332>' Find_Result /tmp/lal-23.0.0/ada/ast.py:9332
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_164 of
               Collection.Items
         loop
   --# scope-start
               --# bind ent Item_164
--# expr-start 4225 '<Cast to Body at ast.py:9336>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9336
--# expr-start 4224 '<as_bare_entity at ast.py:9336>' If_Result /tmp/lal-23.0.0/ada/ast.py:9336
--# expr-start 4223 '<FieldAccess for node at ast.py:9336>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9336
Fld_1 := Item_164.Node;
--# expr-done 4223
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 4224
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Body_Node
   then
      Cast_Result := Create_Internal_Entity_Body_Node
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Body_Node;
   end if;
--# expr-done 4225
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Body_Node then
   --# scope-start
--# expr-start 4230 '<FieldAccess for match_other at ast.py:9337>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9337
--# expr-start 4226 '<FieldAccess for formal_param_holder_or_null at ast.py:9337>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9337
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.formal_param_holder_or_null
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Formal_Param_Holder_Or_Null (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 4226
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4229 '<as_bare_entity at ast.py:9338>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:9338
--# expr-start 4228 '<FieldAccess for node at ast.py:9338>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9338
--# expr-start 4227 '<FieldAccess for subp_decl_spec at ast.py:9338>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9338
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4227
Fld_4 := Fld_3.Node;
--# expr-done 4228
Is_Null_1 := Fld_4 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Base_Subp_Spec;
else
As_Entity_1 := (Info => No_Entity_Info, Node => Fld_4); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 4229
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => If_Result_1.Node,
         Info => If_Result_1.Info);
--# property-call-start '[dispatcher]BaseFormalParamHolder.match_other'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Match_Other (Node => Fld_2.Node, Other => Cast_Result_1, Match_Names => True, E_Info => Fld_2.Info);
--# end
--# expr-done 4230
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      if Result_Var then
         Find_Result := Item_164;
      end if;
   --# end
               exit when Result_Var;
         end loop;
      end;
--# expr-done 4231
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Body_Node
   then
      Cast_Result_2 := Create_Internal_Entity_Body_Node
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_2 := No_Entity_Body_Node;
   end if;
--# expr-done 4232
Block_Var_1 := Cast_Result_2; 
--# bind precise Block_Var_1
--# expr-start 4237 '<If at ast.py:9342>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:9342
--# expr-start 4233 '<IsNull at ast.py:9343>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:9343
Is_Null_2 := Block_Var_1.Node = null; 
--# expr-done 4233
if Is_Null_2 then
   If_Result_2 := Imprecise_Fallback;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   --# expr-start 4236 '<Cast to Body at ast.py:9344>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:9344
--# expr-start 4235 '<Find at ast.py:9344>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:9344
      Find_Result_1 := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_165 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_165
      --# expr-start 4234 '<IsA Body at ast.py:9344>' Is_A /tmp/lal-23.0.0/ada/ast.py:9344
Is_A := Item_165.Node /= null 
and then Item_165.Node.Kind in Ada_Body_Node; 
--# expr-done 4234
      if Is_A then
         Find_Result_1 := Item_165;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 4235
   if Find_Result_1.Node = null
      or else Find_Result_1.Node.Kind in Ada_Body_Node
   then
      Cast_Result_3 := Create_Internal_Entity_Body_Node
        (Node => Find_Result_1.Node,
         Info => Find_Result_1.Info);
   else
         Cast_Result_3 := No_Entity_Body_Node;
   end if;
--# expr-done 4236
   If_Result_3 := Cast_Result_3;
else
   If_Result_3 := Block_Var_1;
end if;
--# expr-done 4237
Block_Var_2 := If_Result_3; 
--# bind result Block_Var_2
--# expr-start 4241 '<Cast to Body at ast.py:9349>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:9349
--# expr-start 4239 '<as_entity at ast.py:9349>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:9349
--# expr-start 4238 '<FieldAccess for node at ast.py:9349>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9349
Fld_6 := Block_Var_2.Node;
--# expr-done 4238
Is_Null_3 := Fld_6 = null; 
if Is_Null_3 then
   If_Result_4 := No_Entity_Body_Node;
else
As_Entity_2 := (Info => E_Info, Node => Fld_6); 
   If_Result_4 := As_Entity_2;
end if;
--# expr-done 4239
Var_Expr_1 := If_Result_4;
if Var_Expr_1 /= No_Entity_Body_Node then
   --# scope-start
--# expr-start 4240 '<FieldAccess for without_md at ast.py:9349>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9349
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.without_md
Fld_7 := Libadalang.Implementation.Ada_Node_P_Without_Md (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4240
Scope_Result_1 := Fld_7;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity;
end if;
   if Result_Var_1.Node = null
      or else Result_Var_1.Node.Kind in Ada_Body_Node
   then
      Cast_Result_4 := Create_Internal_Entity_Body_Node
        (Node => Result_Var_1.Node,
         Info => Result_Var_1.Info);
   else
         Cast_Result_4 := No_Entity_Body_Node;
   end if;
--# expr-done 4241
Let_Result := Cast_Result_4; 
--# end
--# expr-done 4242
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_767;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_767;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Get_Body_In_Env;
--# end
--# property-start BasicSubpDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:9352
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Next_Part_For_Decl
  (Node : Bare_Basic_Subp_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_768 with Inline_Always;
            procedure Finalizer_Scope_2414 with Inline_Always;
            procedure Finalizer_Scope_2415 with Inline_Always;
            procedure Finalizer_Scope_2417 with Inline_Always;
      Block_Var : Bare_Declarative_Part;
Block_Var_1 : Internal_Entity_Basic_Decl;
Block_Var_2 : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Declarative_Part;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Var_Expr_2 : Internal_Entity_Body_Node;
Var_Expr_3 : Internal_Entity_Private_Part;
Var_Expr_4 : Internal_Entity_Body_Node;
Fld : Bare_Declarative_Part;
As_Entity : Internal_Entity_Declarative_Part;
Is_Null : Boolean;
If_Result : Internal_Entity_Declarative_Part;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Basic_Decl;
Is_Null_1 : Boolean;
Not_Val : Boolean;
Is_A : Boolean;
Fld_3 : Internal_Entity_Basic_Decl;
Fld_4 : Lexical_Env := Empty_Env;
Fld_5 : Internal_Entity_Body_Node;
Scope_Result_1 : Internal_Entity_Body_Node;
Result_Var_1 : Internal_Entity_Body_Node;
Is_A_1 : Boolean;
Fld_6 : Internal_Entity_Private_Part;
Fld_7 : Lexical_Env := Empty_Env;
Fld_8 : Internal_Entity_Body_Node;
Scope_Result_2 : Internal_Entity_Body_Node;
Result_Var_2 : Internal_Entity_Body_Node;
Scope_Result_3 : Internal_Entity_Body_Node;
Fld_9 : Internal_Entity_Body_Node;
Fld_10 : Lexical_Env := Empty_Env;
Fld_11 : Internal_Entity_Body_Node;
Scope_Result_4 : Internal_Entity_Body_Node;
Result_Var_3 : Internal_Entity_Body_Node;
Result_Var_4 : Internal_Entity_Body_Node;
Is_Null_2 : Boolean;
Fld_12 : Lexical_Env := Empty_Env;
Fld_13 : Internal_Entity_Body_Node;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Cast_Expr : Internal_Entity_Body_Node;
Cast_Result_2 : Internal_Entity_Basic_Decl;
If_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
If_Result_2 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity_Basic_Decl;
If_Result_3 : Internal_Entity_Basic_Decl;
If_Result_4 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_768 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_768;
            procedure Finalizer_Scope_2414 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2414;
            procedure Finalizer_Scope_2415 is
            begin
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_2415;
            procedure Finalizer_Scope_2417 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_2417;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4265 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4243 '<FieldAccess for declarative_scope at ast.py:9353>' Fld /tmp/lal-23.0.0/ada/ast.py:9353
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 4243
Block_Var := Fld; 
--# bind decl_scope Block_Var
--# expr-start 4244 '<as_entity at ast.py:9354>' If_Result /tmp/lal-23.0.0/ada/ast.py:9354
Is_Null := Block_Var = null; 
if Is_Null then
   If_Result := No_Entity_Declarative_Part;
else
As_Entity := (Info => E_Info, Node => Block_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 4244
Var_Expr := If_Result;
if Var_Expr /= No_Entity_Declarative_Part then
   --# scope-start
   --# bind ds Var_Expr
--# expr-start 4246 '<Cast to BasicDecl at ast.py:9355>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9355
--# expr-start 4245 '<FieldAccess for semantic_parent at ast.py:9355>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9355
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_1 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 4245
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 4246
Scope_Result := Cast_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Block_Var_1 := Result_Var; 
--# bind parent_decl Block_Var_1
--# expr-start 4247 '<FieldAccess for basic_decl_next_part_for_decl at ast.py:9358>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9358
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.basic_decl_next_part_for_decl
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Next_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4247
Block_Var_2 := Fld_2; 
--# bind default_next_part Block_Var_2
--# expr-start 4264 '<Cond at ast.py:9360>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:9360
--# expr-start 4249 '<Not at ast.py:9363>' Not_Val /tmp/lal-23.0.0/ada/ast.py:9363
--# expr-start 4248 '<IsNull at ast.py:9363>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:9363
Is_Null_1 := Block_Var_2.Node = null; 
--# expr-done 4248
Not_Val := not (Is_Null_1); 
--# expr-done 4249
if Not_Val then
   If_Result_4 := Block_Var_2;
else
--# expr-start 4250 '<IsA PrivatePart at ast.py:9367>' Is_A /tmp/lal-23.0.0/ada/ast.py:9367
Is_A := Block_Var /= null 
and then Block_Var.Kind in Ada_Private_Part_Range; 
--# expr-done 4250
if Is_A then
--# expr-start 4251 '<FieldAccess for next_part_for_decl at ast.py:9368>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9368
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Block_Var_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var_1.Info);
--# end
--# expr-done 4251
Var_Expr_1 := Fld_3;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind np Var_Expr_1
--# expr-start 4253 '<FieldAccess for get_body_in_env at ast.py:9369>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9369
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4252 '<FieldAccess for children_env at ast.py:9369>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9369
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Children_Env (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# expr-done 4252
--# property-call-start BasicSubpDecl.get_body_in_env
Fld_5 := Libadalang.Implementation.Basic_Subp_Decl_P_Get_Body_In_Env (Node => Ent.Node, Env => Fld_4, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4253
Scope_Result_1 := Fld_5;
   --# end
      Finalizer_Scope_2414;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Body_Node;
end if;
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Result_Var_1.Node,
         Info => Result_Var_1.Info);
   If_Result_3 := Cast_Result_4;
else
--# expr-start 4254 '<IsA PublicPart at ast.py:9373>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:9373
Is_A_1 := Block_Var /= null 
and then Block_Var.Kind in Ada_Public_Part_Range; 
--# expr-done 4254
if Is_A_1 then
--# expr-start 4255 '<FieldAccess for decl_private_part at ast.py:9376>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9376
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.decl_private_part
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Decl_Private_Part (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 4255
Var_Expr_3 := Fld_6;
if Var_Expr_3 /= No_Entity_Private_Part then
   --# scope-start
   --# bind dpp Var_Expr_3
--# expr-start 4257 '<FieldAccess for get_body_in_env at ast.py:9377>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9377
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4256 '<FieldAccess for children_env at ast.py:9377>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9377
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Children_Env (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# expr-done 4256
--# property-call-start BasicSubpDecl.get_body_in_env
Fld_8 := Libadalang.Implementation.Basic_Subp_Decl_P_Get_Body_In_Env (Node => Ent.Node, Env => Fld_7, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4257
Scope_Result_2 := Fld_8;
   --# end
      Finalizer_Scope_2415;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Body_Node;
end if;
Var_Expr_2 := Result_Var_2;
if Var_Expr_2 /= No_Entity_Body_Node then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_3 := Var_Expr_2;
   --# end
   Result_Var_4 := Scope_Result_3;
else
--# expr-start 4258 '<FieldAccess for body_part_for_decl at ast.py:9380>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9380
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Block_Var_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var_1.Info);
--# end
--# expr-done 4258
Var_Expr_4 := Fld_9;
if Var_Expr_4 /= No_Entity_Body_Node then
   --# scope-start
   --# bind np Var_Expr_4
--# expr-start 4260 '<FieldAccess for get_body_in_env at ast.py:9381>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9381
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4259 '<FieldAccess for children_env at ast.py:9381>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9381
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Children_Env (Node => Var_Expr_4.Node, E_Info => Var_Expr_4.Info);
--# expr-done 4259
--# property-call-start BasicSubpDecl.get_body_in_env
Fld_11 := Libadalang.Implementation.Basic_Subp_Decl_P_Get_Body_In_Env (Node => Ent.Node, Env => Fld_10, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4260
Scope_Result_4 := Fld_11;
   --# end
      Finalizer_Scope_2417;
   Result_Var_3 := Scope_Result_4;
else
   Result_Var_3 := No_Entity_Body_Node;
end if;
   Result_Var_4 := Result_Var_3;
end if;
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Result_Var_4.Node,
         Info => Result_Var_4.Info);
   If_Result_2 := Cast_Result_3;
else
--# expr-start 4261 '<IsNull at ast.py:9385>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:9385
Is_Null_2 := Block_Var = null; 
--# expr-done 4261
if Is_Null_2 then
Cast_Expr := No_Entity_Body_Node; 
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   If_Result_1 := Cast_Result_2;
else
--# expr-start 4263 '<FieldAccess for get_body_in_env at ast.py:9389>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9389
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4262 '<FieldAccess for children_env at ast.py:9389>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9389
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Children_Env (Node => Block_Var);
--# expr-done 4262
--# property-call-start BasicSubpDecl.get_body_in_env
Fld_13 := Libadalang.Implementation.Basic_Subp_Decl_P_Get_Body_In_Env (Node => Ent.Node, Env => Fld_12, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4263
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_13.Node,
         Info => Fld_13.Info);
   If_Result_1 := Cast_Result_1;
end if;
   If_Result_2 := If_Result_1;
end if;
   If_Result_3 := If_Result_2;
end if;
   If_Result_4 := If_Result_3;
end if;
--# expr-done 4264
Let_Result := If_Result_4; 
--# end
--# expr-done 4265
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_768;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_768;
               Finalizer_Scope_2414;
               Finalizer_Scope_2415;
               Finalizer_Scope_2417;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Next_Part_For_Decl;
--# end
--# property-start BasicSubpDecl.constrain_prefix /tmp/lal-23.0.0/ada/ast.py:9393
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Constrain_Prefix
  (Node : Bare_Basic_Subp_Decl
      ; Prefix : Bare_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind prefix Prefix
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_769 with Inline_Always;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Subp_Spec;
Fld_2 : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
True_Rel : Logic_Equation;
Fld_6 : Internal_Entity_Info;
Fld_7 : Internal_Metadata;
Fld_8 : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_769 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_769;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4279 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4278 '<If at ast.py:9394>' If_Result /tmp/lal-23.0.0/ada/ast.py:9394
--# expr-start 4268 '<FieldAccess for dottable_subp at ast.py:9398>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9398
--# expr-start 4267 '<FieldAccess for md at ast.py:9398>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9398
--# expr-start 4266 '<FieldAccess for info at ast.py:9398>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9398
Fld_6 := Ent.Info;
--# expr-done 4266
Fld_7 := Fld_6.Md;
--# expr-done 4267
Fld_8 := Fld_7.Dottable_Subp;
--# expr-done 4268
if Fld_8 then
   --# expr-start 4277 '<And at ast.py:9399>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9399
--# expr-start 4275 '<Bind at ast.py:9399>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:9399
--# expr-start 4269 '<FieldAccess for expected_type_var at ast.py:9399>' Fld /tmp/lal-23.0.0/ada/ast.py:9399
      if Prefix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Prefix);
--# expr-done 4269
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 4272 '<at at ast.py:9401>' Get_Result /tmp/lal-23.0.0/ada/ast.py:9401
--# expr-start 4271 '<FieldAccess for unpacked_formal_params at ast.py:9401>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9401
--# expr-start 4270 '<FieldAccess for subp_decl_spec at ast.py:9400>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9400
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4270
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 4271
Get_Result := Get (Self, Fld_2, 0, True); 
--# expr-done 4272
Var_Expr := Get_Result;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 4274 '<FieldAccess for formal_type at ast.py:9401>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9401
--# expr-start 4273 '<FieldAccess for formal_decl at ast.py:9401>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9401
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_3 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 4273
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_3.Node, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 4274
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
      Cast_Result := Create_Internal_Entity
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9399") else null)); 
--# expr-done 4275
--# expr-start 4276 '<FieldAccess for matches_expected_prefix_type at ast.py:9402>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9402
      if Prefix = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_prefix_type
Fld_5 := Libadalang.Implementation.Expr_P_Matches_Expected_Prefix_Type (Node => Prefix, Origin => Origin);
--# end
--# expr-done 4276
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9399") else null)); 
--# expr-done 4277
   If_Result := And_Pred;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9403") else null)); 
   If_Result := True_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 4278
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 4279
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_769;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_769;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Constrain_Prefix;
--# end
--# property-start BasicSubpDecl.expr_type /tmp/lal-23.0.0/ada/ast.py:9407
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Expr_Type
  (Node : Bare_Basic_Subp_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4282 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4280 '<FieldAccess for subp_spec_or_null at ast.py:9408>' Fld /tmp/lal-23.0.0/ada/ast.py:9408
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4280
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 4281 '<FieldAccess for return_type at ast.py:9408>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9408
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 4281
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 4282
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Expr_Type;
--# end
--# property-start BasicSubpDecl.env_names /tmp/lal-23.0.0/ada/ast.py:9411
pragma Warnings (Off, "is not referenced");
 function Basic_Subp_Decl_P_Env_Names
  (Node : Bare_Basic_Subp_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_771 with Inline_Always;
            procedure Finalizer_Scope_2420 with Inline_Always;
      Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_771 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_771;
            procedure Finalizer_Scope_2420 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2420;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4285 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4283 '<FieldAccess for top_level_env_name at ast.py:9412>' Fld /tmp/lal-23.0.0/ada/ast.py:9412
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4283
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 4284 '<to_symbol at ast.py:9413>' Sym /tmp/lal-23.0.0/ada/ast.py:9413
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 4284
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Sym;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2420;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 4285
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_771;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_771;
               Finalizer_Scope_2420;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Basic_Subp_Decl_P_Env_Names;
--# end
--# property-start '[dispatcher]BasicSubpDecl.subp_decl_spec' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec
  (Node : Bare_Basic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Basic_Subp_Decl (Self.Kind) is
               when Ada_Abstract_Subp_Decl .. Ada_Subp_Decl =>
                  --# property-call-start ClassicSubpDecl.subp_decl_spec
                  Property_Result := Classic_Subp_Decl_P_Subp_Decl_Spec
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Entry_Decl =>
                  --# property-call-start EntryDecl.subp_decl_spec
                  Property_Result := Entry_Decl_P_Subp_Decl_Spec
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Literal_Decl .. Ada_Synthetic_Char_Enum_Lit =>
                  --# property-call-start EnumLiteralDecl.subp_decl_spec
                  Property_Result := Enum_Literal_Decl_P_Subp_Decl_Spec
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Internal =>
                  --# property-call-start GenericSubpInternal.subp_decl_spec
                  Property_Result := Generic_Subp_Internal_P_Subp_Decl_Spec
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Subp_Decl =>
                  --# property-call-start SyntheticSubpDecl.subp_decl_spec
                  Property_Result := Synthetic_Subp_Decl_P_Subp_Decl_Spec
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec;
--# end
--# property-start BasicSubpDecl._env_do_25 /tmp/lal-23.0.0/ada/ast.py:9423
pragma Warnings (Off, "is not referenced");
 function Env_Do_25
  (Node : Bare_Basic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4286 '<FieldAccess for env_hook at ast.py:9423>' Fld /tmp/lal-23.0.0/ada/ast.py:9423
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 4286
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_25;
--# end
--# property-start BasicSubpDecl._initial_env_26 /tmp/lal-23.0.0/ada/ast.py:9429
pragma Warnings (Off, "is not referenced");
 function Initial_Env_26
  (Node : Bare_Basic_Subp_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1495 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1495 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1495;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4287 '<FieldAccess for child_decl_initial_env at ast.py:9429>' Fld /tmp/lal-23.0.0/ada/ast.py:9429
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self, Private_Part => True);
--# end
--# expr-done 4287
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1495;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1495;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_26;
--# end
--# property-start BasicSubpDecl._env_mappings_27 /tmp/lal-23.0.0/ada/ast.py:9432
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_27
  (Node : Bare_Basic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Basic_Subp_Decl :=
     Internal_Entity_Basic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1496 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1496 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1496;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4288 '<FieldAccess for child_decl_env_assocs at ast.py:9432>' Fld /tmp/lal-23.0.0/ada/ast.py:9432
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_env_assocs
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Env_Assocs (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4288
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1496;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1496;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_27;
--# end
--# property-start BasicSubpDecl._env_trans_parent_28 /tmp/lal-23.0.0/ada/ast.py:9421
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_28
  (Node : Bare_Basic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_28;
--# end
--# property-start BasicSubpDecl._env_names_29 /tmp/lal-23.0.0/ada/ast.py:9434
pragma Warnings (Off, "is not referenced");
 function Env_Names_29
  (Node : Bare_Basic_Subp_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1498 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1498 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1498;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4289 '<FieldAccess for env_names at ast.py:9434>' Fld /tmp/lal-23.0.0/ada/ast.py:9434
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicSubpDecl.env_names
Fld := Libadalang.Implementation.Basic_Subp_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 4289
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1498;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1498;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_29;
--# end
--# property-start BasicSubpDecl._env_do_30 /tmp/lal-23.0.0/ada/ast.py:9436
pragma Warnings (Off, "is not referenced");
 function Env_Do_30
  (Node : Bare_Basic_Subp_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1499 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1499 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1499;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4290 '<FieldAccess for populate_dependent_units at ast.py:9436>' Fld /tmp/lal-23.0.0/ada/ast.py:9436
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 4290
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1499;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1499;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_30;
--# end
--# property-start BasicSubpDecl._ref_env_nodes_31 /tmp/lal-23.0.0/ada/ast.py:9439
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_31
  (Node : Bare_Basic_Subp_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1500 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1500 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1500;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4291 '<FieldAccess for top_level_use_package_clauses at ast.py:9439>' Fld /tmp/lal-23.0.0/ada/ast.py:9439
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 4291
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1500;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1500;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_31;
--# end
--# property-start BasicSubpDecl._ref_cond_32 /tmp/lal-23.0.0/ada/ast.py:9441
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_32
  (Node : Bare_Basic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4293 '<IsA LibraryItem, Subunit at ast.py:9441>' Is_A /tmp/lal-23.0.0/ada/ast.py:9441
--# expr-start 4292 '<parent at ast.py:9441>' Fld /tmp/lal-23.0.0/ada/ast.py:9441
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4292
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4293
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_32;
--# end
--# property-start BasicSubpDecl._ref_env_nodes_33 /tmp/lal-23.0.0/ada/ast.py:9445
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_33
  (Node : Bare_Basic_Subp_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1502 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1502 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1502;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4294 '<FieldAccess for top_level_use_type_clauses at ast.py:9445>' Fld /tmp/lal-23.0.0/ada/ast.py:9445
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 4294
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1502;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1502;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_33;
--# end
--# property-start BasicSubpDecl._ref_cond_34 /tmp/lal-23.0.0/ada/ast.py:9447
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_34
  (Node : Bare_Basic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4296 '<IsA LibraryItem, Subunit at ast.py:9447>' Is_A /tmp/lal-23.0.0/ada/ast.py:9447
--# expr-start 4295 '<parent at ast.py:9447>' Fld /tmp/lal-23.0.0/ada/ast.py:9447
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4295
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4296
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_34;
--# end
--# property-start BasicSubpDecl._env_do_35 /tmp/lal-23.0.0/ada/ast.py:9452
pragma Warnings (Off, "is not referenced");
 function Env_Do_35
  (Node : Bare_Basic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Basic_Subp_Decl := Bare_Basic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4297 '<FieldAccess for populate_body_unit at ast.py:9452>' Fld /tmp/lal-23.0.0/ada/ast.py:9452
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_body_unit
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Body_Unit (Node => Self);
--# end
--# expr-done 4297
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_35;
--# end
   --
   --  Primitives for Bare_Classic_Subp_Decl
   --
      procedure Initialize_Fields_For_Classic_Subp_Decl
        (Self : Bare_Classic_Subp_Decl
         ; Classic_Subp_Decl_F_Overriding : Bare_Overriding_Node
         ; Classic_Subp_Decl_F_Subp_Spec : Bare_Subp_Spec
        ) is
      begin
            Self.Classic_Subp_Decl_F_Overriding := Classic_Subp_Decl_F_Overriding;
            Self.Classic_Subp_Decl_F_Subp_Spec := Classic_Subp_Decl_F_Subp_Spec;
      end Initialize_Fields_For_Classic_Subp_Decl;
   function Classic_Subp_Decl_F_Overriding
     (Node : Bare_Classic_Subp_Decl) return Bare_Overriding_Node
   is
   begin
         return Node.Classic_Subp_Decl_F_Overriding;
   end;
   function Classic_Subp_Decl_F_Subp_Spec
     (Node : Bare_Classic_Subp_Decl) return Bare_Subp_Spec
   is
   begin
         return Node.Classic_Subp_Decl_F_Subp_Spec;
   end;
--# property-start ClassicSubpDecl.subp_decl_spec /tmp/lal-23.0.0/ada/ast.py:9466
pragma Warnings (Off, "is not referenced");
 function Classic_Subp_Decl_P_Subp_Decl_Spec
  (Node : Bare_Classic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Classic_Subp_Decl := Bare_Classic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classic_Subp_Decl :=
     Internal_Entity_Classic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Fld : Internal_Entity_Subp_Spec;
Cast_Result : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4298 '<FieldAccess for subp_spec at ast.py:9466>' Fld /tmp/lal-23.0.0/ada/ast.py:9466
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Classic_Subp_Decl_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4298
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classic_Subp_Decl_P_Subp_Decl_Spec;
--# end
--# property-start ClassicSubpDecl.body_part /tmp/lal-23.0.0/ada/ast.py:9470
pragma Warnings (Off, "is not referenced");
 function Classic_Subp_Decl_P_Body_Part
  (Node : Bare_Classic_Subp_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Body
is
   Self : Bare_Classic_Subp_Decl := Bare_Classic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Classic_Subp_Decl :=
     Internal_Entity_Classic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Subp_Body;
      Fld : Internal_Entity_Body_Node;
Cast_Result : Internal_Entity_Base_Subp_Body;
Let_Result : Internal_Entity_Base_Subp_Body;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4301 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4300 '<Cast to BaseSubpBody at ast.py:9474>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9474
--# expr-start 4299 '<FieldAccess for body_part_for_decl at ast.py:9474>' Fld /tmp/lal-23.0.0/ada/ast.py:9474
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4299
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Body
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4300
Let_Result := Cast_Result; 
--# end
--# expr-done 4301
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Classic_Subp_Decl_P_Body_Part;
--# end
   --
   --  Primitives for Bare_Abstract_Subp_Decl
   --
      procedure Initialize_Fields_For_Abstract_Subp_Decl
        (Self : Bare_Abstract_Subp_Decl
         ; Classic_Subp_Decl_F_Overriding : Bare_Overriding_Node
         ; Classic_Subp_Decl_F_Subp_Spec : Bare_Subp_Spec
         ; Abstract_Subp_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Classic_Subp_Decl
              (Self, Classic_Subp_Decl_F_Overriding, Classic_Subp_Decl_F_Subp_Spec);
            Self.Abstract_Subp_Decl_F_Aspects := Abstract_Subp_Decl_F_Aspects;
      end Initialize_Fields_For_Abstract_Subp_Decl;
   --
   --  Primitives for Bare_Formal_Subp_Decl
   --
      procedure Initialize_Fields_For_Formal_Subp_Decl
        (Self : Bare_Formal_Subp_Decl
         ; Classic_Subp_Decl_F_Overriding : Bare_Overriding_Node
         ; Classic_Subp_Decl_F_Subp_Spec : Bare_Subp_Spec
         ; Formal_Subp_Decl_F_Default_Expr : Bare_Expr
         ; Formal_Subp_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Classic_Subp_Decl
              (Self, Classic_Subp_Decl_F_Overriding, Classic_Subp_Decl_F_Subp_Spec);
            Self.Formal_Subp_Decl_F_Default_Expr := Formal_Subp_Decl_F_Default_Expr;
            Self.Formal_Subp_Decl_F_Aspects := Formal_Subp_Decl_F_Aspects;
      end Initialize_Fields_For_Formal_Subp_Decl;
   function Formal_Subp_Decl_F_Default_Expr
     (Node : Bare_Formal_Subp_Decl) return Bare_Expr
   is
   begin
         return Node.Formal_Subp_Decl_F_Default_Expr;
   end;
--# property-start FormalSubpDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:11210
pragma Warnings (Off, "is not referenced");
 function Formal_Subp_Decl_P_Defining_Names
  (Node : Bare_Formal_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Formal_Subp_Decl := Bare_Formal_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Formal_Subp_Decl :=
     Internal_Entity_Formal_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_889 with Inline_Always;
      Fld : Internal_Entity_Subp_Spec;
Fld_1 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_889 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_889;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4303 '<FieldAccess for name at ast.py:11210>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11210
--# expr-start 4302 '<FieldAccess for subp_spec at ast.py:11210>' Fld /tmp/lal-23.0.0/ada/ast.py:11210
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Classic_Subp_Decl_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4302
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4303
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_1;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_889;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_889;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Subp_Decl_P_Defining_Names;
--# end
--# property-start FormalSubpDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:11212
pragma Warnings (Off, "is not referenced");
 function Formal_Subp_Decl_P_Xref_Equation
  (Node : Bare_Formal_Subp_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Formal_Subp_Decl := Bare_Formal_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Formal_Subp_Decl :=
     Internal_Entity_Formal_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_890 with Inline_Always;
            procedure Finalizer_Scope_2421 with Inline_Always;
            procedure Finalizer_Scope_2422 with Inline_Always;
            procedure Finalizer_Scope_2423 with Inline_Always;
            procedure Finalizer_Scope_2424 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Match_0 : Internal_Entity_Null_Literal;
Match_1 : Internal_Entity_Box_Expr;
Match_2 : Internal_Entity_Name;
Match_3 : Internal_Entity_Expr;
Fld : Internal_Entity_Expr;
True_Rel : Logic_Equation;
True_Rel_1 : Logic_Equation;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Var;
Cast_Expr : Internal_Entity_Formal_Subp_Decl;
Cast_Result : Internal_Entity_Basic_Decl;
Pred : Logic_Equation;
And_Pred : Logic_Equation;
False_Rel : Logic_Equation;
True_Rel_2 : Logic_Equation;
Is_A : Boolean;
If_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Match_Prefix : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Null_Literal;
Let_Result : Logic_Equation;
Scope_Result : Logic_Equation;
Cast_Result_2 : Internal_Entity_Box_Expr;
Let_Result_1 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_3 : Internal_Entity_Name;
Let_Result_2 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_4 : Internal_Entity_Expr;
Let_Result_3 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Match_Result : Logic_Equation;
Scope_Result_4 : Logic_Equation;
True_Rel_3 : Logic_Equation;
Result_Var : Logic_Equation;
            procedure Finalizer_Scope_890 is
            begin
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (True_Rel_3);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_890;
            procedure Finalizer_Scope_2421 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_2421;
            procedure Finalizer_Scope_2422 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_2422;
            procedure Finalizer_Scope_2423 is
            begin
                     Dec_Ref (True_Rel_1);
            end Finalizer_Scope_2423;
            procedure Finalizer_Scope_2424 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred);
                     Dec_Ref (False_Rel);
                     Dec_Ref (True_Rel_2);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2424;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 4304 '<FieldAccess for default_expr at ast.py:11213>' Fld /tmp/lal-23.0.0/ada/ast.py:11213
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Formal_Subp_Decl_F_Default_Expr, Info => Ent.Info);
--# expr-done 4304
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 4313 '<Match at ast.py:11213>' Match_Result /tmp/lal-23.0.0/ada/ast.py:11213
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Expr (Match_Prefix.Node.Kind) is
         when Ada_Null_Literal =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Null_Literal
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind _ Match_0
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11214") else null)); 
Let_Result := True_Rel; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2422;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Box_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Box_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind _ Match_1
True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11216") else null)); 
Let_Result_1 := True_Rel_1; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2423;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref .. Ada_String_Literal | Ada_Int_Literal .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind n Match_2
--# expr-start 4312 '<And at ast.py:11218>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:11218
--# expr-start 4309 '<And at ast.py:11219>' And_Pred /tmp/lal-23.0.0/ada/ast.py:11219
--# expr-start 4305 '<FieldAccess for xref_no_overloading at ast.py:11219>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11219
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Match_2.Node, All_Els => True, Env => Env, Origin => Origin, E_Info => Match_2.Info);
--# end
--# expr-done 4305
--# expr-start 4308 '<Predicate on BasicDecl.subp_decl_match_signature at ast.py:11220>' Pred /tmp/lal-23.0.0/ada/ast.py:11220
--# expr-start 4306 '<FieldAccess for ref_var at ast.py:11221>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11221
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Match_2.Node);
--# end
--# expr-done 4306
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 4307 '<Cast to BasicDecl at ast.py:11221>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11221
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-done 4307
Pred := Solver.Create_Predicate (Fld_2, Create_Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate (Cast_Result)); 
--# expr-done 4308
And_Pred := Create_And (Fld_1, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11219") else null)); 
--# expr-done 4309
--# expr-start 4311 '<If at ast.py:11226>' If_Result /tmp/lal-23.0.0/ada/ast.py:11226
--# expr-start 4310 '<IsA AttributeRef at ast.py:11226>' Is_A /tmp/lal-23.0.0/ada/ast.py:11226
Is_A := Match_2.Node /= null 
and then Match_2.Node.Kind in Ada_Attribute_Ref_Range; 
--# expr-done 4310
if Is_A then
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11226") else null)); 
   If_Result := False_Rel;
else
   True_Rel_2 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11226") else null)); 
   If_Result := True_Rel_2;
end if;
      Inc_Ref (If_Result);
--# expr-done 4311
And_Pred_1 := Create_And (And_Pred, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11218") else null)); 
--# expr-done 4312
Let_Result_2 := And_Pred_1; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2424;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Abstract_State_Decl_Expr .. Ada_Relation_Op | Ada_Case_Expr_Alternative .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_4; 
--# bind _ Match_3
Let_Result_3 := raise Property_Error with "Should not happen"; Inc_Ref (Let_Result_3);
--# end
Scope_Result_3 := Let_Result_3;
   Inc_Ref (Scope_Result_3);
   --# end
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
end case;
--# expr-done 4313
Scope_Result_4 := Match_Result;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2421;
   Result_Var := Scope_Result_4;
else
   True_Rel_3 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:11230") else null)); 
   Result_Var := True_Rel_3;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_890;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_890;
               Finalizer_Scope_2421;
               Finalizer_Scope_2422;
               Finalizer_Scope_2423;
               Finalizer_Scope_2424;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Subp_Decl_P_Xref_Equation;
--# end
--# property-start FormalSubpDecl.designated_subprogram_from /tmp/lal-23.0.0/ada/ast.py:11234
pragma Warnings (Off, "is not referenced");
 function Formal_Subp_Decl_P_Designated_Subprogram_From
  (Node : Bare_Formal_Subp_Decl
      ; Inst : Internal_Entity_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Formal_Subp_Decl := Bare_Formal_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Formal_Subp_Decl :=
     Internal_Entity_Formal_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind inst Inst
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_891 with Inline_Always;
      Block_Var : Internal_Entity_Array_Access;
Block_Var_1 : Internal_Entity_Subp_Spec;
Block_Var_2 : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Base_Subp_Spec;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Defining_Name;
Fld_2 : Symbol_Type;
Fld_3 : Bare_Generic_Instantiation;
Cast_Result : Bare_Ada_Node;
Fld_4 : Internal_Entity_Array_Access;
Fld_5 : Bare_Subp_Spec;
Fld_6 : Internal_Entity_Info;
Fld_7 : Internal_Metadata;
Fld_8 : Internal_Entity_Info;
Fld_9 : Env_Rebindings;
Fld_10 : Bare_Ada_Node;
Fld_11 : Lexical_Env := Empty_Env;
Fld_12 : Lexical_Env := Empty_Env;
Rebinding : Env_Rebindings;
Fld_13 : Internal_Entity_Info;
Fld_14 : Boolean;
New_Struct : Internal_Entity_Info;
New_Struct_1 : Internal_Entity_Subp_Spec;
Cast_Expr : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_15 : Internal_Entity_Base_Subp_Spec;
Fld_16 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Find_Result : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_17 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_891 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_891;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4338 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4318 '<FieldAccess for env_get at ast.py:11240>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11240
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4314 '<FieldAccess for node_env at ast.py:11241>' Fld /tmp/lal-23.0.0/ada/ast.py:11241
      if Inst.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Inst.Node, E_Info => Inst.Info);
--# expr-done 4314
--# expr-start 4316 '<FieldAccess for name_symbol at ast.py:11242>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11242
--# expr-start 4315 '<FieldAccess for defining_name at ast.py:11242>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11242
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4315
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_1.Node);
--# end
--# expr-done 4316
--# expr-start 4317 '<FieldAccess for node at ast.py:11243>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11243
Fld_3 := Inst.Node;
--# expr-done 4317
      Cast_Result := Fld_3;
--# property-call-start AdaNode.env_get
Fld_4 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Fld, Symbol => Fld_2, From_Node => Cast_Result);
--# end
--# expr-done 4318
Block_Var := Fld_4; Inc_Ref (Block_Var);
--# bind subps Block_Var
--# expr-start 4331 '<New SubpSpec.entity at ???>' New_Struct_1 None
--# expr-start 4329 '<New EntityInfo at ast.py:11261>' New_Struct /tmp/lal-23.0.0/ada/ast.py:11261
--# expr-start 4320 '<FieldAccess for from_rebound at ast.py:11268>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:11268
--# expr-start 4319 '<FieldAccess for info at ast.py:11268>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:11268
Fld_13 := Ent.Info;
--# expr-done 4319
Fld_14 := Fld_13.From_Rebound;
--# expr-done 4320
--# expr-start 4322 '<FieldAccess for md at ast.py:11262>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:11262
--# expr-start 4321 '<FieldAccess for info at ast.py:11262>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:11262
Fld_6 := Ent.Info;
--# expr-done 4321
Fld_7 := Fld_6.Md;
--# expr-done 4322
--# expr-start 4328 '<append_rebinding at ast.py:11265>' Rebinding /tmp/lal-23.0.0/ada/ast.py:11265
--# expr-start 4324 '<FieldAccess for rebindings at ast.py:11263>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:11263
--# expr-start 4323 '<FieldAccess for info at ast.py:11263>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:11263
Fld_8 := Ent.Info;
--# expr-done 4323
Fld_9 := Fld_8.Rebindings;
--# expr-done 4324
--# expr-start 4326 '<FieldAccess for node_env at ast.py:11266>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:11266
--# expr-start 4325 '<parent at ast.py:11266>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:11266
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Parent; 
--# expr-done 4325
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Node_Env (Node => Fld_10);
--# expr-done 4326
--# expr-start 4327 '<FieldAccess for instantiation_env at ast.py:11266>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:11266
      if Inst.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.instantiation_env
Fld_12 := Libadalang.Implementation.Generic_Instantiation_F_Instantiation_Env (Node => Inst.Node);
--# end
--# expr-done 4327
Rebinding := AST_Envs.Append_Rebinding (Fld_9, Fld_11, Fld_12); 
--# expr-done 4328
New_Struct := (From_Rebound => Fld_14, Md => Fld_7, Rebindings => Rebinding); 
--# expr-done 4329
--# expr-start 4330 '<FieldAccess for subp_spec at ast.py:11260>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:11260
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Classic_Subp_Decl_F_Subp_Spec;
--# expr-done 4330
New_Struct_1 := (Info => New_Struct, Node => Fld_5); 
--# expr-done 4331
Block_Var_1 := New_Struct_1; 
--# bind actual_spec Block_Var_1
--# expr-start 4336 '<Cast to BasicDecl at ast.py:11282>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:11282
--# expr-start 4335 '<Find at ast.py:11273>' Find_Result /tmp/lal-23.0.0/ada/ast.py:11273
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_166 of
               Collection.Items
         loop
   --# scope-start
               --# bind subp Item_166
--# expr-start 4333 '<FieldAccess for subp_spec_or_null at ast.py:11274>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:11274
--# expr-start 4332 '<Cast to BasicDecl at ast.py:11274>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:11274
Cast_Expr := Item_166; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 4332
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_15 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result_1.Node, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 4333
Var_Expr := Fld_15;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr
--# expr-start 4334 '<FieldAccess for match_signature at ast.py:11275>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:11275
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.match_signature
Fld_16 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Block_Var_1.Node, Other => Var_Expr, Match_Name => False, E_Info => Block_Var_1.Info);
--# end
--# expr-done 4334
Scope_Result := Fld_16;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      if Result_Var then
         Find_Result := Item_166;
      end if;
   --# end
               exit when Result_Var;
         end loop;
      end;
--# expr-done 4335
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 4336
Block_Var_2 := Cast_Result_2; 
--# bind found Block_Var_2
Var_Expr_1 := Block_Var_2;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 4337 '<FieldAccess for wrap_public_reference at ast.py:11286>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:11286
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.wrap_public_reference
Fld_17 := Libadalang.Implementation.Basic_Decl_P_Wrap_Public_Reference (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4337
Scope_Result_1 := Fld_17;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 4338
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_891;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_891;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Subp_Decl_P_Designated_Subprogram_From;
--# end
   --
   --  Primitives for Bare_Abstract_Formal_Subp_Decl
   --
      procedure Initialize_Fields_For_Abstract_Formal_Subp_Decl
        (Self : Bare_Abstract_Formal_Subp_Decl
         ; Classic_Subp_Decl_F_Overriding : Bare_Overriding_Node
         ; Classic_Subp_Decl_F_Subp_Spec : Bare_Subp_Spec
         ; Formal_Subp_Decl_F_Default_Expr : Bare_Expr
         ; Formal_Subp_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Formal_Subp_Decl
              (Self, Classic_Subp_Decl_F_Overriding, Classic_Subp_Decl_F_Subp_Spec, Formal_Subp_Decl_F_Default_Expr, Formal_Subp_Decl_F_Aspects);
      end Initialize_Fields_For_Abstract_Formal_Subp_Decl;
   --
   --  Primitives for Bare_Concrete_Formal_Subp_Decl
   --
      procedure Initialize_Fields_For_Concrete_Formal_Subp_Decl
        (Self : Bare_Concrete_Formal_Subp_Decl
         ; Classic_Subp_Decl_F_Overriding : Bare_Overriding_Node
         ; Classic_Subp_Decl_F_Subp_Spec : Bare_Subp_Spec
         ; Formal_Subp_Decl_F_Default_Expr : Bare_Expr
         ; Formal_Subp_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Formal_Subp_Decl
              (Self, Classic_Subp_Decl_F_Overriding, Classic_Subp_Decl_F_Subp_Spec, Formal_Subp_Decl_F_Default_Expr, Formal_Subp_Decl_F_Aspects);
      end Initialize_Fields_For_Concrete_Formal_Subp_Decl;
   --
   --  Primitives for Bare_Subp_Decl
   --
      procedure Initialize_Fields_For_Subp_Decl
        (Self : Bare_Subp_Decl
         ; Classic_Subp_Decl_F_Overriding : Bare_Overriding_Node
         ; Classic_Subp_Decl_F_Subp_Spec : Bare_Subp_Spec
         ; Subp_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Classic_Subp_Decl
              (Self, Classic_Subp_Decl_F_Overriding, Classic_Subp_Decl_F_Subp_Spec);
            Self.Subp_Decl_F_Aspects := Subp_Decl_F_Aspects;
      end Initialize_Fields_For_Subp_Decl;
--# property-start SubpDecl.is_constant_object /tmp/lal-23.0.0/ada/ast.py:9483
pragma Warnings (Off, "is not referenced");
 function Subp_Decl_P_Is_Constant_Object
  (Node : Bare_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Subp_Decl := Bare_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Decl_P_Is_Constant_Object;
--# end
   --
   --  Primitives for Bare_Entry_Decl
   --
      procedure Entry_Decl_Pre_Env_Actions
        (Self            : Bare_Entry_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_131 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:17676");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_132 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Entry_Decl
        (Self : Bare_Entry_Decl
         ; Entry_Decl_F_Overriding : Bare_Overriding_Node
         ; Entry_Decl_F_Spec : Bare_Entry_Spec
         ; Entry_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Entry_Decl_F_Overriding := Entry_Decl_F_Overriding;
            Self.Entry_Decl_F_Spec := Entry_Decl_F_Spec;
            Self.Entry_Decl_F_Aspects := Entry_Decl_F_Aspects;
      end Initialize_Fields_For_Entry_Decl;
   function Entry_Decl_F_Overriding
     (Node : Bare_Entry_Decl) return Bare_Overriding_Node
   is
   begin
         return Node.Entry_Decl_F_Overriding;
   end;
   function Entry_Decl_F_Spec
     (Node : Bare_Entry_Decl) return Bare_Entry_Spec
   is
   begin
         return Node.Entry_Decl_F_Spec;
   end;
--# property-start EntryDecl.subp_decl_spec /tmp/lal-23.0.0/ada/ast.py:17611
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Subp_Decl_Spec
  (Node : Bare_Entry_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Fld : Internal_Entity_Entry_Spec;
Cast_Result : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4339 '<FieldAccess for spec at ast.py:17611>' Fld /tmp/lal-23.0.0/ada/ast.py:17611
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Entry_Spec (Node => Ent.Node.Entry_Decl_F_Spec, Info => Ent.Info);
--# expr-done 4339
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Subp_Decl_Spec;
--# end
--# property-start EntryDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:17613
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Defining_Names
  (Node : Bare_Entry_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1265 with Inline_Always;
      Fld : Internal_Entity_Entry_Spec;
Fld_1 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1265 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1265;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4341 '<FieldAccess for name at ast.py:17613>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17613
--# expr-start 4340 '<FieldAccess for spec at ast.py:17613>' Fld /tmp/lal-23.0.0/ada/ast.py:17613
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Entry_Spec (Node => Ent.Node.Entry_Decl_F_Spec, Info => Ent.Info);
--# expr-done 4340
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4341
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_1;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1265;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1265;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Defining_Names;
--# end
--# property-start EntryDecl.body_part /tmp/lal-23.0.0/ada/ast.py:17617
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Body_Part
  (Node : Bare_Entry_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Entry_Body
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Entry_Body;
      Fld : Internal_Entity_Body_Node;
Cast_Result : Internal_Entity_Entry_Body;
Let_Result : Internal_Entity_Entry_Body;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4344 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4343 '<Cast to EntryBody at ast.py:17621>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17621
--# expr-start 4342 '<FieldAccess for body_part_for_decl at ast.py:17621>' Fld /tmp/lal-23.0.0/ada/ast.py:17621
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4342
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Entry_Body_Range
   then
      Cast_Result := Create_Internal_Entity_Entry_Body
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4343
Let_Result := Cast_Result; 
--# end
--# expr-done 4344
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Body_Part;
--# end
--# property-start EntryDecl.has_family /tmp/lal-23.0.0/ada/ast.py:17624
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Has_Family
  (Node : Bare_Entry_Decl
  )
   return Boolean
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Entry_Spec;
Fld_1 : Bare_Ada_Node;
Is_Null : Boolean;
Not_Val : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4349 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4348 '<Not at ast.py:17628>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17628
--# expr-start 4347 '<IsNull at ast.py:17628>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17628
--# expr-start 4346 '<FieldAccess for family_type at ast.py:17628>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17628
--# expr-start 4345 '<FieldAccess for spec at ast.py:17628>' Fld /tmp/lal-23.0.0/ada/ast.py:17628
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Entry_Decl_F_Spec;
--# expr-done 4345
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Entry_Spec_F_Family_Type;
--# expr-done 4346
Is_Null := Fld_1 = null; 
--# expr-done 4347
Not_Val := not (Is_Null); 
--# expr-done 4348
Let_Result := Not_Val; 
--# end
--# expr-done 4349
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Has_Family;
--# end
--# property-start EntryDecl.family_type /tmp/lal-23.0.0/ada/ast.py:17631
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Family_Type
  (Node : Bare_Entry_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Type_Expr;
Fld : Internal_Entity_Entry_Spec;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Type_Expr;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4354 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4352 '<Cast to TypeExpr at ast.py:17637>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17637
--# expr-start 4351 '<FieldAccess for family_type at ast.py:17637>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17637
--# expr-start 4350 '<FieldAccess for spec at ast.py:17637>' Fld /tmp/lal-23.0.0/ada/ast.py:17637
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Entry_Spec (Node => Ent.Node.Entry_Decl_F_Spec, Info => Ent.Info);
--# expr-done 4350
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity (Node => Fld.Node.Entry_Spec_F_Family_Type, Info => Fld.Info);
--# expr-done 4351
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Type_Expr
   then
      Cast_Result := Create_Internal_Entity_Type_Expr
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Type_Expr;
   end if;
--# expr-done 4352
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Type_Expr then
   --# scope-start
--# expr-start 4353 '<FieldAccess for designated_type at ast.py:17637>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17637
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 4353
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 4354
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Family_Type;
--# end
--# property-start EntryDecl.accept_stmts /tmp/lal-23.0.0/ada/ast.py:17640
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Accept_Stmts
  (Node : Bare_Entry_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Accept_Stmt_Array_Access
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Accept_Stmt_Array_Access;
            procedure Finalizer_Scope_1269 with Inline_Always;
      Match_0 : Internal_Entity_Single_Task_Type_Decl;
Match_1 : Internal_Entity_Task_Type_Decl;
Match_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Single_Task_Type_Decl;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Task_Type_Decl;
Cast_Expr : Internal_Entity_Task_Type_Decl;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Body_Node;
Cast_Result_4 : Internal_Entity;
Fld_3 : Internal_Entity_Accept_Stmt_Array_Access;
Let_Result_3 : Internal_Entity_Accept_Stmt_Array_Access;
            procedure Finalizer_Scope_1269 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_1269;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4360 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4359 '<FieldAccess for find_accept_stmts at ast.py:17644>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17644
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4358 '<FieldAccess for body_part_for_decl at ast.py:17653>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17653
--# expr-start 4357 '<Match at ast.py:17646>' Match_Result /tmp/lal-23.0.0/ada/ast.py:17646
--# expr-start 4355 '<FieldAccess for parent_basic_decl at ast.py:17646>' Fld /tmp/lal-23.0.0/ada/ast.py:17646
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4355
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Single_Task_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind st Match_0
--# expr-start 4356 '<FieldAccess for parent_basic_decl at ast.py:17647>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17647
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_1 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 4356
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Task_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind tt Match_1
Cast_Expr := Match_1; 
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Let_Result_1 := Cast_Result_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Protected_Type_Decl | Ada_Anonymous_Type_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error with "Can only be called on EntryDecl in Tasks"; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 4357
      if Match_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Match_Result.Node, Imprecise_Fallback => False, E_Info => Match_Result.Info);
--# end
--# expr-done 4358
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# property-call-start EntryDecl.find_accept_stmts
Fld_3 := Libadalang.Implementation.Entry_Decl_P_Find_Accept_Stmts (Node => Ent.Node, Root => Cast_Result_4, E_Info => Ent.Info);
--# end
--# expr-done 4359
Let_Result_3 := Fld_3; Inc_Ref (Let_Result_3);
--# end
--# expr-done 4360
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1269;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1269;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Accept_Stmts;
--# end
--# property-start EntryDecl.find_accept_stmts /tmp/lal-23.0.0/ada/ast.py:17657
pragma Warnings (Off, "is not referenced");
 function Entry_Decl_P_Find_Accept_Stmts
  (Node : Bare_Entry_Decl
      ; Root : Internal_Entity
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Accept_Stmt_Array_Access
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   Property_Result : Internal_Entity_Accept_Stmt_Array_Access;
            procedure Finalizer_Scope_1270 with Inline_Always;
            procedure Finalizer_Scope_2433 with Inline_Always;
            procedure Finalizer_Scope_2435 with Inline_Always;
            procedure Finalizer_Scope_2436 with Inline_Always;
      Var_Expr : Internal_Entity_Array_Access;
Var_Expr_1 : Internal_Entity_Accept_Stmt;
Fld : Internal_Entity_Array_Access;
Is_Null : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Array_Access;
Fld_1 : Internal_Entity_Accept_Stmt_Array_Access;
Map_Result_1 : Internal_Entity_Accept_Stmt_Array_Access;
Scope_Result : Internal_Entity_Accept_Stmt_Array_Access;
Result_Var : Internal_Entity_Accept_Stmt_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Accept_Stmt;
Singleton : Internal_Entity_Accept_Stmt_Array_Access;
Fld_2 : Internal_Entity_Entry_Decl;
Cast_Result_1 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Entry_Decl;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Accept_Stmt_Array_Access;
Scope_Result_1 : Internal_Entity_Accept_Stmt_Array_Access;
Result_Var_1 : Internal_Entity_Accept_Stmt_Array_Access;
Concat_Result : Internal_Entity_Accept_Stmt_Array_Access;
Let_Result : Internal_Entity_Accept_Stmt_Array_Access;
            procedure Finalizer_Scope_1270 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1270;
            procedure Finalizer_Scope_2433 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_2433;
            procedure Finalizer_Scope_2435 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2435;
            procedure Finalizer_Scope_2436 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2436;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4372 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4371 '<Concat at ast.py:17665>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:17665
--# expr-start 4361 '<children at ast.py:17662>' Fld /tmp/lal-23.0.0/ada/ast.py:17662
      if Root.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children (Node => Root.Node, E_Info => Root.Info);
--# expr-done 4361
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Array_Type then
   --# scope-start
   --# bind child Var_Expr
--# expr-start 4366 '<Mapcat at ast.py:17664>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:17664
   --# expr-start 4364 '<Filter at ast.py:17663>' Map_Result /tmp/lal-23.0.0/ada/ast.py:17663
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Var_Expr;
      begin
         for Item_168 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_168
         --# expr-start 4363 '<Not at ast.py:17663>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17663
--# expr-start 4362 '<IsNull at ast.py:17663>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17663
Is_Null := Item_168.Node = null; 
--# expr-done 4362
Not_Val := not (Is_Null); 
--# expr-done 4363
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity := Item_168;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4364
      declare
         Map_Result_1_Vec : Internal_Entity_Accept_Stmt_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result;
      begin
         for Item_167 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_167
      --# expr-start 4365 '<FieldAccess for find_accept_stmts at ast.py:17664>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17664
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EntryDecl.find_accept_stmts
Fld_1 := Libadalang.Implementation.Entry_Decl_P_Find_Accept_Stmts (Node => Ent.Node, Root => Item_167, E_Info => Ent.Info);
--# end
--# expr-done 4365
         for Item_To_Append of
               Fld_1.Items
         loop
            Internal_Entity_Accept_Stmt_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2435;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Accept_Stmt_Array
           (Items_Count => Natural (Internal_Entity_Accept_Stmt_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Accept_Stmt_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Accept_Stmt_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Accept_Stmt_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 4366
Scope_Result := Map_Result_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2433;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Accept_Stmt_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# expr-start 4367 '<Cast to AcceptStmt at ast.py:17666>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17666
Cast_Expr := Root; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Accept_Stmt_Range
   then
      Cast_Result := Create_Internal_Entity_Accept_Stmt
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Accept_Stmt;
   end if;
--# expr-done 4367
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Accept_Stmt then
   --# scope-start
   --# bind stmt Var_Expr_1
--# expr-start 4370 '<If at ast.py:17667>' If_Result /tmp/lal-23.0.0/ada/ast.py:17667
--# expr-start 4369 '<Eq at ast.py:17668>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:17668
--# expr-start 4368 '<FieldAccess for corresponding_entry at ast.py:17668>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17668
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AcceptStmt.corresponding_entry
Fld_2 := Libadalang.Implementation.Accept_Stmt_P_Corresponding_Entry (Node => Var_Expr_1.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 4368
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 4369
if Is_Equiv then
                Singleton := Create_Internal_Entity_Accept_Stmt_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr_1;
   If_Result := Singleton;
else
   If_Result := No_Internal_Entity_Accept_Stmt_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 4370
Scope_Result_1 := If_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2436;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Accept_Stmt_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Concat_Result := Concat (Result_Var, Result_Var_1); 
--# expr-done 4371
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 4372
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1270;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1270;
               Finalizer_Scope_2433;
               Finalizer_Scope_2435;
               Finalizer_Scope_2436;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Decl_P_Find_Accept_Stmts;
--# end
--# property-start EntryDecl._env_mappings_131 /tmp/lal-23.0.0/ada/ast.py:17676
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_131
  (Node : Bare_Entry_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Decl :=
     Internal_Entity_Entry_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1600 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Entry_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1600 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1600;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4375 '<New EnvAssoc at ast.py:17676>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:17676
--# expr-start 4373 '<New DesignatedEnv at ast.py:17676>' New_Struct /tmp/lal-23.0.0/ada/ast.py:17676
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4373
--# expr-start 4374 '<FieldAccess for name_symbol at ast.py:17676>' Fld /tmp/lal-23.0.0/ada/ast.py:17676
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4374
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4375
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1600;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1600;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_131;
--# end
--# property-start EntryDecl._env_trans_parent_132 /tmp/lal-23.0.0/ada/ast.py:17675
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_132
  (Node : Bare_Entry_Decl
  )
   return Boolean
is
   Self : Bare_Entry_Decl := Bare_Entry_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_132;
--# end
   --
   --  Primitives for Bare_Enum_Literal_Decl
   --
      procedure Enum_Literal_Decl_Pre_Env_Actions
        (Self            : Bare_Enum_Literal_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_129 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:16903");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_130 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Enum_Literal_Decl
        (Self : Bare_Enum_Literal_Decl
         ; Enum_Literal_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Self.Enum_Literal_Decl_F_Name := Enum_Literal_Decl_F_Name;
      end Initialize_Fields_For_Enum_Literal_Decl;
   function Enum_Literal_Decl_F_Name
     (Node : Bare_Enum_Literal_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Enum_Literal_Decl_F_Name;
   end;
--# property-start EnumLiteralDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:16878
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Is_Static_Decl
  (Node : Bare_Enum_Literal_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Is_Static_Decl;
--# end
--# property-start EnumLiteralDecl.is_constant_object /tmp/lal-23.0.0/ada/ast.py:16880
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Is_Constant_Object
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Is_Constant_Object;
--# end
--# property-start '[dispatcher]EnumLiteralDecl.enum_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Enum_Literal_Decl_P_Enum_Type
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Enum_Literal_Decl_Range (Self.Kind) is
               when Ada_Enum_Literal_Decl =>
                  --# property-call-start EnumLiteralDecl.enum_type
                  Property_Result := Enum_Literal_Decl_P_Enum_Type
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Char_Enum_Lit =>
                  --# property-call-start SyntheticCharEnumLit.enum_type
                  Property_Result := Synthetic_Char_Enum_Lit_P_Enum_Type
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Enum_Literal_Decl_P_Enum_Type;
--# end
--# property-start EnumLiteralDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:16891
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Defining_Names
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Literal_Decl :=
     Internal_Entity_Enum_Literal_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1201 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1201 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1201;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4376 '<FieldAccess for name at ast.py:16891>' Fld /tmp/lal-23.0.0/ada/ast.py:16891
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Enum_Literal_Decl_F_Name, Info => Ent.Info);
--# expr-done 4376
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1201;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1201;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Defining_Names;
--# end
--# property-start EnumLiteralDecl.synth_type_expr /tmp/lal-23.0.0/ada/ast.py:16894
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Synth_Type_Expr
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Enum_Lit_Synth_Type_Expr
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Enum_Lit_Synth_Type_Expr;
      New_Node : Bare_Enum_Lit_Synth_Type_Expr;
As_Entity : Internal_Entity_Enum_Lit_Synth_Type_Expr;
Is_Null : Boolean;
If_Result : Internal_Entity_Enum_Lit_Synth_Type_Expr;
Let_Result : Internal_Entity_Enum_Lit_Synth_Type_Expr;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Enum_Literal_Decl_Enum_Literal_Decl_P_Synth_Type_Expr,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Enum_Literal_Decl,
                                As_Bare_Enum_Literal_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Enum_Lit_Synth_Type_Expr;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 4379 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4378 '<as_entity at ast.py:16895>' If_Result /tmp/lal-23.0.0/ada/ast.py:16895
--# expr-start 4377 '<New EnumLitSynthTypeExpr at ast.py:16895>' New_Node /tmp/lal-23.0.0/ada/ast.py:16895
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Enum_Lit_Synth_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Enum_Lit_Synth_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
--# expr-done 4377
Is_Null := New_Node = null; 
if Is_Null then
   If_Result := No_Entity_Enum_Lit_Synth_Type_Expr;
else
As_Entity := (Info => E_Info, Node => New_Node); 
   If_Result := As_Entity;
end if;
--# expr-done 4378
Let_Result := If_Result; 
--# end
--# expr-done 4379
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Enum_Lit_Synth_Type_Expr,
                        As_Internal_Entity_Enum_Lit_Synth_Type_Expr => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Synth_Type_Expr;
--# end
--# property-start EnumLiteralDecl.subp_decl_spec /tmp/lal-23.0.0/ada/ast.py:16898
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Subp_Decl_Spec
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Subp_Spec;
      New_Node : Bare_Enum_Subp_Spec;
As_Entity : Internal_Entity_Enum_Subp_Spec;
Is_Null : Boolean;
If_Result : Internal_Entity_Enum_Subp_Spec;
Let_Result : Internal_Entity_Enum_Subp_Spec;
Cast_Result : Internal_Entity_Base_Subp_Spec;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Enum_Literal_Decl_Enum_Literal_Decl_P_Subp_Decl_Spec,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Enum_Literal_Decl,
                                As_Bare_Enum_Literal_Decl => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Subp_Spec;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
--# expr-start 4382 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4381 '<as_entity at ???>' If_Result None
--# expr-start 4380 '<New EnumSubpSpec at ???>' New_Node None
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Enum_Subp_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Enum_Subp_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
--# expr-done 4380
Is_Null := New_Node = null; 
if Is_Null then
   If_Result := No_Entity_Enum_Subp_Spec;
else
As_Entity := (Info => E_Info, Node => New_Node); 
   If_Result := As_Entity;
end if;
--# expr-done 4381
Let_Result := If_Result; 
--# end
--# expr-done 4382
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Let_Result.Node,
         Info => Let_Result.Info);
      Property_Result := Cast_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Subp_Spec,
                        As_Internal_Entity_Base_Subp_Spec => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Subp_Decl_Spec;
--# end
--# property-start '[dispatcher]EnumLiteralDecl.enum_decl_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Enum_Literal_Decl_P_Enum_Decl_Name
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Literal_Decl :=
     Internal_Entity_Enum_Literal_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Enum_Literal_Decl_Range (Self.Kind) is
               when Ada_Enum_Literal_Decl =>
                  --# property-call-start EnumLiteralDecl.enum_decl_name
                  Property_Result := Enum_Literal_Decl_P_Enum_Decl_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Char_Enum_Lit =>
                  --# property-call-start SyntheticCharEnumLit.enum_decl_name
                  Property_Result := Synthetic_Char_Enum_Lit_P_Enum_Decl_Name
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Enum_Literal_Decl_P_Enum_Decl_Name;
--# end
--# property-start EnumLiteralDecl._env_mappings_129 /tmp/lal-23.0.0/ada/ast.py:16903
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_129
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Literal_Decl :=
     Internal_Entity_Enum_Literal_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1598 with Inline_Always;
      Fld : Symbol_Type;
Fld_1 : Internal_Entity_Type_Decl;
Fld_2 : Lexical_Env := Empty_Env;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Enum_Literal_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1598 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1598;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4387 '<New EnvAssoc at ast.py:16903>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:16903
--# expr-start 4385 '<New DesignatedEnv at ast.py:16904>' New_Struct /tmp/lal-23.0.0/ada/ast.py:16904
--# expr-start 4384 '<FieldAccess for node_env at ast.py:16904>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16904
--# expr-start 4383 '<FieldAccess for enum_type at ast.py:16904>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16904
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]EnumLiteralDecl.enum_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Enum_Literal_Decl_P_Enum_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4383
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Node_Env (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 4384
Inc_Ref (Fld_2);
New_Struct := (Direct_Env => Fld_2, Env_Name => null, Kind => Direct_Env); 
--# expr-done 4385
--# expr-start 4386 '<FieldAccess for name_symbol at ast.py:16903>' Fld /tmp/lal-23.0.0/ada/ast.py:16903
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 4386
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4387
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1598;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1598;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_129;
--# end
--# property-start EnumLiteralDecl._env_trans_parent_130 /tmp/lal-23.0.0/ada/ast.py:16901
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_130
  (Node : Bare_Enum_Literal_Decl
  )
   return Boolean
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_130;
--# end
--# property-start EnumLiteralDecl.enum_type /tmp/lal-23.0.0/ada/ast.py:16883
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Enum_Type
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Type_Decl;
            procedure Finalizer_Scope_1200 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Type_Decl;
Let_Result : Internal_Entity_Type_Decl;
            procedure Finalizer_Scope_1200 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_1200;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4393 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4392 '<Cast to TypeDecl at ast.py:16889>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16889
--# expr-start 4391 '<as_entity at ast.py:16889>' If_Result /tmp/lal-23.0.0/ada/ast.py:16889
--# expr-start 4390 '<Find at ast.py:16887>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16887
   --# expr-start 4388 '<FieldAccess for parents at ast.py:16887>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:16887
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 4388
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_169 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_169
      --# expr-start 4389 '<IsA TypeDecl at ast.py:16888>' Is_A /tmp/lal-23.0.0/ada/ast.py:16888
Is_A := Item_169 /= null 
and then Item_169.Kind in Ada_Type_Decl; 
--# expr-done 4389
      if Is_A then
         Find_Result := Item_169;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 4390
Is_Null := Find_Result = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Find_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 4391
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Type_Decl;
   end if;
--# expr-done 4392
Let_Result := Cast_Result; 
--# end
--# expr-done 4393
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1200;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1200;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Enum_Type;
--# end
--# property-start EnumLiteralDecl.enum_decl_name /tmp/lal-23.0.0/ada/ast.py:16912
pragma Warnings (Off, "is not referenced");
 function Enum_Literal_Decl_P_Enum_Decl_Name
  (Node : Bare_Enum_Literal_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Enum_Literal_Decl := Bare_Enum_Literal_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Literal_Decl :=
     Internal_Entity_Enum_Literal_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4394 '<FieldAccess for name at ast.py:16912>' Fld /tmp/lal-23.0.0/ada/ast.py:16912
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Enum_Literal_Decl_F_Name, Info => Ent.Info);
--# expr-done 4394
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Literal_Decl_P_Enum_Decl_Name;
--# end
   --
   --  Primitives for Bare_Synthetic_Char_Enum_Lit
   --
      procedure Initialize_Fields_For_Synthetic_Char_Enum_Lit
        (Self : Bare_Synthetic_Char_Enum_Lit
         ; Enum_Literal_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Initialize_Fields_For_Enum_Literal_Decl
              (Self, Enum_Literal_Decl_F_Name);
      Self.Synthetic_Char_Enum_Lit_Char_Symbol := null;
      Self.Synthetic_Char_Enum_Lit_Enum_Type_Decl := No_Entity_Type_Decl;
      end Initialize_Fields_For_Synthetic_Char_Enum_Lit;
--# property-start SyntheticCharEnumLit.enum_type /tmp/lal-23.0.0/ada/ast.py:16923
pragma Warnings (Off, "is not referenced");
 function Synthetic_Char_Enum_Lit_P_Enum_Type
  (Node : Bare_Synthetic_Char_Enum_Lit
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl
is
   Self : Bare_Synthetic_Char_Enum_Lit := Bare_Synthetic_Char_Enum_Lit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Char_Enum_Lit :=
     Internal_Entity_Synthetic_Char_Enum_Lit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Decl;
      Fld : Internal_Entity_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4395 '<FieldAccess for enum_type_decl at ast.py:16923>' Fld /tmp/lal-23.0.0/ada/ast.py:16923
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Ent.Node.Synthetic_Char_Enum_Lit_Enum_Type_Decl;
--# expr-done 4395
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Char_Enum_Lit_P_Enum_Type;
--# end
--# property-start SyntheticCharEnumLit.expr /tmp/lal-23.0.0/ada/ast.py:16925
pragma Warnings (Off, "is not referenced");
 function Synthetic_Char_Enum_Lit_P_Expr
  (Node : Bare_Synthetic_Char_Enum_Lit
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Synthetic_Char_Enum_Lit := Bare_Synthetic_Char_Enum_Lit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Char_Enum_Lit :=
     Internal_Entity_Synthetic_Char_Enum_Lit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_1206 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_1206 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1206;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4397 '<at at ast.py:16925>' Get_Result /tmp/lal-23.0.0/ada/ast.py:16925
--# expr-start 4396 '<FieldAccess for defining_names at ast.py:16925>' Fld /tmp/lal-23.0.0/ada/ast.py:16925
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4396
Get_Result := Get (Self, Fld, 0, True); 
--# expr-done 4397
      Property_Result := Get_Result;
   --# end
      Finalizer_Scope_1206;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1206;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Char_Enum_Lit_P_Expr;
--# end
--# property-start SyntheticCharEnumLit.enum_decl_name /tmp/lal-23.0.0/ada/ast.py:16928
pragma Warnings (Off, "is not referenced");
 function Synthetic_Char_Enum_Lit_P_Enum_Decl_Name
  (Node : Bare_Synthetic_Char_Enum_Lit
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Synthetic_Char_Enum_Lit := Bare_Synthetic_Char_Enum_Lit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Char_Enum_Lit :=
     Internal_Entity_Synthetic_Char_Enum_Lit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4398 '<FieldAccess for expr at ast.py:16928>' Fld /tmp/lal-23.0.0/ada/ast.py:16928
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SyntheticCharEnumLit.expr
Fld := Libadalang.Implementation.Synthetic_Char_Enum_Lit_P_Expr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4398
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Char_Enum_Lit_P_Enum_Decl_Name;
--# end
--# property-start SyntheticCharEnumLit.defining_names /tmp/lal-23.0.0/ada/ast.py:16930
pragma Warnings (Off, "is not referenced");
 function Synthetic_Char_Enum_Lit_P_Defining_Names
  (Node : Bare_Synthetic_Char_Enum_Lit
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Synthetic_Char_Enum_Lit := Bare_Synthetic_Char_Enum_Lit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1208 with Inline_Always;
      Fld : Symbol_Type;
Fld_1 : Bare_Defining_Name;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Array_Lit : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1208 is
            begin
                     Dec_Ref (Array_Lit);
            end Finalizer_Scope_1208;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4402 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 4401 '<as_entity at ast.py:16931>' If_Result /tmp/lal-23.0.0/ada/ast.py:16931
--# expr-start 4400 '<FieldAccess for synthesize_defining_name at ast.py:16931>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16931
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4399 '<FieldAccess for char_symbol at ast.py:16931>' Fld /tmp/lal-23.0.0/ada/ast.py:16931
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Synthetic_Char_Enum_Lit_Char_Symbol;
--# expr-done 4399
--# property-call-start AdaNode.synthesize_defining_name
Fld_1 := Libadalang.Implementation.Ada_Node_P_Synthesize_Defining_Name (Node => Self, Sym => Fld);
--# end
--# expr-done 4400
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 4401
Array_Lit := Create_Internal_Entity_Defining_Name_Array (Internal_Internal_Entity_Defining_Name_Array'(1 => If_Result)); 
--# expr-done 4402
      Property_Result := Array_Lit;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1208;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1208;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Char_Enum_Lit_P_Defining_Names;
--# end
   --
   --  Primitives for Bare_Generic_Subp_Internal
   --
      procedure Generic_Subp_Internal_Pre_Env_Actions
        (Self            : Bare_Generic_Subp_Internal;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_105 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_106 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Generic_Subp_Internal
        (Self : Bare_Generic_Subp_Internal
         ; Generic_Subp_Internal_F_Subp_Spec : Bare_Subp_Spec
         ; Generic_Subp_Internal_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Generic_Subp_Internal_F_Subp_Spec := Generic_Subp_Internal_F_Subp_Spec;
            Self.Generic_Subp_Internal_F_Aspects := Generic_Subp_Internal_F_Aspects;
      end Initialize_Fields_For_Generic_Subp_Internal;
   function Generic_Subp_Internal_F_Subp_Spec
     (Node : Bare_Generic_Subp_Internal) return Bare_Subp_Spec
   is
   begin
         return Node.Generic_Subp_Internal_F_Subp_Spec;
   end;
--# property-start GenericSubpInternal.subp_decl_spec /tmp/lal-23.0.0/ada/ast.py:11384
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Internal_P_Subp_Decl_Spec
  (Node : Bare_Generic_Subp_Internal
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Generic_Subp_Internal := Bare_Generic_Subp_Internal (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Internal :=
     Internal_Entity_Generic_Subp_Internal'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Fld : Internal_Entity_Subp_Spec;
Cast_Result : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4403 '<FieldAccess for subp_spec at ast.py:11384>' Fld /tmp/lal-23.0.0/ada/ast.py:11384
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Generic_Subp_Internal_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4403
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Internal_P_Subp_Decl_Spec;
--# end
--# property-start GenericSubpInternal._env_trans_parent_105 /tmp/lal-23.0.0/ada/ast.py:11386
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_105
  (Node : Bare_Generic_Subp_Internal
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Internal := Bare_Generic_Subp_Internal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_105;
--# end
--# property-start GenericSubpInternal._env_names_106 /tmp/lal-23.0.0/ada/ast.py:11386
pragma Warnings (Off, "is not referenced");
 function Env_Names_106
  (Node : Bare_Generic_Subp_Internal
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Generic_Subp_Internal := Bare_Generic_Subp_Internal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1575 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1575 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1575;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4404 '<FieldAccess for env_names at ast.py:11386>' Fld /tmp/lal-23.0.0/ada/ast.py:11386
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicSubpDecl.env_names
Fld := Libadalang.Implementation.Basic_Subp_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 4404
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1575;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1575;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_106;
--# end
   --
   --  Primitives for Bare_Synthetic_Subp_Decl
   --
      procedure Initialize_Fields_For_Synthetic_Subp_Decl
        (Self : Bare_Synthetic_Subp_Decl
         ; Synthetic_Subp_Decl_F_Spec : Bare_Base_Subp_Spec
        ) is
      begin
            Self.Synthetic_Subp_Decl_F_Spec := Synthetic_Subp_Decl_F_Spec;
      end Initialize_Fields_For_Synthetic_Subp_Decl;
   function Synthetic_Subp_Decl_F_Spec
     (Node : Bare_Synthetic_Subp_Decl) return Bare_Base_Subp_Spec
   is
   begin
         return Node.Synthetic_Subp_Decl_F_Spec;
   end;
--# property-start SyntheticSubpDecl.subp_decl_spec /tmp/lal-23.0.0/ada/ast.py:17577
pragma Warnings (Off, "is not referenced");
 function Synthetic_Subp_Decl_P_Subp_Decl_Spec
  (Node : Bare_Synthetic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Spec
is
   Self : Bare_Synthetic_Subp_Decl := Bare_Synthetic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Subp_Decl :=
     Internal_Entity_Synthetic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Subp_Spec;
      Fld : Internal_Entity_Base_Subp_Spec;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4405 '<FieldAccess for spec at ast.py:17577>' Fld /tmp/lal-23.0.0/ada/ast.py:17577
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Base_Subp_Spec (Node => Ent.Node.Synthetic_Subp_Decl_F_Spec, Info => Ent.Info);
--# expr-done 4405
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Subp_Decl_P_Subp_Decl_Spec;
--# end
--# property-start SyntheticSubpDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:17580
pragma Warnings (Off, "is not referenced");
 function Synthetic_Subp_Decl_P_Next_Part_For_Decl
  (Node : Bare_Synthetic_Subp_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Synthetic_Subp_Decl := Bare_Synthetic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4406 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Basic_Decl; 
--# end
--# expr-done 4406
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Subp_Decl_P_Next_Part_For_Decl;
--# end
--# property-start SyntheticSubpDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:17584
pragma Warnings (Off, "is not referenced");
 function Synthetic_Subp_Decl_P_Is_Static_Decl
  (Node : Bare_Synthetic_Subp_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Synthetic_Subp_Decl := Bare_Synthetic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4407 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := True; 
--# end
--# expr-done 4407
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Subp_Decl_P_Is_Static_Decl;
--# end
   --
   --  Primitives for Bare_Body_Node
   --
--# property-start Body.env_hook_body /tmp/lal-23.0.0/ada/ast.py:3398
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Env_Hook_Body
  (Node : Bare_Body_Node
  )
   return Boolean
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
            procedure Finalizer_Scope_217 with Inline_Always;
      Unused_1 : Internal_Unit;
Var_Expr : Bare_Subp_Body;
As_Entity : Internal_Entity_Body_Node;
Is_Null : Boolean;
If_Result : Internal_Entity_Body_Node;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Symbol_Type_Array_Access;
Is_A : Boolean;
Not_Val : Boolean;
Fld_2 : Internal_Unit;
Cast_Expr : Bare_Body_Node;
Cast_Result : Bare_Subp_Body;
Fld_3 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
Is_A_1 : Boolean;
If_Result_1 : Boolean;
Let_Result_1 : Boolean;
            procedure Finalizer_Scope_217 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_217;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4419 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 4418 '<If at ast.py:3402>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3402
--# expr-start 4408 '<IsA PackageBody, SubpBody at ast.py:3405>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:3405
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Package_Body_Range | Ada_Subp_Body_Range; 
--# expr-done 4408
if Is_A_1 then
   --# expr-start 4417 '<Let at ast.py:3407>' Let_Result /tmp/lal-23.0.0/ada/ast.py:3407
--# scope-start
--# expr-start 4414 '<FieldAccess for get_unit at ast.py:3408>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3408
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4411 '<FieldAccess for as_symbol_array at ast.py:3409>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3409
--# expr-start 4410 '<FieldAccess for defining_name at ast.py:3409>' Fld /tmp/lal-23.0.0/ada/ast.py:3409
--# expr-start 4409 '<as_bare_entity at ast.py:3409>' If_Result /tmp/lal-23.0.0/ada/ast.py:3409
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Body_Node;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 4409
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 4410
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld.Node);
--# end
--# expr-done 4411
--# expr-start 4413 '<Not at ast.py:3412>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3412
--# expr-start 4412 '<IsA SubpBody at ast.py:3412>' Is_A /tmp/lal-23.0.0/ada/ast.py:3412
Is_A := Self /= null 
and then Self.Kind in Ada_Subp_Body_Range; 
--# expr-done 4412
Not_Val := not (Is_A); 
--# expr-done 4413
Fld_2 := Libadalang.Implementation.Extensions.Ada_Node_P_Get_Unit (Node => Self, Name => Fld_1, Kind => Unit_Specification, Load_If_Needed => True, Not_Found_Is_Error => Not_Val);
--# expr-done 4414
Unused_1 := Fld_2; 
--# bind _ Unused_1
--# expr-start 4415 '<Cast to SubpBody at ast.py:3417>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3417
Cast_Expr := Self; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Subp_Body_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 4415
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind subp_body Var_Expr
--# expr-start 4416 '<FieldAccess for env_hook_basic_decl at ast.py:3418>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3418
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.env_hook_basic_decl
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Env_Hook_Basic_Decl (Node => Var_Expr);
--# end
--# expr-done 4416
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 4417
   If_Result_1 := Let_Result;
else
   If_Result_1 := False;
end if;
--# expr-done 4418
Let_Result_1 := If_Result_1; 
--# end
--# expr-done 4419
      Property_Result := Let_Result_1;
   --# end
      Finalizer_Scope_217;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_217;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Env_Hook_Body;
--# end
--# property-start Body.subunit_decl_env /tmp/lal-23.0.0/ada/ast.py:3426
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Subunit_Decl_Env
  (Node : Bare_Body_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_218 with Inline_Always;
            procedure Finalizer_Scope_2441 with Inline_Always;
            procedure Finalizer_Scope_2442 with Inline_Always;
            procedure Finalizer_Scope_2444 with Inline_Always;
            procedure Finalizer_Scope_2445 with Inline_Always;
      Var_Expr : Lexical_Env := Empty_Env;
Match_0 : Internal_Entity_Generic_Package_Decl;
Match_1 : Internal_Entity_Basic_Decl;
Match_2 : Internal_Entity;
Var_Expr_1 : Internal_Entity;
Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Generic_Package_Internal;
Fld_5 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Fld_6 : Lexical_Env := Empty_Env;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Generic_Package_Decl;
Let_Result : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Let_Result_1 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Cast_Result_2 : Internal_Entity;
Let_Result_2 : Lexical_Env := Empty_Env;
Scope_Result_2 : Lexical_Env := Empty_Env;
Match_Result : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result_1 : Internal_Entity_Array_Access;
Get_Result_1 : Internal_Entity;
Fld_7 : Lexical_Env := Empty_Env;
Array_Lit_1 : Lexical_Env_Array_Access;
Group_Env_1 : Lexical_Env := Empty_Env;
Scope_Result_3 : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Scope_Result_4 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Let_Result_3 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_218 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_218;
            procedure Finalizer_Scope_2441 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
            end Finalizer_Scope_2441;
            procedure Finalizer_Scope_2442 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2442;
            procedure Finalizer_Scope_2444 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Env_Get_Result_1);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2444;
            procedure Finalizer_Scope_2445 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (Group_Env_1);
            end Finalizer_Scope_2445;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4439 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4438 '<bind at ast.py:3427>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3427
--# expr-start 4420 '<FieldAccess for default_initial_env at ast.py:3428>' Fld /tmp/lal-23.0.0/ada/ast.py:3428
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 4420
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 4431 '<Match at ast.py:3432>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3432
--# expr-start 4424 '<at at ast.py:3432>' Get_Result /tmp/lal-23.0.0/ada/ast.py:3432
--# expr-start 4423 '<EnvGet at ast.py:3429>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3429
--# expr-start 4421 '<FieldAccess for body_scope at ast.py:3429>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3429
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_scope
Fld_1 := Libadalang.Implementation.Body_Node_P_Body_Scope (Node => Ent.Node, Follow_Private => True, Env => Bound_Env, E_Info => Ent.Info);
--# end
--# expr-done 4421
--# expr-start 4422 '<FieldAccess for name_symbol at ast.py:3430>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3430
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4422
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_1, Key => Fld_2, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 4423
Get_Result := Get (Self, Env_Get_Result, 0, True); 
--# expr-done 4424
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Get_Result; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Generic_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Generic_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind gpd Match_0
--# expr-start 4429 '<env_group at ast.py:3438>' Group_Env /tmp/lal-23.0.0/ada/ast.py:3438
--# expr-start 4428 '<ArrayLiteral at ast.py:3437>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:3437
--# expr-start 4425 '<FieldAccess for children_env at ast.py:3437>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3437
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Children_Env (Node => Match_0.Node, E_Info => Match_0.Info);
--# expr-done 4425
--# expr-start 4427 '<FieldAccess for children_env at ast.py:3437>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3437
--# expr-start 4426 '<FieldAccess for package_decl at ast.py:3437>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3437
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Generic_Package_Internal (Node => Match_0.Node.Generic_Package_Decl_F_Package_Decl, Info => Match_0.Info);
--# expr-done 4426
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Children_Env (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# expr-done 4427
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld_3, 2 => Fld_5)); 
--# expr-done 4428
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 4429
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2441;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Abstract_State_Decl .. Ada_For_Loop_Var_Decl | Ada_Generic_Subp_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind pd Match_1
--# expr-start 4430 '<FieldAccess for children_env at ast.py:3439>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3439
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Children_Env (Node => Match_1.Node, E_Info => Match_1.Info);
--# expr-done 4430
Let_Result_1 := Fld_6; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2442;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
end case;
--# expr-done 4431
Var_Expr := Match_Result;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_Env then
   --# scope-start
   --# bind public_part Var_Expr
--# expr-start 4434 '<at at ast.py:3443>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:3443
--# expr-start 4433 '<EnvGet at ast.py:3441>' Env_Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:3441
--# expr-start 4432 '<Symbol __privatepart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Privatepart); 
--# expr-done 4432
Env_Get_Result_1 := Construct_Entity_Array (AST_Envs.Get (Self => Var_Expr, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 4433
Get_Result_1 := Get (Self, Env_Get_Result_1, 0, True); 
--# expr-done 4434
Var_Expr_1 := Get_Result_1;
if Var_Expr_1 /= No_Entity then
   --# scope-start
   --# bind pp Var_Expr_1
--# expr-start 4437 '<env_group at ast.py:3445>' Group_Env_1 /tmp/lal-23.0.0/ada/ast.py:3445
--# expr-start 4436 '<ArrayLiteral at ast.py:3445>' Array_Lit_1 /tmp/lal-23.0.0/ada/ast.py:3445
--# expr-start 4435 '<FieldAccess for children_env at ast.py:3445>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3445
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Children_Env (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# expr-done 4435
Array_Lit_1 := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld_7, 2 => Var_Expr)); 
--# expr-done 4436
Group_Env_1 := Group (Array_Lit_1, No_Metadata); 
--# expr-done 4437
Scope_Result_3 := Group_Env_1;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2445;
   Result_Var := Scope_Result_3;
else
   Result_Var := Var_Expr;
end if;
      Inc_Ref (Result_Var);
Scope_Result_4 := Result_Var;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2444;
   Result_Var_1 := Scope_Result_4;
else
   Result_Var_1 := Empty_Env;
end if;
      Inc_Ref (Result_Var_1);
Dyn_Var_Bind_Result := Result_Var_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4438
Let_Result_3 := Dyn_Var_Bind_Result; Inc_Ref (Let_Result_3);
--# end
--# expr-done 4439
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_218;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_218;
               Finalizer_Scope_2441;
               Finalizer_Scope_2442;
               Finalizer_Scope_2444;
               Finalizer_Scope_2445;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Subunit_Decl_Env;
--# end
--# property-start Body.in_scope /tmp/lal-23.0.0/ada/ast.py:3451
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_In_Scope
  (Node : Bare_Body_Node
      ; Origin : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
            procedure Finalizer_Scope_219 with Inline_Always;
      Is_Null : Boolean;
Not_Val : Boolean;
Fld : Internal_Unit;
Fld_1 : Internal_Unit;
Is_Equal : Boolean;
If_Result : Boolean;
Node_Parents : Bare_Ada_Node_Array_Access;
Cast_Expr : Bare_Body_Node;
Cast_Result : Bare_Ada_Node;
Is_Equal_1 : Boolean;
Find_Result : Bare_Ada_Node;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_219 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_219;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4450 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4441 '<Not at ast.py:3456>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3456
--# expr-start 4440 '<IsNull at ast.py:3456>' Is_Null /tmp/lal-23.0.0/ada/ast.py:3456
Is_Null := Origin = null; 
--# expr-done 4440
Not_Val := not (Is_Null); 
--# expr-done 4441
if Not_Val then
   --# expr-start 4444 '<Eq at ast.py:3457>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:3457
--# expr-start 4442 '<FieldAccess for unit at ast.py:3457>' Fld /tmp/lal-23.0.0/ada/ast.py:3457
      if Origin = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Unit (Node => Origin);
--# expr-done 4442
--# expr-start 4443 '<FieldAccess for unit at ast.py:3457>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3457
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 4443
Is_Equal := Fld = Fld_1; 
--# expr-done 4444
   If_Result := Is_Equal;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 4449 '<Not at ast.py:3458>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:3458
--# expr-start 4448 '<IsNull at ast.py:3458>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:3458
--# expr-start 4447 '<Find at ast.py:3458>' Find_Result /tmp/lal-23.0.0/ada/ast.py:3458
   --# expr-start 4445 '<FieldAccess for parents at ast.py:3458>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:3458
      if Origin = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Origin, True); 
--# expr-done 4445
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_170 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_170
      --# expr-start 4446 '<Eq at ast.py:3458>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:3458
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Is_Equal_1 := Cast_Result = Item_170; 
--# expr-done 4446
      if Is_Equal_1 then
         Find_Result := Item_170;
      end if;
   --# end
               exit when Is_Equal_1;
         end loop;
      end;
--# expr-done 4447
Is_Null_1 := Find_Result = null; 
--# expr-done 4448
Not_Val_1 := not (Is_Null_1); 
--# expr-done 4449
   If_Result_1 := Not_Val_1;
else
   If_Result_1 := False;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 4450
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_219;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_219;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_In_Scope;
--# end
--# property-start Body.body_decl_scope /tmp/lal-23.0.0/ada/ast.py:3462
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Body_Decl_Scope
  (Node : Bare_Body_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_220 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_220 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_220;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4454 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4453 '<bind at ast.py:3466>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3466
--# expr-start 4451 '<FieldAccess for default_initial_env at ast.py:3467>' Fld /tmp/lal-23.0.0/ada/ast.py:3467
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 4451
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 4452 '<FieldAccess for body_scope at ast.py:3468>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3468
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_scope
Fld_1 := Libadalang.Implementation.Body_Node_P_Body_Scope (Node => Ent.Node, Follow_Private => True, Force_Decl => True, Env => Bound_Env, E_Info => Ent.Info);
--# end
--# expr-done 4452
Dyn_Var_Bind_Result := Fld_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4453
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 4454
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_220;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_220;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Body_Decl_Scope;
--# end
--# property-start Body.body_initial_env_name /tmp/lal-23.0.0/ada/ast.py:3472
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Body_Initial_Env_Name
  (Node : Bare_Body_Node
  )
   return Symbol_Type
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
            procedure Finalizer_Scope_221 with Inline_Always;
      Fld : Boolean;
Fld_1 : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym : Symbol_Type;
Fld_2 : Boolean;
Fld_3 : String_Type;
Str_1 : String_Type;
Concat_Result_1 : String_Type;
Sym_1 : Symbol_Type;
If_Result : Symbol_Type;
If_Result_1 : Symbol_Type;
Let_Result : Symbol_Type;
            procedure Finalizer_Scope_221 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Str_1);
                     Dec_Ref (Concat_Result_1);
            end Finalizer_Scope_221;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4466 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4465 '<Cond at ast.py:3478>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3478
--# expr-start 4455 '<FieldAccess for is_library_item at ast.py:3479>' Fld /tmp/lal-23.0.0/ada/ast.py:3479
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 4455
if Fld then
   --# expr-start 4459 '<to_symbol at ast.py:3480>' Sym /tmp/lal-23.0.0/ada/ast.py:3480
--# expr-start 4458 '<Concat at ast.py:3480>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:3480
--# expr-start 4456 '<FieldAccess for top_level_env_name at ast.py:3480>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3480
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4456
--# expr-start 4457 '<String at ast.py:3480>' Str /tmp/lal-23.0.0/ada/ast.py:3480
Str := Create_String (".__privatepart"); 
--# expr-done 4457
Concat_Result := Concat_String (Fld_1, Str); 
--# expr-done 4458
Sym := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 4459
   If_Result_1 := Sym;
else
--# expr-start 4460 '<FieldAccess for is_subunit at ast.py:3482>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3482
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld_2 := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Self);
--# end
--# expr-done 4460
if Fld_2 then
   --# expr-start 4464 '<to_symbol at ast.py:3483>' Sym_1 /tmp/lal-23.0.0/ada/ast.py:3483
--# expr-start 4463 '<Concat at ast.py:3483>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:3483
--# expr-start 4461 '<FieldAccess for top_level_env_name at ast.py:3483>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3483
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4461
--# expr-start 4462 '<String at ast.py:3483>' Str_1 /tmp/lal-23.0.0/ada/ast.py:3483
Str_1 := Create_String ("__stub"); 
--# expr-done 4462
Concat_Result_1 := Concat_String (Fld_3, Str_1); 
--# expr-done 4463
Sym_1 := String_To_Symbol (Self, Self.Unit.Context, Concat_Result_1); 
--# expr-done 4464
   If_Result := Sym_1;
else
   If_Result := null;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 4465
Let_Result := If_Result_1; 
--# end
--# expr-done 4466
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_221;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_221;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Body_Initial_Env_Name;
--# end
--# property-start Body.body_initial_env /tmp/lal-23.0.0/ada/ast.py:3489
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Body_Initial_Env
  (Node : Bare_Body_Node
  )
   return Internal_Designated_Env
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_222 with Inline_Always;
            procedure Finalizer_Scope_2447 with Inline_Always;
      Var_Expr : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
Let_Result : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_222 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_222;
            procedure Finalizer_Scope_2447 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2447;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4470 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4467 '<FieldAccess for body_initial_env_name at ast.py:3496>' Fld /tmp/lal-23.0.0/ada/ast.py:3496
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_initial_env_name
Fld := Libadalang.Implementation.Body_Node_P_Body_Initial_Env_Name (Node => Self);
--# end
--# expr-done 4467
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind non_null_name Var_Expr
--# expr-start 4468 '<New DesignatedEnv at ???>' New_Struct None
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 4468
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2447;
   Result_Var := Scope_Result;
else
   --# expr-start 4469 '<New DesignatedEnv at ast.py:3495>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:3495
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4469
   Result_Var := New_Struct_1;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 4470
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_222;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_222;
               Finalizer_Scope_2447;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Body_Initial_Env;
--# end
--# property-start '[dispatcher]Body.previous_part_env_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Body_Node_P_Previous_Part_Env_Name
  (Node : Bare_Body_Node
  )
   return Symbol_Type
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Body_Node (Self.Kind) is
               when Ada_Package_Body_Stub .. Ada_Task_Body =>
                  --# property-call-start Body.previous_part_env_name
                  Property_Result := Body_Node_P_Previous_Part_Env_Name
                    (Self
                    );
                  --# end
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
                  --# property-call-start BaseSubpBody.previous_part_env_name
                  Property_Result := Base_Subp_Body_P_Previous_Part_Env_Name
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Body_Node_P_Previous_Part_Env_Name;
--# end
--# property-start '[dispatcher]Body.previous_part_link_env_assoc' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc
  (Node : Bare_Body_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Body_Node (Self.Kind) is
               when Ada_Expr_Function .. Ada_Subp_Renaming_Decl | Ada_Entry_Body .. Ada_Task_Body =>
                  --# property-call-start Body.previous_part_link_env_assoc
                  Property_Result := Body_Node_P_Previous_Part_Link_Env_Assoc
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Package_Body_Stub .. Ada_Task_Body_Stub =>
                  --# property-call-start BodyStub.previous_part_link_env_assoc
                  Property_Result := Body_Stub_P_Previous_Part_Link_Env_Assoc
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc;
--# end
--# property-start Body.subp_previous_part /tmp/lal-23.0.0/ada/ast.py:3545
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Subp_Previous_Part
  (Node : Bare_Body_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_225 with Inline_Always;
            procedure Finalizer_Scope_2450 with Inline_Always;
      Block_Var : Internal_Entity;
Block_Var_1 : Internal_Entity_Array_Access;
Block_Var_2 : Boolean;
Block_Var_3 : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Compilation_Unit;
Match_0 : Internal_Entity_Generic_Subp_Decl;
Match_1 : Internal_Entity_Formal_Subp_Decl;
Match_2 : Internal_Entity_Basic_Subp_Decl;
Match_3 : Internal_Entity_Subp_Body_Stub;
Match_4 : Internal_Entity;
Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity;
Fld_3 : Boolean;
If_Result : Internal_Entity;
Is_Null : Boolean;
Is_A : Boolean;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Compilation_Unit;
Fld_4 : Internal_Entity_Compilation_Unit;
Fld_5 : Bare_Basic_Decl;
Cast_Result_1 : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Singleton : Internal_Entity_Array_Access;
Fld_6 : Bare_Basic_Decl;
Is_A_1 : Boolean;
If_Result_2 : Internal_Entity_Array_Access;
Scope_Result : Internal_Entity_Array_Access;
Result_Var : Internal_Entity_Array_Access;
Is_A_2 : Boolean;
Singleton_1 : Internal_Entity_Array_Access;
Fld_7 : Lexical_Env := Empty_Env;
Fld_8 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
If_Result_3 : Internal_Entity_Array_Access;
If_Result_4 : Internal_Entity_Array_Access;
If_Result_5 : Internal_Entity_Array_Access;
Is_A_3 : Boolean;
Get_Result : Internal_Entity;
Is_Null_2 : Boolean;
Not_Val : Boolean;
Fld_9 : Bare_Ada_Node;
Cast_Expr_1 : Bare_Body_Node;
Cast_Result_2 : Bare_Ada_Node;
Is_Equal : Boolean;
Not_Val_1 : Boolean;
If_Result_6 : Boolean;
Fld_10 : Internal_Entity_Base_Subp_Spec;
Fld_11 : Internal_Entity_Base_Subp_Spec;
Cast_Result_3 : Internal_Entity_Subp_Spec;
Cast_Result_4 : Internal_Entity_Base_Subp_Spec;
Fld_12 : Boolean;
Fld_13 : Internal_Entity_Subp_Spec;
Fld_14 : Internal_Entity_Base_Subp_Spec;
Cast_Result_5 : Internal_Entity_Subp_Spec;
Cast_Result_6 : Internal_Entity_Base_Subp_Spec;
Fld_15 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result_7 : Internal_Entity_Generic_Subp_Decl;
Let_Result : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_8 : Internal_Entity_Formal_Subp_Decl;
Let_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_9 : Internal_Entity_Basic_Subp_Decl;
Let_Result_2 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_10 : Internal_Entity_Subp_Body_Stub;
Let_Result_3 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_11 : Internal_Entity;
Let_Result_4 : Boolean;
Scope_Result_5 : Boolean;
Match_Result : Boolean;
If_Result_7 : Boolean;
Find_Result : Internal_Entity;
If_Result_8 : Internal_Entity;
Cast_Result_12 : Internal_Entity_Basic_Decl;
Is_Null_3 : Boolean;
Not_Val_2 : Boolean;
Fld_16 : Bare_Ada_Node;
Cast_Expr_2 : Bare_Body_Node;
Cast_Result_13 : Bare_Ada_Node;
Is_Equal_1 : Boolean;
Not_Val_3 : Boolean;
If_Result_9 : Boolean;
Is_A_4 : Boolean;
If_Result_10 : Boolean;
Find_Result_1 : Internal_Entity;
Cast_Result_14 : Internal_Entity_Basic_Decl;
Is_Null_4 : Boolean;
If_Result_11 : Boolean;
If_Result_12 : Internal_Entity_Basic_Decl;
Let_Result_5 : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_225 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Singleton_1);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (Block_Var_1);
            end Finalizer_Scope_225;
            procedure Finalizer_Scope_2450 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (If_Result_2);
            end Finalizer_Scope_2450;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4520 '<Block at ???>' Let_Result_5 None
--# scope-start
--# expr-start 4475 '<If at ast.py:3555>' If_Result /tmp/lal-23.0.0/ada/ast.py:3555
--# expr-start 4471 '<FieldAccess for is_library_item at ast.py:3556>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3556
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Ent.Node);
--# end
--# expr-done 4471
if Fld_3 then
   --# expr-start 4473 '<parent at ast.py:3557>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3557
--# expr-start 4472 '<parent at ast.py:3557>' Fld /tmp/lal-23.0.0/ada/ast.py:3557
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 4472
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 4473
   If_Result := Fld_1;
else
   --# expr-start 4474 '<FieldAccess for semantic_parent at ast.py:3558>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3558
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_2 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4474
   If_Result := Fld_2;
end if;
--# expr-done 4475
Block_Var := If_Result; 
--# bind parent Block_Var
--# expr-start 4490 '<Cond at ast.py:3561>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:3561
--# expr-start 4476 '<IsNull at ast.py:3562>' Is_Null /tmp/lal-23.0.0/ada/ast.py:3562
Is_Null := Block_Var.Node = null; 
--# expr-done 4476
if Is_Null then
   If_Result_5 := No_Internal_Entity_Array_Type;
else
--# expr-start 4477 '<IsA CompilationUnit at ast.py:3567>' Is_A /tmp/lal-23.0.0/ada/ast.py:3567
Is_A := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 4477
if Is_A then
--# expr-start 4479 '<FieldAccess for other_part at ast.py:3568>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3568
--# expr-start 4478 '<Cast to CompilationUnit at ast.py:3568>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3568
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Create_Internal_Entity_Compilation_Unit
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Compilation_Unit;
   end if;
--# expr-done 4478
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.other_part
Fld_4 := Libadalang.Implementation.Compilation_Unit_P_Other_Part (Node => Cast_Result.Node);
--# end
--# expr-done 4479
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Compilation_Unit then
   --# scope-start
   --# bind cu Var_Expr
--# expr-start 4485 '<If at ast.py:3571>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:3571
--# expr-start 4481 '<IsA BasicSubpDecl, GenericSubpDecl at ast.py:3572>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:3572
--# expr-start 4480 '<FieldAccess for decl at ast.py:3572>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3572
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_6 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr.Node);
--# end
--# expr-done 4480
Is_A_1 := Fld_6 /= null 
and then Fld_6.Kind in Ada_Basic_Subp_Decl | Ada_Generic_Subp_Decl_Range; 
--# expr-done 4481
if Is_A_1 then
   --# expr-start 4484 '<as_entity at ast.py:3573>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3573
--# expr-start 4483 '<Cast to AdaNode at ast.py:3573>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:3573
--# expr-start 4482 '<FieldAccess for decl at ast.py:3573>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3573
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_5 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr.Node);
--# end
--# expr-done 4482
      Cast_Result_1 := Fld_5;
--# expr-done 4483
Is_Null_1 := Cast_Result_1 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
As_Entity := (Info => E_Info, Node => Cast_Result_1); 
   If_Result_1 := As_Entity;
end if;
--# expr-done 4484
                Singleton := Create_Internal_Entity_Array (Items_Count => 1);
                Singleton.Items (1) := If_Result_1;
   If_Result_2 := Singleton;
else
   If_Result_2 := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 4485
Scope_Result := If_Result_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2450;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var);
   If_Result_4 := Result_Var;
else
--# expr-start 4486 '<IsA BodyStub at ast.py:3580>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:3580
Is_A_2 := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Body_Stub; 
--# expr-done 4486
if Is_A_2 then
                Singleton_1 := Create_Internal_Entity_Array (Items_Count => 1);
                Singleton_1.Items (1) := Block_Var;
   If_Result_3 := Singleton_1;
else
   --# expr-start 4489 '<EnvGet at ast.py:3584>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3584
--# expr-start 4487 '<FieldAccess for immediate_declarative_region at ast.py:3584>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3584
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.immediate_declarative_region'
Fld_7 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Immediate_Declarative_Region (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 4487
--# expr-start 4488 '<FieldAccess for name_symbol at ast.py:3585>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:3585
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4488
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_7, Key => Fld_8, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 4489
   If_Result_3 := Env_Get_Result;
end if;
      Inc_Ref (If_Result_3);
   If_Result_4 := If_Result_3;
end if;
      Inc_Ref (If_Result_4);
   If_Result_5 := If_Result_4;
end if;
      Inc_Ref (If_Result_5);
--# expr-done 4490
Block_Var_1 := If_Result_5; Inc_Ref (Block_Var_1);
--# bind elements Block_Var_1
--# expr-start 4491 '<IsA CompilationUnit, BodyStub at ast.py:3593>' Is_A_3 /tmp/lal-23.0.0/ada/ast.py:3593
Is_A_3 := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Compilation_Unit_Range | Ada_Body_Stub; 
--# expr-done 4491
Block_Var_2 := Is_A_3; 
--# bind already_precise Block_Var_2
--# expr-start 4509 '<Cast to BasicDecl.entity at ast.py:3629>' Cast_Result_12 /tmp/lal-23.0.0/ada/ast.py:3629
--# expr-start 4508 '<If at ast.py:3595>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:3595
if Block_Var_2 then
   --# expr-start 4492 '<at at ast.py:3597>' Get_Result /tmp/lal-23.0.0/ada/ast.py:3597
Get_Result := Get (Self, Block_Var_1, 0, True); 
--# expr-done 4492
   If_Result_8 := Get_Result;
else
   --# expr-start 4507 '<Find at ast.py:3598>' Find_Result /tmp/lal-23.0.0/ada/ast.py:3598
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var_1;
      begin
         for Item_171 of
               Collection.Items
         loop
   --# scope-start
               --# bind sp Item_171
--# expr-start 4494 '<Not at ast.py:3599>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3599
--# expr-start 4493 '<IsNull at ast.py:3599>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:3599
Is_Null_2 := Item_171.Node = null; 
--# expr-done 4493
Not_Val := not (Is_Null_2); 
--# expr-done 4494
if Not_Val then
   --# expr-start 4497 '<Not at ast.py:3600>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:3600
--# expr-start 4496 '<Eq at ast.py:3600>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:3600
--# expr-start 4495 '<FieldAccess for node at ast.py:3600>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:3600
Fld_9 := Item_171.Node;
--# expr-done 4495
Cast_Expr_1 := Self; 
      Cast_Result_2 := Cast_Expr_1;
Is_Equal := Fld_9 = Cast_Result_2; 
--# expr-done 4496
Not_Val_1 := not (Is_Equal); 
--# expr-done 4497
   If_Result_6 := Not_Val_1;
else
   If_Result_6 := False;
end if;
if If_Result_6 then
   --# expr-start 4506 '<Match at ast.py:3601>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3601
      if Item_171.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_171; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Generic_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Generic_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_7; 
--# bind _ Match_0
Let_Result := True; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_Formal_Subp_Decl .. Ada_Concrete_Formal_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Formal_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_8; 
--# bind _ Match_1
Let_Result_1 := False; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Abstract_Subp_Decl | Ada_Subp_Decl .. Ada_Synthetic_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Basic_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_9; 
--# bind subp_decl Match_2
--# expr-start 4501 '<FieldAccess for match_signature at ast.py:3611>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:3611
--# expr-start 4498 '<FieldAccess for subp_decl_spec at ast.py:3611>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:3611
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicSubpDecl.subp_decl_spec'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Subp_Decl_P_Subp_Decl_Spec (Node => Match_2.Node, E_Info => Match_2.Info);
--# end
--# expr-done 4498
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4500 '<Cast to SubpSpec at ast.py:3612>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:3612
--# expr-start 4499 '<FieldAccess for subp_spec_or_null at ast.py:3612>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:3612
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4499
   if Fld_11.Node = null
      or else Fld_11.Node.Kind in Ada_Subp_Spec_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Subp_Spec
        (Node => Fld_11.Node,
         Info => Fld_11.Info);
   else
         Cast_Result_3 := No_Entity_Subp_Spec;
   end if;
--# expr-done 4500
      Cast_Result_4 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Result_3.Node,
         Info => Cast_Result_3.Info);
--# property-call-start BaseSubpSpec.match_signature
Fld_12 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld_10.Node, Other => Cast_Result_4, Match_Name => True, Use_Entity_Info => False, E_Info => Fld_10.Info);
--# end
--# expr-done 4501
Let_Result_2 := Fld_12; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Subp_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity_Subp_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_10; 
--# bind subp_stub Match_3
--# expr-start 4505 '<FieldAccess for match_signature at ast.py:3619>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:3619
--# expr-start 4502 '<FieldAccess for subp_spec at ast.py:3619>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:3619
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Subp_Spec (Node => Match_3.Node.Subp_Body_Stub_F_Subp_Spec, Info => Match_3.Info);
--# expr-done 4502
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4504 '<Cast to SubpSpec at ast.py:3620>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:3620
--# expr-start 4503 '<FieldAccess for subp_spec_or_null at ast.py:3620>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:3620
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_14 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4503
   if Fld_14.Node = null
      or else Fld_14.Node.Kind in Ada_Subp_Spec_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Subp_Spec
        (Node => Fld_14.Node,
         Info => Fld_14.Info);
   else
         Cast_Result_5 := No_Entity_Subp_Spec;
   end if;
--# expr-done 4504
      Cast_Result_6 := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Result_5.Node,
         Info => Cast_Result_5.Info);
--# property-call-start BaseSubpSpec.match_signature
Fld_15 := Libadalang.Implementation.Base_Subp_Spec_P_Match_Signature (Node => Fld_13.Node, Other => Cast_Result_6, Match_Name => True, Use_Entity_Info => False, E_Info => Fld_13.Info);
--# end
--# expr-done 4505
Let_Result_3 := Fld_15; 
--# end
Scope_Result_4 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Abort_Absent .. Ada_Formal_Type_Decl | Ada_Expr_Function .. Ada_Protected_Body_Stub | Ada_Task_Body_Stub .. Ada_Generic_Package_Decl | Ada_Generic_Package_Instantiation .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_11; 
--# bind _ Match_4
Let_Result_4 := False; 
--# end
Scope_Result_5 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_5; 
end case;
--# expr-done 4506
   If_Result_7 := Match_Result;
else
   If_Result_7 := False;
end if;
      if If_Result_7 then
         Find_Result := Item_171;
      end if;
   --# end
               exit when If_Result_7;
         end loop;
      end;
--# expr-done 4507
   If_Result_8 := Find_Result;
end if;
--# expr-done 4508
   if If_Result_8.Node = null
      or else If_Result_8.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_12 := Create_Internal_Entity_Basic_Decl
        (Node => If_Result_8.Node,
         Info => If_Result_8.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4509
Block_Var_3 := Cast_Result_12; 
--# bind precise Block_Var_3
--# expr-start 4519 '<If at ast.py:3631>' If_Result_12 /tmp/lal-23.0.0/ada/ast.py:3631
--# expr-start 4510 '<IsNull at ast.py:3632>' Is_Null_4 /tmp/lal-23.0.0/ada/ast.py:3632
Is_Null_4 := Block_Var_3.Node = null; 
--# expr-done 4510
if Is_Null_4 then
   If_Result_11 := Imprecise_Fallback;
else
   If_Result_11 := False;
end if;
if If_Result_11 then
   --# expr-start 4518 '<Cast to BasicDecl.entity at ast.py:3639>' Cast_Result_14 /tmp/lal-23.0.0/ada/ast.py:3639
--# expr-start 4517 '<Find at ast.py:3633>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:3633
      Find_Result_1 := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var_1;
      begin
         for Item_172 of
               Collection.Items
         loop
   --# scope-start
               --# bind sp Item_172
--# expr-start 4512 '<Not at ast.py:3635>' Not_Val_2 /tmp/lal-23.0.0/ada/ast.py:3635
--# expr-start 4511 '<IsNull at ast.py:3635>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:3635
Is_Null_3 := Item_172.Node = null; 
--# expr-done 4511
Not_Val_2 := not (Is_Null_3); 
--# expr-done 4512
if Not_Val_2 then
   --# expr-start 4515 '<Not at ast.py:3636>' Not_Val_3 /tmp/lal-23.0.0/ada/ast.py:3636
--# expr-start 4514 '<Eq at ast.py:3636>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:3636
--# expr-start 4513 '<FieldAccess for node at ast.py:3636>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:3636
Fld_16 := Item_172.Node;
--# expr-done 4513
Cast_Expr_2 := Self; 
      Cast_Result_13 := Cast_Expr_2;
Is_Equal_1 := Fld_16 = Cast_Result_13; 
--# expr-done 4514
Not_Val_3 := not (Is_Equal_1); 
--# expr-done 4515
   If_Result_9 := Not_Val_3;
else
   If_Result_9 := False;
end if;
if If_Result_9 then
   --# expr-start 4516 '<IsA BasicSubpDecl, SubpBodyStub at ast.py:3637>' Is_A_4 /tmp/lal-23.0.0/ada/ast.py:3637
Is_A_4 := Item_172.Node /= null 
and then Item_172.Node.Kind in Ada_Basic_Subp_Decl | Ada_Subp_Body_Stub_Range; 
--# expr-done 4516
   If_Result_10 := Is_A_4;
else
   If_Result_10 := False;
end if;
      if If_Result_10 then
         Find_Result_1 := Item_172;
      end if;
   --# end
               exit when If_Result_10;
         end loop;
      end;
--# expr-done 4517
   if Find_Result_1.Node = null
      or else Find_Result_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_14 := Create_Internal_Entity_Basic_Decl
        (Node => Find_Result_1.Node,
         Info => Find_Result_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4518
   If_Result_12 := Cast_Result_14;
else
   If_Result_12 := Block_Var_3;
end if;
--# expr-done 4519
Let_Result_5 := If_Result_12; 
--# end
--# expr-done 4520
      Property_Result := Let_Result_5;
   --# end
      Finalizer_Scope_225;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_225;
               Finalizer_Scope_2450;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Subp_Previous_Part;
--# end
--# property-start Body.entry_previous_part /tmp/lal-23.0.0/ada/ast.py:3644
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Entry_Previous_Part
  (Node : Bare_Body_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Entry_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Entry_Decl;
            procedure Finalizer_Scope_226 with Inline_Always;
      Block_Var : Internal_Entity_Entry_Completion_Formal_Params;
Match_0 : Internal_Entity_Entry_Decl;
Match_1 : Internal_Entity;
Cast_Expr : Internal_Entity_Body_Node;
Cast_Result : Internal_Entity_Entry_Body;
Fld : Internal_Entity_Entry_Completion_Formal_Params;
Fld_1 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_2 : Bare_Ada_Node;
Cast_Expr_1 : Bare_Body_Node;
Cast_Result_1 : Bare_Ada_Node;
Is_Equal : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Fld_3 : Internal_Entity_Entry_Spec;
Cast_Expr_2 : Internal_Entity_Entry_Completion_Formal_Params;
Cast_Result_2 : Internal_Entity_Base_Formal_Param_Holder;
Fld_4 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result_3 : Internal_Entity_Entry_Decl;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_4 : Internal_Entity;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Match_Result : Boolean;
If_Result_1 : Boolean;
Find_Result : Internal_Entity;
Cast_Result_5 : Internal_Entity_Entry_Decl;
Let_Result_2 : Internal_Entity_Entry_Decl;
            procedure Finalizer_Scope_226 is
            begin
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_226;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4535 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 4522 '<FieldAccess for params at ast.py:3648>' Fld /tmp/lal-23.0.0/ada/ast.py:3648
--# expr-start 4521 '<Cast to EntryBody at ast.py:3648>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3648
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Entry_Body_Range
   then
      Cast_Result := Create_Internal_Entity_Entry_Body
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4521
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Entry_Completion_Formal_Params (Node => Cast_Result.Node.Entry_Body_F_Params, Info => Cast_Result.Info);
--# expr-done 4522
Block_Var := Fld; 
--# bind spec Block_Var
--# expr-start 4534 '<Cast to EntryDecl.entity at ast.py:3660>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:3660
--# expr-start 4533 '<Find at ast.py:3649>' Find_Result /tmp/lal-23.0.0/ada/ast.py:3649
   --# expr-start 4524 '<EnvGet at ast.py:3649>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3649
--# expr-start 4523 '<FieldAccess for name_symbol at ast.py:3649>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3649
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4523
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Env, Key => Fld_1, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 4524
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_173 of
               Collection.Items
         loop
   --# scope-start
               --# bind sp Item_173
--# expr-start 4526 '<Not at ast.py:3651>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3651
--# expr-start 4525 '<IsNull at ast.py:3651>' Is_Null /tmp/lal-23.0.0/ada/ast.py:3651
Is_Null := Item_173.Node = null; 
--# expr-done 4525
Not_Val := not (Is_Null); 
--# expr-done 4526
if Not_Val then
   --# expr-start 4529 '<Not at ast.py:3652>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:3652
--# expr-start 4528 '<Eq at ast.py:3652>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:3652
--# expr-start 4527 '<FieldAccess for node at ast.py:3652>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3652
Fld_2 := Item_173.Node;
--# expr-done 4527
Cast_Expr_1 := Self; 
      Cast_Result_1 := Cast_Expr_1;
Is_Equal := Fld_2 = Cast_Result_1; 
--# expr-done 4528
Not_Val_1 := not (Is_Equal); 
--# expr-done 4529
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 4532 '<Match at ast.py:3653>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3653
      if Item_173.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_173; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Entry_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Entry_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_3; 
--# bind entry_decl Match_0
--# expr-start 4531 '<FieldAccess for match_formal_params at ast.py:3655>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3655
--# expr-start 4530 '<FieldAccess for spec at ast.py:3655>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3655
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Entry_Spec (Node => Match_0.Node.Entry_Decl_F_Spec, Info => Match_0.Info);
--# expr-done 4530
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_2 := Block_Var; 
      Cast_Result_2 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
--# property-call-start BaseFormalParamHolder.match_formal_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Formal_Params (Node => Fld_3.Node, Other => Cast_Result_2, E_Info => Fld_3.Info);
--# end
--# expr-done 4531
Let_Result := Fld_4; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abort_Absent .. Ada_Subp_Decl | Ada_Enum_Literal_Decl .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_4; 
--# bind _ Match_1
Let_Result_1 := False; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 4532
   If_Result_1 := Match_Result;
else
   If_Result_1 := False;
end if;
      if If_Result_1 then
         Find_Result := Item_173;
      end if;
   --# end
               exit when If_Result_1;
         end loop;
      end;
--# expr-done 4533
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Entry_Decl
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4534
Let_Result_2 := Cast_Result_5; 
--# end
--# expr-done 4535
      Property_Result := Let_Result_2;
   --# end
      Finalizer_Scope_226;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_226;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Entry_Previous_Part;
--# end
--# property-start Body.package_previous_part /tmp/lal-23.0.0/ada/ast.py:3663
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Package_Previous_Part
  (Node : Bare_Body_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_227 with Inline_Always;
            procedure Finalizer_Scope_2461 with Inline_Always;
            procedure Finalizer_Scope_2462 with Inline_Always;
      Var_Expr : Internal_Entity_Compilation_Unit;
Var_Expr_1 : Internal_Entity;
Match_0 : Internal_Entity_Package_Decl;
Match_1 : Internal_Entity_Generic_Package_Decl;
Match_2 : Internal_Entity;
Fld : Bare_Compilation_Unit;
Fld_1 : Internal_Entity_Compilation_Unit;
Fld_2 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Singleton : Internal_Entity_Array_Access;
Scope_Result : Internal_Entity_Array_Access;
Result_Var : Internal_Entity_Array_Access;
Scope_Result_1 : Internal_Entity_Array_Access;
Result_Var_1 : Internal_Entity_Array_Access;
Fld_3 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_4 : Internal_Entity_Defining_Name;
Fld_5 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Fld_6 : Boolean;
If_Result_1 : Internal_Entity_Array_Access;
Fld_7 : Internal_Entity_Generic_Package_Internal;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Package_Decl;
Cast_Expr : Internal_Entity_Package_Decl;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Generic_Package_Decl;
Cast_Result_4 : Internal_Entity_Basic_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_3 : Internal_Entity_Basic_Decl;
Cast_Result_5 : Internal_Entity;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_4 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Is_Null_1 : Boolean;
Not_Val : Boolean;
Find_Result : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_227 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_227;
            procedure Finalizer_Scope_2461 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2461;
            procedure Finalizer_Scope_2462 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2462;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4553 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4552 '<Find at ast.py:3685>' Find_Result /tmp/lal-23.0.0/ada/ast.py:3685
   --# expr-start 4549 '<Map at ast.py:3678>' Map_Result /tmp/lal-23.0.0/ada/ast.py:3678
   --# expr-start 4546 '<If at ast.py:3670>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3670
--# expr-start 4536 '<FieldAccess for is_library_item at ast.py:3671>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3671
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_6 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 4536
if Fld_6 then
--# expr-start 4538 '<FieldAccess for other_part at ast.py:3672>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3672
--# expr-start 4537 '<FieldAccess for enclosing_compilation_unit at ast.py:3672>' Fld /tmp/lal-23.0.0/ada/ast.py:3672
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Self);
--# end
--# expr-done 4537
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.other_part
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Other_Part (Node => Fld);
--# end
--# expr-done 4538
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Compilation_Unit then
   --# scope-start
   --# bind part Var_Expr
--# expr-start 4541 '<Cast to AdaNode at ast.py:3673>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3673
--# expr-start 4540 '<as_entity at ast.py:3673>' If_Result /tmp/lal-23.0.0/ada/ast.py:3673
--# expr-start 4539 '<FieldAccess for decl at ast.py:3673>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3673
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_2 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr.Node);
--# end
--# expr-done 4539
Is_Null := Fld_2 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => E_Info, Node => Fld_2); 
   If_Result := As_Entity;
end if;
--# expr-done 4540
      Cast_Result := Create_Internal_Entity
        (Node => If_Result.Node,
         Info => If_Result.Info);
--# expr-done 4541
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity then
   --# scope-start
                Singleton := Create_Internal_Entity_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr_1;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2462;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var);
Scope_Result_1 := Result_Var;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2461;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
   If_Result_1 := Result_Var_1;
else
   --# expr-start 4545 '<bind at ast.py:3675>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3675
--# expr-start 4542 '<FieldAccess for origin_node at ast.py:3676>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3676
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_3 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 4542
Bound_Origin := Fld_3; 
--# expr-start 4544 '<FieldAccess for all_env_els_impl at ast.py:3676>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3676
--# expr-start 4543 '<FieldAccess for defining_name at ast.py:3676>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3676
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4543
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.all_env_els_impl'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_All_Env_Els_Impl (Node => Fld_4.Node, Env => Env, Origin => Bound_Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 4544
Dyn_Var_Bind_Result := Fld_5; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4545
   If_Result_1 := Dyn_Var_Bind_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 4546
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := If_Result_1;
      begin
         for Item_175 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_175
      --# expr-start 4548 '<Match at ast.py:3679>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3679
      if Item_175.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_175; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind pkg_decl Match_0
Cast_Expr := Match_0; 
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Let_Result := Cast_Result_2; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Generic_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Generic_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind gen_pkg_decl Match_1
--# expr-start 4547 '<FieldAccess for package_decl at ast.py:3682>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3682
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Generic_Package_Internal (Node => Match_1.Node.Generic_Package_Decl_F_Package_Decl, Info => Match_1.Info);
--# expr-done 4547
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
Let_Result_1 := Cast_Result_4; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Abort_Absent .. Ada_Generic_Package_Internal | Ada_Discrete_Base_Subtype_Decl .. Ada_For_Loop_Var_Decl | Ada_Generic_Subp_Decl .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_5; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Basic_Decl; 
--# end
Scope_Result_4 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_4; 
end case;
--# expr-done 4548
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Match_Result;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4549
      Find_Result := No_Entity_Basic_Decl;
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Map_Result;
      begin
         for Item_174 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_174
      --# expr-start 4551 '<Not at ast.py:3686>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3686
--# expr-start 4550 '<IsNull at ast.py:3686>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:3686
Is_Null_1 := Item_174.Node = null; 
--# expr-done 4550
Not_Val := not (Is_Null_1); 
--# expr-done 4551
      if Not_Val then
         Find_Result := Item_174;
      end if;
   --# end
               exit when Not_Val;
         end loop;
      end;
--# expr-done 4552
Let_Result_3 := Find_Result; 
--# end
--# expr-done 4553
      Property_Result := Let_Result_3;
   --# end
      Finalizer_Scope_227;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_227;
               Finalizer_Scope_2461;
               Finalizer_Scope_2462;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Package_Previous_Part;
--# end
--# property-start Body.task_previous_part /tmp/lal-23.0.0/ada/ast.py:3690
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Task_Previous_Part
  (Node : Bare_Body_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_228 with Inline_Always;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Defining_Name;
Fld_2 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_228 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
            end Finalizer_Scope_228;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4560 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4559 '<Cast to BasicDecl at ast.py:3696>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3696
--# expr-start 4558 '<at at ast.py:3696>' Get_Result /tmp/lal-23.0.0/ada/ast.py:3696
--# expr-start 4557 '<bind at ast.py:3694>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3694
--# expr-start 4554 '<FieldAccess for origin_node at ast.py:3695>' Fld /tmp/lal-23.0.0/ada/ast.py:3695
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 4554
Bound_Origin := Fld; 
--# expr-start 4556 '<FieldAccess for all_env_els_impl at ast.py:3695>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3695
--# expr-start 4555 '<FieldAccess for defining_name at ast.py:3695>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3695
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4555
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.all_env_els_impl'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_All_Env_Els_Impl (Node => Fld_1.Node, Env => Env, Origin => Bound_Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 4556
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4557
Get_Result := Get (Self, Dyn_Var_Bind_Result, 0, True); 
--# expr-done 4558
   if Get_Result.Node = null
      or else Get_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Get_Result.Node,
         Info => Get_Result.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 4559
Let_Result := Cast_Result; 
--# end
--# expr-done 4560
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_228;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_228;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Task_Previous_Part;
--# end
--# property-start Body.protected_previous_part /tmp/lal-23.0.0/ada/ast.py:3699
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Protected_Previous_Part
  (Node : Bare_Body_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_229 with Inline_Always;
      Var_Expr : Internal_Entity;
Match_0 : Internal_Entity_Protected_Type_Decl;
Match_1 : Internal_Entity_Single_Protected_Decl;
Match_2 : Internal_Entity;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Protected_Type_Decl;
Cast_Expr : Internal_Entity_Protected_Type_Decl;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Single_Protected_Decl;
Cast_Expr_1 : Internal_Entity_Single_Protected_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Scope_Result_3 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_229 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_229;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4565 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4563 '<at at ast.py:3703>' Get_Result /tmp/lal-23.0.0/ada/ast.py:3703
--# expr-start 4562 '<FieldAccess for env_elements at ast.py:3703>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3703
--# expr-start 4561 '<FieldAccess for defining_name at ast.py:3703>' Fld /tmp/lal-23.0.0/ada/ast.py:3703
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4561
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_1 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Fld.Node, Env => Env, No_Visibility => False, E_Info => Fld.Info);
--# end
--# expr-done 4562
Get_Result := Get (Self, Fld_1, 0, True); 
--# expr-done 4563
Var_Expr := Get_Result;
if Var_Expr /= No_Entity then
   --# scope-start
--# expr-start 4564 '<Match at ast.py:3703>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3703
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Protected_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Protected_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind prot_type Match_0
Cast_Expr := Match_0; 
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Let_Result := Cast_Result_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Single_Protected_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Single_Protected_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind prot_decl Match_1
Cast_Expr_1 := Match_1; 
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Let_Result_1 := Cast_Result_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Incomplete_Tagged_Type_Decl | Ada_Task_Type_Decl .. Ada_Package_Renaming_Decl | Ada_Single_Task_Decl .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Basic_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 4564
Scope_Result_3 := Match_Result;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Let_Result_3 := Result_Var; 
--# end
--# expr-done 4565
      Property_Result := Let_Result_3;
   --# end
      Finalizer_Scope_229;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_229;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Protected_Previous_Part;
--# end
--# property-start Body.unbound_previous_part /tmp/lal-23.0.0/ada/ast.py:3711
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Unbound_Previous_Part
  (Node : Bare_Body_Node
      ; Env : Lexical_Env
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Block_Var : Internal_Entity_Basic_Decl;
Match_0 : Internal_Entity_Base_Subp_Body;
Match_1 : Internal_Entity_Subp_Body_Stub;
Match_2 : Internal_Entity_Entry_Body;
Match_3 : Internal_Entity_Package_Body;
Match_4 : Internal_Entity_Package_Body_Stub;
Match_5 : Internal_Entity_Protected_Body;
Match_6 : Internal_Entity_Protected_Body_Stub;
Match_7 : Internal_Entity_Task_Body;
Match_8 : Internal_Entity_Task_Body_Stub;
Pp_Next_Part : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Entry_Decl;
Fld_3 : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Basic_Decl;
Fld_6 : Internal_Entity_Basic_Decl;
Fld_7 : Internal_Entity_Basic_Decl;
Fld_8 : Internal_Entity_Basic_Decl;
Match_Prefix : Internal_Entity_Body_Node;
Cast_Result : Internal_Entity_Base_Subp_Body;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Subp_Body_Stub;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Entry_Body;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity_Package_Body;
Let_Result_3 : Internal_Entity_Basic_Decl;
Scope_Result_3 : Internal_Entity_Basic_Decl;
Cast_Result_5 : Internal_Entity_Package_Body_Stub;
Let_Result_4 : Internal_Entity_Basic_Decl;
Scope_Result_4 : Internal_Entity_Basic_Decl;
Cast_Result_6 : Internal_Entity_Protected_Body;
Let_Result_5 : Internal_Entity_Basic_Decl;
Scope_Result_5 : Internal_Entity_Basic_Decl;
Cast_Result_7 : Internal_Entity_Protected_Body_Stub;
Let_Result_6 : Internal_Entity_Basic_Decl;
Scope_Result_6 : Internal_Entity_Basic_Decl;
Cast_Result_8 : Internal_Entity_Task_Body;
Let_Result_7 : Internal_Entity_Basic_Decl;
Scope_Result_7 : Internal_Entity_Basic_Decl;
Cast_Result_9 : Internal_Entity_Task_Body_Stub;
Let_Result_8 : Internal_Entity_Basic_Decl;
Scope_Result_8 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Fld_9 : Internal_Entity_Basic_Decl;
Scope_Result_9 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Is_A : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Let_Result_9 : Internal_Entity_Basic_Decl;
Is_A_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Let_Result_10 : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4582 '<Block at ???>' Let_Result_10 None
--# scope-start
--# expr-start 4575 '<Match at ast.py:3716>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3716
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Body_Node (Match_Prefix.Node.Kind) is
         when Ada_Expr_Function .. Ada_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Base_Subp_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind _ Match_0
--# expr-start 4566 '<FieldAccess for subp_previous_part at ast.py:3717>' Fld /tmp/lal-23.0.0/ada/ast.py:3717
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.subp_previous_part
Fld := Libadalang.Implementation.Body_Node_P_Subp_Previous_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4566
Let_Result := Fld; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Subp_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subp_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
--# expr-start 4567 '<FieldAccess for subp_previous_part at ast.py:3718>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3718
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.subp_previous_part
Fld_1 := Libadalang.Implementation.Body_Node_P_Subp_Previous_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4567
Let_Result_1 := Fld_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Entry_Body =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Entry_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
--# expr-start 4568 '<FieldAccess for entry_previous_part at ast.py:3719>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3719
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.entry_previous_part
Fld_2 := Libadalang.Implementation.Body_Node_P_Entry_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4568
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Let_Result_2 := Cast_Result_3; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Package_Body =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Package_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_4; 
--# bind _ Match_3
--# expr-start 4569 '<FieldAccess for package_previous_part at ast.py:3720>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3720
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.package_previous_part
Fld_3 := Libadalang.Implementation.Body_Node_P_Package_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4569
Let_Result_3 := Fld_3; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Package_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Package_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_5; 
--# bind _ Match_4
--# expr-start 4570 '<FieldAccess for package_previous_part at ast.py:3721>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3721
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.package_previous_part
Fld_4 := Libadalang.Implementation.Body_Node_P_Package_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4570
Let_Result_4 := Fld_4; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Protected_Body =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Protected_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_6; 
--# bind _ Match_5
--# expr-start 4571 '<FieldAccess for protected_previous_part at ast.py:3722>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3722
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.protected_previous_part
Fld_5 := Libadalang.Implementation.Body_Node_P_Protected_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4571
Let_Result_5 := Fld_5; 
--# end
Scope_Result_5 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Protected_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Protected_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_6 := Cast_Result_7; 
--# bind _ Match_6
--# expr-start 4572 '<FieldAccess for protected_previous_part at ast.py:3723>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3723
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.protected_previous_part
Fld_6 := Libadalang.Implementation.Body_Node_P_Protected_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4572
Let_Result_6 := Fld_6; 
--# end
Scope_Result_6 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Task_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_7 := Cast_Result_8; 
--# bind _ Match_7
--# expr-start 4573 '<FieldAccess for task_previous_part at ast.py:3724>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3724
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.task_previous_part
Fld_7 := Libadalang.Implementation.Body_Node_P_Task_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4573
Let_Result_7 := Fld_7; 
--# end
Scope_Result_7 := Let_Result_7;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Task_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Task_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_8 := Cast_Result_9; 
--# bind _ Match_8
--# expr-start 4574 '<FieldAccess for task_previous_part at ast.py:3725>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:3725
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.task_previous_part
Fld_8 := Libadalang.Implementation.Body_Node_P_Task_Previous_Part (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 4574
Let_Result_8 := Fld_8; 
--# end
Scope_Result_8 := Let_Result_8;
   --# end
            Match_Result := Scope_Result_8; 
end case;
--# expr-done 4575
Block_Var := Match_Result; 
--# bind pp Block_Var
--# expr-start 4581 '<If at ast.py:3732>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3732
--# expr-start 4576 '<IsA BodyStub at ast.py:3733>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:3733
Is_A_1 := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Body_Stub; 
--# expr-done 4576
if Is_A_1 then
   If_Result_1 := Block_Var;
else
   --# expr-start 4580 '<Let at ast.py:3735>' Let_Result_9 /tmp/lal-23.0.0/ada/ast.py:3735
--# scope-start
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 4577 '<FieldAccess for next_part_for_decl at ast.py:3735>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:3735
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld_9 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 4577
Scope_Result_9 := Fld_9;
   --# end
   Result_Var := Scope_Result_9;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Pp_Next_Part := Result_Var; 
--# bind pp_next_part Pp_Next_Part
--# expr-start 4579 '<If at ast.py:3735>' If_Result /tmp/lal-23.0.0/ada/ast.py:3735
--# expr-start 4578 '<IsA BodyStub at ast.py:3736>' Is_A /tmp/lal-23.0.0/ada/ast.py:3736
Is_A := Pp_Next_Part.Node /= null 
and then Pp_Next_Part.Node.Kind in Ada_Body_Stub; 
--# expr-done 4578
if Is_A then
   If_Result := Pp_Next_Part;
else
   If_Result := Block_Var;
end if;
--# expr-done 4579
Let_Result_9 := If_Result; 
--# end
--# expr-done 4580
   If_Result_1 := Let_Result_9;
end if;
--# expr-done 4581
Let_Result_10 := If_Result_1; 
--# end
--# expr-done 4582
      Property_Result := Let_Result_10;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Unbound_Previous_Part;
--# end
--# property-start Body.previous_part_internal /tmp/lal-23.0.0/ada/ast.py:3744
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Previous_Part_Internal
  (Node : Bare_Body_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_231 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
As_Entity : Internal_Entity_Body_Node;
Is_Null : Boolean;
If_Result : Internal_Entity_Body_Node;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Bare_Basic_Decl;
As_Entity_1 : Internal_Entity_Basic_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_231 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_231;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4589 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4588 '<bind at ast.py:3758>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3758
--# expr-start 4583 '<FieldAccess for node_env at ast.py:3759>' Fld /tmp/lal-23.0.0/ada/ast.py:3759
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Self);
--# expr-done 4583
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 4587 '<as_entity at ast.py:3760>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3760
--# expr-start 4586 '<FieldAccess for node at ast.py:3760>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3760
--# expr-start 4585 '<FieldAccess for unbound_previous_part at ast.py:3760>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3760
--# expr-start 4584 '<as_bare_entity at ast.py:3760>' If_Result /tmp/lal-23.0.0/ada/ast.py:3760
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Body_Node;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 4584
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.unbound_previous_part
Fld_1 := Libadalang.Implementation.Body_Node_P_Unbound_Previous_Part (Node => If_Result.Node, Env => Bound_Env, Imprecise_Fallback => Imprecise_Fallback, E_Info => If_Result.Info);
--# end
--# expr-done 4585
Fld_2 := Fld_1.Node;
--# expr-done 4586
Is_Null_1 := Fld_2 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Fld_2); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 4587
Dyn_Var_Bind_Result := If_Result_1; 
--# expr-done 4588
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 4589
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_231;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_231;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Previous_Part_Internal;
--# end
--# property-start Body.previous_part /tmp/lal-23.0.0/ada/ast.py:3766
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Previous_Part
  (Node : Bare_Body_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Body_Node_Body_Node_P_Previous_Part,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Body_Node,
                                As_Bare_Body_Node => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Boolean,
                                      As_Boolean => Imprecise_Fallback);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 4591 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4590 '<FieldAccess for previous_part_internal at ast.py:3771>' Fld /tmp/lal-23.0.0/ada/ast.py:3771
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.previous_part_internal
Fld := Libadalang.Implementation.Body_Node_P_Previous_Part_Internal (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4590
Let_Result := Fld; 
--# end
--# expr-done 4591
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl,
                        As_Internal_Entity_Basic_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Previous_Part;
--# end
--# property-start Body.decl_part /tmp/lal-23.0.0/ada/ast.py:3774
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Decl_Part
  (Node : Bare_Body_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Basic_Decl;
Match_0 : Internal_Entity_Body_Stub;
Match_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Body_Stub;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4595 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 4592 '<FieldAccess for previous_part_internal at ast.py:3778>' Fld /tmp/lal-23.0.0/ada/ast.py:3778
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.previous_part_internal
Fld := Libadalang.Implementation.Body_Node_P_Previous_Part_Internal (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4592
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind prev_part Var_Expr
--# expr-start 4594 '<Match at ast.py:3779>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3779
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Package_Body_Stub .. Ada_Task_Body_Stub =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Body_Stub
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind stub Match_0
--# expr-start 4593 '<FieldAccess for previous_part_internal at ast.py:3782>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3782
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.previous_part_internal
Fld_1 := Libadalang.Implementation.Body_Node_P_Previous_Part_Internal (Node => Match_0.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_0.Info);
--# end
--# expr-done 4593
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl .. Ada_Subp_Renaming_Decl | Ada_Entry_Body .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind other Match_1
Let_Result_1 := Match_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 4594
Scope_Result_2 := Match_Result;
   --# end
   Result_Var := Scope_Result_2;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Let_Result_2 := Result_Var; 
--# end
--# expr-done 4595
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Decl_Part;
--# end
--# property-start Body.safe_generic_decl_part /tmp/lal-23.0.0/ada/ast.py:3788
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Safe_Generic_Decl_Part
  (Node : Bare_Body_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Generic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Generic_Decl;
            procedure Finalizer_Scope_234 with Inline_Always;
            procedure Finalizer_Scope_2484 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Array_Access;
Var_Expr_2 : Internal_Entity_Generic_Subp_Decl;
Bound_Imprecise_Fallback : Boolean;
Is_A : Boolean;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Generic_Package_Decl;
Scope_Result : Internal_Entity_Generic_Package_Decl;
Result_Var : Internal_Entity_Generic_Package_Decl;
Is_A_1 : Boolean;
Fld_2 : Lexical_Env := Empty_Env;
Env_Parent : Lexical_Env := Empty_Env;
Fld_3 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Generic_Subp_Decl;
Scope_Result_1 : Internal_Entity_Generic_Subp_Decl;
Get_Result_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Generic_Subp_Decl;
Result_Var_1 : Internal_Entity_Generic_Subp_Decl;
Scope_Result_2 : Internal_Entity_Generic_Subp_Decl;
Result_Var_2 : Internal_Entity_Generic_Subp_Decl;
Cast_Result_3 : Internal_Entity_Generic_Decl;
If_Result : Internal_Entity_Generic_Decl;
Cast_Result_4 : Internal_Entity_Generic_Decl;
If_Result_1 : Internal_Entity_Generic_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Generic_Decl;
Let_Result : Internal_Entity_Generic_Decl;
            procedure Finalizer_Scope_234 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Env_Parent);
                     Dec_Ref (Env_Get_Result);
            end Finalizer_Scope_234;
            procedure Finalizer_Scope_2484 is
            begin
                     Dec_Ref (Var_Expr_1);
            end Finalizer_Scope_2484;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4611 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4610 '<bind at ast.py:3793>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3793
Bound_Imprecise_Fallback := False; 
--# expr-start 4609 '<Cond at ast.py:3795>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:3795
--# expr-start 4596 '<IsA PackageBody at ast.py:3796>' Is_A /tmp/lal-23.0.0/ada/ast.py:3796
Is_A := Self /= null 
and then Self.Kind in Ada_Package_Body_Range; 
--# expr-done 4596
if Is_A then
--# expr-start 4597 '<FieldAccess for decl_part at ast.py:3797>' Fld /tmp/lal-23.0.0/ada/ast.py:3797
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Ent.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4597
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind d Var_Expr
--# expr-start 4599 '<Cast to GenericPackageDecl at ast.py:3798>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3798
--# expr-start 4598 '<parent at ast.py:3798>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3798
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# expr-done 4598
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Generic_Package_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Generic_Package_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Generic_Package_Decl;
   end if;
--# expr-done 4599
Scope_Result := Cast_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Generic_Package_Decl;
end if;
      Cast_Result_4 := Create_Internal_Entity_Generic_Decl
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   If_Result_1 := Cast_Result_4;
else
--# expr-start 4600 '<IsA BaseSubpBody, SubpBodyStub at ast.py:3801>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:3801
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Base_Subp_Body | Ada_Subp_Body_Stub_Range; 
--# expr-done 4600
if Is_A_1 then
--# expr-start 4604 '<EnvGet at ast.py:3807>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3807
--# expr-start 4602 '<env_parent at ast.py:3807>' Env_Parent /tmp/lal-23.0.0/ada/ast.py:3807
--# expr-start 4601 '<FieldAccess for children_env at ast.py:3807>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3807
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 4601
Env_Parent := AST_Envs.Parent (Fld_2); 
--# expr-done 4602
--# expr-start 4603 '<FieldAccess for name_symbol at ast.py:3808>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3808
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4603
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Env_Parent, Key => Fld_3, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 4604
Var_Expr_1 := Env_Get_Result;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= No_Internal_Entity_Array_Type then
   --# scope-start
   --# bind results Var_Expr_1
--# expr-start 4606 '<Cast to GenericSubpDecl at ast.py:3811>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:3811
--# expr-start 4605 '<at at ast.py:3811>' Get_Result /tmp/lal-23.0.0/ada/ast.py:3811
Get_Result := Get (Self, Var_Expr_1, 1, True); 
--# expr-done 4605
   if Get_Result.Node = null
      or else Get_Result.Node.Kind in Ada_Generic_Subp_Decl_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Generic_Subp_Decl
        (Node => Get_Result.Node,
         Info => Get_Result.Info);
   else
         Cast_Result_1 := No_Entity_Generic_Subp_Decl;
   end if;
--# expr-done 4606
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Entity_Generic_Subp_Decl then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_1 := Var_Expr_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 4608 '<Cast to GenericSubpDecl at ast.py:3812>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:3812
--# expr-start 4607 '<at at ast.py:3812>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:3812
Get_Result_1 := Get (Self, Var_Expr_1, 2, True); 
--# expr-done 4607
   if Get_Result_1.Node = null
      or else Get_Result_1.Node.Kind in Ada_Generic_Subp_Decl_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Generic_Subp_Decl
        (Node => Get_Result_1.Node,
         Info => Get_Result_1.Info);
   else
         Cast_Result_2 := No_Entity_Generic_Subp_Decl;
   end if;
--# expr-done 4608
   Result_Var_1 := Cast_Result_2;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
      Finalizer_Scope_2484;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Generic_Subp_Decl;
end if;
      Cast_Result_3 := Create_Internal_Entity_Generic_Decl
        (Node => Result_Var_2.Node,
         Info => Result_Var_2.Info);
   If_Result := Cast_Result_3;
else
   If_Result := No_Entity_Generic_Decl;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 4609
Dyn_Var_Bind_Result := If_Result_1; 
--# expr-done 4610
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 4611
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_234;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_234;
               Finalizer_Scope_2484;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Safe_Generic_Decl_Part;
--# end
--# property-start Body.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:3821
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Next_Part_For_Decl
  (Node : Bare_Body_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4612 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Basic_Decl; 
--# end
--# expr-done 4612
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Next_Part_For_Decl;
--# end
--# property-start Body.is_subunit /tmp/lal-23.0.0/ada/ast.py:3829
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Is_Subunit
  (Node : Bare_Body_Node
  )
   return Boolean
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4615 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4614 '<IsA Subunit at ast.py:3830>' Is_A /tmp/lal-23.0.0/ada/ast.py:3830
--# expr-start 4613 '<parent at ast.py:3830>' Fld /tmp/lal-23.0.0/ada/ast.py:3830
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4613
Is_A := Fld /= null 
and then Fld.Kind in Ada_Subunit_Range; 
--# expr-done 4614
Let_Result := Is_A; 
--# end
--# expr-done 4615
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Is_Subunit;
--# end
--# property-start Body.subunit_root /tmp/lal-23.0.0/ada/ast.py:3833
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Subunit_Root
  (Node : Bare_Body_Node
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Bare_Subunit;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Subunit;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4619 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4617 '<Cast to Subunit at ast.py:3837>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:3837
--# expr-start 4616 '<parent at ast.py:3837>' Fld /tmp/lal-23.0.0/ada/ast.py:3837
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4616
   if Fld = null
      or else Fld.Kind in Ada_Subunit_Range
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 4617
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind su Var_Expr
--# expr-start 4618 '<FieldAccess for body_root at ast.py:3837>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3837
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.body_root
Fld_1 := Libadalang.Implementation.Subunit_P_Body_Root (Node => Var_Expr);
--# end
--# expr-done 4618
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 4619
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Subunit_Root;
--# end
--# property-start Body.body_scope /tmp/lal-23.0.0/ada/ast.py:3840
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Body_Scope
  (Node : Bare_Body_Node
      ; Follow_Private : Boolean
      ; Force_Decl : Boolean
         := False
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind follow_private Follow_Private
   --# bind force_decl Force_Decl
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_238 with Inline_Always;
            procedure Finalizer_Scope_2438 with Inline_Always;
            procedure Finalizer_Scope_2439 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Block_Var_1 : Lexical_Env := Empty_Env;
Dns : Lexical_Env := Empty_Env;
Var_Expr : Bare_Generic_Package_Decl;
Var_Expr_1 : Bare_Ada_Node;
Var_Expr_2 : Internal_Entity;
Fld : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Boolean;
Fld_4 : Boolean;
If_Result : Boolean;
Fld_5 : Internal_Entity_Defining_Name;
Fld_6 : Lexical_Env := Empty_Env;
Fld_7 : Internal_Entity_Defining_Name;
Fld_8 : Lexical_Env := Empty_Env;
Is_Equal : Boolean;
Env_Node : Bare_Ada_Node;
Cast_Expr : Bare_Body_Node;
Cast_Result : Bare_Ada_Node;
Is_Equal_1 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
Fld_9 : Boolean;
If_Result_3 : Boolean;
Fld_10 : Internal_Entity_Defining_Name;
Fld_11 : Lexical_Env := Empty_Env;
Fld_12 : Bare_Ada_Node;
Fld_13 : Lexical_Env := Empty_Env;
If_Result_4 : Lexical_Env := Empty_Env;
If_Result_5 : Lexical_Env := Empty_Env;
If_Result_6 : Lexical_Env := Empty_Env;
Env_Node_1 : Bare_Ada_Node;
Cast_Result_1 : Bare_Generic_Package_Decl;
Fld_14 : Bare_Generic_Package_Internal;
Fld_15 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Fld_16 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Env_Node_2 : Bare_Ada_Node;
Is_A : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_7 : Boolean;
If_Result_8 : Lexical_Env := Empty_Env;
Let_Result_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_238 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Dns);
                     Dec_Ref (Fld_8);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_13);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (If_Result_8);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_238;
            procedure Finalizer_Scope_2438 is
            begin
                     Dec_Ref (Fld_15);
            end Finalizer_Scope_2438;
            procedure Finalizer_Scope_2439 is
            begin
                     Dec_Ref (Fld_16);
            end Finalizer_Scope_2439;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4653 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 4641 '<Cond at ast.py:3849>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:3849
--# expr-start 4622 '<Not at ast.py:3854>' Not_Val /tmp/lal-23.0.0/ada/ast.py:3854
--# expr-start 4621 '<IsNull at ast.py:3854>' Is_Null /tmp/lal-23.0.0/ada/ast.py:3854
--# expr-start 4620 '<FieldAccess for subunit_root at ast.py:3854>' Fld /tmp/lal-23.0.0/ada/ast.py:3854
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.subunit_root
Fld := Libadalang.Implementation.Body_Node_P_Subunit_Root (Node => Self);
--# end
--# expr-done 4620
Is_Null := Fld.Node = null; 
--# expr-done 4621
Not_Val := not (Is_Null); 
--# expr-done 4622
if Not_Val then
   --# expr-start 4624 '<FieldAccess for children_env at ast.py:3854>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3854
--# expr-start 4623 '<FieldAccess for subunit_root at ast.py:3854>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3854
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.subunit_root
Fld_1 := Libadalang.Implementation.Body_Node_P_Subunit_Root (Node => Self);
--# end
--# expr-done 4623
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 4624
   If_Result_6 := Fld_2;
else
--# expr-start 4625 '<FieldAccess for is_subprogram at ast.py:3859>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3859
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Self);
--# end
--# expr-done 4625
if Fld_3 then
   --# expr-start 4626 '<FieldAccess for is_compilation_unit_root at ast.py:3859>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3859
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 4626
   If_Result := Fld_4;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 4635 '<Let at ast.py:3860>' Let_Result /tmp/lal-23.0.0/ada/ast.py:3860
--# scope-start
--# expr-start 4628 '<FieldAccess for scope at ast.py:3860>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3860
--# expr-start 4627 '<FieldAccess for defining_name at ast.py:3860>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3860
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4627
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.scope'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Scope (Node => Fld_5.Node, Env => Env);
--# end
--# expr-done 4628
Dns := Fld_6; Inc_Ref (Dns);
--# bind dns Dns
--# expr-start 4634 '<If at ast.py:3863>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:3863
--# expr-start 4629 '<IsNull at ast.py:3863>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:3863
Is_Equal := Equivalent (Dns, Empty_Env); 
--# expr-done 4629
if Is_Equal then
   If_Result_1 := True;
else
   --# expr-start 4631 '<Eq at ast.py:3863>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:3863
--# expr-start 4630 '<env_node at ast.py:3863>' Env_Node /tmp/lal-23.0.0/ada/ast.py:3863
Env_Node := AST_Envs.Env_Node (Dns); 
--# expr-done 4630
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Is_Equal_1 := Env_Node = Cast_Result; 
--# expr-done 4631
   If_Result_1 := Is_Equal_1;
end if;
if If_Result_1 then
   --# expr-start 4633 '<FieldAccess for parent_scope at ast.py:3864>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:3864
--# expr-start 4632 '<FieldAccess for defining_name at ast.py:3864>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3864
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4632
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.parent_scope'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Parent_Scope (Node => Fld_7.Node, Env => Env);
--# end
--# expr-done 4633
   If_Result_2 := Fld_8;
else
   If_Result_2 := Dns;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 4634
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 4635
   If_Result_5 := Let_Result;
else
--# expr-start 4636 '<FieldAccess for is_compilation_unit_root at ast.py:3869>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:3869
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 4636
if Fld_9 then
   If_Result_3 := True;
else
   If_Result_3 := Force_Decl;
end if;
if If_Result_3 then
   --# expr-start 4638 '<FieldAccess for scope at ast.py:3870>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:3870
--# expr-start 4637 '<FieldAccess for defining_name at ast.py:3870>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:3870
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4637
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.scope'
Fld_11 := Libadalang.Implementation.Dispatcher_Name_P_Scope (Node => Fld_10.Node, Env => Env);
--# end
--# expr-done 4638
   If_Result_4 := Fld_11;
else
   --# expr-start 4640 '<FieldAccess for children_env at ast.py:3874>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:3874
--# expr-start 4639 '<parent at ast.py:3874>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:3874
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.Parent; 
--# expr-done 4639
      if Fld_12 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Children_Env (Node => Fld_12);
--# expr-done 4640
   If_Result_4 := Fld_13;
end if;
      Inc_Ref (If_Result_4);
   If_Result_5 := If_Result_4;
end if;
      Inc_Ref (If_Result_5);
   If_Result_6 := If_Result_5;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 4641
Block_Var := If_Result_6; Inc_Ref (Block_Var);
--# bind scope Block_Var
--# expr-start 4643 '<Cast to GenericPackageDecl at ast.py:3879>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:3879
--# expr-start 4642 '<env_node at ast.py:3879>' Env_Node_1 /tmp/lal-23.0.0/ada/ast.py:3879
Env_Node_1 := AST_Envs.Env_Node (Block_Var); 
--# expr-done 4642
   if Env_Node_1 = null
      or else Env_Node_1.Kind in Ada_Generic_Package_Decl_Range
   then
      Cast_Result_1 := Env_Node_1;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 4643
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind gen_pkg_decl Var_Expr
--# expr-start 4645 '<FieldAccess for children_env at ast.py:3880>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:3880
--# expr-start 4644 '<FieldAccess for package_decl at ast.py:3880>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:3880
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Var_Expr.Generic_Package_Decl_F_Package_Decl;
--# expr-done 4644
      if Fld_14 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Children_Env (Node => Fld_14);
--# expr-done 4645
Scope_Result := Fld_15;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2438;
   Result_Var := Scope_Result;
else
   Result_Var := Block_Var;
end if;
      Inc_Ref (Result_Var);
Block_Var_1 := Result_Var; Inc_Ref (Block_Var_1);
--# bind public_scope Block_Var_1
--# expr-start 4652 '<If at ast.py:3886>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:3886
if Follow_Private then
--# expr-start 4646 '<env_node at ast.py:3889>' Env_Node_2 /tmp/lal-23.0.0/ada/ast.py:3889
Env_Node_2 := AST_Envs.Env_Node (Block_Var_1); 
--# expr-done 4646
Var_Expr_1 := Env_Node_2;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 4647 '<IsA BasePackageDecl, SingleProtectedDecl, ProtectedTypeDecl at ast.py:3889>' Is_A /tmp/lal-23.0.0/ada/ast.py:3889
Is_A := Var_Expr_1 /= null 
and then Var_Expr_1.Kind in Ada_Base_Package_Decl | Ada_Single_Protected_Decl_Range | Ada_Protected_Type_Decl_Range; 
--# expr-done 4647
Scope_Result_2 := Is_A;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
   If_Result_7 := Result_Var_2;
else
   If_Result_7 := False;
end if;
if If_Result_7 then
--# expr-start 4650 '<at at ast.py:3896>' Get_Result /tmp/lal-23.0.0/ada/ast.py:3896
--# expr-start 4649 '<EnvGet at ast.py:3894>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:3894
--# expr-start 4648 '<Symbol __privatepart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Privatepart); 
--# expr-done 4648
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Block_Var_1, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 4649
Get_Result := Get (Self, Env_Get_Result, 0, True); 
--# expr-done 4650
Var_Expr_2 := Get_Result;
if Var_Expr_2 /= No_Entity then
   --# scope-start
   --# bind pp Var_Expr_2
--# expr-start 4651 '<FieldAccess for children_env at ast.py:3897>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:3897
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Libadalang.Implementation.Children_Env (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# expr-done 4651
Scope_Result_1 := Fld_16;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2439;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Block_Var_1;
end if;
      Inc_Ref (Result_Var_1);
   If_Result_8 := Result_Var_1;
else
   If_Result_8 := Block_Var_1;
end if;
      Inc_Ref (If_Result_8);
--# expr-done 4652
Let_Result_1 := If_Result_8; Inc_Ref (Let_Result_1);
--# end
--# expr-done 4653
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_238;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_238;
               Finalizer_Scope_2438;
               Finalizer_Scope_2439;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Body_Scope;
--# end
--# property-start Body.previous_part_env_name /tmp/lal-23.0.0/ada/ast.py:3501
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Previous_Part_Env_Name
  (Node : Bare_Body_Node
  )
   return Symbol_Type
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
            procedure Finalizer_Scope_223 with Inline_Always;
      Fld : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym : Symbol_Type;
Fld_1 : String_Type;
Sym_1 : Symbol_Type;
Fld_2 : Boolean;
If_Result : Symbol_Type;
Let_Result : Symbol_Type;
            procedure Finalizer_Scope_223 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_223;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4662 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4661 '<If at ast.py:3508>' If_Result /tmp/lal-23.0.0/ada/ast.py:3508
--# expr-start 4654 '<FieldAccess for is_subunit at ast.py:3509>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3509
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld_2 := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Self);
--# end
--# expr-done 4654
if Fld_2 then
   --# expr-start 4658 '<to_symbol at ast.py:3510>' Sym /tmp/lal-23.0.0/ada/ast.py:3510
--# expr-start 4657 '<Concat at ast.py:3510>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:3510
--# expr-start 4655 '<FieldAccess for top_level_env_name at ast.py:3510>' Fld /tmp/lal-23.0.0/ada/ast.py:3510
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4655
--# expr-start 4656 '<String at ast.py:3510>' Str /tmp/lal-23.0.0/ada/ast.py:3510
Str := Create_String ("__stub"); 
--# expr-done 4656
Concat_Result := Concat_String (Fld, Str); 
--# expr-done 4657
Sym := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 4658
   If_Result := Sym;
else
   --# expr-start 4660 '<to_symbol at ast.py:3511>' Sym_1 /tmp/lal-23.0.0/ada/ast.py:3511
--# expr-start 4659 '<FieldAccess for top_level_env_name at ast.py:3511>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3511
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4659
Sym_1 := String_To_Symbol (Self, Self.Unit.Context, Fld_1); 
--# expr-done 4660
   If_Result := Sym_1;
end if;
--# expr-done 4661
Let_Result := If_Result; 
--# end
--# expr-done 4662
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_223;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_223;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Previous_Part_Env_Name;
--# end
--# property-start Body.previous_part_link_env_assoc /tmp/lal-23.0.0/ada/ast.py:3515
pragma Warnings (Off, "is not referenced");
 function Body_Node_P_Previous_Part_Link_Env_Assoc
  (Node : Bare_Body_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Body_Node := Bare_Body_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Node :=
     Internal_Entity_Body_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_224 with Inline_Always;
            procedure Finalizer_Scope_2448 with Inline_Always;
            procedure Finalizer_Scope_2449 with Inline_Always;
      Var_Expr : Symbol_Type;
Var_Expr_1 : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Scope_Result_1 : Internal_Designated_Env := No_Designated_Env;
New_Struct_2 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
Result_Var_1 : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Body_Node;
Cast_Result : Bare_Ada_Node;
New_Struct_3 : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_224 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (New_Struct_2);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (New_Struct_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_224;
            procedure Finalizer_Scope_2448 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2448;
            procedure Finalizer_Scope_2449 is
            begin
                     Dec_Ref (Var_Expr_1);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_2449;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4672 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4671 '<New EnvAssoc at ast.py:3525>' New_Struct_3 /tmp/lal-23.0.0/ada/ast.py:3525
--# expr-start 4663 '<FieldAccess for previous_part_env_name at ast.py:3528>' Fld /tmp/lal-23.0.0/ada/ast.py:3528
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_env_name'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Env_Name (Node => Self);
--# end
--# expr-done 4663
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind name Var_Expr
--# expr-start 4664 '<New DesignatedEnv at ast.py:3529>' New_Struct /tmp/lal-23.0.0/ada/ast.py:3529
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 4664
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2448;
   Result_Var_1 := Scope_Result;
else
--# expr-start 4667 '<bind at ast.py:3531>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:3531
--# expr-start 4665 '<FieldAccess for default_initial_env at ast.py:3532>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3532
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld_1 := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 4665
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 4666 '<FieldAccess for body_scope at ast.py:3533>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3533
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_scope
Fld_2 := Libadalang.Implementation.Body_Node_P_Body_Scope (Node => Ent.Node, Follow_Private => False, Force_Decl => True, Env => Bound_Env, E_Info => Ent.Info);
--# end
--# expr-done 4666
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4667
Var_Expr_1 := Dyn_Var_Bind_Result;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= Empty_Env then
   --# scope-start
   --# bind non_null_env Var_Expr_1
--# expr-start 4668 '<New DesignatedEnv at ???>' New_Struct_1 None
Inc_Ref (Var_Expr_1);
New_Struct_1 := (Direct_Env => Var_Expr_1, Env_Name => null, Kind => Direct_Env); 
--# expr-done 4668
Scope_Result_1 := New_Struct_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2449;
   Result_Var := Scope_Result_1;
else
   --# expr-start 4669 '<New DesignatedEnv at ast.py:3530>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:3530
Inc_Ref (Empty_Env);
New_Struct_2 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4669
   Result_Var := New_Struct_2;
end if;
      Inc_Ref (Result_Var);
   Result_Var_1 := Result_Var;
end if;
      Inc_Ref (Result_Var_1);
--# expr-start 4670 '<Symbol __nextpart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Nextpart); 
--# expr-done 4670
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (Result_Var_1);
New_Struct_3 := (Dest_Env => Result_Var_1, Key => Sym, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4671
Let_Result := New_Struct_3; Inc_Ref (Let_Result);
--# end
--# expr-done 4672
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_224;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_224;
               Finalizer_Scope_2448;
               Finalizer_Scope_2449;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Node_P_Previous_Part_Link_Env_Assoc;
--# end
function Body_Node_P_Subunit_Decl_Env
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Body_Node_P_Subunit_Decl_Env (E.Node, E_Info);
begin
      return Result;
end;
function Body_Node_P_Body_Decl_Scope
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Body_Node_P_Body_Decl_Scope (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Base_Subp_Body
   --
      procedure Base_Subp_Body_Pre_Env_Actions
        (Self            : Bare_Base_Subp_Body;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_134 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_135 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:19377");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_136 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:19384");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_137 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_138 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:19392");
         Dec_Ref (Mapping.Dest_Env);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_139 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_141 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_140 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_143 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_142 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_145 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_144 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Use_Clauses_In_Spec_Of_Subp_Body'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_147 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_146 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Nested_Generic_Formal_Part'Access,
               Prioritary,
               All_Cats,
               True);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_149 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_148 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Use_Clauses_In_Generic_Formal_Part'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Base_Subp_Body
        (Self : Bare_Base_Subp_Body
         ; Base_Subp_Body_F_Overriding : Bare_Overriding_Node
         ; Base_Subp_Body_F_Subp_Spec : Bare_Subp_Spec
        ) is
      begin
            Self.Base_Subp_Body_F_Overriding := Base_Subp_Body_F_Overriding;
            Self.Base_Subp_Body_F_Subp_Spec := Base_Subp_Body_F_Subp_Spec;
      end Initialize_Fields_For_Base_Subp_Body;
   function Base_Subp_Body_F_Overriding
     (Node : Bare_Base_Subp_Body) return Bare_Overriding_Node
   is
   begin
         return Node.Base_Subp_Body_F_Overriding;
   end;
   function Base_Subp_Body_F_Subp_Spec
     (Node : Bare_Base_Subp_Body) return Bare_Subp_Spec
   is
   begin
         return Node.Base_Subp_Body_F_Subp_Spec;
   end;
--# property-start BaseSubpBody.defining_names /tmp/lal-23.0.0/ada/ast.py:19322
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Defining_Names
  (Node : Bare_Base_Subp_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Body :=
     Internal_Entity_Base_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1371 with Inline_Always;
      Fld : Internal_Entity_Subp_Spec;
Fld_1 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1371 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1371;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4674 '<FieldAccess for name at ast.py:19322>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19322
--# expr-start 4673 '<FieldAccess for subp_spec at ast.py:19322>' Fld /tmp/lal-23.0.0/ada/ast.py:19322
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Base_Subp_Body_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4673
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4674
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_1;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1371;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1371;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Defining_Names;
--# end
--# property-start BaseSubpBody.is_constant_object /tmp/lal-23.0.0/ada/ast.py:19324
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Is_Constant_Object
  (Node : Bare_Base_Subp_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Is_Constant_Object;
--# end
--# property-start BaseSubpBody.defining_env /tmp/lal-23.0.0/ada/ast.py:19327
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Defining_Env
  (Node : Bare_Base_Subp_Body
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Body :=
     Internal_Entity_Base_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1373 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Subp_Spec;
Fld_2 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Base_Subp_Spec;
Fld_5 : Internal_Entity_Info;
Fld_6 : Internal_Metadata;
Fld_7 : Boolean;
Fld_8 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Lexical_Env := Empty_Env;
Fld_9 : Internal_Entity_Subp_Spec;
Fld_10 : Lexical_Env := Empty_Env;
Fld_11 : Boolean;
If_Result_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1373 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (If_Result);
                     Dec_Ref (Fld_10);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1373;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4691 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4690 '<If at ast.py:19328>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19328
--# expr-start 4675 '<FieldAccess for in_scope at ast.py:19329>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:19329
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.in_scope
Fld_11 := Libadalang.Implementation.Body_Node_P_In_Scope (Node => Ent.Node, Origin => Origin);
--# end
--# expr-done 4675
if Fld_11 then
   --# expr-start 4687 '<If at ast.py:19331>' If_Result /tmp/lal-23.0.0/ada/ast.py:19331
--# expr-start 4676 '<FieldAccess for subp_spec_or_null at ast.py:19332>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19332
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4676
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 4680 '<FieldAccess for paramless at ast.py:19332>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19332
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4679 '<FieldAccess for dottable_subp at ast.py:19333>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19333
--# expr-start 4678 '<FieldAccess for md at ast.py:19333>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19333
--# expr-start 4677 '<FieldAccess for info at ast.py:19333>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19333
Fld_5 := Ent.Info;
--# expr-done 4677
Fld_6 := Fld_5.Md;
--# expr-done 4678
Fld_7 := Fld_6.Dottable_Subp;
--# expr-done 4679
--# property-call-start BaseFormalParamHolder.paramless
Fld_8 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Paramless (Node => Var_Expr.Node, Dottable_Subp => Fld_7, Can_Be => True);
--# end
--# expr-done 4680
Scope_Result := Fld_8;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   --# expr-start 4685 '<env_group at ast.py:19336>' Group_Env /tmp/lal-23.0.0/ada/ast.py:19336
--# expr-start 4684 '<ArrayLiteral at ast.py:19334>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:19334
--# expr-start 4681 '<FieldAccess for children_env at ast.py:19335>' Fld /tmp/lal-23.0.0/ada/ast.py:19335
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 4681
--# expr-start 4683 '<FieldAccess for defining_env at ast.py:19335>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19335
--# expr-start 4682 '<FieldAccess for subp_spec at ast.py:19335>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19335
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Base_Subp_Body_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4682
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.defining_env
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_Defining_Env (Node => Fld_1.Node, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 4683
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld, 2 => Fld_2)); 
--# expr-done 4684
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 4685
   If_Result := Group_Env;
else
   --# expr-start 4686 '<FieldAccess for children_env at ast.py:19337>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19337
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 4686
   If_Result := Fld_3;
end if;
      Inc_Ref (If_Result);
--# expr-done 4687
   If_Result_1 := If_Result;
else
   --# expr-start 4689 '<FieldAccess for defining_env at ast.py:19340>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:19340
--# expr-start 4688 '<FieldAccess for subp_spec at ast.py:19340>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:19340
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Base_Subp_Body_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4688
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.defining_env
Fld_10 := Libadalang.Implementation.Base_Subp_Spec_P_Defining_Env (Node => Fld_9.Node, Origin => Origin, E_Info => Fld_9.Info);
--# end
--# expr-done 4689
   If_Result_1 := Fld_10;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 4690
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 4691
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1373;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1373;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Defining_Env;
--# end
--# property-start BaseSubpBody.type_expression /tmp/lal-23.0.0/ada/ast.py:19343
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Type_Expression
  (Node : Bare_Base_Subp_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Body :=
     Internal_Entity_Base_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Subp_Spec;
Fld_1 : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4693 '<FieldAccess for returns at ast.py:19343>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19343
--# expr-start 4692 '<FieldAccess for subp_spec at ast.py:19343>' Fld /tmp/lal-23.0.0/ada/ast.py:19343
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Base_Subp_Body_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4692
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4693
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Type_Expression;
--# end
--# property-start BaseSubpBody.expr_type /tmp/lal-23.0.0/ada/ast.py:19346
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Expr_Type
  (Node : Bare_Base_Subp_Body
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Body :=
     Internal_Entity_Base_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4696 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4694 '<FieldAccess for subp_spec_or_null at ast.py:19347>' Fld /tmp/lal-23.0.0/ada/ast.py:19347
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4694
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 4695 '<FieldAccess for return_type at ast.py:19347>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19347
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 4695
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 4696
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Expr_Type;
--# end
--# property-start BaseSubpBody.initial_env_name /tmp/lal-23.0.0/ada/ast.py:19350
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Initial_Env_Name
  (Node : Bare_Base_Subp_Body
      ; Follow_Private : Boolean
         := False
  )
   return Symbol_Type
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind follow_private Follow_Private
   Property_Result : Symbol_Type;
      Fld : Symbol_Type;
Fld_1 : Symbol_Type;
Fld_2 : Boolean;
If_Result : Symbol_Type;
Let_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4701 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4700 '<If at ast.py:19351>' If_Result /tmp/lal-23.0.0/ada/ast.py:19351
--# expr-start 4697 '<FieldAccess for is_library_item at ast.py:19352>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19352
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 4697
if Fld_2 then
   --# expr-start 4698 '<FieldAccess for child_decl_initial_env_name at ast.py:19353>' Fld /tmp/lal-23.0.0/ada/ast.py:19353
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.child_decl_initial_env_name'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Child_Decl_Initial_Env_Name (Node => Self, Private_Part => Follow_Private);
--# end
--# expr-done 4698
   If_Result := Fld;
else
   --# expr-start 4699 '<FieldAccess for body_initial_env_name at ast.py:19354>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19354
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_initial_env_name
Fld_1 := Libadalang.Implementation.Body_Node_P_Body_Initial_Env_Name (Node => Self);
--# end
--# expr-done 4699
   If_Result := Fld_1;
end if;
--# expr-done 4700
Let_Result := If_Result; 
--# end
--# expr-done 4701
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Initial_Env_Name;
--# end
--# property-start BaseSubpBody.previous_part_env_name /tmp/lal-23.0.0/ada/ast.py:19358
pragma Warnings (Off, "is not referenced");
 function Base_Subp_Body_P_Previous_Part_Env_Name
  (Node : Bare_Base_Subp_Body
  )
   return Symbol_Type
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
            procedure Finalizer_Scope_1377 with Inline_Always;
      Fld : Boolean;
Fld_1 : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym : Symbol_Type;
Fld_2 : Boolean;
Fld_3 : String_Type;
Sym_1 : Symbol_Type;
If_Result : Symbol_Type;
If_Result_1 : Symbol_Type;
Let_Result : Symbol_Type;
            procedure Finalizer_Scope_1377 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_1377;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4711 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4710 '<Cond at ast.py:19364>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19364
--# expr-start 4702 '<FieldAccess for is_subunit at ast.py:19365>' Fld /tmp/lal-23.0.0/ada/ast.py:19365
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Self);
--# end
--# expr-done 4702
if Fld then
   --# expr-start 4706 '<to_symbol at ast.py:19366>' Sym /tmp/lal-23.0.0/ada/ast.py:19366
--# expr-start 4705 '<Concat at ast.py:19366>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:19366
--# expr-start 4703 '<FieldAccess for top_level_env_name at ast.py:19366>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19366
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4703
--# expr-start 4704 '<String at ast.py:19366>' Str /tmp/lal-23.0.0/ada/ast.py:19366
Str := Create_String ("__stub"); 
--# expr-done 4704
Concat_Result := Concat_String (Fld_1, Str); 
--# expr-done 4705
Sym := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 4706
   If_Result_1 := Sym;
else
--# expr-start 4707 '<FieldAccess for is_library_item at ast.py:19368>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19368
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 4707
if Fld_2 then
   --# expr-start 4709 '<to_symbol at ast.py:19369>' Sym_1 /tmp/lal-23.0.0/ada/ast.py:19369
--# expr-start 4708 '<FieldAccess for top_level_env_name at ast.py:19369>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19369
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4708
Sym_1 := String_To_Symbol (Self, Self.Unit.Context, Fld_3); 
--# expr-done 4709
   If_Result := Sym_1;
else
   If_Result := null;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 4710
Let_Result := If_Result_1; 
--# end
--# expr-done 4711
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1377;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1377;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Subp_Body_P_Previous_Part_Env_Name;
--# end
--# property-start BaseSubpBody._env_do_134 /tmp/lal-23.0.0/ada/ast.py:19375
pragma Warnings (Off, "is not referenced");
 function Env_Do_134
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4712 '<FieldAccess for env_hook at ast.py:19375>' Fld /tmp/lal-23.0.0/ada/ast.py:19375
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 4712
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_134;
--# end
--# property-start BaseSubpBody._initial_env_135 /tmp/lal-23.0.0/ada/ast.py:19378
pragma Warnings (Off, "is not referenced");
 function Initial_Env_135
  (Node : Bare_Base_Subp_Body
  )
   return Internal_Designated_Env
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1604 with Inline_Always;
            procedure Finalizer_Scope_2488 with Inline_Always;
      Var_Expr : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1604 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1604;
            procedure Finalizer_Scope_2488 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2488;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 4713 '<FieldAccess for initial_env_name at ast.py:19379>' Fld /tmp/lal-23.0.0/ada/ast.py:19379
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpBody.initial_env_name
Fld := Libadalang.Implementation.Base_Subp_Body_P_Initial_Env_Name (Node => Self, Follow_Private => True);
--# end
--# expr-done 4713
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind non_null_name Var_Expr
--# expr-start 4714 '<New DesignatedEnv at ???>' New_Struct None
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 4714
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2488;
   Result_Var := Scope_Result;
else
   --# expr-start 4715 '<New DesignatedEnv at ast.py:19378>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:19378
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4715
   Result_Var := New_Struct_1;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1604;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1604;
               Finalizer_Scope_2488;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_135;
--# end
--# property-start BaseSubpBody._env_mappings_136 /tmp/lal-23.0.0/ada/ast.py:19385
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_136
  (Node : Bare_Base_Subp_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Body :=
     Internal_Entity_Base_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1605 with Inline_Always;
            procedure Finalizer_Scope_2489 with Inline_Always;
      Var_Expr : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1605 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1605;
            procedure Finalizer_Scope_2489 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2489;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4719 '<FieldAccess for basic_decl_env_assocs at ast.py:19385>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19385
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4716 '<FieldAccess for initial_env_name at ast.py:19386>' Fld /tmp/lal-23.0.0/ada/ast.py:19386
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpBody.initial_env_name
Fld := Libadalang.Implementation.Base_Subp_Body_P_Initial_Env_Name (Node => Self, Follow_Private => False);
--# end
--# expr-done 4716
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind non_null_name Var_Expr
--# expr-start 4717 '<New DesignatedEnv at ???>' New_Struct None
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 4717
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2489;
   Result_Var := Scope_Result;
else
   --# expr-start 4718 '<New DesignatedEnv at ast.py:19386>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:19386
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4718
   Result_Var := New_Struct_1;
end if;
      Inc_Ref (Result_Var);
--# property-call-start BasicDecl.basic_decl_env_assocs
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Basic_Decl_Env_Assocs (Node => Ent.Node, Dest_Env => Result_Var, E_Info => Ent.Info);
--# end
--# expr-done 4719
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1605;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1605;
               Finalizer_Scope_2489;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_136;
--# end
--# property-start BaseSubpBody._env_trans_parent_137 /tmp/lal-23.0.0/ada/ast.py:19374
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_137
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_137;
--# end
--# property-start BaseSubpBody._env_mappings_138 /tmp/lal-23.0.0/ada/ast.py:19392
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_138
  (Node : Bare_Base_Subp_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Subp_Body :=
     Internal_Entity_Base_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1607 with Inline_Always;
            procedure Finalizer_Scope_2490 with Inline_Always;
            procedure Finalizer_Scope_2491 with Inline_Always;
      Var_Expr : Symbol_Type;
Var_Expr_1 : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
New_Struct_2 : Internal_Designated_Env := No_Designated_Env;
Scope_Result_1 : Internal_Designated_Env := No_Designated_Env;
New_Struct_3 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
Fld_3 : Boolean;
If_Result : Internal_Designated_Env := No_Designated_Env;
Result_Var_1 : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Base_Subp_Body;
Cast_Result : Bare_Ada_Node;
New_Struct_4 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1607 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (New_Struct_3);
                     Dec_Ref (Result_Var);
                     Dec_Ref (If_Result);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (New_Struct_4);
            end Finalizer_Scope_1607;
            procedure Finalizer_Scope_2490 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2490;
            procedure Finalizer_Scope_2491 is
            begin
                     Dec_Ref (Var_Expr_1);
                     Dec_Ref (New_Struct_2);
            end Finalizer_Scope_2491;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4731 '<New EnvAssoc at ast.py:19392>' New_Struct_4 /tmp/lal-23.0.0/ada/ast.py:19392
--# expr-start 4720 '<FieldAccess for previous_part_env_name at ast.py:19395>' Fld /tmp/lal-23.0.0/ada/ast.py:19395
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_env_name'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Env_Name (Node => Self);
--# end
--# expr-done 4720
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind name Var_Expr
--# expr-start 4721 '<New DesignatedEnv at ast.py:19396>' New_Struct /tmp/lal-23.0.0/ada/ast.py:19396
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 4721
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2490;
   Result_Var_1 := Scope_Result;
else
   --# expr-start 4729 '<If at ast.py:19402>' If_Result /tmp/lal-23.0.0/ada/ast.py:19402
--# expr-start 4722 '<FieldAccess for has_top_level_env_name at ast.py:19403>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19403
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.has_top_level_env_name
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Has_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4722
if Fld_3 then
   --# expr-start 4723 '<New DesignatedEnv at ast.py:19404>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:19404
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => None); 
--# expr-done 4723
   If_Result := New_Struct_1;
else
--# expr-start 4726 '<bind at ast.py:19406>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:19406
--# expr-start 4724 '<FieldAccess for default_initial_env at ast.py:19407>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19407
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld_1 := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 4724
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 4725 '<FieldAccess for body_scope at ast.py:19408>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19408
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_scope
Fld_2 := Libadalang.Implementation.Body_Node_P_Body_Scope (Node => Ent.Node, Follow_Private => False, Force_Decl => True, Env => Bound_Env, E_Info => Ent.Info);
--# end
--# expr-done 4725
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4726
Var_Expr_1 := Dyn_Var_Bind_Result;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= Empty_Env then
   --# scope-start
   --# bind non_null_env Var_Expr_1
--# expr-start 4727 '<New DesignatedEnv at ???>' New_Struct_2 None
Inc_Ref (Var_Expr_1);
New_Struct_2 := (Direct_Env => Var_Expr_1, Env_Name => null, Kind => Direct_Env); 
--# expr-done 4727
Scope_Result_1 := New_Struct_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2491;
   Result_Var := Scope_Result_1;
else
   --# expr-start 4728 '<New DesignatedEnv at ast.py:19405>' New_Struct_3 /tmp/lal-23.0.0/ada/ast.py:19405
Inc_Ref (Empty_Env);
New_Struct_3 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4728
   Result_Var := New_Struct_3;
end if;
      Inc_Ref (Result_Var);
   If_Result := Result_Var;
end if;
      Inc_Ref (If_Result);
--# expr-done 4729
   Result_Var_1 := If_Result;
end if;
      Inc_Ref (Result_Var_1);
--# expr-start 4730 '<Symbol __nextpart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Nextpart); 
--# expr-done 4730
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (Result_Var_1);
New_Struct_4 := (Dest_Env => Result_Var_1, Key => Sym, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4731
      Property_Result := New_Struct_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1607;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1607;
               Finalizer_Scope_2490;
               Finalizer_Scope_2491;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_138;
--# end
--# property-start BaseSubpBody._env_do_139 /tmp/lal-23.0.0/ada/ast.py:19419
pragma Warnings (Off, "is not referenced");
 function Env_Do_139
  (Node : Bare_Base_Subp_Body
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1608 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1608 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1608;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4732 '<FieldAccess for populate_dependent_units at ast.py:19419>' Fld /tmp/lal-23.0.0/ada/ast.py:19419
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 4732
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1608;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1608;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_139;
--# end
--# property-start BaseSubpBody._ref_env_nodes_140 /tmp/lal-23.0.0/ada/ast.py:19422
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_140
  (Node : Bare_Base_Subp_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1609 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1609 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1609;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4733 '<FieldAccess for top_level_use_package_clauses at ast.py:19422>' Fld /tmp/lal-23.0.0/ada/ast.py:19422
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 4733
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1609;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1609;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_140;
--# end
--# property-start BaseSubpBody._ref_cond_141 /tmp/lal-23.0.0/ada/ast.py:19424
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_141
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4735 '<IsA LibraryItem, Subunit at ast.py:19424>' Is_A /tmp/lal-23.0.0/ada/ast.py:19424
--# expr-start 4734 '<parent at ast.py:19424>' Fld /tmp/lal-23.0.0/ada/ast.py:19424
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4734
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4735
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_141;
--# end
--# property-start BaseSubpBody._ref_env_nodes_142 /tmp/lal-23.0.0/ada/ast.py:19428
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_142
  (Node : Bare_Base_Subp_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1611 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1611 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1611;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4736 '<FieldAccess for top_level_use_type_clauses at ast.py:19428>' Fld /tmp/lal-23.0.0/ada/ast.py:19428
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 4736
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1611;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1611;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_142;
--# end
--# property-start BaseSubpBody._ref_cond_143 /tmp/lal-23.0.0/ada/ast.py:19430
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_143
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4738 '<IsA LibraryItem, Subunit at ast.py:19430>' Is_A /tmp/lal-23.0.0/ada/ast.py:19430
--# expr-start 4737 '<parent at ast.py:19430>' Fld /tmp/lal-23.0.0/ada/ast.py:19430
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4737
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4738
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_143;
--# end
--# property-start BaseSubpBody._ref_env_nodes_144 /tmp/lal-23.0.0/ada/ast.py:19437
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_144
  (Node : Bare_Base_Subp_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1613 with Inline_Always;
            procedure Finalizer_Scope_2492 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Base_Subp_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1613 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1613;
            procedure Finalizer_Scope_2492 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2492;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4739 '<Cast to AdaNode at ast.py:19437>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19437
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4739
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2492;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1613;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1613;
               Finalizer_Scope_2492;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_144;
--# end
--# property-start BaseSubpBody._ref_cond_145 /tmp/lal-23.0.0/ada/ast.py:19439
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_145
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4741 '<IsA LibraryItem at ast.py:19439>' Is_A /tmp/lal-23.0.0/ada/ast.py:19439
--# expr-start 4740 '<parent at ast.py:19439>' Fld /tmp/lal-23.0.0/ada/ast.py:19439
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4740
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range; 
--# expr-done 4741
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_145;
--# end
--# property-start BaseSubpBody._ref_env_nodes_146 /tmp/lal-23.0.0/ada/ast.py:19443
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_146
  (Node : Bare_Base_Subp_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1615 with Inline_Always;
            procedure Finalizer_Scope_2493 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Base_Subp_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1615 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1615;
            procedure Finalizer_Scope_2493 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2493;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4742 '<Cast to AdaNode at ast.py:19443>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19443
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4742
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2493;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1615;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1615;
               Finalizer_Scope_2493;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_146;
--# end
--# property-start BaseSubpBody._ref_cond_147 /tmp/lal-23.0.0/ada/ast.py:19445
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_147
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4743 '<FieldAccess for should_ref_generic_formals at ast.py:19445>' Fld /tmp/lal-23.0.0/ada/ast.py:19445
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4743
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_147;
--# end
--# property-start BaseSubpBody._ref_env_nodes_148 /tmp/lal-23.0.0/ada/ast.py:19453
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_148
  (Node : Bare_Base_Subp_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1617 with Inline_Always;
            procedure Finalizer_Scope_2494 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Base_Subp_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1617 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1617;
            procedure Finalizer_Scope_2494 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2494;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4744 '<Cast to AdaNode at ast.py:19453>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19453
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4744
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2494;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1617;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1617;
               Finalizer_Scope_2494;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_148;
--# end
--# property-start BaseSubpBody._ref_cond_149 /tmp/lal-23.0.0/ada/ast.py:19455
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_149
  (Node : Bare_Base_Subp_Body
  )
   return Boolean
is
   Self : Bare_Base_Subp_Body := Bare_Base_Subp_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4745 '<FieldAccess for should_ref_generic_formals at ast.py:19455>' Fld /tmp/lal-23.0.0/ada/ast.py:19455
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4745
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_149;
--# end
   --
   --  Primitives for Bare_Expr_Function
   --
      procedure Initialize_Fields_For_Expr_Function
        (Self : Bare_Expr_Function
         ; Base_Subp_Body_F_Overriding : Bare_Overriding_Node
         ; Base_Subp_Body_F_Subp_Spec : Bare_Subp_Spec
         ; Expr_Function_F_Expr : Bare_Expr
         ; Expr_Function_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Base_Subp_Body
              (Self, Base_Subp_Body_F_Overriding, Base_Subp_Body_F_Subp_Spec);
            Self.Expr_Function_F_Expr := Expr_Function_F_Expr;
            Self.Expr_Function_F_Aspects := Expr_Function_F_Aspects;
      end Initialize_Fields_For_Expr_Function;
   function Expr_Function_F_Expr
     (Node : Bare_Expr_Function) return Bare_Expr
   is
   begin
         return Node.Expr_Function_F_Expr;
   end;
--# property-start ExprFunction.xref_equation /tmp/lal-23.0.0/ada/ast.py:19469
pragma Warnings (Off, "is not referenced");
 function Expr_Function_P_Xref_Equation
  (Node : Bare_Expr_Function
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Expr_Function := Bare_Expr_Function (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr_Function :=
     Internal_Entity_Expr_Function'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1378 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Subp_Spec;
Fld_3 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_Expr;
Fld_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
            procedure Finalizer_Scope_1378 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_1378;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4756 '<And at ast.py:19470>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19470
--# expr-start 4753 '<And at ast.py:19470>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19470
--# expr-start 4750 '<Bind at ast.py:19470>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19470
--# expr-start 4747 '<FieldAccess for expected_type_var at ast.py:19470>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19470
--# expr-start 4746 '<FieldAccess for expr at ast.py:19470>' Fld /tmp/lal-23.0.0/ada/ast.py:19470
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Expr_Function_F_Expr, Info => Ent.Info);
--# expr-done 4746
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld.Node);
--# expr-done 4747
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 4749 '<FieldAccess for return_type at ast.py:19470>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19470
--# expr-start 4748 '<FieldAccess for subp_spec at ast.py:19470>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19470
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Base_Subp_Body_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4748
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_3 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld_2.Node, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 4749
      Cast_Result := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19470") else null)); 
--# expr-done 4750
--# expr-start 4752 '<FieldAccess for sub_equation at ast.py:19471>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19471
--# expr-start 4751 '<FieldAccess for expr at ast.py:19471>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19471
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Ent.Node.Expr_Function_F_Expr, Info => Ent.Info);
--# expr-done 4751
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_4.Node, Env => Env, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 4752
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19470") else null)); 
--# expr-done 4753
--# expr-start 4755 '<FieldAccess for matches_expected_assign_type at ast.py:19472>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19472
--# expr-start 4754 '<FieldAccess for expr at ast.py:19472>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19472
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Expr_Function_F_Expr;
--# expr-done 4754
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_7 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Fld_6, Origin => Origin);
--# end
--# expr-done 4755
And_Pred_1 := Create_And (And_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19470") else null)); 
--# expr-done 4756
      Property_Result := And_Pred_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1378;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1378;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_Function_P_Xref_Equation;
--# end
--# property-start ExprFunction.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:19475
pragma Warnings (Off, "is not referenced");
 function Expr_Function_P_Xref_Entry_Point
  (Node : Bare_Expr_Function
  )
   return Boolean
is
   Self : Bare_Expr_Function := Bare_Expr_Function (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_Function_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_Null_Subp_Decl
   --
      procedure Initialize_Fields_For_Null_Subp_Decl
        (Self : Bare_Null_Subp_Decl
         ; Base_Subp_Body_F_Overriding : Bare_Overriding_Node
         ; Base_Subp_Body_F_Subp_Spec : Bare_Subp_Spec
         ; Null_Subp_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Base_Subp_Body
              (Self, Base_Subp_Body_F_Overriding, Base_Subp_Body_F_Subp_Spec);
            Self.Null_Subp_Decl_F_Aspects := Null_Subp_Decl_F_Aspects;
      end Initialize_Fields_For_Null_Subp_Decl;
   --
   --  Primitives for Bare_Subp_Body
   --
      procedure Initialize_Fields_For_Subp_Body
        (Self : Bare_Subp_Body
         ; Base_Subp_Body_F_Overriding : Bare_Overriding_Node
         ; Base_Subp_Body_F_Subp_Spec : Bare_Subp_Spec
         ; Subp_Body_F_Aspects : Bare_Aspect_Spec
         ; Subp_Body_F_Decls : Bare_Declarative_Part
         ; Subp_Body_F_Stmts : Bare_Handled_Stmts
         ; Subp_Body_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Base_Subp_Body
              (Self, Base_Subp_Body_F_Overriding, Base_Subp_Body_F_Subp_Spec);
            Self.Subp_Body_F_Aspects := Subp_Body_F_Aspects;
            Self.Subp_Body_F_Decls := Subp_Body_F_Decls;
            Self.Subp_Body_F_Stmts := Subp_Body_F_Stmts;
            Self.Subp_Body_F_End_Name := Subp_Body_F_End_Name;
      end Initialize_Fields_For_Subp_Body;
   function Subp_Body_F_Decls
     (Node : Bare_Subp_Body) return Bare_Declarative_Part
   is
   begin
         return Node.Subp_Body_F_Decls;
   end;
   function Subp_Body_F_Stmts
     (Node : Bare_Subp_Body) return Bare_Handled_Stmts
   is
   begin
         return Node.Subp_Body_F_Stmts;
   end;
   function Subp_Body_F_End_Name
     (Node : Bare_Subp_Body) return Bare_End_Name
   is
   begin
         return Node.Subp_Body_F_End_Name;
   end;
--# property-start SubpBody.declarative_parts /tmp/lal-23.0.0/ada/ast.py:19532
pragma Warnings (Off, "is not referenced");
 function Subp_Body_P_Declarative_Parts
  (Node : Bare_Subp_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Subp_Body := Bare_Subp_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Body :=
     Internal_Entity_Subp_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1382 with Inline_Always;
      Fld : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1382 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1382;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4757 '<FieldAccess for decls at ast.py:19532>' Fld /tmp/lal-23.0.0/ada/ast.py:19532
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Declarative_Part (Node => Ent.Node.Subp_Body_F_Decls, Info => Ent.Info);
--# expr-done 4757
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1382;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1382;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Body_P_Declarative_Parts;
--# end
   --
   --  Primitives for Bare_Subp_Renaming_Decl
   --
      procedure Initialize_Fields_For_Subp_Renaming_Decl
        (Self : Bare_Subp_Renaming_Decl
         ; Base_Subp_Body_F_Overriding : Bare_Overriding_Node
         ; Base_Subp_Body_F_Subp_Spec : Bare_Subp_Spec
         ; Subp_Renaming_Decl_F_Renames : Bare_Renaming_Clause
         ; Subp_Renaming_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Base_Subp_Body
              (Self, Base_Subp_Body_F_Overriding, Base_Subp_Body_F_Subp_Spec);
            Self.Subp_Renaming_Decl_F_Renames := Subp_Renaming_Decl_F_Renames;
            Self.Subp_Renaming_Decl_F_Aspects := Subp_Renaming_Decl_F_Aspects;
      end Initialize_Fields_For_Subp_Renaming_Decl;
   function Subp_Renaming_Decl_F_Renames
     (Node : Bare_Subp_Renaming_Decl) return Bare_Renaming_Clause
   is
   begin
         return Node.Subp_Renaming_Decl_F_Renames;
   end;
--# property-start SubpRenamingDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:19494
pragma Warnings (Off, "is not referenced");
 function Subp_Renaming_Decl_P_Xref_Entry_Point
  (Node : Bare_Subp_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Subp_Renaming_Decl := Bare_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Renaming_Decl_P_Xref_Entry_Point;
--# end
--# property-start SubpRenamingDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:19495
pragma Warnings (Off, "is not referenced");
 function Subp_Renaming_Decl_P_Xref_Equation
  (Node : Bare_Subp_Renaming_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Subp_Renaming_Decl := Bare_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Renaming_Decl :=
     Internal_Entity_Subp_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1381 with Inline_Always;
      Fld : Internal_Entity_Renaming_Clause;
Fld_1 : Internal_Entity_Name;
Is_A : Boolean;
Fld_2 : Internal_Entity_Renaming_Clause;
Fld_3 : Internal_Entity_Name;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity_Subp_Spec;
Fld_6 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_7 : Internal_Entity_Renaming_Clause;
Fld_8 : Internal_Entity_Name;
Fld_9 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_10 : Internal_Entity_Renaming_Clause;
Fld_11 : Internal_Entity_Name;
Is_A_1 : Boolean;
Fld_12 : Internal_Entity_Renaming_Clause;
Fld_13 : Internal_Entity_Name;
Fld_14 : Logic_Equation;
Fld_15 : Internal_Entity_Renaming_Clause;
Fld_16 : Internal_Entity_Name;
Fld_17 : Logic_Equation;
Fld_18 : Internal_Entity_Renaming_Clause;
Fld_19 : Internal_Entity_Name;
Fld_20 : Logic_Var;
Cast_Expr : Internal_Entity_Subp_Renaming_Decl;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Pred : Logic_Equation;
And_Pred_1 : Logic_Equation;
If_Result : Logic_Equation;
If_Result_1 : Logic_Equation;
True_Rel : Logic_Equation;
False_Rel : Logic_Equation;
Fld_21 : Internal_Entity_Renaming_Clause;
Fld_22 : Internal_Entity_Name;
Fld_23 : Boolean;
If_Result_2 : Logic_Equation;
Or_Pred : Logic_Equation;
            procedure Finalizer_Scope_1381 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Or_Pred);
            end Finalizer_Scope_1381;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4791 '<Or at ast.py:19495>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:19495
--# expr-start 4786 '<Cond at ast.py:19496>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19496
--# expr-start 4760 '<IsA CharLiteral at ast.py:19497>' Is_A /tmp/lal-23.0.0/ada/ast.py:19497
--# expr-start 4759 '<FieldAccess for renamed_object at ast.py:19497>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19497
--# expr-start 4758 '<FieldAccess for renames at ast.py:19497>' Fld /tmp/lal-23.0.0/ada/ast.py:19497
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4758
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Fld.Node.Renaming_Clause_F_Renamed_Object, Info => Fld.Info);
--# expr-done 4759
Is_A := Fld_1.Node /= null 
and then Fld_1.Node.Kind in Ada_Char_Literal_Range; 
--# expr-done 4760
if Is_A then
   --# expr-start 4770 '<And at ast.py:19501>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19501
--# expr-start 4766 '<Bind at ast.py:19501>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19501
--# expr-start 4763 '<FieldAccess for expected_type_var at ast.py:19501>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19501
--# expr-start 4762 '<FieldAccess for renamed_object at ast.py:19501>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19501
--# expr-start 4761 '<FieldAccess for renames at ast.py:19501>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19501
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4761
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Fld_2.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_2.Info);
--# expr-done 4762
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_3.Node);
--# expr-done 4763
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 4765 '<FieldAccess for return_type at ast.py:19502>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19502
--# expr-start 4764 '<FieldAccess for subp_spec at ast.py:19502>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19502
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Base_Subp_Body_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4764
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_6 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld_5.Node, Origin => Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 4765
      Cast_Result := Create_Internal_Entity
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19501") else null)); 
--# expr-done 4766
--# expr-start 4769 '<FieldAccess for sub_equation at ast.py:19503>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:19503
--# expr-start 4768 '<FieldAccess for renamed_object at ast.py:19503>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19503
--# expr-start 4767 '<FieldAccess for renames at ast.py:19503>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19503
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4767
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Name (Node => Fld_7.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_7.Info);
--# expr-done 4768
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_9 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_8.Node, Env => Env, Origin => Origin, E_Info => Fld_8.Info);
--# end
--# expr-done 4769
And_Pred := Create_And (Bind_Result, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19501") else null)); 
--# expr-done 4770
   If_Result_1 := And_Pred;
else
--# expr-start 4773 '<IsA AttributeRef at ast.py:19505>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:19505
--# expr-start 4772 '<FieldAccess for renamed_object at ast.py:19505>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:19505
--# expr-start 4771 '<FieldAccess for renames at ast.py:19505>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:19505
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4771
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Name (Node => Fld_10.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_10.Info);
--# expr-done 4772
Is_A_1 := Fld_11.Node /= null 
and then Fld_11.Node.Kind in Ada_Attribute_Ref_Range; 
--# expr-done 4773
if Is_A_1 then
   --# expr-start 4776 '<FieldAccess for sub_equation at ast.py:19508>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:19508
--# expr-start 4775 '<FieldAccess for renamed_object at ast.py:19508>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:19508
--# expr-start 4774 '<FieldAccess for renames at ast.py:19508>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:19508
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4774
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Name (Node => Fld_12.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_12.Info);
--# expr-done 4775
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_14 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_13.Node, Env => Env, Origin => Origin, E_Info => Fld_13.Info);
--# end
--# expr-done 4776
   If_Result := Fld_14;
else
   --# expr-start 4785 '<And at ast.py:19510>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19510
--# expr-start 4779 '<FieldAccess for xref_no_overloading at ast.py:19510>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:19510
--# expr-start 4778 '<FieldAccess for renamed_object at ast.py:19510>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:19510
--# expr-start 4777 '<FieldAccess for renames at ast.py:19510>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:19510
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4777
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Name (Node => Fld_15.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_15.Info);
--# expr-done 4778
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_17 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_16.Node, All_Els => True, Env => Env, Origin => Origin, E_Info => Fld_16.Info);
--# end
--# expr-done 4779
--# expr-start 4784 '<Predicate on BasicDecl.subp_decl_match_signature at ast.py:19511>' Pred /tmp/lal-23.0.0/ada/ast.py:19511
--# expr-start 4782 '<FieldAccess for ref_var at ast.py:19512>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:19512
--# expr-start 4781 '<FieldAccess for renamed_object at ast.py:19512>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:19512
--# expr-start 4780 '<FieldAccess for renames at ast.py:19512>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:19512
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4780
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Name (Node => Fld_18.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_18.Info);
--# expr-done 4781
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_20 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_19.Node);
--# end
--# expr-done 4782
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
--# expr-start 4783 '<Cast to BasicDecl at ast.py:19513>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:19513
Cast_Expr := Ent; 
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-done 4783
Pred := Solver.Create_Predicate (Fld_20, Create_Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate (Cast_Result_1)); 
--# expr-done 4784
And_Pred_1 := Create_And (Fld_17, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19510") else null)); 
--# expr-done 4785
   If_Result := And_Pred_1;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 4786
--# expr-start 4790 '<If at ast.py:19517>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:19517
--# expr-start 4789 '<FieldAccess for is_operator_name at ast.py:19517>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:19517
--# expr-start 4788 '<FieldAccess for renamed_object at ast.py:19517>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:19517
--# expr-start 4787 '<FieldAccess for renames at ast.py:19517>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:19517
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4787
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Create_Internal_Entity_Name (Node => Fld_21.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_21.Info);
--# expr-done 4788
      if Fld_22.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_operator_name
Fld_23 := Libadalang.Implementation.Name_P_Is_Operator_Name (Node => Fld_22.Node, E_Info => Fld_22.Info);
--# end
--# expr-done 4789
if Fld_23 then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19518") else null)); 
   If_Result_2 := True_Rel;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19518") else null)); 
   If_Result_2 := False_Rel;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 4790
Or_Pred := Create_Or (If_Result_1, If_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19495") else null)); 
--# expr-done 4791
      Property_Result := Or_Pred;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1381;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1381;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Renaming_Decl_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Body_Stub
   --
--# property-start BodyStub.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:3911
pragma Warnings (Off, "is not referenced");
 function Body_Stub_P_Next_Part_For_Decl
  (Node : Bare_Body_Stub
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Body_Stub := Bare_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Body_Stub :=
     Internal_Entity_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_239 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
Fld_1 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_239 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_239;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4795 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4794 '<as_entity at ast.py:3917>' If_Result /tmp/lal-23.0.0/ada/ast.py:3917
--# expr-start 4793 '<FieldAccess for get_unit_root_decl at ast.py:3912>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3912
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4792 '<FieldAccess for fully_qualified_name_array at ast.py:3913>' Fld /tmp/lal-23.0.0/ada/ast.py:3913
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_array
Fld := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Array (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4792
--# property-call-start AdaNode.get_unit_root_decl
Fld_1 := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Fld, Kind => Unit_Body, Process_Parents => False);
--# end
--# expr-done 4793
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 4794
Let_Result := If_Result; 
--# end
--# expr-done 4795
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_239;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_239;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Stub_P_Next_Part_For_Decl;
--# end
--# property-start BodyStub.syntactic_fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:3920
pragma Warnings (Off, "is not referenced");
 function Body_Stub_P_Syntactic_Fully_Qualified_Name
  (Node : Bare_Body_Stub
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Body_Stub := Bare_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_240 with Inline_Always;
      Block_Var : Symbol_Type_Array_Access;
Block_Var_1 : Bare_Body_Node;
Block_Var_2 : Bare_Compilation_Unit;
Match_0 : Bare_Subp_Body;
Match_1 : Bare_Protected_Body;
Match_2 : Bare_Package_Body;
Match_3 : Bare_Task_Body;
Match_4 : Bare_Ada_Node;
As_Entity : Internal_Entity_Body_Stub;
Is_Null : Boolean;
If_Result : Internal_Entity_Body_Stub;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Symbol_Type_Array_Access;
Fld_2 : Bare_Ada_Node;
Fld_3 : Bare_Ada_Node;
Fld_4 : Bare_Ada_Node;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Subp_Body;
Cast_Expr : Bare_Subp_Body;
Cast_Result_1 : Bare_Body_Node;
Let_Result : Bare_Body_Node;
Scope_Result : Bare_Body_Node;
Cast_Result_2 : Bare_Protected_Body;
Cast_Expr_1 : Bare_Protected_Body;
Cast_Result_3 : Bare_Body_Node;
Let_Result_1 : Bare_Body_Node;
Scope_Result_1 : Bare_Body_Node;
Cast_Result_4 : Bare_Package_Body;
Cast_Expr_2 : Bare_Package_Body;
Cast_Result_5 : Bare_Body_Node;
Let_Result_2 : Bare_Body_Node;
Scope_Result_2 : Bare_Body_Node;
Cast_Result_6 : Bare_Task_Body;
Cast_Expr_3 : Bare_Task_Body;
Cast_Result_7 : Bare_Body_Node;
Let_Result_3 : Bare_Body_Node;
Scope_Result_3 : Bare_Body_Node;
Cast_Result_8 : Bare_Ada_Node;
Let_Result_4 : Bare_Body_Node;
Scope_Result_4 : Bare_Body_Node;
Match_Result : Bare_Body_Node;
Fld_5 : Bare_Ada_Node;
Fld_6 : Bare_Ada_Node;
Cast_Result_9 : Bare_Compilation_Unit;
Fld_7 : Bare_Ada_Node;
Is_A : Boolean;
Fld_8 : Bare_Ada_Node;
Is_A_1 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Bare_Compilation_Unit;
Fld_9 : Symbol_Type_Array_Access;
Concat_Result : Symbol_Type_Array_Access;
Let_Result_5 : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_240 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result_5);
            end Finalizer_Scope_240;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4813 '<Block at ???>' Let_Result_5 None
--# scope-start
--# expr-start 4798 '<FieldAccess for as_symbol_array at ast.py:3928>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:3928
--# expr-start 4797 '<FieldAccess for defining_name at ast.py:3928>' Fld /tmp/lal-23.0.0/ada/ast.py:3928
--# expr-start 4796 '<as_bare_entity at ast.py:3928>' If_Result /tmp/lal-23.0.0/ada/ast.py:3928
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Body_Stub;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 4796
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 4797
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld.Node);
--# end
--# expr-done 4798
Block_Var := Fld_1; Inc_Ref (Block_Var);
--# bind rel_name Block_Var
--# expr-start 4802 '<Match at ast.py:3939>' Match_Result /tmp/lal-23.0.0/ada/ast.py:3939
--# expr-start 4801 '<parent at ast.py:3939>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:3939
--# expr-start 4800 '<parent at ast.py:3939>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:3939
--# expr-start 4799 '<parent at ast.py:3939>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:3939
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Parent; 
--# expr-done 4799
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Fld_2.Parent; 
--# expr-done 4800
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Fld_3.Parent; 
--# expr-done 4801
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_4; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Subp_Body =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind b Match_0
Cast_Expr := Match_0; 
      Cast_Result_1 := Cast_Expr;
Let_Result := Cast_Result_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Protected_Body =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_1 := Cast_Result_2; 
--# bind b Match_1
Cast_Expr_1 := Match_1; 
      Cast_Result_3 := Cast_Expr_1;
Let_Result_1 := Cast_Result_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Package_Body =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix;
Match_2 := Cast_Result_4; 
--# bind b Match_2
Cast_Expr_2 := Match_2; 
      Cast_Result_5 := Cast_Expr_2;
Let_Result_2 := Cast_Result_5; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Match_Prefix;
Match_3 := Cast_Result_6; 
--# bind b Match_3
Cast_Expr_3 := Match_3; 
      Cast_Result_7 := Cast_Expr_3;
Let_Result_3 := Cast_Result_7; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Abort_Absent .. Ada_Null_Subp_Decl | Ada_Subp_Renaming_Decl .. Ada_Entry_Body | Ada_Entry_Index_Spec .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Match_Prefix;
Match_4 := Cast_Result_8; 
--# bind _ Match_4
Let_Result_4 := raise Property_Error with "invalid body stub"; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_4; 
end case;
--# expr-done 4802
Block_Var_1 := Match_Result; 
--# bind top_body Block_Var_1
--# expr-start 4810 '<If at ast.py:3946>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:3946
--# expr-start 4804 '<IsA LibraryItem at ast.py:3947>' Is_A /tmp/lal-23.0.0/ada/ast.py:3947
--# expr-start 4803 '<parent at ast.py:3947>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:3947
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Block_Var_1.Parent; 
--# expr-done 4803
Is_A := Fld_7 /= null 
and then Fld_7.Kind in Ada_Library_Item_Range; 
--# expr-done 4804
if Is_A then
   If_Result_1 := True;
else
   --# expr-start 4806 '<IsA Subunit at ast.py:3948>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:3948
--# expr-start 4805 '<parent at ast.py:3948>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:3948
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Block_Var_1.Parent; 
--# expr-done 4805
Is_A_1 := Fld_8 /= null 
and then Fld_8.Kind in Ada_Subunit_Range; 
--# expr-done 4806
   If_Result_1 := Is_A_1;
end if;
if If_Result_1 then
   --# expr-start 4809 '<Cast to CompilationUnit at ast.py:3950>' Cast_Result_9 /tmp/lal-23.0.0/ada/ast.py:3950
--# expr-start 4808 '<parent at ast.py:3950>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:3950
--# expr-start 4807 '<parent at ast.py:3950>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:3950
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Block_Var_1.Parent; 
--# expr-done 4807
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Fld_5.Parent; 
--# expr-done 4808
   if Fld_6 = null
      or else Fld_6.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result_9 := Fld_6;
   else
         Cast_Result_9 := No_Bare_Ada_Node;
   end if;
--# expr-done 4809
   If_Result_2 := Cast_Result_9;
else
   If_Result_2 := raise Property_Error with "invalid body stub";
end if;
--# expr-done 4810
Block_Var_2 := If_Result_2; 
--# bind cu Block_Var_2
--# expr-start 4812 '<Concat at ast.py:3954>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:3954
--# expr-start 4811 '<FieldAccess for syntactic_fully_qualified_name at ast.py:3954>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:3954
      if Block_Var_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.syntactic_fully_qualified_name
Fld_9 := Libadalang.Implementation.Compilation_Unit_P_Syntactic_Fully_Qualified_Name (Node => Block_Var_2);
--# end
--# expr-done 4811
Concat_Result := Concat (Fld_9, Block_Var); 
--# expr-done 4812
Let_Result_5 := Concat_Result; Inc_Ref (Let_Result_5);
--# end
--# expr-done 4813
      Property_Result := Let_Result_5;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_240;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_240;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Stub_P_Syntactic_Fully_Qualified_Name;
--# end
--# property-start BodyStub.env_names /tmp/lal-23.0.0/ada/ast.py:3957
pragma Warnings (Off, "is not referenced");
 function Body_Stub_P_Env_Names
  (Node : Bare_Body_Stub
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Body_Stub := Bare_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_241 with Inline_Always;
      Fld : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_241 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_241;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4819 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4818 '<ArrayLiteral at ast.py:3962>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:3962
--# expr-start 4817 '<to_symbol at ast.py:3963>' Sym /tmp/lal-23.0.0/ada/ast.py:3963
--# expr-start 4816 '<Concat at ast.py:3963>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:3963
--# expr-start 4814 '<FieldAccess for top_level_env_name at ast.py:3963>' Fld /tmp/lal-23.0.0/ada/ast.py:3963
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4814
--# expr-start 4815 '<String at ast.py:3963>' Str /tmp/lal-23.0.0/ada/ast.py:3963
Str := Create_String ("__stub"); 
--# expr-done 4815
Concat_Result := Concat_String (Fld, Str); 
--# expr-done 4816
Sym := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 4817
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym)); 
--# expr-done 4818
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 4819
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_241;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_241;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Stub_P_Env_Names;
--# end
--# property-start BodyStub.previous_part_link_env_assoc /tmp/lal-23.0.0/ada/ast.py:3967
pragma Warnings (Off, "is not referenced");
 function Body_Stub_P_Previous_Part_Link_Env_Assoc
  (Node : Bare_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Body_Stub := Bare_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_242 with Inline_Always;
      Sym : Symbol_Type;
Fld : String_Type;
Sym_1 : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Body_Stub;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Let_Result : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_242 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_242;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4825 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4824 '<New EnvAssoc at ast.py:3968>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:3968
--# expr-start 4822 '<New DesignatedEnv at ast.py:3971>' New_Struct /tmp/lal-23.0.0/ada/ast.py:3971
--# expr-start 4821 '<to_symbol at ast.py:3971>' Sym_1 /tmp/lal-23.0.0/ada/ast.py:3971
--# expr-start 4820 '<FieldAccess for top_level_env_name at ast.py:3971>' Fld /tmp/lal-23.0.0/ada/ast.py:3971
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 4820
Sym_1 := String_To_Symbol (Self, Self.Unit.Context, Fld); 
--# expr-done 4821
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Sym_1, Kind => Named_Env); 
--# expr-done 4822
--# expr-start 4823 '<Symbol __nextpart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Nextpart); 
--# expr-done 4823
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Sym, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4824
Let_Result := New_Struct_1; Inc_Ref (Let_Result);
--# end
--# expr-done 4825
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_242;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_242;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Body_Stub_P_Previous_Part_Link_Env_Assoc;
--# end
   --
   --  Primitives for Bare_Package_Body_Stub
   --
      procedure Package_Body_Stub_Pre_Env_Actions
        (Self            : Bare_Package_Body_Stub;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_225 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20692");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_226 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_227 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Package_Body_Stub
        (Self : Bare_Package_Body_Stub
         ; Package_Body_Stub_F_Name : Bare_Defining_Name
         ; Package_Body_Stub_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Package_Body_Stub_F_Name := Package_Body_Stub_F_Name;
            Self.Package_Body_Stub_F_Aspects := Package_Body_Stub_F_Aspects;
      end Initialize_Fields_For_Package_Body_Stub;
   function Package_Body_Stub_F_Name
     (Node : Bare_Package_Body_Stub) return Bare_Defining_Name
   is
   begin
         return Node.Package_Body_Stub_F_Name;
   end;
--# property-start PackageBodyStub.defining_names /tmp/lal-23.0.0/ada/ast.py:20689
pragma Warnings (Off, "is not referenced");
 function Package_Body_Stub_P_Defining_Names
  (Node : Bare_Package_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Package_Body_Stub := Bare_Package_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body_Stub :=
     Internal_Entity_Package_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1453 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1453 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1453;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4826 '<FieldAccess for name at ast.py:20689>' Fld /tmp/lal-23.0.0/ada/ast.py:20689
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Package_Body_Stub_F_Name, Info => Ent.Info);
--# expr-done 4826
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1453;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1453;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Body_Stub_P_Defining_Names;
--# end
--# property-start PackageBodyStub._env_mappings_225 /tmp/lal-23.0.0/ada/ast.py:20692
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_225
  (Node : Bare_Package_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Package_Body_Stub := Bare_Package_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body_Stub :=
     Internal_Entity_Package_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1694 with Inline_Always;
      Fld : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1694 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1694;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4827 '<FieldAccess for previous_part_link_env_assoc at ast.py:20692>' Fld /tmp/lal-23.0.0/ada/ast.py:20692
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_link_env_assoc'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4827
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1694;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1694;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_225;
--# end
--# property-start PackageBodyStub._env_trans_parent_226 /tmp/lal-23.0.0/ada/ast.py:20691
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_226
  (Node : Bare_Package_Body_Stub
  )
   return Boolean
is
   Self : Bare_Package_Body_Stub := Bare_Package_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_226;
--# end
--# property-start PackageBodyStub._env_names_227 /tmp/lal-23.0.0/ada/ast.py:20693
pragma Warnings (Off, "is not referenced");
 function Env_Names_227
  (Node : Bare_Package_Body_Stub
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Package_Body_Stub := Bare_Package_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1696 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1696 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1696;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4828 '<FieldAccess for env_names at ast.py:20693>' Fld /tmp/lal-23.0.0/ada/ast.py:20693
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BodyStub.env_names
Fld := Libadalang.Implementation.Body_Stub_P_Env_Names (Node => Self);
--# end
--# expr-done 4828
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1696;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1696;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_227;
--# end
   --
   --  Primitives for Bare_Protected_Body_Stub
   --
      procedure Protected_Body_Stub_Pre_Env_Actions
        (Self            : Bare_Protected_Body_Stub;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_215 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20635");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_216 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_217 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Protected_Body_Stub
        (Self : Bare_Protected_Body_Stub
         ; Protected_Body_Stub_F_Name : Bare_Defining_Name
         ; Protected_Body_Stub_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Protected_Body_Stub_F_Name := Protected_Body_Stub_F_Name;
            Self.Protected_Body_Stub_F_Aspects := Protected_Body_Stub_F_Aspects;
      end Initialize_Fields_For_Protected_Body_Stub;
   function Protected_Body_Stub_F_Name
     (Node : Bare_Protected_Body_Stub) return Bare_Defining_Name
   is
   begin
         return Node.Protected_Body_Stub_F_Name;
   end;
--# property-start ProtectedBodyStub.defining_names /tmp/lal-23.0.0/ada/ast.py:20632
pragma Warnings (Off, "is not referenced");
 function Protected_Body_Stub_P_Defining_Names
  (Node : Bare_Protected_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Protected_Body_Stub := Bare_Protected_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Body_Stub :=
     Internal_Entity_Protected_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1450 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1450 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1450;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4829 '<FieldAccess for name at ast.py:20632>' Fld /tmp/lal-23.0.0/ada/ast.py:20632
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Protected_Body_Stub_F_Name, Info => Ent.Info);
--# expr-done 4829
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1450;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1450;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Body_Stub_P_Defining_Names;
--# end
--# property-start ProtectedBodyStub._env_mappings_215 /tmp/lal-23.0.0/ada/ast.py:20635
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_215
  (Node : Bare_Protected_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Protected_Body_Stub := Bare_Protected_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Body_Stub :=
     Internal_Entity_Protected_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1684 with Inline_Always;
      Fld : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1684 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1684;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4830 '<FieldAccess for previous_part_link_env_assoc at ast.py:20635>' Fld /tmp/lal-23.0.0/ada/ast.py:20635
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_link_env_assoc'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4830
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1684;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1684;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_215;
--# end
--# property-start ProtectedBodyStub._env_trans_parent_216 /tmp/lal-23.0.0/ada/ast.py:20634
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_216
  (Node : Bare_Protected_Body_Stub
  )
   return Boolean
is
   Self : Bare_Protected_Body_Stub := Bare_Protected_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_216;
--# end
--# property-start ProtectedBodyStub._env_names_217 /tmp/lal-23.0.0/ada/ast.py:20636
pragma Warnings (Off, "is not referenced");
 function Env_Names_217
  (Node : Bare_Protected_Body_Stub
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Protected_Body_Stub := Bare_Protected_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1686 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1686 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1686;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4831 '<FieldAccess for env_names at ast.py:20636>' Fld /tmp/lal-23.0.0/ada/ast.py:20636
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BodyStub.env_names
Fld := Libadalang.Implementation.Body_Stub_P_Env_Names (Node => Self);
--# end
--# expr-done 4831
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1686;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1686;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_217;
--# end
   --
   --  Primitives for Bare_Subp_Body_Stub
   --
      procedure Subp_Body_Stub_Pre_Env_Actions
        (Self            : Bare_Subp_Body_Stub;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_218 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20654");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_219 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_220 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      if Libadalang.Implementation.Ref_Cond_222 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_221 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Nested_Generic_Formal_Part'Access,
               Prioritary,
               All_Cats,
               True);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_224 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_223 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Use_Clauses_In_Generic_Formal_Part'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Subp_Body_Stub
        (Self : Bare_Subp_Body_Stub
         ; Subp_Body_Stub_F_Overriding : Bare_Overriding_Node
         ; Subp_Body_Stub_F_Subp_Spec : Bare_Subp_Spec
         ; Subp_Body_Stub_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Subp_Body_Stub_F_Overriding := Subp_Body_Stub_F_Overriding;
            Self.Subp_Body_Stub_F_Subp_Spec := Subp_Body_Stub_F_Subp_Spec;
            Self.Subp_Body_Stub_F_Aspects := Subp_Body_Stub_F_Aspects;
      end Initialize_Fields_For_Subp_Body_Stub;
   function Subp_Body_Stub_F_Overriding
     (Node : Bare_Subp_Body_Stub) return Bare_Overriding_Node
   is
   begin
         return Node.Subp_Body_Stub_F_Overriding;
   end;
   function Subp_Body_Stub_F_Subp_Spec
     (Node : Bare_Subp_Body_Stub) return Bare_Subp_Spec
   is
   begin
         return Node.Subp_Body_Stub_F_Subp_Spec;
   end;
--# property-start SubpBodyStub.defining_names /tmp/lal-23.0.0/ada/ast.py:20649
pragma Warnings (Off, "is not referenced");
 function Subp_Body_Stub_P_Defining_Names
  (Node : Bare_Subp_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Body_Stub :=
     Internal_Entity_Subp_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1451 with Inline_Always;
      Fld : Internal_Entity_Subp_Spec;
Fld_1 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1451 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1451;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4833 '<FieldAccess for name at ast.py:20649>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20649
--# expr-start 4832 '<FieldAccess for subp_spec at ast.py:20649>' Fld /tmp/lal-23.0.0/ada/ast.py:20649
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Subp_Body_Stub_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4832
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4833
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_1;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1451;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1451;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Body_Stub_P_Defining_Names;
--# end
--# property-start SubpBodyStub.type_expression /tmp/lal-23.0.0/ada/ast.py:20678
pragma Warnings (Off, "is not referenced");
 function Subp_Body_Stub_P_Type_Expression
  (Node : Bare_Subp_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subp_Body_Stub :=
     Internal_Entity_Subp_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Subp_Spec;
Fld_1 : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4835 '<FieldAccess for returns at ast.py:20678>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20678
--# expr-start 4834 '<FieldAccess for subp_spec at ast.py:20678>' Fld /tmp/lal-23.0.0/ada/ast.py:20678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Subp_Body_Stub_F_Subp_Spec, Info => Ent.Info);
--# expr-done 4834
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 4835
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subp_Body_Stub_P_Type_Expression;
--# end
--# property-start SubpBodyStub._env_mappings_218 /tmp/lal-23.0.0/ada/ast.py:20654
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_218
  (Node : Bare_Subp_Body_Stub
  )
   return Internal_Env_Assoc
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1687 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Subp_Body_Stub;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1687 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1687;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4838 '<New EnvAssoc at ast.py:20654>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:20654
--# expr-start 4836 '<New DesignatedEnv at ast.py:20654>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20654
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4836
--# expr-start 4837 '<FieldAccess for name_symbol at ast.py:20655>' Fld /tmp/lal-23.0.0/ada/ast.py:20655
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 4837
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4838
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1687;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1687;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_218;
--# end
--# property-start SubpBodyStub._env_trans_parent_219 /tmp/lal-23.0.0/ada/ast.py:20653
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_219
  (Node : Bare_Subp_Body_Stub
  )
   return Boolean
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_219;
--# end
--# property-start SubpBodyStub._env_names_220 /tmp/lal-23.0.0/ada/ast.py:20658
pragma Warnings (Off, "is not referenced");
 function Env_Names_220
  (Node : Bare_Subp_Body_Stub
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1689 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1689 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1689;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4839 '<FieldAccess for env_names at ast.py:20658>' Fld /tmp/lal-23.0.0/ada/ast.py:20658
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BodyStub.env_names
Fld := Libadalang.Implementation.Body_Stub_P_Env_Names (Node => Self);
--# end
--# expr-done 4839
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1689;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1689;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_220;
--# end
--# property-start SubpBodyStub._ref_env_nodes_221 /tmp/lal-23.0.0/ada/ast.py:20661
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_221
  (Node : Bare_Subp_Body_Stub
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1690 with Inline_Always;
            procedure Finalizer_Scope_2500 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Subp_Body_Stub;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1690 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1690;
            procedure Finalizer_Scope_2500 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2500;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4840 '<Cast to AdaNode at ast.py:20661>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20661
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4840
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2500;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1690;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1690;
               Finalizer_Scope_2500;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_221;
--# end
--# property-start SubpBodyStub._ref_cond_222 /tmp/lal-23.0.0/ada/ast.py:20663
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_222
  (Node : Bare_Subp_Body_Stub
  )
   return Boolean
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4841 '<FieldAccess for should_ref_generic_formals at ast.py:20663>' Fld /tmp/lal-23.0.0/ada/ast.py:20663
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4841
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_222;
--# end
--# property-start SubpBodyStub._ref_env_nodes_223 /tmp/lal-23.0.0/ada/ast.py:20671
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_223
  (Node : Bare_Subp_Body_Stub
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1692 with Inline_Always;
            procedure Finalizer_Scope_2501 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Subp_Body_Stub;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1692 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1692;
            procedure Finalizer_Scope_2501 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2501;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4842 '<Cast to AdaNode at ast.py:20671>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20671
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4842
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2501;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1692;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1692;
               Finalizer_Scope_2501;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_223;
--# end
--# property-start SubpBodyStub._ref_cond_224 /tmp/lal-23.0.0/ada/ast.py:20673
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_224
  (Node : Bare_Subp_Body_Stub
  )
   return Boolean
is
   Self : Bare_Subp_Body_Stub := Bare_Subp_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4843 '<FieldAccess for should_ref_generic_formals at ast.py:20673>' Fld /tmp/lal-23.0.0/ada/ast.py:20673
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4843
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_224;
--# end
   --
   --  Primitives for Bare_Task_Body_Stub
   --
      procedure Task_Body_Stub_Pre_Env_Actions
        (Self            : Bare_Task_Body_Stub;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_228 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20708");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_229 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_230 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Task_Body_Stub
        (Self : Bare_Task_Body_Stub
         ; Task_Body_Stub_F_Name : Bare_Defining_Name
         ; Task_Body_Stub_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Task_Body_Stub_F_Name := Task_Body_Stub_F_Name;
            Self.Task_Body_Stub_F_Aspects := Task_Body_Stub_F_Aspects;
      end Initialize_Fields_For_Task_Body_Stub;
   function Task_Body_Stub_F_Name
     (Node : Bare_Task_Body_Stub) return Bare_Defining_Name
   is
   begin
         return Node.Task_Body_Stub_F_Name;
   end;
--# property-start TaskBodyStub.defining_names /tmp/lal-23.0.0/ada/ast.py:20705
pragma Warnings (Off, "is not referenced");
 function Task_Body_Stub_P_Defining_Names
  (Node : Bare_Task_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Task_Body_Stub := Bare_Task_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body_Stub :=
     Internal_Entity_Task_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1454 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1454 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1454;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4844 '<FieldAccess for name at ast.py:20705>' Fld /tmp/lal-23.0.0/ada/ast.py:20705
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Task_Body_Stub_F_Name, Info => Ent.Info);
--# expr-done 4844
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1454;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1454;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Body_Stub_P_Defining_Names;
--# end
--# property-start TaskBodyStub._env_mappings_228 /tmp/lal-23.0.0/ada/ast.py:20708
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_228
  (Node : Bare_Task_Body_Stub
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Task_Body_Stub := Bare_Task_Body_Stub (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body_Stub :=
     Internal_Entity_Task_Body_Stub'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1697 with Inline_Always;
      Fld : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1697 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1697;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4845 '<FieldAccess for previous_part_link_env_assoc at ast.py:20708>' Fld /tmp/lal-23.0.0/ada/ast.py:20708
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_link_env_assoc'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4845
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1697;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1697;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_228;
--# end
--# property-start TaskBodyStub._env_trans_parent_229 /tmp/lal-23.0.0/ada/ast.py:20707
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_229
  (Node : Bare_Task_Body_Stub
  )
   return Boolean
is
   Self : Bare_Task_Body_Stub := Bare_Task_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_229;
--# end
--# property-start TaskBodyStub._env_names_230 /tmp/lal-23.0.0/ada/ast.py:20709
pragma Warnings (Off, "is not referenced");
 function Env_Names_230
  (Node : Bare_Task_Body_Stub
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Task_Body_Stub := Bare_Task_Body_Stub (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1699 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1699 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1699;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4846 '<FieldAccess for env_names at ast.py:20709>' Fld /tmp/lal-23.0.0/ada/ast.py:20709
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BodyStub.env_names
Fld := Libadalang.Implementation.Body_Stub_P_Env_Names (Node => Self);
--# end
--# expr-done 4846
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1699;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1699;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_230;
--# end
   --
   --  Primitives for Bare_Entry_Body
   --
      procedure Entry_Body_Pre_Env_Actions
        (Self            : Bare_Entry_Body;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_210 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_211 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:20530");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_212 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20540");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_213 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Entry_Body
        (Self : Bare_Entry_Body
         ; Entry_Body_F_Entry_Name : Bare_Defining_Name
         ; Entry_Body_F_Index_Spec : Bare_Entry_Index_Spec
         ; Entry_Body_F_Params : Bare_Entry_Completion_Formal_Params
         ; Entry_Body_F_Aspects : Bare_Aspect_Spec
         ; Entry_Body_F_Barrier : Bare_Expr
         ; Entry_Body_F_Decls : Bare_Declarative_Part
         ; Entry_Body_F_Stmts : Bare_Handled_Stmts
         ; Entry_Body_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Entry_Body_F_Entry_Name := Entry_Body_F_Entry_Name;
            Self.Entry_Body_F_Index_Spec := Entry_Body_F_Index_Spec;
            Self.Entry_Body_F_Params := Entry_Body_F_Params;
            Self.Entry_Body_F_Aspects := Entry_Body_F_Aspects;
            Self.Entry_Body_F_Barrier := Entry_Body_F_Barrier;
            Self.Entry_Body_F_Decls := Entry_Body_F_Decls;
            Self.Entry_Body_F_Stmts := Entry_Body_F_Stmts;
            Self.Entry_Body_F_End_Name := Entry_Body_F_End_Name;
      end Initialize_Fields_For_Entry_Body;
   function Entry_Body_F_Entry_Name
     (Node : Bare_Entry_Body) return Bare_Defining_Name
   is
   begin
         return Node.Entry_Body_F_Entry_Name;
   end;
   function Entry_Body_F_Index_Spec
     (Node : Bare_Entry_Body) return Bare_Entry_Index_Spec
   is
   begin
         return Node.Entry_Body_F_Index_Spec;
   end;
   function Entry_Body_F_Params
     (Node : Bare_Entry_Body) return Bare_Entry_Completion_Formal_Params
   is
   begin
         return Node.Entry_Body_F_Params;
   end;
   function Entry_Body_F_Barrier
     (Node : Bare_Entry_Body) return Bare_Expr
   is
   begin
         return Node.Entry_Body_F_Barrier;
   end;
   function Entry_Body_F_Decls
     (Node : Bare_Entry_Body) return Bare_Declarative_Part
   is
   begin
         return Node.Entry_Body_F_Decls;
   end;
   function Entry_Body_F_Stmts
     (Node : Bare_Entry_Body) return Bare_Handled_Stmts
   is
   begin
         return Node.Entry_Body_F_Stmts;
   end;
   function Entry_Body_F_End_Name
     (Node : Bare_Entry_Body) return Bare_End_Name
   is
   begin
         return Node.Entry_Body_F_End_Name;
   end;
--# property-start EntryBody.defining_names /tmp/lal-23.0.0/ada/ast.py:20523
pragma Warnings (Off, "is not referenced");
 function Entry_Body_P_Defining_Names
  (Node : Bare_Entry_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Body :=
     Internal_Entity_Entry_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1436 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1436 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1436;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4847 '<FieldAccess for entry_name at ast.py:20523>' Fld /tmp/lal-23.0.0/ada/ast.py:20523
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Entry_Body_F_Entry_Name, Info => Ent.Info);
--# expr-done 4847
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1436;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1436;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Body_P_Defining_Names;
--# end
--# property-start EntryBody.declarative_parts /tmp/lal-23.0.0/ada/ast.py:20525
pragma Warnings (Off, "is not referenced");
 function Entry_Body_P_Declarative_Parts
  (Node : Bare_Entry_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Body :=
     Internal_Entity_Entry_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1437 with Inline_Always;
      Fld : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1437 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1437;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4848 '<FieldAccess for decls at ast.py:20525>' Fld /tmp/lal-23.0.0/ada/ast.py:20525
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Declarative_Part (Node => Ent.Node.Entry_Body_F_Decls, Info => Ent.Info);
--# expr-done 4848
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1437;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1437;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Body_P_Declarative_Parts;
--# end
--# property-start EntryBody.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:20547
pragma Warnings (Off, "is not referenced");
 function Entry_Body_P_Xref_Entry_Point
  (Node : Bare_Entry_Body
  )
   return Boolean
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Body_P_Xref_Entry_Point;
--# end
--# property-start EntryBody.xref_equation /tmp/lal-23.0.0/ada/ast.py:20550
pragma Warnings (Off, "is not referenced");
 function Entry_Body_P_Xref_Equation
  (Node : Bare_Entry_Body
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Body :=
     Internal_Entity_Entry_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1439 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1439 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1439;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4859 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4858 '<And at ast.py:20551>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:20551
--# expr-start 4855 '<And at ast.py:20551>' And_Pred /tmp/lal-23.0.0/ada/ast.py:20551
--# expr-start 4852 '<Bind at ast.py:20552>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:20552
--# expr-start 4850 '<FieldAccess for expected_type_var at ast.py:20552>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20552
--# expr-start 4849 '<FieldAccess for barrier at ast.py:20552>' Fld /tmp/lal-23.0.0/ada/ast.py:20552
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Entry_Body_F_Barrier;
--# expr-done 4849
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 4850
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 4851 '<FieldAccess for bool_type at ast.py:20552>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20552
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 4851
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20552") else null)); 
--# expr-done 4852
--# expr-start 4854 '<FieldAccess for sub_equation at ast.py:20553>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20553
--# expr-start 4853 '<FieldAccess for barrier at ast.py:20553>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20553
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Entry_Body_F_Barrier, Info => Ent.Info);
--# expr-done 4853
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 4854
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20551") else null)); 
--# expr-done 4855
--# expr-start 4857 '<FieldAccess for matches_expected_formal_prim_type at ast.py:20554>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:20554
--# expr-start 4856 '<FieldAccess for barrier at ast.py:20554>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:20554
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Entry_Body_F_Barrier, Info => Ent.Info);
--# expr-done 4856
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 4857
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20551") else null)); 
--# expr-done 4858
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 4859
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1439;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1439;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Body_P_Xref_Equation;
--# end
--# property-start EntryBody._env_do_210 /tmp/lal-23.0.0/ada/ast.py:20528
pragma Warnings (Off, "is not referenced");
 function Env_Do_210
  (Node : Bare_Entry_Body
  )
   return Boolean
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4860 '<FieldAccess for env_hook at ast.py:20528>' Fld /tmp/lal-23.0.0/ada/ast.py:20528
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 4860
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_210;
--# end
--# property-start EntryBody._initial_env_211 /tmp/lal-23.0.0/ada/ast.py:20531
pragma Warnings (Off, "is not referenced");
 function Initial_Env_211
  (Node : Bare_Entry_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Designated_Env
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Body :=
     Internal_Entity_Entry_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1680 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
New_Struct : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1680 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_1680;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4864 '<New DesignatedEnv at ast.py:20531>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20531
--# expr-start 4863 '<bind at ast.py:20532>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:20532
--# expr-start 4861 '<FieldAccess for default_initial_env at ast.py:20533>' Fld /tmp/lal-23.0.0/ada/ast.py:20533
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 4861
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 4862 '<FieldAccess for body_scope at ast.py:20534>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20534
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_scope
Fld_1 := Libadalang.Implementation.Body_Node_P_Body_Scope (Node => Ent.Node, Follow_Private => False, Env => Bound_Env, E_Info => Ent.Info);
--# end
--# expr-done 4862
Dyn_Var_Bind_Result := Fld_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 4863
Inc_Ref (Dyn_Var_Bind_Result);
New_Struct := (Direct_Env => Dyn_Var_Bind_Result, Env_Name => null, Kind => Direct_Env); 
--# expr-done 4864
      Property_Result := New_Struct;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1680;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1680;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_211;
--# end
--# property-start EntryBody._env_mappings_212 /tmp/lal-23.0.0/ada/ast.py:20541
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_212
  (Node : Bare_Entry_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Body :=
     Internal_Entity_Entry_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1681 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Entry_Body;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Singleton : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1681 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1681;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4867 '<New EnvAssoc at ast.py:20541>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:20541
--# expr-start 4865 '<New DesignatedEnv at ast.py:20541>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20541
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4865
--# expr-start 4866 '<FieldAccess for name_symbol at ast.py:20541>' Fld /tmp/lal-23.0.0/ada/ast.py:20541
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4866
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4867
                Singleton := Create_Internal_Env_Assoc_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct_1;
                Inc_Ref (Singleton.Items (1));
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1681;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1681;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_212;
--# end
--# property-start EntryBody._env_trans_parent_213 /tmp/lal-23.0.0/ada/ast.py:20527
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_213
  (Node : Bare_Entry_Body
  )
   return Boolean
is
   Self : Bare_Entry_Body := Bare_Entry_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_213;
--# end
   --
   --  Primitives for Bare_Package_Body
   --
      procedure Package_Body_Pre_Env_Actions
        (Self            : Bare_Package_Body;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_159 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_160 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:20270");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_161 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20272");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_162 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_163 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_165 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_164 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_167 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_166 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_169 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_168 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Nested_Generic_Formal_Part'Access,
               Prioritary,
               All_Cats,
               True);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_171 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_170 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Use_Clauses_In_Generic_Formal_Part'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_173 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_172 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Body_Node_P_Subunit_Decl_Env'Access,
               Prioritary,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_175 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_174 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Body_Node_P_Body_Decl_Scope'Access,
               Prioritary,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_177 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_176 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Package_Body_P_Package_Decl_Uses_Clauses_Envs'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Package_Body
        (Self : Bare_Package_Body
         ; Package_Body_F_Package_Name : Bare_Defining_Name
         ; Package_Body_F_Aspects : Bare_Aspect_Spec
         ; Package_Body_F_Decls : Bare_Declarative_Part
         ; Package_Body_F_Stmts : Bare_Handled_Stmts
         ; Package_Body_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Package_Body_F_Package_Name := Package_Body_F_Package_Name;
            Self.Package_Body_F_Aspects := Package_Body_F_Aspects;
            Self.Package_Body_F_Decls := Package_Body_F_Decls;
            Self.Package_Body_F_Stmts := Package_Body_F_Stmts;
            Self.Package_Body_F_End_Name := Package_Body_F_End_Name;
      end Initialize_Fields_For_Package_Body;
   function Package_Body_F_Package_Name
     (Node : Bare_Package_Body) return Bare_Defining_Name
   is
   begin
         return Node.Package_Body_F_Package_Name;
   end;
   function Package_Body_F_Decls
     (Node : Bare_Package_Body) return Bare_Declarative_Part
   is
   begin
         return Node.Package_Body_F_Decls;
   end;
   function Package_Body_F_Stmts
     (Node : Bare_Package_Body) return Bare_Handled_Stmts
   is
   begin
         return Node.Package_Body_F_Stmts;
   end;
   function Package_Body_F_End_Name
     (Node : Bare_Package_Body) return Bare_End_Name
   is
   begin
         return Node.Package_Body_F_End_Name;
   end;
--# property-start PackageBody.defining_names /tmp/lal-23.0.0/ada/ast.py:20348
pragma Warnings (Off, "is not referenced");
 function Package_Body_P_Defining_Names
  (Node : Bare_Package_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body :=
     Internal_Entity_Package_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1426 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1426 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1426;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4868 '<FieldAccess for package_name at ast.py:20348>' Fld /tmp/lal-23.0.0/ada/ast.py:20348
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Package_Body_F_Package_Name, Info => Ent.Info);
--# expr-done 4868
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1426;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1426;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Body_P_Defining_Names;
--# end
--# property-start PackageBody.defining_env /tmp/lal-23.0.0/ada/ast.py:20349
pragma Warnings (Off, "is not referenced");
 function Package_Body_P_Defining_Env
  (Node : Bare_Package_Body
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body :=
     Internal_Entity_Package_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1427 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1427 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1427;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4869 '<FieldAccess for children_env at ast.py:20349>' Fld /tmp/lal-23.0.0/ada/ast.py:20349
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 4869
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1427;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1427;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Body_P_Defining_Env;
--# end
--# property-start PackageBody.declarative_parts /tmp/lal-23.0.0/ada/ast.py:20351
pragma Warnings (Off, "is not referenced");
 function Package_Body_P_Declarative_Parts
  (Node : Bare_Package_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body :=
     Internal_Entity_Package_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1428 with Inline_Always;
      Fld : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1428 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1428;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4870 '<FieldAccess for decls at ast.py:20351>' Fld /tmp/lal-23.0.0/ada/ast.py:20351
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Declarative_Part (Node => Ent.Node.Package_Body_F_Decls, Info => Ent.Info);
--# expr-done 4870
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1428;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1428;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Body_P_Declarative_Parts;
--# end
--# property-start PackageBody.package_decl_uses_clauses_envs /tmp/lal-23.0.0/ada/ast.py:20354
pragma Warnings (Off, "is not referenced");
 function Package_Body_P_Package_Decl_Uses_Clauses_Envs
  (Node : Bare_Package_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body :=
     Internal_Entity_Package_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1429 with Inline_Always;
            procedure Finalizer_Scope_2503 with Inline_Always;
      Block_Var : Internal_Entity_Base_Package_Decl;
Var_Expr : Internal_Entity_Private_Part;
Bound_Imprecise_Fallback : Boolean;
Fld : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Base_Package_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Package_Decl;
Fld_1 : Internal_Entity_Public_Part;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Internal_Entity_Private_Part;
Fld_4 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1429 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1429;
            procedure Finalizer_Scope_2503 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2503;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4880 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4873 '<bind at ast.py:20359>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:20359
Bound_Imprecise_Fallback := False; 
--# expr-start 4872 '<Cast to BasePackageDecl at ast.py:20360>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20360
--# expr-start 4871 '<FieldAccess for decl_part at ast.py:20360>' Fld /tmp/lal-23.0.0/ada/ast.py:20360
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Ent.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4871
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Package_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Package_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4872
Dyn_Var_Bind_Result := Cast_Result; 
--# expr-done 4873
Block_Var := Dyn_Var_Bind_Result; 
--# bind pd Block_Var
--# expr-start 4879 '<env_group at ast.py:20364>' Group_Env /tmp/lal-23.0.0/ada/ast.py:20364
--# expr-start 4878 '<ArrayLiteral at ast.py:20363>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:20363
--# expr-start 4875 '<FieldAccess for use_clauses_envs at ast.py:20363>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20363
--# expr-start 4874 '<FieldAccess for public_part at ast.py:20363>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20363
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Public_Part (Node => Block_Var.Node.Base_Package_Decl_F_Public_Part, Info => Block_Var.Info);
--# expr-done 4874
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DeclarativePart.use_clauses_envs
Fld_2 := Libadalang.Implementation.Declarative_Part_P_Use_Clauses_Envs (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 4875
--# expr-start 4876 '<FieldAccess for private_part at ast.py:20364>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20364
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Private_Part (Node => Block_Var.Node.Base_Package_Decl_F_Private_Part, Info => Block_Var.Info);
--# expr-done 4876
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Private_Part then
   --# scope-start
--# expr-start 4877 '<FieldAccess for use_clauses_envs at ast.py:20364>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20364
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DeclarativePart.use_clauses_envs
Fld_4 := Libadalang.Implementation.Declarative_Part_P_Use_Clauses_Envs (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 4877
Scope_Result := Fld_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2503;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld_2, 2 => Result_Var)); 
--# expr-done 4878
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 4879
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 4880
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1429;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1429;
               Finalizer_Scope_2503;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Body_P_Package_Decl_Uses_Clauses_Envs;
--# end
--# property-start PackageBody._env_do_159 /tmp/lal-23.0.0/ada/ast.py:20267
pragma Warnings (Off, "is not referenced");
 function Env_Do_159
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4881 '<FieldAccess for env_hook at ast.py:20267>' Fld /tmp/lal-23.0.0/ada/ast.py:20267
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 4881
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_159;
--# end
--# property-start PackageBody._initial_env_160 /tmp/lal-23.0.0/ada/ast.py:20270
pragma Warnings (Off, "is not referenced");
 function Initial_Env_160
  (Node : Bare_Package_Body
  )
   return Internal_Designated_Env
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1629 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1629 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1629;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4882 '<FieldAccess for body_initial_env at ast.py:20270>' Fld /tmp/lal-23.0.0/ada/ast.py:20270
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_initial_env
Fld := Libadalang.Implementation.Body_Node_P_Body_Initial_Env (Node => Self);
--# end
--# expr-done 4882
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1629;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1629;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_160;
--# end
--# property-start PackageBody._env_mappings_161 /tmp/lal-23.0.0/ada/ast.py:20272
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_161
  (Node : Bare_Package_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Body :=
     Internal_Entity_Package_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1630 with Inline_Always;
      Fld : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1630 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1630;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4883 '<FieldAccess for previous_part_link_env_assoc at ast.py:20272>' Fld /tmp/lal-23.0.0/ada/ast.py:20272
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_link_env_assoc'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4883
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1630;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1630;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_161;
--# end
--# property-start PackageBody._env_trans_parent_162 /tmp/lal-23.0.0/ada/ast.py:20276
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_162
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4884 '<FieldAccess for is_library_item at ast.py:20276>' Fld /tmp/lal-23.0.0/ada/ast.py:20276
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 4884
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_162;
--# end
--# property-start PackageBody._env_do_163 /tmp/lal-23.0.0/ada/ast.py:20278
pragma Warnings (Off, "is not referenced");
 function Env_Do_163
  (Node : Bare_Package_Body
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1632 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1632 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1632;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4885 '<FieldAccess for populate_dependent_units at ast.py:20278>' Fld /tmp/lal-23.0.0/ada/ast.py:20278
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 4885
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1632;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1632;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_163;
--# end
--# property-start PackageBody._ref_env_nodes_164 /tmp/lal-23.0.0/ada/ast.py:20281
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_164
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1633 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1633 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1633;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4886 '<FieldAccess for top_level_use_package_clauses at ast.py:20281>' Fld /tmp/lal-23.0.0/ada/ast.py:20281
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 4886
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1633;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1633;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_164;
--# end
--# property-start PackageBody._ref_cond_165 /tmp/lal-23.0.0/ada/ast.py:20283
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_165
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4888 '<IsA LibraryItem, Subunit at ast.py:20283>' Is_A /tmp/lal-23.0.0/ada/ast.py:20283
--# expr-start 4887 '<parent at ast.py:20283>' Fld /tmp/lal-23.0.0/ada/ast.py:20283
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4887
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4888
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_165;
--# end
--# property-start PackageBody._ref_env_nodes_166 /tmp/lal-23.0.0/ada/ast.py:20287
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_166
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1635 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1635 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1635;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4889 '<FieldAccess for top_level_use_type_clauses at ast.py:20287>' Fld /tmp/lal-23.0.0/ada/ast.py:20287
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 4889
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1635;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1635;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_166;
--# end
--# property-start PackageBody._ref_cond_167 /tmp/lal-23.0.0/ada/ast.py:20289
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_167
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4891 '<IsA LibraryItem, Subunit at ast.py:20289>' Is_A /tmp/lal-23.0.0/ada/ast.py:20289
--# expr-start 4890 '<parent at ast.py:20289>' Fld /tmp/lal-23.0.0/ada/ast.py:20289
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4890
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4891
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_167;
--# end
--# property-start PackageBody._ref_env_nodes_168 /tmp/lal-23.0.0/ada/ast.py:20293
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_168
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1637 with Inline_Always;
            procedure Finalizer_Scope_2504 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Package_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1637 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1637;
            procedure Finalizer_Scope_2504 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2504;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4892 '<Cast to AdaNode at ast.py:20293>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20293
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4892
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2504;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1637;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1637;
               Finalizer_Scope_2504;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_168;
--# end
--# property-start PackageBody._ref_cond_169 /tmp/lal-23.0.0/ada/ast.py:20295
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_169
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4893 '<FieldAccess for should_ref_generic_formals at ast.py:20295>' Fld /tmp/lal-23.0.0/ada/ast.py:20295
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4893
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_169;
--# end
--# property-start PackageBody._ref_env_nodes_170 /tmp/lal-23.0.0/ada/ast.py:20303
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_170
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1639 with Inline_Always;
            procedure Finalizer_Scope_2505 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Package_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1639 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1639;
            procedure Finalizer_Scope_2505 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2505;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4894 '<Cast to AdaNode at ast.py:20303>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20303
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4894
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2505;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1639;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1639;
               Finalizer_Scope_2505;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_170;
--# end
--# property-start PackageBody._ref_cond_171 /tmp/lal-23.0.0/ada/ast.py:20305
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_171
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4895 '<FieldAccess for should_ref_generic_formals at ast.py:20305>' Fld /tmp/lal-23.0.0/ada/ast.py:20305
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4895
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_171;
--# end
--# property-start PackageBody._ref_env_nodes_172 /tmp/lal-23.0.0/ada/ast.py:20316
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_172
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1641 with Inline_Always;
      Cast_Expr : Bare_Package_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1641 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1641;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4896 '<Cast to AdaNode at ast.py:20316>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20316
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4896
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1641;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1641;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_172;
--# end
--# property-start PackageBody._ref_cond_173 /tmp/lal-23.0.0/ada/ast.py:20318
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_173
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4897 '<FieldAccess for is_subunit at ast.py:20318>' Fld /tmp/lal-23.0.0/ada/ast.py:20318
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Self);
--# end
--# expr-done 4897
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_173;
--# end
--# property-start PackageBody._ref_env_nodes_174 /tmp/lal-23.0.0/ada/ast.py:20330
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_174
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1643 with Inline_Always;
      Cast_Expr : Bare_Package_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1643 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1643;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4898 '<Cast to AdaNode at ast.py:20330>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20330
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4898
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1643;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1643;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_174;
--# end
--# property-start PackageBody._ref_cond_175 /tmp/lal-23.0.0/ada/ast.py:20332
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_175
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4900 '<Not at ast.py:20332>' Not_Val /tmp/lal-23.0.0/ada/ast.py:20332
--# expr-start 4899 '<FieldAccess for is_compilation_unit_root at ast.py:20332>' Fld /tmp/lal-23.0.0/ada/ast.py:20332
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 4899
Not_Val := not (Fld); 
--# expr-done 4900
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_175;
--# end
--# property-start PackageBody._ref_env_nodes_176 /tmp/lal-23.0.0/ada/ast.py:20337
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_176
  (Node : Bare_Package_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1645 with Inline_Always;
      Cast_Expr : Bare_Package_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1645 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1645;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4901 '<Cast to AdaNode at ast.py:20337>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20337
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4901
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1645;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1645;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_176;
--# end
--# property-start PackageBody._ref_cond_177 /tmp/lal-23.0.0/ada/ast.py:20339
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_177
  (Node : Bare_Package_Body
  )
   return Boolean
is
   Self : Bare_Package_Body := Bare_Package_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4903 '<Not at ast.py:20339>' Not_Val /tmp/lal-23.0.0/ada/ast.py:20339
--# expr-start 4902 '<FieldAccess for is_compilation_unit_root at ast.py:20339>' Fld /tmp/lal-23.0.0/ada/ast.py:20339
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_compilation_unit_root
Fld := Libadalang.Implementation.Basic_Decl_P_Is_Compilation_Unit_Root (Node => Self);
--# end
--# expr-done 4902
Not_Val := not (Fld); 
--# expr-done 4903
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_177;
--# end
function Package_Body_P_Package_Decl_Uses_Clauses_Envs
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Package_Body_P_Package_Decl_Uses_Clauses_Envs (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Protected_Body
   --
      procedure Protected_Body_Pre_Env_Actions
        (Self            : Bare_Protected_Body;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_194 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_195 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:20452");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_196 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20454");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_197 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_198 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_200 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_199 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_202 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_201 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_204 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_203 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Nested_Generic_Formal_Part'Access,
               Prioritary,
               All_Cats,
               True);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_206 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_205 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Use_Clauses_In_Generic_Formal_Part'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_207 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Body_Node_P_Body_Decl_Scope'Access,
               Prioritary,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      if Libadalang.Implementation.Ref_Cond_209 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_208 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Body_Node_P_Subunit_Decl_Env'Access,
               Prioritary,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Protected_Body
        (Self : Bare_Protected_Body
         ; Protected_Body_F_Name : Bare_Defining_Name
         ; Protected_Body_F_Aspects : Bare_Aspect_Spec
         ; Protected_Body_F_Decls : Bare_Declarative_Part
         ; Protected_Body_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Protected_Body_F_Name := Protected_Body_F_Name;
            Self.Protected_Body_F_Aspects := Protected_Body_F_Aspects;
            Self.Protected_Body_F_Decls := Protected_Body_F_Decls;
            Self.Protected_Body_F_End_Name := Protected_Body_F_End_Name;
      end Initialize_Fields_For_Protected_Body;
   function Protected_Body_F_Name
     (Node : Bare_Protected_Body) return Bare_Defining_Name
   is
   begin
         return Node.Protected_Body_F_Name;
   end;
   function Protected_Body_F_Decls
     (Node : Bare_Protected_Body) return Bare_Declarative_Part
   is
   begin
         return Node.Protected_Body_F_Decls;
   end;
   function Protected_Body_F_End_Name
     (Node : Bare_Protected_Body) return Bare_End_Name
   is
   begin
         return Node.Protected_Body_F_End_Name;
   end;
--# property-start ProtectedBody.defining_names /tmp/lal-23.0.0/ada/ast.py:20503
pragma Warnings (Off, "is not referenced");
 function Protected_Body_P_Defining_Names
  (Node : Bare_Protected_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Body :=
     Internal_Entity_Protected_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1434 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1434 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1434;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4904 '<FieldAccess for name at ast.py:20503>' Fld /tmp/lal-23.0.0/ada/ast.py:20503
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Protected_Body_F_Name, Info => Ent.Info);
--# expr-done 4904
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1434;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1434;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Body_P_Defining_Names;
--# end
--# property-start ProtectedBody.declarative_parts /tmp/lal-23.0.0/ada/ast.py:20505
pragma Warnings (Off, "is not referenced");
 function Protected_Body_P_Declarative_Parts
  (Node : Bare_Protected_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Body :=
     Internal_Entity_Protected_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1435 with Inline_Always;
      Fld : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1435 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1435;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4905 '<FieldAccess for decls at ast.py:20505>' Fld /tmp/lal-23.0.0/ada/ast.py:20505
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Declarative_Part (Node => Ent.Node.Protected_Body_F_Decls, Info => Ent.Info);
--# expr-done 4905
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1435;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1435;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Body_P_Declarative_Parts;
--# end
--# property-start ProtectedBody._env_do_194 /tmp/lal-23.0.0/ada/ast.py:20450
pragma Warnings (Off, "is not referenced");
 function Env_Do_194
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4906 '<FieldAccess for env_hook at ast.py:20450>' Fld /tmp/lal-23.0.0/ada/ast.py:20450
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 4906
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_194;
--# end
--# property-start ProtectedBody._initial_env_195 /tmp/lal-23.0.0/ada/ast.py:20452
pragma Warnings (Off, "is not referenced");
 function Initial_Env_195
  (Node : Bare_Protected_Body
  )
   return Internal_Designated_Env
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1664 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1664 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1664;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4907 '<FieldAccess for body_initial_env at ast.py:20452>' Fld /tmp/lal-23.0.0/ada/ast.py:20452
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_initial_env
Fld := Libadalang.Implementation.Body_Node_P_Body_Initial_Env (Node => Self);
--# end
--# expr-done 4907
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1664;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1664;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_195;
--# end
--# property-start ProtectedBody._env_mappings_196 /tmp/lal-23.0.0/ada/ast.py:20454
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_196
  (Node : Bare_Protected_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Protected_Body :=
     Internal_Entity_Protected_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1665 with Inline_Always;
      Fld : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1665 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1665;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4908 '<FieldAccess for previous_part_link_env_assoc at ast.py:20454>' Fld /tmp/lal-23.0.0/ada/ast.py:20454
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_link_env_assoc'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4908
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1665;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1665;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_196;
--# end
--# property-start ProtectedBody._env_trans_parent_197 /tmp/lal-23.0.0/ada/ast.py:20449
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_197
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_197;
--# end
--# property-start ProtectedBody._env_do_198 /tmp/lal-23.0.0/ada/ast.py:20458
pragma Warnings (Off, "is not referenced");
 function Env_Do_198
  (Node : Bare_Protected_Body
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1667 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1667 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1667;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4909 '<FieldAccess for populate_dependent_units at ast.py:20458>' Fld /tmp/lal-23.0.0/ada/ast.py:20458
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 4909
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1667;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1667;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_198;
--# end
--# property-start ProtectedBody._ref_env_nodes_199 /tmp/lal-23.0.0/ada/ast.py:20461
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_199
  (Node : Bare_Protected_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1668 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1668 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1668;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4910 '<FieldAccess for top_level_use_package_clauses at ast.py:20461>' Fld /tmp/lal-23.0.0/ada/ast.py:20461
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 4910
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1668;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1668;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_199;
--# end
--# property-start ProtectedBody._ref_cond_200 /tmp/lal-23.0.0/ada/ast.py:20463
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_200
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4912 '<IsA LibraryItem, Subunit at ast.py:20463>' Is_A /tmp/lal-23.0.0/ada/ast.py:20463
--# expr-start 4911 '<parent at ast.py:20463>' Fld /tmp/lal-23.0.0/ada/ast.py:20463
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4911
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4912
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_200;
--# end
--# property-start ProtectedBody._ref_env_nodes_201 /tmp/lal-23.0.0/ada/ast.py:20466
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_201
  (Node : Bare_Protected_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1670 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1670 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1670;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4913 '<FieldAccess for top_level_use_type_clauses at ast.py:20466>' Fld /tmp/lal-23.0.0/ada/ast.py:20466
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 4913
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1670;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1670;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_201;
--# end
--# property-start ProtectedBody._ref_cond_202 /tmp/lal-23.0.0/ada/ast.py:20468
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_202
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4915 '<IsA LibraryItem, Subunit at ast.py:20468>' Is_A /tmp/lal-23.0.0/ada/ast.py:20468
--# expr-start 4914 '<parent at ast.py:20468>' Fld /tmp/lal-23.0.0/ada/ast.py:20468
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4914
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4915
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_202;
--# end
--# property-start ProtectedBody._ref_env_nodes_203 /tmp/lal-23.0.0/ada/ast.py:20471
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_203
  (Node : Bare_Protected_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1672 with Inline_Always;
            procedure Finalizer_Scope_2506 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Protected_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1672 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1672;
            procedure Finalizer_Scope_2506 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2506;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4916 '<Cast to AdaNode at ast.py:20471>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20471
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4916
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2506;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1672;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1672;
               Finalizer_Scope_2506;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_203;
--# end
--# property-start ProtectedBody._ref_cond_204 /tmp/lal-23.0.0/ada/ast.py:20473
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_204
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4917 '<FieldAccess for should_ref_generic_formals at ast.py:20473>' Fld /tmp/lal-23.0.0/ada/ast.py:20473
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4917
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_204;
--# end
--# property-start ProtectedBody._ref_env_nodes_205 /tmp/lal-23.0.0/ada/ast.py:20481
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_205
  (Node : Bare_Protected_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1674 with Inline_Always;
            procedure Finalizer_Scope_2507 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Protected_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1674 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1674;
            procedure Finalizer_Scope_2507 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2507;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4918 '<Cast to AdaNode at ast.py:20481>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20481
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4918
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2507;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1674;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1674;
               Finalizer_Scope_2507;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_205;
--# end
--# property-start ProtectedBody._ref_cond_206 /tmp/lal-23.0.0/ada/ast.py:20483
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_206
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4919 '<FieldAccess for should_ref_generic_formals at ast.py:20483>' Fld /tmp/lal-23.0.0/ada/ast.py:20483
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4919
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_206;
--# end
--# property-start ProtectedBody._ref_env_nodes_207 /tmp/lal-23.0.0/ada/ast.py:20487
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_207
  (Node : Bare_Protected_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1676 with Inline_Always;
      Cast_Expr : Bare_Protected_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1676 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1676;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4920 '<Cast to AdaNode at ast.py:20487>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20487
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4920
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1676;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1676;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_207;
--# end
--# property-start ProtectedBody._ref_env_nodes_208 /tmp/lal-23.0.0/ada/ast.py:20492
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_208
  (Node : Bare_Protected_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1677 with Inline_Always;
      Cast_Expr : Bare_Protected_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1677 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1677;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4921 '<Cast to AdaNode at ast.py:20492>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20492
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4921
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1677;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1677;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_208;
--# end
--# property-start ProtectedBody._ref_cond_209 /tmp/lal-23.0.0/ada/ast.py:20494
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_209
  (Node : Bare_Protected_Body
  )
   return Boolean
is
   Self : Bare_Protected_Body := Bare_Protected_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4922 '<FieldAccess for is_subunit at ast.py:20494>' Fld /tmp/lal-23.0.0/ada/ast.py:20494
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Self);
--# end
--# expr-done 4922
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_209;
--# end
   --
   --  Primitives for Bare_Task_Body
   --
      procedure Task_Body_Pre_Env_Actions
        (Self            : Bare_Task_Body;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_178 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_179 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:20385");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_180 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20387");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_181 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_182 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_184 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_183 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_186 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_185 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_188 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_187 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Nested_Generic_Formal_Part'Access,
               Prioritary,
               All_Cats,
               True);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_190 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_189 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Ada_Node_P_Use_Clauses_In_Generic_Formal_Part'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_191 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Task_Body_P_Task_Type_Decl_Scope'Access,
               Prioritary,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      if Libadalang.Implementation.Ref_Cond_193 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_192 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Body_Node_P_Subunit_Decl_Env'Access,
               Prioritary,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Task_Body
        (Self : Bare_Task_Body
         ; Task_Body_F_Name : Bare_Defining_Name
         ; Task_Body_F_Aspects : Bare_Aspect_Spec
         ; Task_Body_F_Decls : Bare_Declarative_Part
         ; Task_Body_F_Stmts : Bare_Handled_Stmts
         ; Task_Body_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Task_Body_F_Name := Task_Body_F_Name;
            Self.Task_Body_F_Aspects := Task_Body_F_Aspects;
            Self.Task_Body_F_Decls := Task_Body_F_Decls;
            Self.Task_Body_F_Stmts := Task_Body_F_Stmts;
            Self.Task_Body_F_End_Name := Task_Body_F_End_Name;
      end Initialize_Fields_For_Task_Body;
   function Task_Body_F_Name
     (Node : Bare_Task_Body) return Bare_Defining_Name
   is
   begin
         return Node.Task_Body_F_Name;
   end;
   function Task_Body_F_Decls
     (Node : Bare_Task_Body) return Bare_Declarative_Part
   is
   begin
         return Node.Task_Body_F_Decls;
   end;
   function Task_Body_F_Stmts
     (Node : Bare_Task_Body) return Bare_Handled_Stmts
   is
   begin
         return Node.Task_Body_F_Stmts;
   end;
   function Task_Body_F_End_Name
     (Node : Bare_Task_Body) return Bare_End_Name
   is
   begin
         return Node.Task_Body_F_End_Name;
   end;
--# property-start TaskBody.defining_names /tmp/lal-23.0.0/ada/ast.py:20378
pragma Warnings (Off, "is not referenced");
 function Task_Body_P_Defining_Names
  (Node : Bare_Task_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body :=
     Internal_Entity_Task_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1430 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1430 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1430;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4923 '<FieldAccess for name at ast.py:20378>' Fld /tmp/lal-23.0.0/ada/ast.py:20378
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Task_Body_F_Name, Info => Ent.Info);
--# expr-done 4923
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1430;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1430;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Body_P_Defining_Names;
--# end
--# property-start TaskBody.declarative_parts /tmp/lal-23.0.0/ada/ast.py:20380
pragma Warnings (Off, "is not referenced");
 function Task_Body_P_Declarative_Parts
  (Node : Bare_Task_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body :=
     Internal_Entity_Task_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1431 with Inline_Always;
      Fld : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_1431 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1431;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4924 '<FieldAccess for decls at ast.py:20380>' Fld /tmp/lal-23.0.0/ada/ast.py:20380
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Declarative_Part (Node => Ent.Node.Task_Body_F_Decls, Info => Ent.Info);
--# expr-done 4924
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1431;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1431;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Body_P_Declarative_Parts;
--# end
--# property-start TaskBody.task_type_decl_scope /tmp/lal-23.0.0/ada/ast.py:20433
pragma Warnings (Off, "is not referenced");
 function Task_Body_P_Task_Type_Decl_Scope
  (Node : Bare_Task_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body :=
     Internal_Entity_Task_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1432 with Inline_Always;
      Fld : Internal_Entity_Task_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1432 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1432;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4926 '<FieldAccess for children_env at ast.py:20433>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20433
--# expr-start 4925 '<FieldAccess for task_type at ast.py:20433>' Fld /tmp/lal-23.0.0/ada/ast.py:20433
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TaskBody.task_type
Fld := Libadalang.Implementation.Task_Body_P_Task_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4925
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 4926
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1432;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1432;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Body_P_Task_Type_Decl_Scope;
--# end
--# property-start TaskBody.task_type /tmp/lal-23.0.0/ada/ast.py:20436
pragma Warnings (Off, "is not referenced");
 function Task_Body_P_Task_Type
  (Node : Bare_Task_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Task_Type_Decl
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body :=
     Internal_Entity_Task_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Task_Type_Decl;
      Match_0 : Internal_Entity_Task_Type_Decl;
Match_1 : Internal_Entity_Single_Task_Decl;
Match_2 : Internal_Entity_Basic_Decl;
Bound_Imprecise_Fallback : Boolean;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Single_Task_Type_Decl;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Task_Type_Decl;
Let_Result : Internal_Entity_Task_Type_Decl;
Scope_Result : Internal_Entity_Task_Type_Decl;
Cast_Result_1 : Internal_Entity_Single_Task_Decl;
Cast_Result_2 : Internal_Entity_Task_Type_Decl;
Let_Result_1 : Internal_Entity_Task_Type_Decl;
Scope_Result_1 : Internal_Entity_Task_Type_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Task_Type_Decl;
Scope_Result_2 : Internal_Entity_Task_Type_Decl;
Match_Result : Internal_Entity_Task_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Task_Type_Decl;
Let_Result_3 : Internal_Entity_Task_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4931 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 4930 '<bind at ast.py:20437>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:20437
Bound_Imprecise_Fallback := False; 
--# expr-start 4929 '<Match at ast.py:20437>' Match_Result /tmp/lal-23.0.0/ada/ast.py:20437
--# expr-start 4927 '<FieldAccess for decl_part at ast.py:20437>' Fld /tmp/lal-23.0.0/ada/ast.py:20437
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Ent.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 4927
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Task_Type_Decl .. Ada_Single_Task_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Task_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind t Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Single_Task_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind t Match_1
--# expr-start 4928 '<FieldAccess for task_type at ast.py:20439>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20439
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Single_Task_Type_Decl (Node => Match_1.Node.Single_Task_Decl_F_Task_Type, Info => Match_1.Info);
--# expr-done 4928
      Cast_Result_2 := Create_Internal_Entity_Task_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Let_Result_1 := Cast_Result_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Protected_Type_Decl | Ada_Anonymous_Type_Decl .. Ada_Single_Protected_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error with "Should not happen"; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 4929
Dyn_Var_Bind_Result := Match_Result; 
--# expr-done 4930
Let_Result_3 := Dyn_Var_Bind_Result; 
--# end
--# expr-done 4931
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Body_P_Task_Type;
--# end
--# property-start TaskBody._env_do_178 /tmp/lal-23.0.0/ada/ast.py:20383
pragma Warnings (Off, "is not referenced");
 function Env_Do_178
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4932 '<FieldAccess for env_hook at ast.py:20383>' Fld /tmp/lal-23.0.0/ada/ast.py:20383
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 4932
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_178;
--# end
--# property-start TaskBody._initial_env_179 /tmp/lal-23.0.0/ada/ast.py:20385
pragma Warnings (Off, "is not referenced");
 function Initial_Env_179
  (Node : Bare_Task_Body
  )
   return Internal_Designated_Env
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1648 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1648 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1648;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4933 '<FieldAccess for body_initial_env at ast.py:20385>' Fld /tmp/lal-23.0.0/ada/ast.py:20385
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.body_initial_env
Fld := Libadalang.Implementation.Body_Node_P_Body_Initial_Env (Node => Self);
--# end
--# expr-done 4933
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1648;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1648;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_179;
--# end
--# property-start TaskBody._env_mappings_180 /tmp/lal-23.0.0/ada/ast.py:20387
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_180
  (Node : Bare_Task_Body
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Body :=
     Internal_Entity_Task_Body'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1649 with Inline_Always;
      Fld : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1649 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1649;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4934 '<FieldAccess for previous_part_link_env_assoc at ast.py:20387>' Fld /tmp/lal-23.0.0/ada/ast.py:20387
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Body.previous_part_link_env_assoc'
Fld := Libadalang.Implementation.Dispatcher_Body_Node_P_Previous_Part_Link_Env_Assoc (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 4934
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1649;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1649;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_180;
--# end
--# property-start TaskBody._env_trans_parent_181 /tmp/lal-23.0.0/ada/ast.py:20382
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_181
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_181;
--# end
--# property-start TaskBody._env_do_182 /tmp/lal-23.0.0/ada/ast.py:20391
pragma Warnings (Off, "is not referenced");
 function Env_Do_182
  (Node : Bare_Task_Body
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1651 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1651 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1651;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4935 '<FieldAccess for populate_dependent_units at ast.py:20391>' Fld /tmp/lal-23.0.0/ada/ast.py:20391
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 4935
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1651;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1651;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_182;
--# end
--# property-start TaskBody._ref_env_nodes_183 /tmp/lal-23.0.0/ada/ast.py:20394
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_183
  (Node : Bare_Task_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1652 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1652 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1652;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4936 '<FieldAccess for top_level_use_package_clauses at ast.py:20394>' Fld /tmp/lal-23.0.0/ada/ast.py:20394
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 4936
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1652;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1652;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_183;
--# end
--# property-start TaskBody._ref_cond_184 /tmp/lal-23.0.0/ada/ast.py:20396
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_184
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4938 '<IsA LibraryItem, Subunit at ast.py:20396>' Is_A /tmp/lal-23.0.0/ada/ast.py:20396
--# expr-start 4937 '<parent at ast.py:20396>' Fld /tmp/lal-23.0.0/ada/ast.py:20396
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4937
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4938
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_184;
--# end
--# property-start TaskBody._ref_env_nodes_185 /tmp/lal-23.0.0/ada/ast.py:20400
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_185
  (Node : Bare_Task_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1654 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1654 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1654;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4939 '<FieldAccess for top_level_use_type_clauses at ast.py:20400>' Fld /tmp/lal-23.0.0/ada/ast.py:20400
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 4939
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1654;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1654;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_185;
--# end
--# property-start TaskBody._ref_cond_186 /tmp/lal-23.0.0/ada/ast.py:20402
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_186
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4941 '<IsA LibraryItem, Subunit at ast.py:20402>' Is_A /tmp/lal-23.0.0/ada/ast.py:20402
--# expr-start 4940 '<parent at ast.py:20402>' Fld /tmp/lal-23.0.0/ada/ast.py:20402
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 4940
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 4941
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_186;
--# end
--# property-start TaskBody._ref_env_nodes_187 /tmp/lal-23.0.0/ada/ast.py:20406
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_187
  (Node : Bare_Task_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1656 with Inline_Always;
            procedure Finalizer_Scope_2511 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Task_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1656 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1656;
            procedure Finalizer_Scope_2511 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2511;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4942 '<Cast to AdaNode at ast.py:20406>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20406
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4942
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2511;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1656;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1656;
               Finalizer_Scope_2511;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_187;
--# end
--# property-start TaskBody._ref_cond_188 /tmp/lal-23.0.0/ada/ast.py:20408
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_188
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4943 '<FieldAccess for should_ref_generic_formals at ast.py:20408>' Fld /tmp/lal-23.0.0/ada/ast.py:20408
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4943
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_188;
--# end
--# property-start TaskBody._ref_env_nodes_189 /tmp/lal-23.0.0/ada/ast.py:20416
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_189
  (Node : Bare_Task_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1658 with Inline_Always;
            procedure Finalizer_Scope_2512 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Cast_Expr : Bare_Task_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
Scope_Result : Bare_Ada_Node_Array_Access;
Result_Var : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1658 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1658;
            procedure Finalizer_Scope_2512 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2512;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4944 '<Cast to AdaNode at ast.py:20416>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20416
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4944
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2512;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1658;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1658;
               Finalizer_Scope_2512;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_189;
--# end
--# property-start TaskBody._ref_cond_190 /tmp/lal-23.0.0/ada/ast.py:20418
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_190
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4945 '<FieldAccess for should_ref_generic_formals at ast.py:20418>' Fld /tmp/lal-23.0.0/ada/ast.py:20418
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.should_ref_generic_formals
Fld := Libadalang.Implementation.Basic_Decl_P_Should_Ref_Generic_Formals (Node => Self);
--# end
--# expr-done 4945
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_190;
--# end
--# property-start TaskBody._ref_env_nodes_191 /tmp/lal-23.0.0/ada/ast.py:20422
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_191
  (Node : Bare_Task_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1660 with Inline_Always;
      Cast_Expr : Bare_Task_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1660 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1660;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4946 '<Cast to AdaNode at ast.py:20422>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20422
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4946
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1660;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1660;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_191;
--# end
--# property-start TaskBody._ref_env_nodes_192 /tmp/lal-23.0.0/ada/ast.py:20427
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_192
  (Node : Bare_Task_Body
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1661 with Inline_Always;
      Cast_Expr : Bare_Task_Body;
Cast_Result : Bare_Ada_Node;
Singleton : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1661 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1661;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4947 '<Cast to AdaNode at ast.py:20427>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20427
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# expr-done 4947
                Singleton := Create_Bare_Ada_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1661;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1661;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_192;
--# end
--# property-start TaskBody._ref_cond_193 /tmp/lal-23.0.0/ada/ast.py:20429
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_193
  (Node : Bare_Task_Body
  )
   return Boolean
is
   Self : Bare_Task_Body := Bare_Task_Body (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4948 '<FieldAccess for is_subunit at ast.py:20429>' Fld /tmp/lal-23.0.0/ada/ast.py:20429
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.is_subunit
Fld := Libadalang.Implementation.Body_Node_P_Is_Subunit (Node => Self);
--# end
--# expr-done 4948
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_193;
--# end
function Task_Body_P_Task_Type_Decl_Scope
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Task_Body_P_Task_Type_Decl_Scope (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Entry_Index_Spec
   --
      procedure Entry_Index_Spec_Pre_Env_Actions
        (Self            : Bare_Entry_Index_Spec;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_214 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20567");
         Dec_Ref (Mapping.Dest_Env);
      end;
      end;
      procedure Initialize_Fields_For_Entry_Index_Spec
        (Self : Bare_Entry_Index_Spec
         ; Entry_Index_Spec_F_Id : Bare_Defining_Name
         ; Entry_Index_Spec_F_Subtype : Bare_Ada_Node
         ; Entry_Index_Spec_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Entry_Index_Spec_F_Id := Entry_Index_Spec_F_Id;
            Self.Entry_Index_Spec_F_Subtype := Entry_Index_Spec_F_Subtype;
            Self.Entry_Index_Spec_F_Aspects := Entry_Index_Spec_F_Aspects;
      end Initialize_Fields_For_Entry_Index_Spec;
   function Entry_Index_Spec_F_Id
     (Node : Bare_Entry_Index_Spec) return Bare_Defining_Name
   is
   begin
         return Node.Entry_Index_Spec_F_Id;
   end;
   function Entry_Index_Spec_F_Subtype
     (Node : Bare_Entry_Index_Spec) return Bare_Ada_Node
   is
   begin
         return Node.Entry_Index_Spec_F_Subtype;
   end;
--# property-start EntryIndexSpec.defining_names /tmp/lal-23.0.0/ada/ast.py:20569
pragma Warnings (Off, "is not referenced");
 function Entry_Index_Spec_P_Defining_Names
  (Node : Bare_Entry_Index_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Entry_Index_Spec := Bare_Entry_Index_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Index_Spec :=
     Internal_Entity_Entry_Index_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1440 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1440 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1440;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4949 '<FieldAccess for id at ast.py:20569>' Fld /tmp/lal-23.0.0/ada/ast.py:20569
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Entry_Index_Spec_F_Id, Info => Ent.Info);
--# expr-done 4949
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1440;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1440;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Index_Spec_P_Defining_Names;
--# end
--# property-start EntryIndexSpec.defining_env /tmp/lal-23.0.0/ada/ast.py:20570
pragma Warnings (Off, "is not referenced");
 function Entry_Index_Spec_P_Defining_Env
  (Node : Bare_Entry_Index_Spec
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Entry_Index_Spec := Bare_Entry_Index_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Index_Spec :=
     Internal_Entity_Entry_Index_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1441 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1441 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1441;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4951 '<FieldAccess for defining_env at ast.py:20570>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20570
--# expr-start 4950 '<FieldAccess for expr_type at ast.py:20570>' Fld /tmp/lal-23.0.0/ada/ast.py:20570
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 4950
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 4951
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1441;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1441;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Index_Spec_P_Defining_Env;
--# end
--# property-start EntryIndexSpec.expr_type /tmp/lal-23.0.0/ada/ast.py:20571
pragma Warnings (Off, "is not referenced");
 function Entry_Index_Spec_P_Expr_Type
  (Node : Bare_Entry_Index_Spec
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Entry_Index_Spec := Bare_Entry_Index_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Index_Spec :=
     Internal_Entity_Entry_Index_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Subtype_Indication;
Match_1 : Internal_Entity;
Fld : Internal_Entity;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
Fld_2 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Subtype_Indication;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4956 '<Match at ast.py:20571>' Match_Result /tmp/lal-23.0.0/ada/ast.py:20571
--# expr-start 4952 '<FieldAccess for subtype at ast.py:20571>' Fld /tmp/lal-23.0.0/ada/ast.py:20571
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Entry_Index_Spec_F_Subtype, Info => Ent.Info);
--# expr-done 4952
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind subt Match_0
--# expr-start 4953 '<FieldAccess for designated_type at ast.py:20572>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20572
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 4953
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abort_Absent .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind e Match_1
--# expr-start 4955 '<FieldAccess for expression_type at ast.py:20573>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20573
--# expr-start 4954 '<Cast to Expr at ast.py:20573>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20573
Cast_Expr := Match_1; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 4954
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_2 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 4955
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 4956
      Property_Result := Match_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Index_Spec_P_Expr_Type;
--# end
--# property-start EntryIndexSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:20577
pragma Warnings (Off, "is not referenced");
 function Entry_Index_Spec_P_Xref_Equation
  (Node : Bare_Entry_Index_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Entry_Index_Spec := Bare_Entry_Index_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Index_Spec :=
     Internal_Entity_Entry_Index_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1443 with Inline_Always;
      Fld : Internal_Entity;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1443 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1443;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4959 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4958 '<FieldAccess for sub_equation at ast.py:20578>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20578
--# expr-start 4957 '<FieldAccess for subtype at ast.py:20578>' Fld /tmp/lal-23.0.0/ada/ast.py:20578
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Entry_Index_Spec_F_Subtype, Info => Ent.Info);
--# expr-done 4957
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 4958
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 4959
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1443;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1443;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Index_Spec_P_Xref_Equation;
--# end
--# property-start EntryIndexSpec.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:20580
pragma Warnings (Off, "is not referenced");
 function Entry_Index_Spec_P_Xref_Entry_Point
  (Node : Bare_Entry_Index_Spec
  )
   return Boolean
is
   Self : Bare_Entry_Index_Spec := Bare_Entry_Index_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Entry_Index_Spec_P_Xref_Entry_Point;
--# end
--# property-start EntryIndexSpec._env_mappings_214 /tmp/lal-23.0.0/ada/ast.py:20567
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_214
  (Node : Bare_Entry_Index_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Entry_Index_Spec := Bare_Entry_Index_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Entry_Index_Spec :=
     Internal_Entity_Entry_Index_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1683 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Entry_Index_Spec;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1683 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1683;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4962 '<New EnvAssoc at ast.py:20567>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:20567
--# expr-start 4960 '<New DesignatedEnv at ast.py:20567>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20567
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4960
--# expr-start 4961 '<FieldAccess for name_symbol at ast.py:20567>' Fld /tmp/lal-23.0.0/ada/ast.py:20567
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 4961
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4962
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1683;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1683;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_214;
--# end
   --
   --  Primitives for Bare_Error_Decl
   --
--# property-start ErrorDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:3378
pragma Warnings (Off, "is not referenced");
 function Error_Decl_P_Defining_Names
  (Node : Bare_Error_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Error_Decl := Bare_Error_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Defining_Name_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Error_Decl_P_Defining_Names;
--# end
--# property-start ErrorDecl.child_decl_initial_env_name /tmp/lal-23.0.0/ada/ast.py:3381
pragma Warnings (Off, "is not referenced");
 function Error_Decl_P_Child_Decl_Initial_Env_Name
  (Node : Bare_Error_Decl
      ; Private_Part : Boolean
         := False
  )
   return Symbol_Type
is
   Self : Bare_Error_Decl := Bare_Error_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind private_part Private_Part
   Property_Result : Symbol_Type;
      Let_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4963 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := null; 
--# end
--# expr-done 4963
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Error_Decl_P_Child_Decl_Initial_Env_Name;
--# end
   --
   --  Primitives for Bare_Exception_Decl
   --
      procedure Exception_Decl_Pre_Env_Actions
        (Self            : Bare_Exception_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_58 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10559");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Exception_Decl
        (Self : Bare_Exception_Decl
         ; Exception_Decl_F_Ids : Bare_Defining_Name_List
         ; Exception_Decl_F_Renames : Bare_Renaming_Clause
         ; Exception_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Exception_Decl_F_Ids := Exception_Decl_F_Ids;
            Self.Exception_Decl_F_Renames := Exception_Decl_F_Renames;
            Self.Exception_Decl_F_Aspects := Exception_Decl_F_Aspects;
      end Initialize_Fields_For_Exception_Decl;
   function Exception_Decl_F_Ids
     (Node : Bare_Exception_Decl) return Bare_Defining_Name_List
   is
   begin
         return Node.Exception_Decl_F_Ids;
   end;
   function Exception_Decl_F_Renames
     (Node : Bare_Exception_Decl) return Bare_Renaming_Clause
   is
   begin
         return Node.Exception_Decl_F_Renames;
   end;
--# property-start ExceptionDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:10550
pragma Warnings (Off, "is not referenced");
 function Exception_Decl_P_Defining_Names
  (Node : Bare_Exception_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Exception_Decl := Bare_Exception_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Exception_Decl :=
     Internal_Entity_Exception_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_842 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_List;
Fld_1 : Bare_Defining_Name_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Item_176 : Internal_Entity_Defining_Name;
Bare_Item_176 : Bare_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_842 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_842;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4965 '<Map at ast.py:10550>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10550
   --# expr-start 4964 '<FieldAccess for ids at ast.py:10550>' Fld /tmp/lal-23.0.0/ada/ast.py:10550
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name_List (Node => Ent.Node.Exception_Decl_F_Ids, Info => Ent.Info);
--# expr-done 4964
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Defining_Name_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld_1;
      begin
         for Untyped_Item_176 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_176 := Untyped_Item_176; 
Is_Null := Bare_Item_176 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_176); 
   If_Result := As_Entity;
end if;
                  Item_176 := If_Result; 
   --# scope-start
               --# bind id Item_176
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Item_176;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4965
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_842;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_842;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Decl_P_Defining_Names;
--# end
--# property-start ExceptionDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:10553
pragma Warnings (Off, "is not referenced");
 function Exception_Decl_P_Next_Part_For_Decl
  (Node : Bare_Exception_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Exception_Decl := Bare_Exception_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4966 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Basic_Decl; 
--# end
--# expr-done 4966
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Decl_P_Next_Part_For_Decl;
--# end
--# property-start ExceptionDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:10561
pragma Warnings (Off, "is not referenced");
 function Exception_Decl_P_Xref_Entry_Point
  (Node : Bare_Exception_Decl
  )
   return Boolean
is
   Self : Bare_Exception_Decl := Bare_Exception_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Decl_P_Xref_Entry_Point;
--# end
--# property-start ExceptionDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:10564
pragma Warnings (Off, "is not referenced");
 function Exception_Decl_P_Xref_Equation
  (Node : Bare_Exception_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Exception_Decl := Bare_Exception_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Exception_Decl :=
     Internal_Entity_Exception_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_845 with Inline_Always;
            procedure Finalizer_Scope_2516 with Inline_Always;
      Var_Expr : Internal_Entity_Renaming_Clause;
Fld : Internal_Entity_Renaming_Clause;
Fld_1 : Internal_Entity_Name;
Fld_2 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_845 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_845;
            procedure Finalizer_Scope_2516 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2516;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4970 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4967 '<FieldAccess for renames at ast.py:10565>' Fld /tmp/lal-23.0.0/ada/ast.py:10565
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Exception_Decl_F_Renames, Info => Ent.Info);
--# expr-done 4967
Var_Expr := Fld;
if Var_Expr /= No_Entity_Renaming_Clause then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 4969 '<FieldAccess for xref_no_overloading at ast.py:10566>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10566
--# expr-start 4968 '<FieldAccess for renamed_object at ast.py:10566>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10566
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr.Info);
--# expr-done 4968
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_2 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 4969
Scope_Result := Fld_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2516;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10567") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 4970
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_845;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_845;
               Finalizer_Scope_2516;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Decl_P_Xref_Equation;
--# end
--# property-start ExceptionDecl._env_mappings_58 /tmp/lal-23.0.0/ada/ast.py:10559
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_58
  (Node : Bare_Exception_Decl
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Exception_Decl := Bare_Exception_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1527 with Inline_Always;
      Fld : Bare_Defining_Name_List;
Cast_Expr : Bare_Exception_Decl;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1527 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1527;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4972 '<FieldAccess for env_mappings at ast.py:10559>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10559
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4971 '<FieldAccess for ids at ast.py:10559>' Fld /tmp/lal-23.0.0/ada/ast.py:10559
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Exception_Decl_F_Ids;
--# expr-done 4971
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start AdaNode.env_mappings
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Mappings (Node => Self, Defining_Names => Fld, Value => Cast_Result);
--# end
--# expr-done 4972
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1527;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1527;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_58;
--# end
   --
   --  Primitives for Bare_Exception_Handler
   --
      procedure Exception_Handler_Pre_Env_Actions
        (Self            : Bare_Exception_Handler;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_150 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_151 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:19558");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Exception_Handler
        (Self : Bare_Exception_Handler
         ; Exception_Handler_F_Exception_Name : Bare_Defining_Name
         ; Exception_Handler_F_Handled_Exceptions : Bare_Alternatives_List
         ; Exception_Handler_F_Stmts : Bare_Stmt_List
        ) is
      begin
            Self.Exception_Handler_F_Exception_Name := Exception_Handler_F_Exception_Name;
            Self.Exception_Handler_F_Handled_Exceptions := Exception_Handler_F_Handled_Exceptions;
            Self.Exception_Handler_F_Stmts := Exception_Handler_F_Stmts;
      end Initialize_Fields_For_Exception_Handler;
   function Exception_Handler_F_Exception_Name
     (Node : Bare_Exception_Handler) return Bare_Defining_Name
   is
   begin
         return Node.Exception_Handler_F_Exception_Name;
   end;
   function Exception_Handler_F_Handled_Exceptions
     (Node : Bare_Exception_Handler) return Bare_Alternatives_List
   is
   begin
         return Node.Exception_Handler_F_Handled_Exceptions;
   end;
   function Exception_Handler_F_Stmts
     (Node : Bare_Exception_Handler) return Bare_Stmt_List
   is
   begin
         return Node.Exception_Handler_F_Stmts;
   end;
--# property-start ExceptionHandler.defining_names /tmp/lal-23.0.0/ada/ast.py:19568
pragma Warnings (Off, "is not referenced");
 function Exception_Handler_P_Defining_Names
  (Node : Bare_Exception_Handler
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Exception_Handler :=
     Internal_Entity_Exception_Handler'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1383 with Inline_Always;
            procedure Finalizer_Scope_2517 with Inline_Always;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1383 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1383;
            procedure Finalizer_Scope_2517 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2517;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4973 '<FieldAccess for exception_name at ast.py:19569>' Fld /tmp/lal-23.0.0/ada/ast.py:19569
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Exception_Handler_F_Exception_Name, Info => Ent.Info);
--# expr-done 4973
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind n Var_Expr
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2517;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1383;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1383;
               Finalizer_Scope_2517;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Handler_P_Defining_Names;
--# end
--# property-start ExceptionHandler.expr_type /tmp/lal-23.0.0/ada/ast.py:19573
pragma Warnings (Off, "is not referenced");
 function Exception_Handler_P_Expr_Type
  (Node : Bare_Exception_Handler
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Exception_Handler :=
     Internal_Entity_Exception_Handler'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1384 with Inline_Always;
            procedure Finalizer_Scope_2518 with Inline_Always;
      Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1384 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1384;
            procedure Finalizer_Scope_2518 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2518;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4982 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 4981 '<Cast to BaseTypeDecl at ast.py:19578>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19578
--# expr-start 4980 '<EnvGet at ast.py:19575>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:19575
--# expr-start 4977 '<FieldAccess for get_unit_root_decl at ast.py:19576>' Fld /tmp/lal-23.0.0/ada/ast.py:19576
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 4976 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 4974 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 4974
--# expr-start 4975 '<Symbol Exceptions at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exceptions); 
--# expr-done 4975
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 4976
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 4977
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 4978 '<FieldAccess for children_env at ast.py:19577>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19577
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 4978
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2518;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 4979 '<Symbol Exception_Occurrence at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exception_Occurrence); 
--# expr-done 4979
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 4980
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 4981
Let_Result := Cast_Result; 
--# end
--# expr-done 4982
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1384;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1384;
               Finalizer_Scope_2518;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Handler_P_Expr_Type;
--# end
--# property-start ExceptionHandler.xref_equation /tmp/lal-23.0.0/ada/ast.py:19581
pragma Warnings (Off, "is not referenced");
 function Exception_Handler_P_Xref_Equation
  (Node : Bare_Exception_Handler
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1385 with Inline_Always;
            procedure Finalizer_Scope_2519 with Inline_Always;
      Fld : Bare_Alternatives_List;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_1 : Logic_Equation;
Item_177 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
            procedure Finalizer_Scope_1385 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_1385;
            procedure Finalizer_Scope_2519 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2519;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4987 '<LogicAll at ast.py:19582>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:19582
--# expr-start 4986 '<Map at ast.py:19582>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19582
   --# expr-start 4983 '<FieldAccess for handled_exceptions at ast.py:19582>' Fld /tmp/lal-23.0.0/ada/ast.py:19582
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Exception_Handler_F_Handled_Exceptions;
--# expr-done 4983
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld;
      begin
         for Untyped_Item_177 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_177 := Untyped_Item_177; 
   --# scope-start
               --# bind he Item_177
      --# expr-start 4985 '<FieldAccess for sub_equation at ast.py:19582>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19582
--# expr-start 4984 '<as_entity at ast.py:19582>' If_Result /tmp/lal-23.0.0/ada/ast.py:19582
Is_Null := Item_177 = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Item_177); 
   If_Result := As_Entity;
end if;
--# expr-done 4984
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => If_Result.Node, Env => Env, Origin => Origin, E_Info => If_Result.Info);
--# end
--# expr-done 4985
         declare
            Item_To_Append : constant Logic_Equation := Fld_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2519;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4986
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19582") else null)); 
--# expr-done 4987
      Property_Result := Logic_Boolean_Op;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1385;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1385;
               Finalizer_Scope_2519;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Handler_P_Xref_Equation;
--# end
--# property-start ExceptionHandler.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:19585
pragma Warnings (Off, "is not referenced");
 function Exception_Handler_P_Xref_Entry_Point
  (Node : Bare_Exception_Handler
  )
   return Boolean
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Handler_P_Xref_Entry_Point;
--# end
--# property-start ExceptionHandler.is_constant_object /tmp/lal-23.0.0/ada/ast.py:19587
pragma Warnings (Off, "is not referenced");
 function Exception_Handler_P_Is_Constant_Object
  (Node : Bare_Exception_Handler
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exception_Handler_P_Is_Constant_Object;
--# end
--# property-start ExceptionHandler._env_trans_parent_150 /tmp/lal-23.0.0/ada/ast.py:19556
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_150
  (Node : Bare_Exception_Handler
  )
   return Boolean
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_150;
--# end
--# property-start ExceptionHandler._env_mappings_151 /tmp/lal-23.0.0/ada/ast.py:19559
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_151
  (Node : Bare_Exception_Handler
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Exception_Handler := Bare_Exception_Handler (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Exception_Handler :=
     Internal_Entity_Exception_Handler'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1620 with Inline_Always;
            procedure Finalizer_Scope_2520 with Inline_Always;
            procedure Finalizer_Scope_2521 with Inline_Always;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Exception_Handler;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
Map_Result : Internal_Env_Assoc_Array_Access;
Scope_Result : Internal_Env_Assoc_Array_Access;
Result_Var : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1620 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1620;
            procedure Finalizer_Scope_2520 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2520;
            procedure Finalizer_Scope_2521 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_2521;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 4988 '<FieldAccess for exception_name at ast.py:19559>' Fld /tmp/lal-23.0.0/ada/ast.py:19559
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Exception_Handler_F_Exception_Name, Info => Ent.Info);
--# expr-done 4988
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind n Var_Expr
--# expr-start 4992 '<Map at ast.py:19559>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19559
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
      declare
         Map_Result_Vec : Internal_Env_Assoc_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Singleton;
      begin
         for Item_178 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_178
      --# expr-start 4991 '<New EnvAssoc at ast.py:19561>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:19561
--# expr-start 4989 '<New DesignatedEnv at ast.py:19563>' New_Struct /tmp/lal-23.0.0/ada/ast.py:19563
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 4989
--# expr-start 4990 '<FieldAccess for name_symbol at ast.py:19561>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19561
      if Item_178.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Item_178.Node);
--# end
--# expr-done 4990
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld_1, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 4991
         declare
            Item_To_Append : constant Internal_Env_Assoc := New_Struct_1;
         begin
               Inc_Ref (Item_To_Append);
            Internal_Env_Assoc_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2521;
         end loop;
      end;
         Map_Result := Create_Internal_Env_Assoc_Array
           (Items_Count => Natural (Internal_Env_Assoc_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Env_Assoc_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Env_Assoc_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Env_Assoc_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 4992
Scope_Result := Map_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2520;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Env_Assoc_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1620;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1620;
               Finalizer_Scope_2520;
               Finalizer_Scope_2521;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_151;
--# end
   --
   --  Primitives for Bare_For_Loop_Var_Decl
   --
      procedure For_Loop_Var_Decl_Pre_Env_Actions
        (Self            : Bare_For_Loop_Var_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_133 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:17771");
         Dec_Ref (Mapping.Dest_Env);
      end;
      end;
      procedure Initialize_Fields_For_For_Loop_Var_Decl
        (Self : Bare_For_Loop_Var_Decl
         ; For_Loop_Var_Decl_F_Id : Bare_Defining_Name
         ; For_Loop_Var_Decl_F_Id_Type : Bare_Type_Expr
        ) is
      begin
            Self.For_Loop_Var_Decl_F_Id := For_Loop_Var_Decl_F_Id;
            Self.For_Loop_Var_Decl_F_Id_Type := For_Loop_Var_Decl_F_Id_Type;
      end Initialize_Fields_For_For_Loop_Var_Decl;
   function For_Loop_Var_Decl_F_Id
     (Node : Bare_For_Loop_Var_Decl) return Bare_Defining_Name
   is
   begin
         return Node.For_Loop_Var_Decl_F_Id;
   end;
   function For_Loop_Var_Decl_F_Id_Type
     (Node : Bare_For_Loop_Var_Decl) return Bare_Type_Expr
   is
   begin
         return Node.For_Loop_Var_Decl_F_Id_Type;
   end;
--# property-start ForLoopVarDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:17743
pragma Warnings (Off, "is not referenced");
 function For_Loop_Var_Decl_P_Defining_Names
  (Node : Bare_For_Loop_Var_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_For_Loop_Var_Decl := Bare_For_Loop_Var_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Var_Decl :=
     Internal_Entity_For_Loop_Var_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1275 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1275 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1275;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 4993 '<FieldAccess for id at ast.py:17743>' Fld /tmp/lal-23.0.0/ada/ast.py:17743
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.For_Loop_Var_Decl_F_Id, Info => Ent.Info);
--# expr-done 4993
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1275;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1275;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Var_Decl_P_Defining_Names;
--# end
--# property-start ForLoopVarDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:17745
pragma Warnings (Off, "is not referenced");
 function For_Loop_Var_Decl_P_Defining_Env
  (Node : Bare_For_Loop_Var_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_For_Loop_Var_Decl := Bare_For_Loop_Var_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Var_Decl :=
     Internal_Entity_For_Loop_Var_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1276 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1276 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1276;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 4995 '<FieldAccess for defining_env at ast.py:17745>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17745
--# expr-start 4994 '<FieldAccess for expr_type at ast.py:17745>' Fld /tmp/lal-23.0.0/ada/ast.py:17745
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 4994
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 4995
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1276;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1276;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Var_Decl_P_Defining_Env;
--# end
--# property-start ForLoopVarDecl.expr_type /tmp/lal-23.0.0/ada/ast.py:17748
pragma Warnings (Off, "is not referenced");
 function For_Loop_Var_Decl_P_Expr_Type
  (Node : Bare_For_Loop_Var_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_For_Loop_Var_Decl := Bare_For_Loop_Var_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Var_Decl :=
     Internal_Entity_For_Loop_Var_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Defining_Name;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Defining_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Ada_Node;
Cast_Result_1 : Bare_For_Loop_Spec;
Fld_5 : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_6 : Internal_Entity_Type_Expr;
Fld_7 : Internal_Entity_Base_Type_Decl;
Fld_8 : Bare_Type_Expr;
Is_Null : Boolean;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_For_Loop_Var_Decl_For_Loop_Var_Decl_P_Expr_Type,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_For_Loop_Var_Decl,
                                As_Bare_For_Loop_Var_Decl => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 5010 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5009 '<If at ast.py:17749>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:17749
--# expr-start 4997 '<IsNull at ast.py:17750>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17750
--# expr-start 4996 '<FieldAccess for id_type at ast.py:17750>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17750
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Self.For_Loop_Var_Decl_F_Id_Type;
--# expr-done 4996
Is_Null := Fld_8 = null; 
--# expr-done 4997
if Is_Null then
   --# expr-start 5006 '<If at ast.py:17761>' If_Result /tmp/lal-23.0.0/ada/ast.py:17761
--# expr-start 5000 '<FieldAccess for is_iterated_assoc_spec at ast.py:17762>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17762
--# expr-start 4999 '<Cast to ForLoopSpec at ast.py:17762>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:17762
--# expr-start 4998 '<parent at ast.py:17762>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17762
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Parent; 
--# expr-done 4998
   if Fld_4 = null
      or else Fld_4.Kind in Ada_For_Loop_Spec_Range
   then
      Cast_Result_1 := Fld_4;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 4999
      if Cast_Result_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ForLoopSpec.is_iterated_assoc_spec
Fld_5 := Libadalang.Implementation.For_Loop_Spec_P_Is_Iterated_Assoc_Spec (Node => Cast_Result_1);
--# end
--# expr-done 5000
if Fld_5 then
   --# expr-start 5003 '<Cast to BaseTypeDecl at ast.py:17763>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17763
--# expr-start 5002 '<FieldAccess for type_val at ast.py:17763>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17763
--# expr-start 5001 '<FieldAccess for id at ast.py:17763>' Fld /tmp/lal-23.0.0/ada/ast.py:17763
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.For_Loop_Var_Decl_F_Id;
--# expr-done 5001
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_1 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld);
--# end
--# expr-done 5002
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5003
   If_Result := Cast_Result;
else
   --# expr-start 5005 '<FieldAccess for expression_type at ast.py:17764>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17764
--# expr-start 5004 '<FieldAccess for id at ast.py:17764>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17764
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Defining_Name (Node => Ent.Node.For_Loop_Var_Decl_F_Id, Info => Ent.Info);
--# expr-done 5004
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_3 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 5005
   If_Result := Fld_3;
end if;
--# expr-done 5006
   If_Result_1 := If_Result;
else
   --# expr-start 5008 '<FieldAccess for designated_type at ast.py:17768>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17768
--# expr-start 5007 '<FieldAccess for id_type at ast.py:17768>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17768
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Type_Expr (Node => Ent.Node.For_Loop_Var_Decl_F_Id_Type, Info => Ent.Info);
--# expr-done 5007
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_6.Node, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 5008
   If_Result_1 := Fld_7;
end if;
--# expr-done 5009
Let_Result := If_Result_1; 
--# end
--# expr-done 5010
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Var_Decl_P_Expr_Type;
--# end
--# property-start ForLoopVarDecl.is_constant_object /tmp/lal-23.0.0/ada/ast.py:17774
pragma Warnings (Off, "is not referenced");
 function For_Loop_Var_Decl_P_Is_Constant_Object
  (Node : Bare_For_Loop_Var_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_For_Loop_Var_Decl := Bare_For_Loop_Var_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Var_Decl :=
     Internal_Entity_For_Loop_Var_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Block_Var : Internal_Entity_For_Loop_Spec;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_For_Loop_Spec;
Fld_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Name;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Iter_Type;
Is_A : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5019 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5012 '<Cast to ForLoopSpec at ast.py:17776>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17776
--# expr-start 5011 '<parent at ast.py:17776>' Fld /tmp/lal-23.0.0/ada/ast.py:17776
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 5011
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_For_Loop_Spec_Range
   then
      Cast_Result := Create_Internal_Entity_For_Loop_Spec
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_For_Loop_Spec;
   end if;
--# expr-done 5012
Block_Var := Cast_Result; 
--# bind loop_spec Block_Var
--# expr-start 5018 '<If at ast.py:17777>' If_Result /tmp/lal-23.0.0/ada/ast.py:17777
--# expr-start 5014 '<IsA IterType.Of at ast.py:17780>' Is_A /tmp/lal-23.0.0/ada/ast.py:17780
--# expr-start 5013 '<FieldAccess for loop_type at ast.py:17780>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17780
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Iter_Type (Node => Block_Var.Node.For_Loop_Spec_F_Loop_Type, Info => Block_Var.Info);
--# expr-done 5013
Is_A := Fld_3.Node /= null 
and then Fld_3.Node.Kind in Ada_Iter_Type_Of_Range; 
--# expr-done 5014
if Is_A then
   --# expr-start 5017 '<FieldAccess for is_constant at ast.py:17781>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17781
--# expr-start 5016 '<Cast to Name at ast.py:17781>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:17781
--# expr-start 5015 '<FieldAccess for iter_expr at ast.py:17781>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17781
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity (Node => Block_Var.Node.For_Loop_Spec_F_Iter_Expr, Info => Block_Var.Info);
--# expr-done 5015
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5016
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.is_constant'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Is_Constant (Node => Cast_Result_1.Node, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 5017
   If_Result := Fld_2;
else
   If_Result := True;
end if;
--# expr-done 5018
Let_Result := If_Result; 
--# end
--# expr-done 5019
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Var_Decl_P_Is_Constant_Object;
--# end
--# property-start ForLoopVarDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:17787
pragma Warnings (Off, "is not referenced");
 function For_Loop_Var_Decl_P_Xref_Equation
  (Node : Bare_For_Loop_Var_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_For_Loop_Var_Decl := Bare_For_Loop_Var_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Var_Decl :=
     Internal_Entity_For_Loop_Var_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1279 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Fld_1 : Logic_Equation;
True_Rel : Logic_Equation;
Fld_2 : Internal_Entity_Type_Expr;
Fld_3 : Logic_Equation;
Fld_4 : Internal_Entity_Type_Expr;
Is_Null : Boolean;
If_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1279 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Fld_3);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1279;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5028 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5027 '<And at ast.py:17788>' And_Pred /tmp/lal-23.0.0/ada/ast.py:17788
--# expr-start 5021 '<FieldAccess for sub_equation at ast.py:17788>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17788
--# expr-start 5020 '<FieldAccess for id at ast.py:17788>' Fld /tmp/lal-23.0.0/ada/ast.py:17788
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.For_Loop_Var_Decl_F_Id, Info => Ent.Info);
--# expr-done 5020
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 5021
--# expr-start 5026 '<If at ast.py:17788>' If_Result /tmp/lal-23.0.0/ada/ast.py:17788
--# expr-start 5023 '<IsNull at ast.py:17789>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17789
--# expr-start 5022 '<FieldAccess for id_type at ast.py:17789>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17789
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Type_Expr (Node => Ent.Node.For_Loop_Var_Decl_F_Id_Type, Info => Ent.Info);
--# expr-done 5022
Is_Null := Fld_4.Node = null; 
--# expr-done 5023
if Is_Null then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17790") else null)); 
   If_Result := True_Rel;
else
   --# expr-start 5025 '<FieldAccess for sub_equation at ast.py:17791>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17791
--# expr-start 5024 '<FieldAccess for id_type at ast.py:17791>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17791
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Type_Expr (Node => Ent.Node.For_Loop_Var_Decl_F_Id_Type, Info => Ent.Info);
--# expr-done 5024
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 5025
   If_Result := Fld_3;
end if;
      Inc_Ref (If_Result);
--# expr-done 5026
And_Pred := Create_And (Fld_1, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17788") else null)); 
--# expr-done 5027
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5028
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1279;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1279;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Var_Decl_P_Xref_Equation;
--# end
--# property-start ForLoopVarDecl._env_mappings_133 /tmp/lal-23.0.0/ada/ast.py:17771
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_133
  (Node : Bare_For_Loop_Var_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_For_Loop_Var_Decl := Bare_For_Loop_Var_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1602 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_For_Loop_Var_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1602 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1602;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5031 '<New EnvAssoc at ast.py:17771>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:17771
--# expr-start 5029 '<New DesignatedEnv at ast.py:17771>' New_Struct /tmp/lal-23.0.0/ada/ast.py:17771
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5029
--# expr-start 5030 '<FieldAccess for name_symbol at ast.py:17771>' Fld /tmp/lal-23.0.0/ada/ast.py:17771
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 5030
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5031
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1602;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1602;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_133;
--# end
   --
   --  Primitives for Bare_Generic_Decl
   --
      procedure Initialize_Fields_For_Generic_Decl
        (Self : Bare_Generic_Decl
         ; Generic_Decl_F_Formal_Part : Bare_Generic_Formal_Part
        ) is
      begin
            Self.Generic_Decl_F_Formal_Part := Generic_Decl_F_Formal_Part;
      end Initialize_Fields_For_Generic_Decl;
   function Generic_Decl_F_Formal_Part
     (Node : Bare_Generic_Decl) return Bare_Generic_Formal_Part
   is
   begin
         return Node.Generic_Decl_F_Formal_Part;
   end;
--# property-start '[dispatcher]GenericDecl.decl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Generic_Decl_P_Decl
  (Node : Bare_Generic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Decl := Bare_Generic_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Generic_Decl (Self.Kind) is
               when Ada_Generic_Package_Decl =>
                  --# property-call-start GenericPackageDecl.decl
                  Property_Result := Generic_Package_Decl_P_Decl
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Decl =>
                  --# property-call-start GenericSubpDecl.decl
                  Property_Result := Generic_Subp_Decl_P_Decl
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Generic_Decl_P_Decl;
--# end
--# property-start GenericDecl.get_aspect_assoc /tmp/lal-23.0.0/ada/ast.py:11400
pragma Warnings (Off, "is not referenced");
 function Generic_Decl_P_Get_Aspect_Assoc
  (Node : Bare_Generic_Decl
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Aspect_Assoc
is
   Self : Bare_Generic_Decl := Bare_Generic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Decl :=
     Internal_Entity_Generic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Aspect_Assoc;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Aspect_Assoc;
Let_Result : Internal_Entity_Aspect_Assoc;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5034 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5033 '<FieldAccess for get_aspect_assoc at ast.py:11403>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11403
--# expr-start 5032 '<FieldAccess for decl at ast.py:11403>' Fld /tmp/lal-23.0.0/ada/ast.py:11403
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericDecl.decl'
Fld := Libadalang.Implementation.Dispatcher_Generic_Decl_P_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5032
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.get_aspect_assoc'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Get_Aspect_Assoc (Node => Fld.Node, Name => Name, E_Info => Fld.Info);
--# end
--# expr-done 5033
Let_Result := Fld_1; 
--# end
--# expr-done 5034
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Decl_P_Get_Aspect_Assoc;
--# end
--# property-start GenericDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:11406
pragma Warnings (Off, "is not referenced");
 function Generic_Decl_P_Next_Part_For_Decl
  (Node : Bare_Generic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Decl := Bare_Generic_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Decl :=
     Internal_Entity_Generic_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5037 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5036 '<FieldAccess for next_part_for_decl at ast.py:11407>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11407
--# expr-start 5035 '<FieldAccess for decl at ast.py:11407>' Fld /tmp/lal-23.0.0/ada/ast.py:11407
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericDecl.decl'
Fld := Libadalang.Implementation.Dispatcher_Generic_Decl_P_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5035
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 5036
Let_Result := Fld_1; 
--# end
--# expr-done 5037
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Decl_P_Next_Part_For_Decl;
--# end
   --
   --  Primitives for Bare_Generic_Package_Decl
   --
      procedure Generic_Package_Decl_Pre_Env_Actions
        (Self            : Bare_Generic_Package_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_119 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_120 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:11494");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_121 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:11501");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_122 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_123 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_125 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_124 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_127 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_126 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Generic_Package_Decl
        (Self : Bare_Generic_Package_Decl
         ; Generic_Decl_F_Formal_Part : Bare_Generic_Formal_Part
         ; Generic_Package_Decl_F_Package_Decl : Bare_Generic_Package_Internal
        ) is
      begin
            Initialize_Fields_For_Generic_Decl
              (Self, Generic_Decl_F_Formal_Part);
            Self.Generic_Package_Decl_F_Package_Decl := Generic_Package_Decl_F_Package_Decl;
      end Initialize_Fields_For_Generic_Package_Decl;
   function Generic_Package_Decl_F_Package_Decl
     (Node : Bare_Generic_Package_Decl) return Bare_Generic_Package_Internal
   is
   begin
         return Node.Generic_Package_Decl_F_Package_Decl;
   end;
--# property-start GenericPackageDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:11521
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Decl_P_Defining_Env
  (Node : Bare_Generic_Package_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Decl :=
     Internal_Entity_Generic_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_909 with Inline_Always;
      Fld : Internal_Entity_Generic_Package_Internal;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_909 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_909;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5039 '<FieldAccess for defining_env at ast.py:11521>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11521
--# expr-start 5038 '<FieldAccess for package_decl at ast.py:11521>' Fld /tmp/lal-23.0.0/ada/ast.py:11521
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Package_Internal (Node => Ent.Node.Generic_Package_Decl_F_Package_Decl, Info => Ent.Info);
--# expr-done 5038
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 5039
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_909;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_909;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Decl_P_Defining_Env;
--# end
--# property-start GenericPackageDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:11523
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Decl_P_Defining_Names
  (Node : Bare_Generic_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_910 with Inline_Always;
      Fld : Bare_Generic_Package_Internal;
Fld_1 : Bare_Defining_Name;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_910 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_910;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5042 '<as_entity at ast.py:11524>' If_Result /tmp/lal-23.0.0/ada/ast.py:11524
--# expr-start 5041 '<FieldAccess for package_name at ast.py:11524>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11524
--# expr-start 5040 '<FieldAccess for package_decl at ast.py:11524>' Fld /tmp/lal-23.0.0/ada/ast.py:11524
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Generic_Package_Decl_F_Package_Decl;
--# expr-done 5040
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Base_Package_Decl_F_Package_Name;
--# expr-done 5041
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 5042
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := If_Result;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_910;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_910;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Decl_P_Defining_Names;
--# end
--# property-start GenericPackageDecl.body_part /tmp/lal-23.0.0/ada/ast.py:11528
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Decl_P_Body_Part
  (Node : Bare_Generic_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Package_Body
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Decl :=
     Internal_Entity_Generic_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Package_Body;
      Fld : Internal_Entity_Generic_Package_Internal;
Fld_1 : Internal_Entity_Package_Body;
Let_Result : Internal_Entity_Package_Body;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5045 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5044 '<FieldAccess for body_part at ast.py:11533>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11533
--# expr-start 5043 '<FieldAccess for package_decl at ast.py:11533>' Fld /tmp/lal-23.0.0/ada/ast.py:11533
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Package_Internal (Node => Ent.Node.Generic_Package_Decl_F_Package_Decl, Info => Ent.Info);
--# expr-done 5043
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasePackageDecl.body_part
Fld_1 := Libadalang.Implementation.Base_Package_Decl_P_Body_Part (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 5044
Let_Result := Fld_1; 
--# end
--# expr-done 5045
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Decl_P_Body_Part;
--# end
--# property-start GenericPackageDecl.decl /tmp/lal-23.0.0/ada/ast.py:11535
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Decl_P_Decl
  (Node : Bare_Generic_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Decl :=
     Internal_Entity_Generic_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Generic_Package_Internal;
Cast_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 5046 '<FieldAccess for package_decl at ast.py:11535>' Fld /tmp/lal-23.0.0/ada/ast.py:11535
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Package_Internal (Node => Ent.Node.Generic_Package_Decl_F_Package_Decl, Info => Ent.Info);
--# expr-done 5046
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Decl_P_Decl;
--# end
--# property-start GenericPackageDecl._env_do_119 /tmp/lal-23.0.0/ada/ast.py:11492
pragma Warnings (Off, "is not referenced");
 function Env_Do_119
  (Node : Bare_Generic_Package_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5047 '<FieldAccess for env_hook at ast.py:11492>' Fld /tmp/lal-23.0.0/ada/ast.py:11492
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5047
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_119;
--# end
--# property-start GenericPackageDecl._initial_env_120 /tmp/lal-23.0.0/ada/ast.py:11498
pragma Warnings (Off, "is not referenced");
 function Initial_Env_120
  (Node : Bare_Generic_Package_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1589 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1589 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1589;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5048 '<FieldAccess for child_decl_initial_env at ast.py:11498>' Fld /tmp/lal-23.0.0/ada/ast.py:11498
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self, Private_Part => True);
--# end
--# expr-done 5048
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1589;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1589;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_120;
--# end
--# property-start GenericPackageDecl._env_mappings_121 /tmp/lal-23.0.0/ada/ast.py:11501
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_121
  (Node : Bare_Generic_Package_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Decl :=
     Internal_Entity_Generic_Package_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1590 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1590 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1590;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5049 '<FieldAccess for child_decl_env_assocs at ast.py:11501>' Fld /tmp/lal-23.0.0/ada/ast.py:11501
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_env_assocs
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Env_Assocs (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5049
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1590;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1590;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_121;
--# end
--# property-start GenericPackageDecl._env_trans_parent_122 /tmp/lal-23.0.0/ada/ast.py:11491
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_122
  (Node : Bare_Generic_Package_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_122;
--# end
--# property-start GenericPackageDecl._env_do_123 /tmp/lal-23.0.0/ada/ast.py:11505
pragma Warnings (Off, "is not referenced");
 function Env_Do_123
  (Node : Bare_Generic_Package_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1592 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1592 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1592;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5050 '<FieldAccess for populate_dependent_units at ast.py:11505>' Fld /tmp/lal-23.0.0/ada/ast.py:11505
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5050
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1592;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1592;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_123;
--# end
--# property-start GenericPackageDecl._ref_env_nodes_124 /tmp/lal-23.0.0/ada/ast.py:11507
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_124
  (Node : Bare_Generic_Package_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1593 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1593 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1593;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5051 '<FieldAccess for top_level_use_package_clauses at ast.py:11507>' Fld /tmp/lal-23.0.0/ada/ast.py:11507
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5051
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1593;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1593;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_124;
--# end
--# property-start GenericPackageDecl._ref_cond_125 /tmp/lal-23.0.0/ada/ast.py:11509
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_125
  (Node : Bare_Generic_Package_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5053 '<IsA LibraryItem, Subunit at ast.py:11509>' Is_A /tmp/lal-23.0.0/ada/ast.py:11509
--# expr-start 5052 '<parent at ast.py:11509>' Fld /tmp/lal-23.0.0/ada/ast.py:11509
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5052
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5053
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_125;
--# end
--# property-start GenericPackageDecl._ref_env_nodes_126 /tmp/lal-23.0.0/ada/ast.py:11512
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_126
  (Node : Bare_Generic_Package_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1595 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1595 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1595;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5054 '<FieldAccess for top_level_use_type_clauses at ast.py:11512>' Fld /tmp/lal-23.0.0/ada/ast.py:11512
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5054
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1595;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1595;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_126;
--# end
--# property-start GenericPackageDecl._ref_cond_127 /tmp/lal-23.0.0/ada/ast.py:11514
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_127
  (Node : Bare_Generic_Package_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Decl := Bare_Generic_Package_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5056 '<IsA LibraryItem, Subunit at ast.py:11514>' Is_A /tmp/lal-23.0.0/ada/ast.py:11514
--# expr-start 5055 '<parent at ast.py:11514>' Fld /tmp/lal-23.0.0/ada/ast.py:11514
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5055
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5056
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_127;
--# end
   --
   --  Primitives for Bare_Generic_Subp_Decl
   --
      procedure Generic_Subp_Decl_Pre_Env_Actions
        (Self            : Bare_Generic_Subp_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_107 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_108 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:11431");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_109 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:11438");
         end loop;
         Dec_Ref (Mappings);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_110 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_111 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_113 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_112 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_115 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_114 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Generic_Subp_Decl_Post_Env_Actions
        (Self : Bare_Generic_Subp_Decl; State : in out PLE_Node_State) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_116 (Node => 
Self);
      end;
      end;
      procedure Initialize_Fields_For_Generic_Subp_Decl
        (Self : Bare_Generic_Subp_Decl
         ; Generic_Decl_F_Formal_Part : Bare_Generic_Formal_Part
         ; Generic_Subp_Decl_F_Subp_Decl : Bare_Generic_Subp_Internal
        ) is
      begin
            Initialize_Fields_For_Generic_Decl
              (Self, Generic_Decl_F_Formal_Part);
            Self.Generic_Subp_Decl_F_Subp_Decl := Generic_Subp_Decl_F_Subp_Decl;
      end Initialize_Fields_For_Generic_Subp_Decl;
   function Generic_Subp_Decl_F_Subp_Decl
     (Node : Bare_Generic_Subp_Decl) return Bare_Generic_Subp_Internal
   is
   begin
         return Node.Generic_Subp_Decl_F_Subp_Decl;
   end;
--# property-start GenericSubpDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:11418
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Decl_P_Defining_Names
  (Node : Bare_Generic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Decl :=
     Internal_Entity_Generic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_903 with Inline_Always;
      Fld : Internal_Entity_Generic_Subp_Internal;
Fld_1 : Internal_Entity_Subp_Spec;
Fld_2 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_903 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_903;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5059 '<FieldAccess for name at ast.py:11418>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11418
--# expr-start 5058 '<FieldAccess for subp_spec at ast.py:11418>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11418
--# expr-start 5057 '<FieldAccess for subp_decl at ast.py:11418>' Fld /tmp/lal-23.0.0/ada/ast.py:11418
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Subp_Internal (Node => Ent.Node.Generic_Subp_Decl_F_Subp_Decl, Info => Ent.Info);
--# expr-done 5057
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Subp_Spec (Node => Fld.Node.Generic_Subp_Internal_F_Subp_Spec, Info => Fld.Info);
--# expr-done 5058
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.name'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Name (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 5059
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_2;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_903;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_903;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Decl_P_Defining_Names;
--# end
--# property-start GenericSubpDecl.body_part /tmp/lal-23.0.0/ada/ast.py:11421
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Decl_P_Body_Part
  (Node : Bare_Generic_Subp_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Subp_Body
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Decl :=
     Internal_Entity_Generic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Base_Subp_Body;
      Fld : Internal_Entity_Body_Node;
Cast_Result : Internal_Entity_Base_Subp_Body;
Let_Result : Internal_Entity_Base_Subp_Body;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5062 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5061 '<Cast to BaseSubpBody at ast.py:11425>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11425
--# expr-start 5060 '<FieldAccess for body_part_for_decl at ast.py:11425>' Fld /tmp/lal-23.0.0/ada/ast.py:11425
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 5060
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Body
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 5061
Let_Result := Cast_Result; 
--# end
--# expr-done 5062
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Decl_P_Body_Part;
--# end
--# property-start GenericSubpDecl.decl /tmp/lal-23.0.0/ada/ast.py:11460
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Decl_P_Decl
  (Node : Bare_Generic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Decl :=
     Internal_Entity_Generic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Generic_Subp_Internal;
Cast_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 5063 '<FieldAccess for subp_decl at ast.py:11460>' Fld /tmp/lal-23.0.0/ada/ast.py:11460
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Subp_Internal (Node => Ent.Node.Generic_Subp_Decl_F_Subp_Decl, Info => Ent.Info);
--# expr-done 5063
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Decl_P_Decl;
--# end
--# property-start GenericSubpDecl.is_imported /tmp/lal-23.0.0/ada/ast.py:11463
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Decl_P_Is_Imported
  (Node : Bare_Generic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Decl :=
     Internal_Entity_Generic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Generic_Subp_Internal;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5065 '<FieldAccess for is_imported at ast.py:11463>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11463
--# expr-start 5064 '<FieldAccess for subp_decl at ast.py:11463>' Fld /tmp/lal-23.0.0/ada/ast.py:11463
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Subp_Internal (Node => Ent.Node.Generic_Subp_Decl_F_Subp_Decl, Info => Ent.Info);
--# expr-done 5064
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_imported'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Imported (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 5065
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Decl_P_Is_Imported;
--# end
--# property-start GenericSubpDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:11466
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Decl_P_Next_Part_For_Decl
  (Node : Bare_Generic_Subp_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Decl :=
     Internal_Entity_Generic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Generic_Subp_Internal;
Fld_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5068 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5067 '<FieldAccess for next_part_for_decl at ast.py:11467>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11467
--# expr-start 5066 '<FieldAccess for subp_decl at ast.py:11467>' Fld /tmp/lal-23.0.0/ada/ast.py:11467
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Generic_Subp_Internal (Node => Ent.Node.Generic_Subp_Decl_F_Subp_Decl, Info => Ent.Info);
--# expr-done 5066
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.next_part_for_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Decl (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 5067
Let_Result := Fld_1; 
--# end
--# expr-done 5068
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Decl_P_Next_Part_For_Decl;
--# end
--# property-start GenericSubpDecl._env_do_107 /tmp/lal-23.0.0/ada/ast.py:11429
pragma Warnings (Off, "is not referenced");
 function Env_Do_107
  (Node : Bare_Generic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5069 '<FieldAccess for env_hook at ast.py:11429>' Fld /tmp/lal-23.0.0/ada/ast.py:11429
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5069
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_107;
--# end
--# property-start GenericSubpDecl._initial_env_108 /tmp/lal-23.0.0/ada/ast.py:11435
pragma Warnings (Off, "is not referenced");
 function Initial_Env_108
  (Node : Bare_Generic_Subp_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1577 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1577 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1577;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5070 '<FieldAccess for child_decl_initial_env at ast.py:11435>' Fld /tmp/lal-23.0.0/ada/ast.py:11435
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self, Private_Part => True);
--# end
--# expr-done 5070
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1577;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1577;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_108;
--# end
--# property-start GenericSubpDecl._env_mappings_109 /tmp/lal-23.0.0/ada/ast.py:11438
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_109
  (Node : Bare_Generic_Subp_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Decl :=
     Internal_Entity_Generic_Subp_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1578 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1578 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1578;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5071 '<FieldAccess for child_decl_env_assocs at ast.py:11438>' Fld /tmp/lal-23.0.0/ada/ast.py:11438
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_env_assocs
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Env_Assocs (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5071
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1578;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1578;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_109;
--# end
--# property-start GenericSubpDecl._env_trans_parent_110 /tmp/lal-23.0.0/ada/ast.py:11427
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_110
  (Node : Bare_Generic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_110;
--# end
--# property-start GenericSubpDecl._env_do_111 /tmp/lal-23.0.0/ada/ast.py:11442
pragma Warnings (Off, "is not referenced");
 function Env_Do_111
  (Node : Bare_Generic_Subp_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1580 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1580 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1580;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5072 '<FieldAccess for populate_dependent_units at ast.py:11442>' Fld /tmp/lal-23.0.0/ada/ast.py:11442
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5072
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1580;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1580;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_111;
--# end
--# property-start GenericSubpDecl._ref_env_nodes_112 /tmp/lal-23.0.0/ada/ast.py:11445
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_112
  (Node : Bare_Generic_Subp_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1581 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1581 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1581;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5073 '<FieldAccess for top_level_use_package_clauses at ast.py:11445>' Fld /tmp/lal-23.0.0/ada/ast.py:11445
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5073
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1581;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1581;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_112;
--# end
--# property-start GenericSubpDecl._ref_cond_113 /tmp/lal-23.0.0/ada/ast.py:11447
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_113
  (Node : Bare_Generic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5075 '<IsA LibraryItem, Subunit at ast.py:11447>' Is_A /tmp/lal-23.0.0/ada/ast.py:11447
--# expr-start 5074 '<parent at ast.py:11447>' Fld /tmp/lal-23.0.0/ada/ast.py:11447
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5074
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5075
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_113;
--# end
--# property-start GenericSubpDecl._ref_env_nodes_114 /tmp/lal-23.0.0/ada/ast.py:11450
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_114
  (Node : Bare_Generic_Subp_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1583 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1583 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1583;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5076 '<FieldAccess for top_level_use_type_clauses at ast.py:11450>' Fld /tmp/lal-23.0.0/ada/ast.py:11450
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5076
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1583;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1583;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_114;
--# end
--# property-start GenericSubpDecl._ref_cond_115 /tmp/lal-23.0.0/ada/ast.py:11452
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_115
  (Node : Bare_Generic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5078 '<IsA LibraryItem, Subunit at ast.py:11452>' Is_A /tmp/lal-23.0.0/ada/ast.py:11452
--# expr-start 5077 '<parent at ast.py:11452>' Fld /tmp/lal-23.0.0/ada/ast.py:11452
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5077
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5078
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_115;
--# end
--# property-start GenericSubpDecl._env_do_116 /tmp/lal-23.0.0/ada/ast.py:11457
pragma Warnings (Off, "is not referenced");
 function Env_Do_116
  (Node : Bare_Generic_Subp_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Decl := Bare_Generic_Subp_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5079 '<FieldAccess for populate_body_unit at ast.py:11457>' Fld /tmp/lal-23.0.0/ada/ast.py:11457
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_body_unit
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Body_Unit (Node => Self);
--# end
--# expr-done 5079
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_116;
--# end
   --
   --  Primitives for Bare_Generic_Instantiation
   --
      procedure Initialize_Fields_For_Generic_Instantiation
        (Self : Bare_Generic_Instantiation
        ) is
      begin
      Self.Lf_Present_Instantiation_Env := False;
      Self.Lf_Stg_Instantiation_Env := Empty_Env;
      Self.Lf_Present_Actual_Expr_Decls := False;
      Self.Lf_Stg_Actual_Expr_Decls := No_Bare_Anonymous_Expr_Decl_Array_Type;
      end Initialize_Fields_For_Generic_Instantiation;
--# property-start GenericInstantiation.instantiation_env /tmp/lal-23.0.0/ada/ast.py:10577
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_F_Instantiation_Env
  (Node : Bare_Generic_Instantiation
  )
   return Lexical_Env
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_846 with Inline_Always;
      Dyn_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_846 is
            begin
                     Dec_Ref (Dyn_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_846;
begin
   --# property-body-start
      if Self.Lf_Present_Instantiation_Env then
         Property_Result := Self.Lf_Stg_Instantiation_Env;
            Inc_Ref (Property_Result);
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5081 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5080 '<DynamicLexicalEnv at ast.py:10578>' Dyn_Env /tmp/lal-23.0.0/ada/ast.py:10578
Dyn_Env := Create_Dynamic_Lexical_Env (Self, Generic_Instantiation_P_Instantiation_Bindings'Access, Ada_Node_P_Resolve_Generic_Actual'Access, False); 
--# expr-done 5080
Let_Result := Dyn_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 5081
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_846;
      Self.Lf_Present_Instantiation_Env := True;
      Self.Lf_Stg_Instantiation_Env := Property_Result;
         Inc_Ref (Property_Result);
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_846;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_F_Instantiation_Env;
--# end
--# property-start GenericInstantiation.instantiation_bindings /tmp/lal-23.0.0/ada/ast.py:10585
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Instantiation_Bindings
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Inner_Env_Assoc_Array_Access
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Instantiation :=
     Internal_Entity_Generic_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_847 with Inline_Always;
      Block_Var : Internal_Entity_Generic_Decl;
Fld : Internal_Entity_Generic_Decl;
Fld_1 : Internal_Inner_Env_Assoc_Array_Access;
Let_Result : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_847 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_847;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5084 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5082 '<FieldAccess for nonbound_generic_decl at ast.py:10590>' Fld /tmp/lal-23.0.0/ada/ast.py:10590
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.nonbound_generic_decl
Fld := Libadalang.Implementation.Generic_Instantiation_P_Nonbound_Generic_Decl (Node => Self);
--# end
--# expr-done 5082
Block_Var := Fld; 
--# expr-start 5083 '<FieldAccess for instantiation_bindings_internal at ast.py:10591>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10591
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.instantiation_bindings_internal
Fld_1 := Libadalang.Implementation.Generic_Instantiation_P_Instantiation_Bindings_Internal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5083
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5084
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_847;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_847;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Instantiation_Bindings;
--# end
--# property-start GenericInstantiation.instantiation_bindings_internal /tmp/lal-23.0.0/ada/ast.py:10595
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Instantiation_Bindings_Internal
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Inner_Env_Assoc_Array_Access
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Instantiation :=
     Internal_Entity_Generic_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_848 with Inline_Always;
            procedure Finalizer_Scope_2522 with Inline_Always;
            procedure Finalizer_Scope_2524 with Inline_Always;
      Var_Expr : Internal_Entity_Generic_Decl;
Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Generic_Decl;
Fld_2 : Internal_Entity_Generic_Formal_Part;
Fld_3 : Internal_Entity_Assoc_List;
Fld_4 : Internal_Param_Match_Array_Access;
Scope_Result : Internal_Param_Match_Array_Access;
Result_Var : Internal_Param_Match_Array_Access;
Fld_5 : Internal_Single_Actual;
Fld_6 : Internal_Entity_Basic_Assoc;
Fld_7 : Internal_Entity_Expr;
Is_A : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Param_Match_Array_Access;
Fld_8 : Internal_Entity_Defining_Name;
Fld_9 : Internal_Entity_Name;
Fld_10 : Symbol_Type;
Fld_11 : Bare_Anonymous_Expr_Decl_Array_Access;
Get_Result : Bare_Anonymous_Expr_Decl;
Fld_12 : Internal_Single_Actual;
Fld_13 : Internal_Entity_Basic_Assoc;
Fld_14 : Internal_Entity_Expr;
Fld_15 : Bare_Expr;
Cast_Result : Bare_Ada_Node;
Cast_Result_1 : Bare_Ada_Node;
Fld_16 : Internal_Entity_Defining_Name;
Fld_17 : Internal_Entity_Base_Formal_Param_Decl;
Is_A_1 : Boolean;
If_Result : Bare_Ada_Node;
New_Struct : Internal_Metadata;
New_Struct_1 : Internal_Inner_Env_Assoc;
Index_180 : Integer;
Map_Result_1 : Internal_Inner_Env_Assoc_Array_Access;
Dyn_Var_Bind_Result : Internal_Inner_Env_Assoc_Array_Access;
Fld_18 : Boolean;
If_Result_1 : Internal_Inner_Env_Assoc_Array_Access;
Let_Result : Internal_Inner_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_848 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_848;
            procedure Finalizer_Scope_2522 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2522;
            procedure Finalizer_Scope_2524 is
            begin
                     Dec_Ref (Fld_11);
            end Finalizer_Scope_2524;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Generic_Instantiation_Generic_Instantiation_P_Instantiation_Bindings_Internal,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Generic_Instantiation,
                                As_Bare_Generic_Instantiation => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Inner_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
      end if;
   --# scope-start
      --# expr-start 5115 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5114 '<If at ast.py:10596>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:10596
--# expr-start 5085 '<FieldAccess for is_any_formal at ast.py:10597>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:10597
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.is_any_formal
Fld_18 := Libadalang.Implementation.Generic_Instantiation_P_Is_Any_Formal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5085
if Fld_18 then
   If_Result_1 := No_Internal_Inner_Env_Assoc_Array_Type;
else
   --# expr-start 5113 '<bind at ast.py:10599>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:10599
--# expr-start 5086 '<FieldAccess for default_initial_env at ast.py:10600>' Fld /tmp/lal-23.0.0/ada/ast.py:10600
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.default_initial_env
Fld := Libadalang.Implementation.Ada_Node_P_Default_Initial_Env (Node => Self);
--# end
--# expr-done 5086
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 5112 '<Map at ast.py:10605>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:10605
   --# expr-start 5096 '<Filter at ast.py:10603>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10603
--# expr-start 5087 '<FieldAccess for nonbound_generic_decl at ast.py:10601>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10601
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.nonbound_generic_decl
Fld_1 := Libadalang.Implementation.Generic_Instantiation_P_Nonbound_Generic_Decl (Node => Self);
--# end
--# expr-done 5087
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 5090 '<FieldAccess for match_param_list at ast.py:10601>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10601
--# expr-start 5088 '<FieldAccess for formal_part at ast.py:10601>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10601
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Generic_Formal_Part (Node => Var_Expr.Node.Generic_Decl_F_Formal_Part, Info => Var_Expr.Info);
--# expr-done 5088
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5089 '<FieldAccess for generic_inst_params at ast.py:10602>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10602
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_inst_params'
Fld_3 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Inst_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5089
--# property-call-start BaseFormalParamHolder.match_param_list
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Param_List (Node => Fld_2.Node, Params => Fld_3, Is_Dottable_Subp => False, Env => Bound_Env, E_Info => Fld_2.Info);
--# end
--# expr-done 5090
Scope_Result := Fld_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2522;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Param_Match_Array_Type;
end if;
      Inc_Ref (Result_Var);
      declare
         Map_Result_Vec : Internal_Param_Match_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Result_Var;
      begin
         for Item_181 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_181
         --# expr-start 5095 '<Not at ast.py:10604>' Not_Val /tmp/lal-23.0.0/ada/ast.py:10604
--# expr-start 5094 '<IsA BoxExpr at ast.py:10604>' Is_A /tmp/lal-23.0.0/ada/ast.py:10604
--# expr-start 5093 '<FieldAccess for expr at ast.py:10604>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10604
--# expr-start 5092 '<FieldAccess for assoc at ast.py:10604>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10604
--# expr-start 5091 '<FieldAccess for actual at ast.py:10604>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10604
Fld_5 := Item_181.Actual;
--# expr-done 5091
Fld_6 := Fld_5.Assoc;
--# expr-done 5092
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 5093
Is_A := Fld_7.Node /= null 
and then Fld_7.Node.Kind in Ada_Box_Expr_Range; 
--# expr-done 5094
Not_Val := not (Is_A); 
--# expr-done 5095
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Param_Match := Item_181;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5096
      declare
         Map_Result_1_Vec : Internal_Inner_Env_Assoc_Vectors.Vector;
      begin
         Index_180 := 0;
      declare
         Collection : constant Internal_Param_Match_Array_Access := Map_Result;
      begin
         for Item_179 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_179
               --# bind i Index_180
      --# expr-start 5111 '<New InnerEnvAssoc at ast.py:10606>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10606
--# expr-start 5099 '<FieldAccess for name_symbol at ast.py:10607>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10607
--# expr-start 5098 '<FieldAccess for name at ast.py:10607>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10607
--# expr-start 5097 '<FieldAccess for formal at ast.py:10607>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10607
Fld_8 := Item_179.Formal;
--# expr-done 5097
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Name (Node => Fld_8.Node.Defining_Name_F_Name, Info => Fld_8.Info);
--# expr-done 5098
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_10 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_9.Node);
--# end
--# expr-done 5099
--# expr-start 5100 '<New Metadata at ast.py:10613>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10613
New_Struct := (Dottable_Subp => False, Primitive => No_Bare_Ada_Node, Primitive_Real_Type => No_Bare_Ada_Node); 
--# expr-done 5100
--# expr-start 5110 '<If at ast.py:10608>' If_Result /tmp/lal-23.0.0/ada/ast.py:10608
--# expr-start 5103 '<IsA GenericFormalObjDecl at ast.py:10609>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:10609
--# expr-start 5102 '<FieldAccess for formal_decl at ast.py:10609>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:10609
--# expr-start 5101 '<FieldAccess for formal at ast.py:10609>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:10609
Fld_16 := Item_179.Formal;
--# expr-done 5101
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_17 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_16.Node, E_Info => Fld_16.Info);
--# end
--# expr-done 5102
Is_A_1 := Fld_17.Node /= null 
and then Fld_17.Node.Kind in Ada_Generic_Formal_Obj_Decl_Range; 
--# expr-done 5103
if Is_A_1 then
--# expr-start 5105 '<at at ast.py:10610>' Get_Result /tmp/lal-23.0.0/ada/ast.py:10610
--# expr-start 5104 '<FieldAccess for actual_expr_decls at ast.py:10610>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10610
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.actual_expr_decls
Fld_11 := Libadalang.Implementation.Generic_Instantiation_F_Actual_Expr_Decls (Node => Ent.Node);
--# end
--# expr-done 5104
Get_Result := Get (Self, Fld_11, Index_180, True); 
--# expr-done 5105
      Cast_Result := Get_Result;
   If_Result := Cast_Result;
else
--# expr-start 5109 '<FieldAccess for node at ast.py:10611>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:10611
--# expr-start 5108 '<FieldAccess for expr at ast.py:10611>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:10611
--# expr-start 5107 '<FieldAccess for assoc at ast.py:10611>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10611
--# expr-start 5106 '<FieldAccess for actual at ast.py:10611>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10611
Fld_12 := Item_179.Actual;
--# expr-done 5106
Fld_13 := Fld_12.Assoc;
--# expr-done 5107
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_14 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_13.Node, E_Info => Fld_13.Info);
--# end
--# expr-done 5108
Fld_15 := Fld_14.Node;
--# expr-done 5109
      Cast_Result_1 := Fld_15;
   If_Result := Cast_Result_1;
end if;
--# expr-done 5110
New_Struct_1 := (Key => Fld_10, Metadata => New_Struct, Value => If_Result); 
--# expr-done 5111
         declare
            Item_To_Append : constant Internal_Inner_Env_Assoc := New_Struct_1;
         begin
            Internal_Inner_Env_Assoc_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2524;
               Index_180 := Index_180 + 1;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Inner_Env_Assoc_Array
           (Items_Count => Natural (Internal_Inner_Env_Assoc_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Inner_Env_Assoc_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Inner_Env_Assoc_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Inner_Env_Assoc_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 5112
Dyn_Var_Bind_Result := Map_Result_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 5113
   If_Result_1 := Dyn_Var_Bind_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 5114
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5115
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_848;
      if Self /= null then
            Mmz_Val := (Kind => Mmz_Internal_Inner_Env_Assoc_Array_Access,
                        As_Internal_Inner_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_848;
               Finalizer_Scope_2522;
               Finalizer_Scope_2524;
         if Self /= null then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Instantiation_Bindings_Internal;
--# end
--# property-start '[dispatcher]GenericInstantiation.generic_entity_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Generic_Instantiation_P_Generic_Entity_Name
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Generic_Instantiation (Self.Kind) is
               when Ada_Generic_Package_Instantiation =>
                  --# property-call-start GenericPackageInstantiation.generic_entity_name
                  Property_Result := Generic_Package_Instantiation_P_Generic_Entity_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericSubpInstantiation.generic_entity_name
                  Property_Result := Generic_Subp_Instantiation_P_Generic_Entity_Name
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Generic_Instantiation_P_Generic_Entity_Name;
--# end
--# property-start '[dispatcher]GenericInstantiation.generic_inst_params' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Generic_Instantiation_P_Generic_Inst_Params
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Assoc_List
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Assoc_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Generic_Instantiation (Self.Kind) is
               when Ada_Generic_Package_Instantiation =>
                  --# property-call-start GenericPackageInstantiation.generic_inst_params
                  Property_Result := Generic_Package_Instantiation_P_Generic_Inst_Params
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericSubpInstantiation.generic_inst_params
                  Property_Result := Generic_Subp_Instantiation_P_Generic_Inst_Params
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Generic_Instantiation_P_Generic_Inst_Params;
--# end
--# property-start GenericInstantiation.is_any_formal /tmp/lal-23.0.0/ada/ast.py:10632
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Is_Any_Formal
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Instantiation :=
     Internal_Entity_Generic_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Basic_Assoc;
Fld : Internal_Entity_Assoc_List;
Fld_1 : Bare_Assoc_List;
Fld_2 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_3 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5118 '<IsA BoxExpr at ast.py:10633>' Is_A /tmp/lal-23.0.0/ada/ast.py:10633
--# expr-start 5116 '<FieldAccess for generic_inst_params at ast.py:10633>' Fld /tmp/lal-23.0.0/ada/ast.py:10633
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_inst_params'
Fld := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Inst_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5116
Fld_1 := Fld.Node;
Get_Result := Get (Self, Fld_1, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Get_Result); 
   If_Result := As_Entity;
end if;
Var_Expr := If_Result;
if Var_Expr /= No_Entity_Basic_Assoc then
   --# scope-start
--# expr-start 5117 '<FieldAccess for expr at ast.py:10633>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10633
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 5117
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Expr;
end if;
Is_A := Result_Var.Node /= null 
and then Result_Var.Node.Kind in Ada_Box_Expr_Range; 
--# expr-done 5118
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Is_Any_Formal;
--# end
--# property-start GenericInstantiation.nonbound_generic_decl /tmp/lal-23.0.0/ada/ast.py:10636
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Nonbound_Generic_Decl
  (Node : Bare_Generic_Instantiation
  )
   return Internal_Entity_Generic_Decl
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Generic_Decl;
            procedure Finalizer_Scope_852 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity;
Match_0 : Internal_Entity_Body_Node;
Match_1 : Internal_Entity_Generic_Renaming_Decl;
Match_2 : Internal_Entity_Basic_Decl;
Match_3 : Internal_Entity;
As_Entity : Internal_Entity_Generic_Instantiation;
Is_Null : Boolean;
If_Result : Internal_Entity_Generic_Instantiation;
Fld : Internal_Entity_Name;
Cast_Expr : Bare_Generic_Instantiation;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Entity_Array_Access;
Fld_2 : Boolean;
Find_Result : Internal_Entity;
Bound_Imprecise_Fallback : Boolean;
Fld_3 : Internal_Entity_Basic_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Generic_Decl;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Body_Node;
Let_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Generic_Renaming_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Let_Result_1 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity_Basic_Decl;
Let_Result_2 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Cast_Result_5 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Generic_Decl;
Cast_Result_6 : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Basic_Decl;
Scope_Result_3 : Internal_Entity_Basic_Decl;
Match_Result : Internal_Entity_Basic_Decl;
Scope_Result_4 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Cast_Expr_2 : Internal_Entity_Basic_Decl;
Cast_Result_7 : Internal_Entity_Generic_Decl;
Scope_Result_5 : Internal_Entity_Generic_Decl;
Result_Var_1 : Internal_Entity_Generic_Decl;
            procedure Finalizer_Scope_852 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_852;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 5123 '<Find at ast.py:10640>' Find_Result /tmp/lal-23.0.0/ada/ast.py:10640
   --# expr-start 5121 '<FieldAccess for all_env_elements_internal at ast.py:10637>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10637
--# expr-start 5120 '<FieldAccess for generic_entity_name at ast.py:10637>' Fld /tmp/lal-23.0.0/ada/ast.py:10637
--# expr-start 5119 '<as_bare_entity at ast.py:10637>' If_Result /tmp/lal-23.0.0/ada/ast.py:10637
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Generic_Instantiation;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 5119
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_entity_name'
Fld := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Entity_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 5120
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start Name.all_env_elements_internal
Fld_1 := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Fld.Node, Seq => True, Seq_From => Cast_Result, Categories => (Inherited_Primitives => False, Nocat => True), E_Info => Fld.Info);
--# end
--# expr-done 5121
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_1;
      begin
         for Item_182 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_182
      --# expr-start 5122 '<FieldAccess for has_visibility at ast.py:10641>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10641
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_visibility
Fld_2 := Libadalang.Implementation.Ada_Node_P_Has_Visibility (Node => Self, Other_Entity => Item_182);
--# end
--# expr-done 5122
      if Fld_2 then
         Find_Result := Item_182;
      end if;
   --# end
               exit when Fld_2;
         end loop;
      end;
--# expr-done 5123
Var_Expr_1 := Find_Result;
if Var_Expr_1 /= No_Entity then
   --# scope-start
--# expr-start 5127 '<Match at ast.py:10642>' Match_Result /tmp/lal-23.0.0/ada/ast.py:10642
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr_1; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Expr_Function .. Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Body_Node
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind b Match_0
--# expr-start 5125 '<bind at ast.py:10643>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:10643
Bound_Imprecise_Fallback := False; 
--# expr-start 5124 '<FieldAccess for decl_part at ast.py:10643>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10643
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld_3 := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Match_0.Node, Imprecise_Fallback => Bound_Imprecise_Fallback, E_Info => Match_0.Info);
--# end
--# expr-done 5124
Dyn_Var_Bind_Result := Fld_3; 
--# expr-done 5125
Let_Result := Dyn_Var_Bind_Result; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Generic_Package_Renaming_Decl .. Ada_Generic_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Generic_Renaming_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind rd Match_1
--# expr-start 5126 '<FieldAccess for resolve at ast.py:10644>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10644
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericRenamingDecl.resolve
Fld_4 := Libadalang.Implementation.Generic_Renaming_Decl_P_Resolve (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 5126
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Let_Result_1 := Cast_Result_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Synthetic_Subp_Decl | Ada_Entry_Index_Spec .. Ada_Generic_Subp_Instantiation | Ada_Label_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind d Match_2
Let_Result_2 := Match_2; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_5; 
--# bind _ Match_3
Cast_Expr_1 := No_Entity_Generic_Decl; 
      Cast_Result_6 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Let_Result_3 := Cast_Result_6; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 5127
Scope_Result_4 := Match_Result;
   --# end
   Result_Var := Scope_Result_4;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 5128 '<Cast to GenericDecl at ast.py:10647>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:10647
Cast_Expr_2 := Var_Expr; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Generic_Decl
   then
      Cast_Result_7 := Create_Internal_Entity_Generic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_7 := No_Entity_Generic_Decl;
   end if;
--# expr-done 5128
Scope_Result_5 := Cast_Result_7;
   --# end
   Result_Var_1 := Scope_Result_5;
else
   Result_Var_1 := No_Entity_Generic_Decl;
end if;
      Property_Result := Result_Var_1;
   --# end
      Finalizer_Scope_852;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_852;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Nonbound_Generic_Decl;
--# end
--# property-start '[dispatcher]GenericInstantiation.designated_generic_decl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Generic_Instantiation_P_Designated_Generic_Decl
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Generic_Instantiation (Self.Kind) is
               when Ada_Generic_Package_Instantiation =>
                  --# property-call-start GenericPackageInstantiation.designated_generic_decl
                  Property_Result := Generic_Package_Instantiation_P_Designated_Generic_Decl
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Instantiation =>
                  --# property-call-start GenericSubpInstantiation.designated_generic_decl
                  Property_Result := Generic_Subp_Instantiation_P_Designated_Generic_Decl
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Generic_Instantiation_P_Designated_Generic_Decl;
--# end
--# property-start GenericInstantiation.actual_expr_decls /tmp/lal-23.0.0/ada/ast.py:10664
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_F_Actual_Expr_Decls
  (Node : Bare_Generic_Instantiation
  )
   return Bare_Anonymous_Expr_Decl_Array_Access
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Anonymous_Expr_Decl_Array_Access;
            procedure Finalizer_Scope_854 with Inline_Always;
      Match_0 : Bare_Generic_Subp_Instantiation;
Match_1 : Bare_Generic_Package_Instantiation;
Fld : Bare_Assoc_List;
Fld_1 : Bare_Assoc_List;
Match_Prefix : Bare_Generic_Instantiation;
Cast_Result : Bare_Generic_Subp_Instantiation;
Let_Result : Bare_Assoc_List;
Scope_Result : Bare_Assoc_List;
Cast_Result_1 : Bare_Generic_Package_Instantiation;
Let_Result_1 : Bare_Assoc_List;
Scope_Result_1 : Bare_Assoc_List;
Match_Result : Bare_Assoc_List;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Bare_Expr;
New_Node : Bare_Anonymous_Expr_Decl;
Item_183 : Bare_Basic_Assoc;
Map_Result : Bare_Anonymous_Expr_Decl_Array_Access;
Let_Result_2 : Bare_Anonymous_Expr_Decl_Array_Access;
            procedure Finalizer_Scope_854 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_854;
begin
   --# property-body-start
      if Self.Lf_Present_Actual_Expr_Decls then
         Property_Result := Self.Lf_Stg_Actual_Expr_Decls;
            Inc_Ref (Property_Result);
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5137 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 5136 '<Map at ast.py:10668>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10668
   --# expr-start 5131 '<Match at ast.py:10665>' Match_Result /tmp/lal-23.0.0/ada/ast.py:10665
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Generic_Instantiation (Match_Prefix.Kind) is
         when Ada_Generic_Subp_Instantiation =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind subp Match_0
--# expr-start 5129 '<FieldAccess for params at ast.py:10666>' Fld /tmp/lal-23.0.0/ada/ast.py:10666
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Match_0.Generic_Subp_Instantiation_F_Params;
--# expr-done 5129
Let_Result := Fld; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Generic_Package_Instantiation =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind pkg Match_1
--# expr-start 5130 '<FieldAccess for params at ast.py:10667>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10667
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Match_1.Generic_Package_Instantiation_F_Params;
--# expr-done 5130
Let_Result_1 := Fld_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 5131
      declare
         Map_Result_Vec : Bare_Anonymous_Expr_Decl_Vectors.Vector;
      begin
      if Match_Result = null then
      Map_Result := Create_Bare_Anonymous_Expr_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Match_Result;
      begin
         for Untyped_Item_183 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_183 := Untyped_Item_183; 
   --# scope-start
               --# bind assoc Item_183
      --# expr-start 5135 '<New AnonymousExprDecl at ast.py:10669>' New_Node /tmp/lal-23.0.0/ada/ast.py:10669
--# expr-start 5134 '<FieldAccess for node at ast.py:10670>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10670
--# expr-start 5133 '<FieldAccess for expr at ast.py:10670>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10670
--# expr-start 5132 '<as_bare_entity at ast.py:10670>' If_Result /tmp/lal-23.0.0/ada/ast.py:10670
Is_Null := Item_183 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
As_Entity := (Info => No_Entity_Info, Node => Item_183); 
   If_Result := As_Entity;
end if;
--# expr-done 5132
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 5133
Fld_3 := Fld_2.Node;
--# expr-done 5134
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Anonymous_Expr_Decl);
Initialize
  (Self => New_Node,
   Kind => Ada_Anonymous_Expr_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Anonymous_Expr_Decl
     (Self => New_Node,
      Anonymous_Expr_Decl_F_Expr => Fld_3);
--# expr-done 5135
         declare
            Item_To_Append : constant Bare_Anonymous_Expr_Decl := New_Node;
         begin
            Bare_Anonymous_Expr_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Anonymous_Expr_Decl_Array
           (Items_Count => Natural (Bare_Anonymous_Expr_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Anonymous_Expr_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Anonymous_Expr_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Anonymous_Expr_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5136
Let_Result_2 := Map_Result; Inc_Ref (Let_Result_2);
--# end
--# expr-done 5137
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_854;
      Self.Lf_Present_Actual_Expr_Decls := True;
      Self.Lf_Stg_Actual_Expr_Decls := Property_Result;
         Inc_Ref (Property_Result);
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_854;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_F_Actual_Expr_Decls;
--# end
--# property-start GenericInstantiation.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:10674
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Xref_Entry_Point
  (Node : Bare_Generic_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Xref_Entry_Point;
--# end
--# property-start GenericInstantiation.xref_equation /tmp/lal-23.0.0/ada/ast.py:10676
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Xref_Equation
  (Node : Bare_Generic_Instantiation
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Instantiation :=
     Internal_Entity_Generic_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_856 with Inline_Always;
            procedure Finalizer_Scope_2529 with Inline_Always;
            procedure Finalizer_Scope_2530 with Inline_Always;
            procedure Finalizer_Scope_2531 with Inline_Always;
            procedure Finalizer_Scope_2533 with Inline_Always;
            procedure Finalizer_Scope_2534 with Inline_Always;
            procedure Finalizer_Scope_2535 with Inline_Always;
            procedure Finalizer_Scope_2536 with Inline_Always;
            procedure Finalizer_Scope_2537 with Inline_Always;
            procedure Finalizer_Scope_2538 with Inline_Always;
      Match_0 : Internal_Entity_Dotted_Name;
Match_1 : Internal_Entity_Name;
Var_Expr : Internal_Entity_Generic_Decl;
Actual_Name : Internal_Entity_Name;
Match_0_1 : Internal_Entity_Type_Decl;
Match_1_1 : Internal_Entity_Formal_Subp_Decl;
Match_2 : Internal_Entity_Object_Decl;
Match_3 : Internal_Entity_Basic_Decl;
Var_Expr_1 : Bare_Base_Id;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Generic_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Name;
Fld_4 : Internal_Entity_Name;
Fld_5 : Logic_Equation;
True_Rel : Logic_Equation;
Match_Prefix : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Dotted_Name;
Let_Result : Logic_Equation;
Scope_Result : Logic_Equation;
Cast_Result_2 : Internal_Entity_Name;
Let_Result_1 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Match_Result : Logic_Equation;
And_Pred : Logic_Equation;
True_Rel_1 : Logic_Equation;
Fld_6 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Generic_Decl;
Fld_7 : Internal_Entity_Generic_Formal_Part;
Fld_8 : Internal_Entity_Assoc_List;
Fld_9 : Internal_Param_Match_Array_Access;
Scope_Result_2 : Internal_Param_Match_Array_Access;
Result_Var : Internal_Param_Match_Array_Access;
Fld_10 : Internal_Single_Actual;
Fld_11 : Internal_Entity_Basic_Assoc;
Fld_12 : Internal_Entity_Expr;
Is_A : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Param_Match_Array_Access;
Fld_13 : Internal_Single_Actual;
Fld_14 : Internal_Entity_Basic_Assoc;
Fld_15 : Internal_Entity_Expr;
Cast_Result_4 : Internal_Entity_Name;
Fld_16 : Internal_Entity_Defining_Name;
Fld_17 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_5 : Internal_Entity_Generic_Formal;
Fld_18 : Internal_Entity_Basic_Decl;
Fld_19 : Logic_Equation;
Fld_20 : Logic_Equation;
Fld_21 : Logic_Equation;
Fld_22 : Logic_Var;
Cast_Expr : Internal_Entity_Formal_Subp_Decl;
Cast_Result_6 : Internal_Entity_Basic_Decl;
Pred : Logic_Equation;
And_Pred_1 : Logic_Equation;
True_Rel_2 : Logic_Equation;
Or_Pred : Logic_Equation;
Is_A_1 : Boolean;
If_Result : Logic_Equation;
Fld_23 : Internal_Single_Actual;
Fld_24 : Internal_Entity_Basic_Assoc;
Fld_25 : Internal_Entity_Expr;
Fld_26 : Logic_Var;
Fld_27 : Internal_Entity_Base_Type_Decl;
Cast_Result_7 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_28 : Internal_Single_Actual;
Fld_29 : Internal_Entity_Basic_Assoc;
Fld_30 : Internal_Entity_Expr;
Fld_31 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_32 : Internal_Single_Actual;
Fld_33 : Internal_Entity_Basic_Assoc;
Fld_34 : Internal_Entity_Expr;
Fld_35 : Logic_Equation;
And_Pred_3 : Logic_Equation;
True_Rel_3 : Logic_Equation;
Match_Prefix_1 : Internal_Entity_Basic_Decl;
Cast_Result_8 : Internal_Entity_Type_Decl;
Let_Result_2 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Cast_Result_9 : Internal_Entity_Formal_Subp_Decl;
Let_Result_3 : Logic_Equation;
Scope_Result_4 : Logic_Equation;
Cast_Result_10 : Internal_Entity_Object_Decl;
Let_Result_4 : Logic_Equation;
Scope_Result_5 : Logic_Equation;
Cast_Result_11 : Internal_Entity_Basic_Decl;
Let_Result_5 : Logic_Equation;
Scope_Result_6 : Logic_Equation;
Match_Result_1 : Logic_Equation;
Fld_36 : Internal_Single_Actual;
Fld_37 : Bare_Base_Id;
Fld_38 : Logic_Var;
Fld_39 : Internal_Entity_Defining_Name;
Fld_40 : Bare_Defining_Name;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result_1 : Internal_Entity_Defining_Name;
Fld_41 : Internal_Entity_Basic_Decl;
Cast_Result_12 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Scope_Result_7 : Logic_Equation;
True_Rel_4 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Let_Result_6 : Logic_Equation;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_42 : Boolean;
If_Result_2 : Logic_Equation;
And_Pred_5 : Logic_Equation;
            procedure Finalizer_Scope_856 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Match_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (And_Pred_5);
            end Finalizer_Scope_856;
            procedure Finalizer_Scope_2529 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2529;
            procedure Finalizer_Scope_2530 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_2530;
            procedure Finalizer_Scope_2531 is
            begin
                     Dec_Ref (Fld_9);
            end Finalizer_Scope_2531;
            procedure Finalizer_Scope_2533 is
            begin
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Let_Result_4);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Let_Result_5);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Match_Result_1);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (True_Rel_4);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Let_Result_6);
            end Finalizer_Scope_2533;
            procedure Finalizer_Scope_2534 is
            begin
                     Dec_Ref (Fld_19);
            end Finalizer_Scope_2534;
            procedure Finalizer_Scope_2535 is
            begin
                     Dec_Ref (Fld_20);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (True_Rel_2);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2535;
            procedure Finalizer_Scope_2536 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_31);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_35);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_2536;
            procedure Finalizer_Scope_2537 is
            begin
                     Dec_Ref (True_Rel_3);
            end Finalizer_Scope_2537;
            procedure Finalizer_Scope_2538 is
            begin
                     Dec_Ref (Bind_Result_2);
            end Finalizer_Scope_2538;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5207 '<And at ast.py:10677>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:10677
--# expr-start 5146 '<And at ast.py:10677>' And_Pred /tmp/lal-23.0.0/ada/ast.py:10677
--# expr-start 5141 '<Bind at ast.py:10677>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:10677
--# expr-start 5139 '<FieldAccess for ref_var at ast.py:10677>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10677
--# expr-start 5138 '<FieldAccess for generic_entity_name at ast.py:10677>' Fld /tmp/lal-23.0.0/ada/ast.py:10677
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_entity_name'
Fld := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Entity_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5138
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld.Node);
--# end
--# expr-done 5139
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 5140 '<FieldAccess for nonbound_generic_decl at ast.py:10678>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.nonbound_generic_decl
Fld_2 := Libadalang.Implementation.Generic_Instantiation_P_Nonbound_Generic_Decl (Node => Ent.Node);
--# end
--# expr-done 5140
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10677") else null)); 
--# expr-done 5141
--# expr-start 5145 '<Match at ast.py:10679>' Match_Result /tmp/lal-23.0.0/ada/ast.py:10679
--# expr-start 5142 '<FieldAccess for generic_entity_name at ast.py:10679>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10679
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_entity_name'
Fld_3 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Entity_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5142
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_3; 
case Ada_Name (Match_Prefix.Node.Kind) is
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Dotted_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind dn Match_0
--# expr-start 5144 '<FieldAccess for xref_no_overloading at ast.py:10680>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10680
--# expr-start 5143 '<FieldAccess for prefix at ast.py:10680>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10680
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Match_0.Node.Dotted_Name_F_Prefix, Info => Match_0.Info);
--# expr-done 5143
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_5 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_4.Node, Env => Env, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 5144
Let_Result := Fld_5; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2529;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind _ Match_1
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10681") else null)); 
Let_Result_1 := True_Rel; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2530;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
end case;
--# expr-done 5145
And_Pred := Create_And (Bind_Result, Match_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10677") else null)); 
--# expr-done 5146
--# expr-start 5206 '<If at ast.py:10682>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:10682
--# expr-start 5147 '<FieldAccess for is_any_formal at ast.py:10683>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:10683
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.is_any_formal
Fld_42 := Libadalang.Implementation.Generic_Instantiation_P_Is_Any_Formal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5147
if Fld_42 then
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10684") else null)); 
   If_Result_2 := True_Rel_1;
else
   --# expr-start 5205 '<LogicAll at ast.py:10691>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:10691
--# expr-start 5204 '<Map at ast.py:10691>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:10691
   --# expr-start 5158 '<Filter at ast.py:10689>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10689
--# expr-start 5149 '<Cast to GenericDecl at ast.py:10686>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:10686
--# expr-start 5148 '<FieldAccess for designated_generic_decl at ast.py:10686>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.designated_generic_decl'
Fld_6 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Designated_Generic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5148
   if Fld_6.Node = null
      or else Fld_6.Node.Kind in Ada_Generic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Generic_Decl
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5149
Var_Expr := Cast_Result_3;
if Var_Expr /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 5152 '<FieldAccess for match_param_list at ast.py:10687>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10687
--# expr-start 5150 '<FieldAccess for formal_part at ast.py:10687>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10687
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Generic_Formal_Part (Node => Var_Expr.Node.Generic_Decl_F_Formal_Part, Info => Var_Expr.Info);
--# expr-done 5150
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5151 '<FieldAccess for generic_inst_params at ast.py:10688>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10688
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_inst_params'
Fld_8 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Inst_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5151
--# property-call-start BaseFormalParamHolder.match_param_list
Fld_9 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Param_List (Node => Fld_7.Node, Params => Fld_8, Is_Dottable_Subp => False, Env => Env, E_Info => Fld_7.Info);
--# end
--# expr-done 5152
Scope_Result_2 := Fld_9;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2531;
   Result_Var := Scope_Result_2;
else
   Result_Var := No_Internal_Param_Match_Array_Type;
end if;
      Inc_Ref (Result_Var);
      declare
         Map_Result_Vec : Internal_Param_Match_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Result_Var;
      begin
         for Item_185 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_185
         --# expr-start 5157 '<Not at ast.py:10690>' Not_Val /tmp/lal-23.0.0/ada/ast.py:10690
--# expr-start 5156 '<IsA BoxExpr at ast.py:10690>' Is_A /tmp/lal-23.0.0/ada/ast.py:10690
--# expr-start 5155 '<FieldAccess for expr at ast.py:10690>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10690
--# expr-start 5154 '<FieldAccess for assoc at ast.py:10690>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10690
--# expr-start 5153 '<FieldAccess for actual at ast.py:10690>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10690
Fld_10 := Item_185.Actual;
--# expr-done 5153
Fld_11 := Fld_10.Assoc;
--# expr-done 5154
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_12 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_11.Node, E_Info => Fld_11.Info);
--# end
--# expr-done 5155
Is_A := Fld_12.Node /= null 
and then Fld_12.Node.Kind in Ada_Box_Expr_Range; 
--# expr-done 5156
Not_Val := not (Is_A); 
--# expr-done 5157
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Param_Match := Item_185;
         begin
            Internal_Param_Match_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Match_Array
           (Items_Count => Natural (Internal_Param_Match_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Match_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Match_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Match_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5158
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Map_Result;
      begin
         for Item_184 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_184
      --# expr-start 5203 '<Let at ast.py:10691>' Let_Result_6 /tmp/lal-23.0.0/ada/ast.py:10691
--# scope-start
--# expr-start 5162 '<Cast to Name at ast.py:10692>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:10692
--# expr-start 5161 '<FieldAccess for expr at ast.py:10692>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:10692
--# expr-start 5160 '<FieldAccess for assoc at ast.py:10692>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:10692
--# expr-start 5159 '<FieldAccess for actual at ast.py:10692>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10692
Fld_13 := Item_184.Actual;
--# expr-done 5159
Fld_14 := Fld_13.Assoc;
--# expr-done 5160
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_15 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_14.Node, E_Info => Fld_14.Info);
--# end
--# expr-done 5161
   if Fld_15.Node = null
      or else Fld_15.Node.Kind in Ada_Name
   then
      Cast_Result_4 := Create_Internal_Entity_Name
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
   else
         Cast_Result_4 := No_Entity_Name;
   end if;
--# expr-done 5162
Actual_Name := Cast_Result_4; 
--# bind actual_name Actual_Name
--# expr-start 5202 '<And at ast.py:10693>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:10693
--# expr-start 5193 '<Match at ast.py:10693>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:10693
--# expr-start 5166 '<FieldAccess for decl at ast.py:10693>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:10693
--# expr-start 5165 '<Cast to GenericFormal at ast.py:10693>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:10693
--# expr-start 5164 '<FieldAccess for formal_decl at ast.py:10693>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:10693
--# expr-start 5163 '<FieldAccess for formal at ast.py:10693>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:10693
Fld_16 := Item_184.Formal;
--# expr-done 5163
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_17 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_16.Node, E_Info => Fld_16.Info);
--# end
--# expr-done 5164
   if Fld_17.Node = null
      or else Fld_17.Node.Kind in Ada_Generic_Formal
   then
      Cast_Result_5 := Create_Internal_Entity_Generic_Formal
        (Node => Fld_17.Node,
         Info => Fld_17.Info);
   else
         Cast_Result_5 := No_Entity_Generic_Formal;
   end if;
--# expr-done 5165
      if Cast_Result_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Basic_Decl (Node => Cast_Result_5.Node.Generic_Formal_F_Decl, Info => Cast_Result_5.Info);
--# expr-done 5166
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Fld_18; 
case Ada_Basic_Decl (Match_Prefix_1.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Type_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_0_1 := Cast_Result_8; 
--# bind _ Match_0_1
--# expr-start 5167 '<FieldAccess for xref_no_overloading at ast.py:10694>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:10694
      if Actual_Name.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_19 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Actual_Name.Node, Env => Env, Origin => Origin, E_Info => Actual_Name.Info);
--# end
--# expr-done 5167
Let_Result_2 := Fld_19; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2534;
            Match_Result_1 := Scope_Result_3; Inc_Ref (Match_Result_1);
         when Ada_Abstract_Formal_Subp_Decl .. Ada_Concrete_Formal_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Formal_Subp_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_1_1 := Cast_Result_9; 
--# bind subp_decl Match_1_1
--# expr-start 5176 '<If at ast.py:10697>' If_Result /tmp/lal-23.0.0/ada/ast.py:10697
--# expr-start 5168 '<IsA AttributeRef at ast.py:10698>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:10698
Is_A_1 := Actual_Name.Node /= null 
and then Actual_Name.Node.Kind in Ada_Attribute_Ref_Range; 
--# expr-done 5168
if Is_A_1 then
   --# expr-start 5169 '<FieldAccess for sub_equation at ast.py:10699>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:10699
      if Actual_Name.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_20 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Actual_Name.Node, Env => Env, Origin => Origin, E_Info => Actual_Name.Info);
--# end
--# expr-done 5169
   If_Result := Fld_20;
else
   --# expr-start 5175 '<Or at ast.py:10700>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:10700
--# expr-start 5174 '<And at ast.py:10700>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:10700
--# expr-start 5170 '<FieldAccess for xref_no_overloading at ast.py:10700>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:10700
      if Actual_Name.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_21 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Actual_Name.Node, All_Els => True, Env => Env, Origin => Origin, E_Info => Actual_Name.Info);
--# end
--# expr-done 5170
--# expr-start 5173 '<Predicate on BasicDecl.subp_decl_match_signature at ast.py:10701>' Pred /tmp/lal-23.0.0/ada/ast.py:10701
--# expr-start 5171 '<FieldAccess for ref_var at ast.py:10702>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:10702
      if Actual_Name.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_22 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Actual_Name.Node);
--# end
--# expr-done 5171
Fld_22.Value := No_Entity;
Entity_Vars.Reset (Fld_22);
--# expr-start 5172 '<Cast to BasicDecl at ast.py:10703>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:10703
Cast_Expr := Match_1_1; 
      Cast_Result_6 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-done 5172
Pred := Solver.Create_Predicate (Fld_22, Create_Basic_Decl_P_Subp_Decl_Match_Signature_0_Predicate (Cast_Result_6)); 
--# expr-done 5173
And_Pred_1 := Create_And (Fld_21, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10700") else null)); 
--# expr-done 5174
True_Rel_2 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10704") else null)); 
Or_Pred := Create_Or (And_Pred_1, True_Rel_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10700") else null)); 
--# expr-done 5175
   If_Result := Or_Pred;
end if;
      Inc_Ref (If_Result);
--# expr-done 5176
Let_Result_3 := If_Result; Inc_Ref (Let_Result_3);
--# end
Scope_Result_4 := Let_Result_3;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2535;
            Match_Result_1 := Scope_Result_4; Inc_Ref (Match_Result_1);
         when Ada_Object_Decl .. Ada_No_Type_Object_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity_Object_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_2 := Cast_Result_10; 
--# bind obj_decl Match_2
--# expr-start 5192 '<And at ast.py:10708>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:10708
--# expr-start 5187 '<And at ast.py:10708>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:10708
--# expr-start 5182 '<Bind at ast.py:10708>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:10708
--# expr-start 5180 '<FieldAccess for expected_type_var at ast.py:10708>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:10708
--# expr-start 5179 '<FieldAccess for expr at ast.py:10708>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:10708
--# expr-start 5178 '<FieldAccess for assoc at ast.py:10708>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:10708
--# expr-start 5177 '<FieldAccess for actual at ast.py:10708>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:10708
Fld_23 := Item_184.Actual;
--# expr-done 5177
Fld_24 := Fld_23.Assoc;
--# expr-done 5178
      if Fld_24.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_25 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_24.Node, E_Info => Fld_24.Info);
--# end
--# expr-done 5179
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_25.Node);
--# expr-done 5180
Fld_26.Value := No_Entity;
Entity_Vars.Reset (Fld_26);
--# expr-start 5181 '<FieldAccess for expr_type at ast.py:10709>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:10709
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_27 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Match_2.Node, Origin => Origin, E_Info => Match_2.Info);
--# end
--# expr-done 5181
      Cast_Result_7 := Create_Internal_Entity
        (Node => Fld_27.Node,
         Info => Fld_27.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_26, Cast_Result_7, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10708") else null)); 
--# expr-done 5182
--# expr-start 5186 '<FieldAccess for sub_equation at ast.py:10710>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:10710
--# expr-start 5185 '<FieldAccess for expr at ast.py:10710>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:10710
--# expr-start 5184 '<FieldAccess for assoc at ast.py:10710>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:10710
--# expr-start 5183 '<FieldAccess for actual at ast.py:10710>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:10710
Fld_28 := Item_184.Actual;
--# expr-done 5183
Fld_29 := Fld_28.Assoc;
--# expr-done 5184
      if Fld_29.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_30 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_29.Node, E_Info => Fld_29.Info);
--# end
--# expr-done 5185
      if Fld_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_31 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_30.Node, Env => Env, Origin => Origin, E_Info => Fld_30.Info);
--# end
--# expr-done 5186
And_Pred_2 := Create_And (Bind_Result_1, Fld_31, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10708") else null)); 
--# expr-done 5187
--# expr-start 5191 '<FieldAccess for matches_expected_assign_type at ast.py:10711>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:10711
--# expr-start 5190 '<FieldAccess for expr at ast.py:10711>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:10711
--# expr-start 5189 '<FieldAccess for assoc at ast.py:10711>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:10711
--# expr-start 5188 '<FieldAccess for actual at ast.py:10711>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:10711
Fld_32 := Item_184.Actual;
--# expr-done 5188
Fld_33 := Fld_32.Assoc;
--# expr-done 5189
      if Fld_33.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_34 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_33.Node, E_Info => Fld_33.Info);
--# end
--# expr-done 5190
      if Fld_34.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_35 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Fld_34.Node, Origin => Origin);
--# end
--# expr-done 5191
And_Pred_3 := Create_And (And_Pred_2, Fld_35, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10708") else null)); 
--# expr-done 5192
Let_Result_4 := And_Pred_3; Inc_Ref (Let_Result_4);
--# end
Scope_Result_5 := Let_Result_4;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2536;
            Match_Result_1 := Scope_Result_5; Inc_Ref (Match_Result_1);
         when Ada_Abstract_State_Decl .. Ada_Single_Task_Type_Decl | Ada_Abstract_Subp_Decl | Ada_Subp_Decl .. Ada_Number_Decl | Ada_Package_Renaming_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_3 := Cast_Result_11; 
--# bind _ Match_3
True_Rel_3 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10713") else null)); 
Let_Result_5 := True_Rel_3; Inc_Ref (Let_Result_5);
--# end
Scope_Result_6 := Let_Result_5;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_2537;
            Match_Result_1 := Scope_Result_6; Inc_Ref (Match_Result_1);
end case;
--# expr-done 5193
--# expr-start 5195 '<FieldAccess for name at ast.py:10714>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:10714
--# expr-start 5194 '<FieldAccess for actual at ast.py:10714>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:10714
Fld_36 := Item_184.Actual;
--# expr-done 5194
Fld_37 := Fld_36.Name;
--# expr-done 5195
Var_Expr_1 := Fld_37;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind n Var_Expr_1
--# expr-start 5201 '<Bind at ast.py:10716>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:10716
--# expr-start 5196 '<FieldAccess for ref_var at ast.py:10716>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:10716
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_38 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Var_Expr_1);
--# end
--# expr-done 5196
Fld_38.Value := No_Entity;
Entity_Vars.Reset (Fld_38);
--# expr-start 5200 '<FieldAccess for basic_decl at ast.py:10717>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:10717
--# expr-start 5199 '<as_bare_entity at ast.py:10717>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:10717
--# expr-start 5198 '<FieldAccess for node at ast.py:10717>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:10717
--# expr-start 5197 '<FieldAccess for formal at ast.py:10717>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:10717
Fld_39 := Item_184.Formal;
--# expr-done 5197
Fld_40 := Fld_39.Node;
--# expr-done 5198
Is_Null := Fld_40 = null; 
if Is_Null then
   If_Result_1 := No_Entity_Defining_Name;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_40); 
   If_Result_1 := As_Entity;
end if;
--# expr-done 5199
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_41 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => If_Result_1.Node, E_Info => If_Result_1.Info);
--# end
--# expr-done 5200
      Cast_Result_12 := Create_Internal_Entity
        (Node => Fld_41.Node,
         Info => Fld_41.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_38, Cast_Result_12, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10716") else null)); 
--# expr-done 5201
Scope_Result_7 := Bind_Result_2;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_2538;
   Result_Var_1 := Scope_Result_7;
else
   True_Rel_4 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10718") else null)); 
   Result_Var_1 := True_Rel_4;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_4 := Create_And (Match_Result_1, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10693") else null)); 
--# expr-done 5202
Let_Result_6 := And_Pred_4; Inc_Ref (Let_Result_6);
--# end
--# expr-done 5203
         declare
            Item_To_Append : constant Logic_Equation := Let_Result_6;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2533;
         end loop;
      end;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 5204
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10691") else null)); 
--# expr-done 5205
   If_Result_2 := Logic_Boolean_Op;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 5206
And_Pred_5 := Create_And (And_Pred, If_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10677") else null)); 
--# expr-done 5207
      Property_Result := And_Pred_5;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_856;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_856;
               Finalizer_Scope_2529;
               Finalizer_Scope_2530;
               Finalizer_Scope_2531;
               Finalizer_Scope_2533;
               Finalizer_Scope_2534;
               Finalizer_Scope_2535;
               Finalizer_Scope_2536;
               Finalizer_Scope_2537;
               Finalizer_Scope_2538;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Xref_Equation;
--# end
--# property-start GenericInstantiation.inst_params /tmp/lal-23.0.0/ada/ast.py:10725
pragma Warnings (Off, "is not referenced");
 function Generic_Instantiation_P_Inst_Params
  (Node : Bare_Generic_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Actual_Array_Access
is
   Self : Bare_Generic_Instantiation := Bare_Generic_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Instantiation :=
     Internal_Entity_Generic_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_857 with Inline_Always;
            procedure Finalizer_Scope_2540 with Inline_Always;
            procedure Finalizer_Scope_2541 with Inline_Always;
            procedure Finalizer_Scope_2542 with Inline_Always;
            procedure Finalizer_Scope_2543 with Inline_Always;
            procedure Finalizer_Scope_2545 with Inline_Always;
            procedure Finalizer_Scope_2547 with Inline_Always;
      Block_Var : Internal_Entity_Assoc_List;
Var_Expr : Internal_Entity_Generic_Decl;
Match_0 : Internal_Entity_Generic_Formal_Package;
Match_1 : Internal_Entity_Generic_Formal_Type_Decl;
Match_2 : Internal_Entity_Generic_Formal_Obj_Decl;
Match_3 : Internal_Entity_Generic_Formal_Subp_Decl;
Match_4 : Internal_Entity;
Subp : Internal_Entity_Formal_Subp_Decl;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Assoc_List;
Fld_1 : Internal_Entity_Generic_Decl;
Fld_2 : Internal_Entity_Generic_Formal_Part;
Fld_3 : Internal_Entity_Ada_Node_List;
Scope_Result : Internal_Entity_Ada_Node_List;
Result_Var : Internal_Entity_Ada_Node_List;
Fld_4 : Bare_Ada_Node_List;
Fld_5 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_6 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Generic_Package_Instantiation;
Fld_7 : Internal_Entity_Defining_Name;
New_Struct : Internal_Param_Actual;
Singleton : Internal_Param_Actual_Array_Access;
Fld_8 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Type_Decl;
Fld_9 : Internal_Entity_Defining_Name;
New_Struct_1 : Internal_Param_Actual;
Singleton_1 : Internal_Param_Actual_Array_Access;
Fld_10 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Object_Decl;
Fld_11 : Internal_Entity_Defining_Name_List;
Fld_12 : Bare_Defining_Name_List;
Fld_13 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Defining_Name;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Defining_Name;
Fld_14 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Object_Decl;
Fld_15 : Internal_Entity_Expr;
New_Struct_2 : Internal_Param_Actual;
Item_189 : Internal_Entity_Defining_Name;
Bare_Item_189 : Bare_Defining_Name;
Map_Result : Internal_Param_Actual_Array_Access;
Fld_16 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity_Formal_Subp_Decl;
Fld_17 : Internal_Entity_Defining_Name;
Fld_18 : Internal_Entity_Basic_Decl;
Fld_19 : Internal_Entity_Defining_Name;
Scope_Result_1 : Internal_Entity_Defining_Name;
Result_Var_1 : Internal_Entity_Defining_Name;
Fld_20 : Internal_Entity_Expr;
Cast_Result_5 : Internal_Entity_Expr;
Fld_21 : Internal_Entity_Expr;
Is_A : Boolean;
If_Result_2 : Internal_Entity_Expr;
New_Struct_3 : Internal_Param_Actual;
Let_Result : Internal_Param_Actual;
Singleton_2 : Internal_Param_Actual_Array_Access;
Singleton_3 : Internal_Param_Actual_Array_Access;
Match_Prefix : Internal_Entity;
Cast_Result_6 : Internal_Entity_Generic_Formal_Package;
Let_Result_1 : Internal_Param_Actual_Array_Access;
Scope_Result_2 : Internal_Param_Actual_Array_Access;
Cast_Result_7 : Internal_Entity_Generic_Formal_Type_Decl;
Let_Result_2 : Internal_Param_Actual_Array_Access;
Scope_Result_3 : Internal_Param_Actual_Array_Access;
Cast_Result_8 : Internal_Entity_Generic_Formal_Obj_Decl;
Let_Result_3 : Internal_Param_Actual_Array_Access;
Scope_Result_4 : Internal_Param_Actual_Array_Access;
Cast_Result_9 : Internal_Entity_Generic_Formal_Subp_Decl;
Let_Result_4 : Internal_Param_Actual_Array_Access;
Scope_Result_5 : Internal_Param_Actual_Array_Access;
Cast_Result_10 : Internal_Entity;
Let_Result_5 : Internal_Param_Actual_Array_Access;
Scope_Result_6 : Internal_Param_Actual_Array_Access;
Match_Result : Internal_Param_Actual_Array_Access;
Item_188 : Internal_Entity;
Bare_Item_188 : Bare_Ada_Node;
Map_Result_1 : Internal_Param_Actual_Array_Access;
Fld_22 : Internal_Entity_Defining_Name;
Fld_23 : Internal_Entity_Defining_Name;
Fld_24 : Internal_Entity_Expr;
Fld_25 : Internal_Entity_Expr;
New_Struct_4 : Internal_Param_Actual;
Index_187 : Integer;
Map_Result_2 : Internal_Param_Actual_Array_Access;
Let_Result_6 : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_857 is
            begin
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Let_Result_6);
            end Finalizer_Scope_857;
            procedure Finalizer_Scope_2540 is
            begin
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Let_Result_4);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Let_Result_5);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_2540;
            procedure Finalizer_Scope_2541 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2541;
            procedure Finalizer_Scope_2542 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2542;
            procedure Finalizer_Scope_2543 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2543;
            procedure Finalizer_Scope_2545 is
            begin
                     Dec_Ref (Singleton_2);
            end Finalizer_Scope_2545;
            procedure Finalizer_Scope_2547 is
            begin
                     Dec_Ref (Singleton_3);
            end Finalizer_Scope_2547;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5247 '<Block at ???>' Let_Result_6 None
--# scope-start
--# expr-start 5208 '<FieldAccess for generic_inst_params at ast.py:10730>' Fld /tmp/lal-23.0.0/ada/ast.py:10730
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.generic_inst_params'
Fld := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Generic_Inst_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5208
Block_Var := Fld; 
--# bind ap Block_Var
--# expr-start 5246 '<Map at ast.py:10766>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:10766
   --# expr-start 5240 '<Mapcat at ast.py:10732>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:10732
--# expr-start 5209 '<FieldAccess for nonbound_generic_decl at ast.py:10732>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10732
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.nonbound_generic_decl
Fld_1 := Libadalang.Implementation.Generic_Instantiation_P_Nonbound_Generic_Decl (Node => Ent.Node);
--# end
--# expr-done 5209
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 5211 '<FieldAccess for decls at ast.py:10732>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10732
--# expr-start 5210 '<FieldAccess for formal_part at ast.py:10732>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10732
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Generic_Formal_Part (Node => Var_Expr.Node.Generic_Decl_F_Formal_Part, Info => Var_Expr.Info);
--# expr-done 5210
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Ada_Node_List (Node => Fld_2.Node.Generic_Formal_Part_F_Decls, Info => Fld_2.Info);
--# expr-done 5211
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Ada_Node_List;
end if;
Fld_4 := Result_Var.Node;
      declare
         Map_Result_1_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      if Fld_4 = null then
      Map_Result_1 := Create_Internal_Param_Actual_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_4;
      begin
         for Untyped_Item_188 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_188 := Untyped_Item_188; 
Is_Null := Bare_Item_188 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_5 := Result_Var.Info;
As_Entity := (Info => Fld_5, Node => Bare_Item_188); 
   If_Result := As_Entity;
end if;
                  Item_188 := If_Result; 
   --# scope-start
               --# bind d Item_188
      --# expr-start 5239 '<Match at ast.py:10734>' Match_Result /tmp/lal-23.0.0/ada/ast.py:10734
      if Item_188.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_188; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Generic_Formal_Package =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Generic_Formal_Package
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_6; 
--# bind t Match_0
--# expr-start 5215 '<New ParamActual at ast.py:10735>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10735
--# expr-start 5214 '<FieldAccess for name at ast.py:10736>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10736
--# expr-start 5213 '<Cast to GenericPackageInstantiation at ast.py:10736>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10736
--# expr-start 5212 '<FieldAccess for decl at ast.py:10736>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10736
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Basic_Decl (Node => Match_0.Node.Generic_Formal_F_Decl, Info => Match_0.Info);
--# expr-done 5212
   if Fld_6.Node = null
      or else Fld_6.Node.Kind in Ada_Generic_Package_Instantiation_Range
   then
      Cast_Result := Create_Internal_Entity_Generic_Package_Instantiation
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
   else
         Cast_Result := No_Entity_Generic_Package_Instantiation;
   end if;
--# expr-done 5213
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Defining_Name (Node => Cast_Result.Node.Generic_Package_Instantiation_F_Name, Info => Cast_Result.Info);
--# expr-done 5214
New_Struct := (Actual => No_Entity_Expr, Param => Fld_7); 
--# expr-done 5215
                Singleton := Create_Internal_Param_Actual_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
Let_Result_1 := Singleton; Inc_Ref (Let_Result_1);
--# end
Scope_Result_2 := Let_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2541;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Generic_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Generic_Formal_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_7; 
--# bind t Match_1
--# expr-start 5219 '<New ParamActual at ast.py:10739>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10739
--# expr-start 5218 '<FieldAccess for name at ast.py:10740>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10740
--# expr-start 5217 '<Cast to TypeDecl at ast.py:10740>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:10740
--# expr-start 5216 '<FieldAccess for decl at ast.py:10740>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10740
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Basic_Decl (Node => Match_1.Node.Generic_Formal_F_Decl, Info => Match_1.Info);
--# expr-done 5216
   if Fld_8.Node = null
      or else Fld_8.Node.Kind in Ada_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Type_Decl
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
   else
         Cast_Result_1 := No_Entity_Type_Decl;
   end if;
--# expr-done 5217
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Defining_Name (Node => Cast_Result_1.Node.Base_Type_Decl_F_Name, Info => Cast_Result_1.Info);
--# expr-done 5218
New_Struct_1 := (Actual => No_Entity_Expr, Param => Fld_9); 
--# expr-done 5219
                Singleton_1 := Create_Internal_Param_Actual_Array (Items_Count => 1);
                Singleton_1.Items (1) := New_Struct_1;
Let_Result_2 := Singleton_1; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2542;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Generic_Formal_Obj_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Generic_Formal_Obj_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_8; 
--# bind o Match_2
--# expr-start 5227 '<Map at ast.py:10744>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10744
   --# expr-start 5222 '<FieldAccess for ids at ast.py:10744>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10744
--# expr-start 5221 '<Cast to ObjectDecl at ast.py:10744>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:10744
--# expr-start 5220 '<FieldAccess for decl at ast.py:10744>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10744
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Basic_Decl (Node => Match_2.Node.Generic_Formal_F_Decl, Info => Match_2.Info);
--# expr-done 5220
   if Fld_10.Node = null
      or else Fld_10.Node.Kind in Ada_Object_Decl_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Object_Decl
        (Node => Fld_10.Node,
         Info => Fld_10.Info);
   else
         Cast_Result_2 := No_Entity_Object_Decl;
   end if;
--# expr-done 5221
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Defining_Name_List (Node => Cast_Result_2.Node.Object_Decl_F_Ids, Info => Cast_Result_2.Info);
--# expr-done 5222
Fld_12 := Fld_11.Node;
      declare
         Map_Result_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      if Fld_12 = null then
      Map_Result := Create_Internal_Param_Actual_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld_12;
      begin
         for Untyped_Item_189 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_189 := Untyped_Item_189; 
Is_Null_1 := Bare_Item_189 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Defining_Name;
else
Fld_13 := Fld_11.Info;
As_Entity_1 := (Info => Fld_13, Node => Bare_Item_189); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_189 := If_Result_1; 
   --# scope-start
               --# bind i Item_189
      --# expr-start 5226 '<New ParamActual at ast.py:10745>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:10745
--# expr-start 5225 '<FieldAccess for default_expr at ast.py:10747>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:10747
--# expr-start 5224 '<Cast to ObjectDecl at ast.py:10747>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:10747
--# expr-start 5223 '<FieldAccess for decl at ast.py:10747>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:10747
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Basic_Decl (Node => Match_2.Node.Generic_Formal_F_Decl, Info => Match_2.Info);
--# expr-done 5223
   if Fld_14.Node = null
      or else Fld_14.Node.Kind in Ada_Object_Decl_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Object_Decl
        (Node => Fld_14.Node,
         Info => Fld_14.Info);
   else
         Cast_Result_3 := No_Entity_Object_Decl;
   end if;
--# expr-done 5224
      if Cast_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Expr (Node => Cast_Result_3.Node.Object_Decl_F_Default_Expr, Info => Cast_Result_3.Info);
--# expr-done 5225
New_Struct_2 := (Actual => Fld_15, Param => Item_189); 
--# expr-done 5226
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct_2;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5227
Let_Result_3 := Map_Result; Inc_Ref (Let_Result_3);
--# end
Scope_Result_4 := Let_Result_3;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2543;
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
         when Ada_Generic_Formal_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Generic_Formal_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_9; 
--# bind sp Match_3
--# expr-start 5238 '<Let at ast.py:10750>' Let_Result /tmp/lal-23.0.0/ada/ast.py:10750
--# scope-start
--# expr-start 5229 '<Cast to FormalSubpDecl at ast.py:10751>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:10751
--# expr-start 5228 '<FieldAccess for decl at ast.py:10751>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:10751
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Basic_Decl (Node => Match_3.Node.Generic_Formal_F_Decl, Info => Match_3.Info);
--# expr-done 5228
   if Fld_16.Node = null
      or else Fld_16.Node.Kind in Ada_Formal_Subp_Decl
   then
      Cast_Result_4 := Create_Internal_Entity_Formal_Subp_Decl
        (Node => Fld_16.Node,
         Info => Fld_16.Info);
   else
         Cast_Result_4 := No_Entity_Formal_Subp_Decl;
   end if;
--# expr-done 5229
Subp := Cast_Result_4; 
--# bind subp Subp
--# expr-start 5237 '<New ParamActual at ast.py:10753>' New_Struct_3 /tmp/lal-23.0.0/ada/ast.py:10753
--# expr-start 5235 '<If at ast.py:10755>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:10755
--# expr-start 5231 '<IsA BoxExpr at ast.py:10756>' Is_A /tmp/lal-23.0.0/ada/ast.py:10756
--# expr-start 5230 '<FieldAccess for default_expr at ast.py:10756>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:10756
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Expr (Node => Subp.Node.Formal_Subp_Decl_F_Default_Expr, Info => Subp.Info);
--# expr-done 5230
Is_A := Fld_21.Node /= null 
and then Fld_21.Node.Kind in Ada_Box_Expr_Range; 
--# expr-done 5231
if Is_A then
--# expr-start 5232 '<FieldAccess for designated_subprogram_from at ast.py:10757>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:10757
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start FormalSubpDecl.designated_subprogram_from
Fld_18 := Libadalang.Implementation.Formal_Subp_Decl_P_Designated_Subprogram_From (Node => Subp.Node, Inst => Ent, E_Info => Subp.Info);
--# end
--# expr-done 5232
Var_Expr_1 := Fld_18;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 5233 '<FieldAccess for defining_name at ast.py:10759>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:10759
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_19 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 5233
Scope_Result_1 := Fld_19;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Defining_Name;
end if;
      Cast_Result_5 := Create_Internal_Entity_Expr
        (Node => Result_Var_1.Node,
         Info => Result_Var_1.Info);
   If_Result_2 := Cast_Result_5;
else
   --# expr-start 5234 '<FieldAccess for default_expr at ast.py:10760>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:10760
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Expr (Node => Subp.Node.Formal_Subp_Decl_F_Default_Expr, Info => Subp.Info);
--# expr-done 5234
   If_Result_2 := Fld_20;
end if;
--# expr-done 5235
--# expr-start 5236 '<FieldAccess for defining_name at ast.py:10754>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:10754
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_17 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Match_3.Node, E_Info => Match_3.Info);
--# end
--# expr-done 5236
New_Struct_3 := (Actual => If_Result_2, Param => Fld_17); 
--# expr-done 5237
Let_Result := New_Struct_3; 
--# end
--# expr-done 5238
                Singleton_2 := Create_Internal_Param_Actual_Array (Items_Count => 1);
                Singleton_2.Items (1) := Let_Result;
Let_Result_4 := Singleton_2; Inc_Ref (Let_Result_4);
--# end
Scope_Result_5 := Let_Result_4;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2545;
            Match_Result := Scope_Result_5; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Discriminant_Spec | Ada_Param_Spec .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_10; 
--# bind _ Match_4
                Singleton_3 := Create_Internal_Param_Actual_Array (Items_Count => 1);
                Singleton_3.Items (1) := No_Param_Actual;
Let_Result_5 := Singleton_3; Inc_Ref (Let_Result_5);
--# end
Scope_Result_6 := Let_Result_5;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_2547;
            Match_Result := Scope_Result_6; Inc_Ref (Match_Result);
end case;
--# expr-done 5239
         for Item_To_Append of
               Match_Result.Items
         loop
            Internal_Param_Actual_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2540;
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 5240
      declare
         Map_Result_2_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
         Index_187 := 0;
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Map_Result_1;
      begin
         for Item_186 of
               Collection.Items
         loop
   --# scope-start
               --# bind dp Item_186
               --# bind i Index_187
      --# expr-start 5245 '<New ParamActual at ast.py:10768>' New_Struct_4 /tmp/lal-23.0.0/ada/ast.py:10768
--# expr-start 5243 '<FieldAccess for actual_for_param_at at ast.py:10770>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:10770
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5241 '<FieldAccess for param at ast.py:10770>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:10770
Fld_23 := Item_186.Param;
--# expr-done 5241
--# expr-start 5242 '<FieldAccess for actual at ast.py:10770>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:10770
Fld_24 := Item_186.Actual;
--# expr-done 5242
--# property-call-start AssocList.actual_for_param_at
Fld_25 := Libadalang.Implementation.Assoc_List_P_Actual_For_Param_At (Node => Block_Var.Node, Param => Fld_23, Pos => Index_187, Default_Expr => Fld_24, E_Info => Block_Var.Info);
--# end
--# expr-done 5243
--# expr-start 5244 '<FieldAccess for param at ast.py:10769>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:10769
Fld_22 := Item_186.Param;
--# expr-done 5244
New_Struct_4 := (Actual => Fld_25, Param => Fld_22); 
--# expr-done 5245
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct_4;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
               Index_187 := Index_187 + 1;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 5246
Let_Result_6 := Map_Result_2; Inc_Ref (Let_Result_6);
--# end
--# expr-done 5247
      Property_Result := Let_Result_6;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_857;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_857;
               Finalizer_Scope_2540;
               Finalizer_Scope_2541;
               Finalizer_Scope_2542;
               Finalizer_Scope_2543;
               Finalizer_Scope_2545;
               Finalizer_Scope_2547;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Instantiation_P_Inst_Params;
--# end
function Generic_Instantiation_P_Instantiation_Bindings
  (E : Entity
  ) return Internal_Inner_Env_Assoc_Array_Access
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Internal_Inner_Env_Assoc_Array_Access :=
      Generic_Instantiation_P_Instantiation_Bindings (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Generic_Package_Instantiation
   --
      procedure Generic_Package_Instantiation_Pre_Env_Actions
        (Self            : Bare_Generic_Package_Instantiation;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_68 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_69 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:10973");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_70 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10980");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_71 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_72 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_73 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_75 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_74 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_77 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_76 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Generic_Package_Instantiation
        (Self : Bare_Generic_Package_Instantiation
         ; Generic_Package_Instantiation_F_Name : Bare_Defining_Name
         ; Generic_Package_Instantiation_F_Generic_Pkg_Name : Bare_Name
         ; Generic_Package_Instantiation_F_Params : Bare_Assoc_List
         ; Generic_Package_Instantiation_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Generic_Instantiation
              (Self);
            Self.Generic_Package_Instantiation_F_Name := Generic_Package_Instantiation_F_Name;
            Self.Generic_Package_Instantiation_F_Generic_Pkg_Name := Generic_Package_Instantiation_F_Generic_Pkg_Name;
            Self.Generic_Package_Instantiation_F_Params := Generic_Package_Instantiation_F_Params;
            Self.Generic_Package_Instantiation_F_Aspects := Generic_Package_Instantiation_F_Aspects;
      end Initialize_Fields_For_Generic_Package_Instantiation;
   function Generic_Package_Instantiation_F_Name
     (Node : Bare_Generic_Package_Instantiation) return Bare_Defining_Name
   is
   begin
         return Node.Generic_Package_Instantiation_F_Name;
   end;
   function Generic_Package_Instantiation_F_Generic_Pkg_Name
     (Node : Bare_Generic_Package_Instantiation) return Bare_Name
   is
   begin
         return Node.Generic_Package_Instantiation_F_Generic_Pkg_Name;
   end;
   function Generic_Package_Instantiation_F_Params
     (Node : Bare_Generic_Package_Instantiation) return Bare_Assoc_List
   is
   begin
         return Node.Generic_Package_Instantiation_F_Params;
   end;
--# property-start GenericPackageInstantiation.generic_entity_name /tmp/lal-23.0.0/ada/ast.py:10860
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Generic_Entity_Name
  (Node : Bare_Generic_Package_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Name;
      Fld : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5248 '<FieldAccess for generic_pkg_name at ast.py:10860>' Fld /tmp/lal-23.0.0/ada/ast.py:10860
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Generic_Package_Instantiation_F_Generic_Pkg_Name, Info => Ent.Info);
--# expr-done 5248
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Generic_Entity_Name;
--# end
--# property-start GenericPackageInstantiation.generic_inst_params /tmp/lal-23.0.0/ada/ast.py:10861
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Generic_Inst_Params
  (Node : Bare_Generic_Package_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Assoc_List
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Assoc_List;
      Fld : Internal_Entity_Assoc_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5249 '<FieldAccess for params at ast.py:10861>' Fld /tmp/lal-23.0.0/ada/ast.py:10861
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Generic_Package_Instantiation_F_Params, Info => Ent.Info);
--# expr-done 5249
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Generic_Inst_Params;
--# end
--# property-start GenericPackageInstantiation.designated_package /tmp/lal-23.0.0/ada/ast.py:10864
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Designated_Package
  (Node : Bare_Generic_Package_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Package_Decl
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Package_Decl;
            procedure Finalizer_Scope_2549 with Inline_Always;
      Var_Expr : Internal_Entity_Generic_Decl;
Var_Expr_1 : Internal_Entity_Generic_Decl;
Fld : Internal_Entity_Generic_Decl;
Fld_1 : Bare_Generic_Decl;
Cast_Result : Bare_Generic_Package_Decl;
Fld_2 : Bare_Generic_Package_Internal;
Fld_3 : Internal_Entity_Info;
Fld_4 : Internal_Metadata;
Fld_5 : Internal_Entity_Info;
Fld_6 : Env_Rebindings;
Fld_7 : Internal_Entity_Basic_Decl;
Fld_8 : Internal_Entity_Info;
Scope_Result : Internal_Entity_Info;
Result_Var : Internal_Entity_Info;
Fld_9 : Env_Rebindings;
Rebinding : Env_Rebindings;
Fld_10 : Bare_Generic_Decl;
Fld_11 : Lexical_Env := Empty_Env;
Fld_12 : Lexical_Env := Empty_Env;
Rebinding_1 : Env_Rebindings;
Fld_13 : Internal_Entity_Info;
Fld_14 : Boolean;
New_Struct : Internal_Entity_Info;
Cast_Result_1 : Bare_Base_Package_Decl;
New_Struct_1 : Internal_Entity_Base_Package_Decl;
Scope_Result_1 : Internal_Entity_Base_Package_Decl;
Result_Var_1 : Internal_Entity_Base_Package_Decl;
Let_Result : Internal_Entity_Base_Package_Decl;
            procedure Finalizer_Scope_2549 is
            begin
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2549;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5270 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5250 '<FieldAccess for nonbound_generic_decl at ast.py:10865>' Fld /tmp/lal-23.0.0/ada/ast.py:10865
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.nonbound_generic_decl
Fld := Libadalang.Implementation.Generic_Instantiation_P_Nonbound_Generic_Decl (Node => Self);
--# end
--# expr-done 5250
Var_Expr := Fld;
if Var_Expr /= No_Entity_Generic_Decl then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 5269 '<New BasePackageDecl.entity at ???>' New_Struct_1 None
--# expr-start 5265 '<New EntityInfo at ast.py:10868>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10868
--# expr-start 5252 '<FieldAccess for from_rebound at ast.py:10885>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:10885
--# expr-start 5251 '<FieldAccess for info at ast.py:10885>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10885
Fld_13 := Var_Expr.Info;
--# expr-done 5251
Fld_14 := Fld_13.From_Rebound;
--# expr-done 5252
--# expr-start 5254 '<FieldAccess for md at ast.py:10869>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10869
--# expr-start 5253 '<FieldAccess for info at ast.py:10869>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10869
Fld_3 := Var_Expr.Info;
--# expr-done 5253
Fld_4 := Fld_3.Md;
--# expr-done 5254
--# expr-start 5264 '<append_rebinding at ast.py:10883>' Rebinding_1 /tmp/lal-23.0.0/ada/ast.py:10883
--# expr-start 5260 '<concat_rebindings at ast.py:10875>' Rebinding /tmp/lal-23.0.0/ada/ast.py:10875
--# expr-start 5256 '<FieldAccess for rebindings at ast.py:10872>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10872
--# expr-start 5255 '<FieldAccess for info at ast.py:10872>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10872
Fld_5 := Ent.Info;
--# expr-done 5255
Fld_6 := Fld_5.Rebindings;
--# expr-done 5256
--# expr-start 5259 '<FieldAccess for rebindings at ast.py:10875>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10875
Var_Expr_1 := Var_Expr;
if Var_Expr_1 /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 5258 '<FieldAccess for info at ast.py:10875>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10875
--# expr-start 5257 '<FieldAccess for decl at ast.py:10875>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10875
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericDecl.decl'
Fld_7 := Libadalang.Implementation.Dispatcher_Generic_Decl_P_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 5257
Fld_8 := Fld_7.Info;
--# expr-done 5258
Scope_Result := Fld_8;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Info;
end if;
Fld_9 := Result_Var.Rebindings;
--# expr-done 5259
Rebinding := AST_Envs.Combine (Fld_6, Fld_9); 
--# expr-done 5260
--# expr-start 5262 '<FieldAccess for children_env at ast.py:10883>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10883
--# expr-start 5261 '<FieldAccess for node at ast.py:10883>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10883
Fld_10 := Var_Expr.Node;
--# expr-done 5261
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Children_Env (Node => Fld_10);
--# expr-done 5262
--# expr-start 5263 '<FieldAccess for instantiation_env at ast.py:10884>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10884
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.instantiation_env
Fld_12 := Libadalang.Implementation.Generic_Instantiation_F_Instantiation_Env (Node => Self);
--# end
--# expr-done 5263
Rebinding_1 := AST_Envs.Append_Rebinding (Rebinding, Fld_11, Fld_12); 
--# expr-done 5264
New_Struct := (From_Rebound => Fld_14, Md => Fld_4, Rebindings => Rebinding_1); 
--# expr-done 5265
--# expr-start 5268 '<FieldAccess for package_decl at ast.py:10867>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10867
--# expr-start 5267 '<Cast to GenericPackageDecl at ast.py:10867>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10867
--# expr-start 5266 '<FieldAccess for node at ast.py:10867>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10867
Fld_1 := Var_Expr.Node;
--# expr-done 5266
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Generic_Package_Decl_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5267
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Generic_Package_Decl_F_Package_Decl;
--# expr-done 5268
      Cast_Result_1 := Fld_2;
New_Struct_1 := (Info => New_Struct, Node => Cast_Result_1); 
--# expr-done 5269
Scope_Result_1 := New_Struct_1;
   --# end
      Finalizer_Scope_2549;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Package_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 5270
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2549;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Designated_Package;
--# end
--# property-start GenericPackageInstantiation.designated_generic_decl /tmp/lal-23.0.0/ada/ast.py:10890
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Designated_Generic_Decl
  (Node : Bare_Generic_Package_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Base_Package_Decl;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5273 '<Cast to BasicDecl at ast.py:10891>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10891
--# expr-start 5272 '<parent at ast.py:10891>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10891
--# expr-start 5271 '<FieldAccess for designated_package at ast.py:10891>' Fld /tmp/lal-23.0.0/ada/ast.py:10891
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericPackageInstantiation.designated_package
Fld := Libadalang.Implementation.Generic_Package_Instantiation_P_Designated_Package (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5271
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 5272
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 5273
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Designated_Generic_Decl;
--# end
--# property-start GenericPackageInstantiation.defining_env_impl /tmp/lal-23.0.0/ada/ast.py:10895
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Defining_Env_Impl
  (Node : Bare_Generic_Package_Instantiation
      ; Inst_From_Formal : Boolean
         := False
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind inst_from_formal Inst_From_Formal
   --# bind origin Origin
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_869 with Inline_Always;
      Block_Var : Internal_Entity_Base_Package_Decl;
Fld : Internal_Entity_Base_Package_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity;
Fld_3 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Fld_4 : Lexical_Env := Empty_Env;
Fld_5 : Boolean;
If_Result : Boolean;
If_Result_1 : Lexical_Env := Empty_Env;
Fld_6 : Lexical_Env := Empty_Env;
Array_Lit_1 : Lexical_Env_Array_Access;
Group_Env_1 : Lexical_Env := Empty_Env;
Is_Null : Boolean;
If_Result_2 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_869 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Fld_4);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (Group_Env_1);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_869;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5288 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5274 '<FieldAccess for designated_package at ast.py:10904>' Fld /tmp/lal-23.0.0/ada/ast.py:10904
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericPackageInstantiation.designated_package
Fld := Libadalang.Implementation.Generic_Package_Instantiation_P_Designated_Package (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5274
Block_Var := Fld; 
--# bind dp Block_Var
--# expr-start 5287 '<If at ast.py:10905>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:10905
--# expr-start 5275 '<IsNull at ast.py:10925>' Is_Null /tmp/lal-23.0.0/ada/ast.py:10925
Is_Null := Block_Var.Node = null; 
--# expr-done 5275
if Is_Null then
   If_Result_2 := Empty_Env;
else
   --# expr-start 5286 '<env_group at ast.py:10947>' Group_Env_1 /tmp/lal-23.0.0/ada/ast.py:10947
--# expr-start 5285 '<ArrayLiteral at ast.py:10927>' Array_Lit_1 /tmp/lal-23.0.0/ada/ast.py:10927
--# expr-start 5283 '<If at ast.py:10928>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:10928
--# expr-start 5276 '<FieldAccess for is_formal at ast.py:10929>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10929
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_formal
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Is_Formal (Node => Self);
--# end
--# expr-done 5276
if Fld_5 then
   If_Result := True;
else
   If_Result := Inst_From_Formal;
end if;
if If_Result then
   --# expr-start 5281 '<env_group at ast.py:10933>' Group_Env /tmp/lal-23.0.0/ada/ast.py:10933
--# expr-start 5280 '<ArrayLiteral at ast.py:10930>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:10930
--# expr-start 5277 '<FieldAccess for children_env at ast.py:10931>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10931
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 5277
--# expr-start 5279 '<FieldAccess for children_env at ast.py:10932>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10932
--# expr-start 5278 '<parent at ast.py:10932>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10932
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 5278
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Children_Env (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# expr-done 5279
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld_1, 2 => Fld_3)); 
--# expr-done 5280
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 5281
   If_Result_1 := Group_Env;
else
   --# expr-start 5282 '<FieldAccess for children_env at ast.py:10934>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10934
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Children_Env (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 5282
   If_Result_1 := Fld_4;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 5283
--# expr-start 5284 '<FieldAccess for children_env at ast.py:10946>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10946
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 5284
Array_Lit_1 := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => If_Result_1, 2 => Fld_6)); 
--# expr-done 5285
Group_Env_1 := Group (Array_Lit_1, No_Metadata); 
--# expr-done 5286
   If_Result_2 := Group_Env_1;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 5287
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 5288
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_869;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_869;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Defining_Env_Impl;
--# end
--# property-start GenericPackageInstantiation.defining_env /tmp/lal-23.0.0/ada/ast.py:10951
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Defining_Env
  (Node : Bare_Generic_Package_Instantiation
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_870 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_870 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_870;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5290 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5289 '<FieldAccess for defining_env_impl at ast.py:10952>' Fld /tmp/lal-23.0.0/ada/ast.py:10952
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericPackageInstantiation.defining_env_impl
Fld := Libadalang.Implementation.Generic_Package_Instantiation_P_Defining_Env_Impl (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 5289
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 5290
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_870;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_870;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Defining_Env;
--# end
--# property-start GenericPackageInstantiation.initial_env_name /tmp/lal-23.0.0/ada/ast.py:10955
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Initial_Env_Name
  (Node : Bare_Generic_Package_Instantiation
  )
   return Symbol_Type
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Fld : Symbol_Type;
Fld_1 : Boolean;
If_Result : Symbol_Type;
Let_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5294 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5293 '<If at ast.py:10956>' If_Result /tmp/lal-23.0.0/ada/ast.py:10956
--# expr-start 5291 '<FieldAccess for is_library_item at ast.py:10957>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10957
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_library_item'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Library_Item (Node => Self);
--# end
--# expr-done 5291
if Fld_1 then
   --# expr-start 5292 '<FieldAccess for child_decl_initial_env_name at ast.py:10958>' Fld /tmp/lal-23.0.0/ada/ast.py:10958
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.child_decl_initial_env_name'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Child_Decl_Initial_Env_Name (Node => Self);
--# end
--# expr-done 5292
   If_Result := Fld;
else
   If_Result := null;
end if;
--# expr-done 5293
Let_Result := If_Result; 
--# end
--# expr-done 5294
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Initial_Env_Name;
--# end
--# property-start GenericPackageInstantiation.env_names /tmp/lal-23.0.0/ada/ast.py:10963
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Env_Names
  (Node : Bare_Generic_Package_Instantiation
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_872 with Inline_Always;
            procedure Finalizer_Scope_2551 with Inline_Always;
      Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_872 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_872;
            procedure Finalizer_Scope_2551 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2551;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5297 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5295 '<FieldAccess for top_level_env_name at ast.py:10964>' Fld /tmp/lal-23.0.0/ada/ast.py:10964
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 5295
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 5296 '<to_symbol at ast.py:10965>' Sym /tmp/lal-23.0.0/ada/ast.py:10965
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 5296
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Sym;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2551;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 5297
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_872;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_872;
               Finalizer_Scope_2551;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Env_Names;
--# end
--# property-start GenericPackageInstantiation.defining_names /tmp/lal-23.0.0/ada/ast.py:10968
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Instantiation_P_Defining_Names
  (Node : Bare_Generic_Package_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_873 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_873 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_873;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5298 '<FieldAccess for name at ast.py:10968>' Fld /tmp/lal-23.0.0/ada/ast.py:10968
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Generic_Package_Instantiation_F_Name, Info => Ent.Info);
--# expr-done 5298
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_873;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_873;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Instantiation_P_Defining_Names;
--# end
--# property-start GenericPackageInstantiation._env_do_68 /tmp/lal-23.0.0/ada/ast.py:10971
pragma Warnings (Off, "is not referenced");
 function Env_Do_68
  (Node : Bare_Generic_Package_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5299 '<FieldAccess for env_hook at ast.py:10971>' Fld /tmp/lal-23.0.0/ada/ast.py:10971
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5299
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_68;
--# end
--# property-start GenericPackageInstantiation._initial_env_69 /tmp/lal-23.0.0/ada/ast.py:10974
pragma Warnings (Off, "is not referenced");
 function Initial_Env_69
  (Node : Bare_Generic_Package_Instantiation
  )
   return Internal_Designated_Env
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1538 with Inline_Always;
            procedure Finalizer_Scope_2552 with Inline_Always;
      Var_Expr : Symbol_Type;
Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Scope_Result : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Result_Var : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1538 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1538;
            procedure Finalizer_Scope_2552 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_2552;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 5300 '<FieldAccess for initial_env_name at ast.py:10975>' Fld /tmp/lal-23.0.0/ada/ast.py:10975
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericPackageInstantiation.initial_env_name
Fld := Libadalang.Implementation.Generic_Package_Instantiation_P_Initial_Env_Name (Node => Self);
--# end
--# expr-done 5300
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind non_null_name Var_Expr
--# expr-start 5301 '<New DesignatedEnv at ???>' New_Struct None
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Var_Expr, Kind => Named_Env); 
--# expr-done 5301
Scope_Result := New_Struct;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2552;
   Result_Var := Scope_Result;
else
   --# expr-start 5302 '<New DesignatedEnv at ast.py:10974>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10974
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5302
   Result_Var := New_Struct_1;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1538;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1538;
               Finalizer_Scope_2552;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_69;
--# end
--# property-start GenericPackageInstantiation._env_mappings_70 /tmp/lal-23.0.0/ada/ast.py:10980
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_70
  (Node : Bare_Generic_Package_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Instantiation :=
     Internal_Entity_Generic_Package_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1539 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Generic_Package_Instantiation;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1539 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1539;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5305 '<New EnvAssoc at ast.py:10980>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10980
--# expr-start 5303 '<New DesignatedEnv at ast.py:10980>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10980
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5303
--# expr-start 5304 '<FieldAccess for name_symbol at ast.py:10980>' Fld /tmp/lal-23.0.0/ada/ast.py:10980
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 5304
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5305
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1539;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1539;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_70;
--# end
--# property-start GenericPackageInstantiation._env_trans_parent_71 /tmp/lal-23.0.0/ada/ast.py:10970
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_71
  (Node : Bare_Generic_Package_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_71;
--# end
--# property-start GenericPackageInstantiation._env_names_72 /tmp/lal-23.0.0/ada/ast.py:10982
pragma Warnings (Off, "is not referenced");
 function Env_Names_72
  (Node : Bare_Generic_Package_Instantiation
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1541 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1541 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1541;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5306 '<FieldAccess for env_names at ast.py:10982>' Fld /tmp/lal-23.0.0/ada/ast.py:10982
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericPackageInstantiation.env_names
Fld := Libadalang.Implementation.Generic_Package_Instantiation_P_Env_Names (Node => Self);
--# end
--# expr-done 5306
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1541;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1541;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_72;
--# end
--# property-start GenericPackageInstantiation._env_do_73 /tmp/lal-23.0.0/ada/ast.py:10984
pragma Warnings (Off, "is not referenced");
 function Env_Do_73
  (Node : Bare_Generic_Package_Instantiation
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1542 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1542 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1542;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5307 '<FieldAccess for populate_dependent_units at ast.py:10984>' Fld /tmp/lal-23.0.0/ada/ast.py:10984
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5307
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1542;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1542;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_73;
--# end
--# property-start GenericPackageInstantiation._ref_env_nodes_74 /tmp/lal-23.0.0/ada/ast.py:10986
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_74
  (Node : Bare_Generic_Package_Instantiation
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1543 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1543 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1543;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5308 '<FieldAccess for top_level_use_package_clauses at ast.py:10986>' Fld /tmp/lal-23.0.0/ada/ast.py:10986
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5308
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1543;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1543;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_74;
--# end
--# property-start GenericPackageInstantiation._ref_cond_75 /tmp/lal-23.0.0/ada/ast.py:10988
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_75
  (Node : Bare_Generic_Package_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5310 '<IsA LibraryItem, Subunit at ast.py:10988>' Is_A /tmp/lal-23.0.0/ada/ast.py:10988
--# expr-start 5309 '<parent at ast.py:10988>' Fld /tmp/lal-23.0.0/ada/ast.py:10988
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5309
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5310
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_75;
--# end
--# property-start GenericPackageInstantiation._ref_env_nodes_76 /tmp/lal-23.0.0/ada/ast.py:10991
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_76
  (Node : Bare_Generic_Package_Instantiation
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1545 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1545 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1545;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5311 '<FieldAccess for top_level_use_type_clauses at ast.py:10991>' Fld /tmp/lal-23.0.0/ada/ast.py:10991
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5311
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1545;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1545;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_76;
--# end
--# property-start GenericPackageInstantiation._ref_cond_77 /tmp/lal-23.0.0/ada/ast.py:10993
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_77
  (Node : Bare_Generic_Package_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Package_Instantiation := Bare_Generic_Package_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5313 '<IsA LibraryItem, Subunit at ast.py:10993>' Is_A /tmp/lal-23.0.0/ada/ast.py:10993
--# expr-start 5312 '<parent at ast.py:10993>' Fld /tmp/lal-23.0.0/ada/ast.py:10993
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5312
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5313
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_77;
--# end
   --
   --  Primitives for Bare_Generic_Subp_Instantiation
   --
      procedure Generic_Subp_Instantiation_Pre_Env_Actions
        (Self            : Bare_Generic_Subp_Instantiation;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_59 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_60 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:10826");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_61 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10828");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_62 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_63 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_65 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_64 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_67 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_66 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Generic_Subp_Instantiation
        (Self : Bare_Generic_Subp_Instantiation
         ; Generic_Subp_Instantiation_F_Overriding : Bare_Overriding_Node
         ; Generic_Subp_Instantiation_F_Kind : Bare_Subp_Kind
         ; Generic_Subp_Instantiation_F_Subp_Name : Bare_Defining_Name
         ; Generic_Subp_Instantiation_F_Generic_Subp_Name : Bare_Name
         ; Generic_Subp_Instantiation_F_Params : Bare_Assoc_List
         ; Generic_Subp_Instantiation_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Generic_Instantiation
              (Self);
            Self.Generic_Subp_Instantiation_F_Overriding := Generic_Subp_Instantiation_F_Overriding;
            Self.Generic_Subp_Instantiation_F_Kind := Generic_Subp_Instantiation_F_Kind;
            Self.Generic_Subp_Instantiation_F_Subp_Name := Generic_Subp_Instantiation_F_Subp_Name;
            Self.Generic_Subp_Instantiation_F_Generic_Subp_Name := Generic_Subp_Instantiation_F_Generic_Subp_Name;
            Self.Generic_Subp_Instantiation_F_Params := Generic_Subp_Instantiation_F_Params;
            Self.Generic_Subp_Instantiation_F_Aspects := Generic_Subp_Instantiation_F_Aspects;
      end Initialize_Fields_For_Generic_Subp_Instantiation;
   function Generic_Subp_Instantiation_F_Overriding
     (Node : Bare_Generic_Subp_Instantiation) return Bare_Overriding_Node
   is
   begin
         return Node.Generic_Subp_Instantiation_F_Overriding;
   end;
   function Generic_Subp_Instantiation_F_Kind
     (Node : Bare_Generic_Subp_Instantiation) return Bare_Subp_Kind
   is
   begin
         return Node.Generic_Subp_Instantiation_F_Kind;
   end;
   function Generic_Subp_Instantiation_F_Subp_Name
     (Node : Bare_Generic_Subp_Instantiation) return Bare_Defining_Name
   is
   begin
         return Node.Generic_Subp_Instantiation_F_Subp_Name;
   end;
   function Generic_Subp_Instantiation_F_Generic_Subp_Name
     (Node : Bare_Generic_Subp_Instantiation) return Bare_Name
   is
   begin
         return Node.Generic_Subp_Instantiation_F_Generic_Subp_Name;
   end;
   function Generic_Subp_Instantiation_F_Params
     (Node : Bare_Generic_Subp_Instantiation) return Bare_Assoc_List
   is
   begin
         return Node.Generic_Subp_Instantiation_F_Params;
   end;
--# property-start GenericSubpInstantiation.defining_names /tmp/lal-23.0.0/ada/ast.py:10787
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Defining_Names
  (Node : Bare_Generic_Subp_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_858 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_858 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_858;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5314 '<FieldAccess for subp_name at ast.py:10787>' Fld /tmp/lal-23.0.0/ada/ast.py:10787
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Generic_Subp_Instantiation_F_Subp_Name, Info => Ent.Info);
--# expr-done 5314
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_858;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_858;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Defining_Names;
--# end
--# property-start GenericSubpInstantiation.generic_entity_name /tmp/lal-23.0.0/ada/ast.py:10789
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Generic_Entity_Name
  (Node : Bare_Generic_Subp_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Name;
      Fld : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5315 '<FieldAccess for generic_subp_name at ast.py:10789>' Fld /tmp/lal-23.0.0/ada/ast.py:10789
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Generic_Subp_Instantiation_F_Generic_Subp_Name, Info => Ent.Info);
--# expr-done 5315
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Generic_Entity_Name;
--# end
--# property-start GenericSubpInstantiation.generic_inst_params /tmp/lal-23.0.0/ada/ast.py:10790
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Generic_Inst_Params
  (Node : Bare_Generic_Subp_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Assoc_List
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Assoc_List;
      Fld : Internal_Entity_Assoc_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5316 '<FieldAccess for params at ast.py:10790>' Fld /tmp/lal-23.0.0/ada/ast.py:10790
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Generic_Subp_Instantiation_F_Params, Info => Ent.Info);
--# expr-done 5316
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Generic_Inst_Params;
--# end
--# property-start GenericSubpInstantiation.expr_type /tmp/lal-23.0.0/ada/ast.py:10793
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Expr_Type
  (Node : Bare_Generic_Subp_Instantiation
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5319 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5317 '<FieldAccess for subp_spec_or_null at ast.py:10794>' Fld /tmp/lal-23.0.0/ada/ast.py:10794
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5317
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 5318 '<FieldAccess for return_type at ast.py:10794>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10794
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 5318
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 5319
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Expr_Type;
--# end
--# property-start GenericSubpInstantiation.defining_env /tmp/lal-23.0.0/ada/ast.py:10796
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Defining_Env
  (Node : Bare_Generic_Subp_Instantiation
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_862 with Inline_Always;
            procedure Finalizer_Scope_2554 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_862 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_862;
            procedure Finalizer_Scope_2554 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2554;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 5320 '<FieldAccess for subp_spec_or_null at ast.py:10796>' Fld /tmp/lal-23.0.0/ada/ast.py:10796
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5320
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 5321 '<FieldAccess for defining_env at ast.py:10796>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10796
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.defining_env
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Defining_Env (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 5321
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2554;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_862;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_862;
               Finalizer_Scope_2554;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Defining_Env;
--# end
--# property-start GenericSubpInstantiation.designated_subp /tmp/lal-23.0.0/ada/ast.py:10799
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Designated_Subp
  (Node : Bare_Generic_Subp_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Subp_Decl
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Subp_Decl;
            procedure Finalizer_Scope_2134 with Inline_Always;
      Var_Expr : Internal_Entity_Generic_Decl;
Var_Expr_1 : Internal_Entity_Generic_Decl;
Fld : Internal_Entity_Generic_Decl;
Fld_1 : Bare_Generic_Decl;
Cast_Result : Bare_Generic_Subp_Decl;
Fld_2 : Bare_Generic_Subp_Internal;
Fld_3 : Internal_Entity_Info;
Fld_4 : Internal_Metadata;
Fld_5 : Internal_Entity_Info;
Fld_6 : Env_Rebindings;
Fld_7 : Internal_Entity_Basic_Decl;
Fld_8 : Internal_Entity_Info;
Scope_Result : Internal_Entity_Info;
Result_Var : Internal_Entity_Info;
Fld_9 : Env_Rebindings;
Rebinding : Env_Rebindings;
Fld_10 : Bare_Generic_Decl;
Fld_11 : Lexical_Env := Empty_Env;
Fld_12 : Lexical_Env := Empty_Env;
Rebinding_1 : Env_Rebindings;
Fld_13 : Internal_Entity_Info;
Fld_14 : Boolean;
New_Struct : Internal_Entity_Info;
Cast_Result_1 : Bare_Basic_Subp_Decl;
New_Struct_1 : Internal_Entity_Basic_Subp_Decl;
Scope_Result_1 : Internal_Entity_Basic_Subp_Decl;
Result_Var_1 : Internal_Entity_Basic_Subp_Decl;
Let_Result : Internal_Entity_Basic_Subp_Decl;
            procedure Finalizer_Scope_2134 is
            begin
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2134;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5342 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5322 '<FieldAccess for nonbound_generic_decl at ast.py:10803>' Fld /tmp/lal-23.0.0/ada/ast.py:10803
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.nonbound_generic_decl
Fld := Libadalang.Implementation.Generic_Instantiation_P_Nonbound_Generic_Decl (Node => Self);
--# end
--# expr-done 5322
Var_Expr := Fld;
if Var_Expr /= No_Entity_Generic_Decl then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 5341 '<New BasicSubpDecl.entity at ???>' New_Struct_1 None
--# expr-start 5337 '<New EntityInfo at ast.py:10806>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10806
--# expr-start 5324 '<FieldAccess for from_rebound at ast.py:10814>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:10814
--# expr-start 5323 '<FieldAccess for info at ast.py:10814>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10814
Fld_13 := Var_Expr.Info;
--# expr-done 5323
Fld_14 := Fld_13.From_Rebound;
--# expr-done 5324
--# expr-start 5326 '<FieldAccess for md at ast.py:10807>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10807
--# expr-start 5325 '<FieldAccess for info at ast.py:10807>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10807
Fld_3 := Var_Expr.Info;
--# expr-done 5325
Fld_4 := Fld_3.Md;
--# expr-done 5326
--# expr-start 5336 '<append_rebinding at ast.py:10811>' Rebinding_1 /tmp/lal-23.0.0/ada/ast.py:10811
--# expr-start 5332 '<concat_rebindings at ast.py:10810>' Rebinding /tmp/lal-23.0.0/ada/ast.py:10810
--# expr-start 5328 '<FieldAccess for rebindings at ast.py:10808>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10808
--# expr-start 5327 '<FieldAccess for info at ast.py:10808>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10808
Fld_5 := Ent.Info;
--# expr-done 5327
Fld_6 := Fld_5.Rebindings;
--# expr-done 5328
--# expr-start 5331 '<FieldAccess for rebindings at ast.py:10810>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10810
Var_Expr_1 := Var_Expr;
if Var_Expr_1 /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 5330 '<FieldAccess for info at ast.py:10810>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10810
--# expr-start 5329 '<FieldAccess for decl at ast.py:10810>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10810
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericDecl.decl'
Fld_7 := Libadalang.Implementation.Dispatcher_Generic_Decl_P_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 5329
Fld_8 := Fld_7.Info;
--# expr-done 5330
Scope_Result := Fld_8;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Info;
end if;
Fld_9 := Result_Var.Rebindings;
--# expr-done 5331
Rebinding := AST_Envs.Combine (Fld_6, Fld_9); 
--# expr-done 5332
--# expr-start 5334 '<FieldAccess for children_env at ast.py:10812>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10812
--# expr-start 5333 '<FieldAccess for node at ast.py:10812>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10812
Fld_10 := Var_Expr.Node;
--# expr-done 5333
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Children_Env (Node => Fld_10);
--# expr-done 5334
--# expr-start 5335 '<FieldAccess for instantiation_env at ast.py:10812>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10812
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericInstantiation.instantiation_env
Fld_12 := Libadalang.Implementation.Generic_Instantiation_F_Instantiation_Env (Node => Self);
--# end
--# expr-done 5335
Rebinding_1 := AST_Envs.Append_Rebinding (Rebinding, Fld_11, Fld_12); 
--# expr-done 5336
New_Struct := (From_Rebound => Fld_14, Md => Fld_4, Rebindings => Rebinding_1); 
--# expr-done 5337
--# expr-start 5340 '<FieldAccess for subp_decl at ast.py:10805>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10805
--# expr-start 5339 '<Cast to GenericSubpDecl at ast.py:10805>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10805
--# expr-start 5338 '<FieldAccess for node at ast.py:10805>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10805
Fld_1 := Var_Expr.Node;
--# expr-done 5338
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Generic_Subp_Decl_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5339
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Generic_Subp_Decl_F_Subp_Decl;
--# expr-done 5340
      Cast_Result_1 := Fld_2;
New_Struct_1 := (Info => New_Struct, Node => Cast_Result_1); 
--# expr-done 5341
Scope_Result_1 := New_Struct_1;
   --# end
      Finalizer_Scope_2134;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Subp_Decl;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 5342
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2134;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Designated_Subp;
--# end
--# property-start GenericSubpInstantiation.designated_generic_decl /tmp/lal-23.0.0/ada/ast.py:10819
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Instantiation_P_Designated_Generic_Decl
  (Node : Bare_Generic_Subp_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Subp_Decl;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5345 '<Cast to BasicDecl at ast.py:10820>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10820
--# expr-start 5344 '<parent at ast.py:10820>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10820
--# expr-start 5343 '<FieldAccess for designated_subp at ast.py:10820>' Fld /tmp/lal-23.0.0/ada/ast.py:10820
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericSubpInstantiation.designated_subp
Fld := Libadalang.Implementation.Generic_Subp_Instantiation_P_Designated_Subp (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5343
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 5344
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 5345
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Instantiation_P_Designated_Generic_Decl;
--# end
--# property-start GenericSubpInstantiation._env_do_59 /tmp/lal-23.0.0/ada/ast.py:10824
pragma Warnings (Off, "is not referenced");
 function Env_Do_59
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5346 '<FieldAccess for env_hook at ast.py:10824>' Fld /tmp/lal-23.0.0/ada/ast.py:10824
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5346
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_59;
--# end
--# property-start GenericSubpInstantiation._initial_env_60 /tmp/lal-23.0.0/ada/ast.py:10826
pragma Warnings (Off, "is not referenced");
 function Initial_Env_60
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Internal_Designated_Env
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1529 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1529 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1529;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5347 '<FieldAccess for child_decl_initial_env at ast.py:10826>' Fld /tmp/lal-23.0.0/ada/ast.py:10826
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self);
--# end
--# expr-done 5347
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1529;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1529;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_60;
--# end
--# property-start GenericSubpInstantiation._env_mappings_61 /tmp/lal-23.0.0/ada/ast.py:10828
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_61
  (Node : Bare_Generic_Subp_Instantiation
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Instantiation :=
     Internal_Entity_Generic_Subp_Instantiation'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1530 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Generic_Subp_Instantiation;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1530 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1530;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5350 '<New EnvAssoc at ast.py:10828>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10828
--# expr-start 5348 '<New DesignatedEnv at ast.py:10828>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10828
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5348
--# expr-start 5349 '<FieldAccess for name_symbol at ast.py:10829>' Fld /tmp/lal-23.0.0/ada/ast.py:10829
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 5349
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5350
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1530;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1530;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_61;
--# end
--# property-start GenericSubpInstantiation._env_trans_parent_62 /tmp/lal-23.0.0/ada/ast.py:10823
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_62
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_62;
--# end
--# property-start GenericSubpInstantiation._env_do_63 /tmp/lal-23.0.0/ada/ast.py:10835
pragma Warnings (Off, "is not referenced");
 function Env_Do_63
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1532 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1532 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1532;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5351 '<FieldAccess for populate_dependent_units at ast.py:10835>' Fld /tmp/lal-23.0.0/ada/ast.py:10835
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5351
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1532;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1532;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_63;
--# end
--# property-start GenericSubpInstantiation._ref_env_nodes_64 /tmp/lal-23.0.0/ada/ast.py:10838
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_64
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1533 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1533 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1533;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5352 '<FieldAccess for top_level_use_package_clauses at ast.py:10838>' Fld /tmp/lal-23.0.0/ada/ast.py:10838
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5352
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1533;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1533;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_64;
--# end
--# property-start GenericSubpInstantiation._ref_cond_65 /tmp/lal-23.0.0/ada/ast.py:10840
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_65
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5354 '<IsA LibraryItem, Subunit at ast.py:10840>' Is_A /tmp/lal-23.0.0/ada/ast.py:10840
--# expr-start 5353 '<parent at ast.py:10840>' Fld /tmp/lal-23.0.0/ada/ast.py:10840
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5353
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5354
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_65;
--# end
--# property-start GenericSubpInstantiation._ref_env_nodes_66 /tmp/lal-23.0.0/ada/ast.py:10843
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_66
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1535 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1535 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1535;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5355 '<FieldAccess for top_level_use_type_clauses at ast.py:10843>' Fld /tmp/lal-23.0.0/ada/ast.py:10843
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5355
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1535;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1535;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_66;
--# end
--# property-start GenericSubpInstantiation._ref_cond_67 /tmp/lal-23.0.0/ada/ast.py:10845
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_67
  (Node : Bare_Generic_Subp_Instantiation
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Instantiation := Bare_Generic_Subp_Instantiation (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5357 '<IsA LibraryItem, Subunit at ast.py:10845>' Is_A /tmp/lal-23.0.0/ada/ast.py:10845
--# expr-start 5356 '<parent at ast.py:10845>' Fld /tmp/lal-23.0.0/ada/ast.py:10845
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5356
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5357
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_67;
--# end
   --
   --  Primitives for Bare_Generic_Renaming_Decl
   --
--# property-start '[dispatcher]GenericRenamingDecl.renaming_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Generic_Renaming_Decl_P_Renaming_Name
  (Node : Bare_Generic_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Generic_Renaming_Decl := Bare_Generic_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Generic_Renaming_Decl (Self.Kind) is
               when Ada_Generic_Package_Renaming_Decl =>
                  --# property-call-start GenericPackageRenamingDecl.renaming_name
                  Property_Result := Generic_Package_Renaming_Decl_P_Renaming_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Generic_Subp_Renaming_Decl =>
                  --# property-call-start GenericSubpRenamingDecl.renaming_name
                  Property_Result := Generic_Subp_Renaming_Decl_P_Renaming_Name
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Generic_Renaming_Decl_P_Renaming_Name;
--# end
--# property-start GenericRenamingDecl.resolve /tmp/lal-23.0.0/ada/ast.py:11096
pragma Warnings (Off, "is not referenced");
 function Generic_Renaming_Decl_P_Resolve
  (Node : Bare_Generic_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Generic_Decl
is
   Self : Bare_Generic_Renaming_Decl := Bare_Generic_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Renaming_Decl :=
     Internal_Entity_Generic_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Generic_Decl;
            procedure Finalizer_Scope_881 with Inline_Always;
      Var_Expr : Internal_Entity;
Match_0 : Internal_Entity_Generic_Decl;
Match_1 : Internal_Entity_Generic_Renaming_Decl;
Match_2 : Internal_Entity;
Fld : Internal_Entity_Name;
Cast_Expr : Bare_Generic_Renaming_Decl;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Fld_2 : Internal_Entity_Generic_Decl;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Generic_Decl;
Let_Result : Internal_Entity_Generic_Decl;
Scope_Result : Internal_Entity_Generic_Decl;
Cast_Result_2 : Internal_Entity_Generic_Renaming_Decl;
Let_Result_1 : Internal_Entity_Generic_Decl;
Scope_Result_1 : Internal_Entity_Generic_Decl;
Cast_Result_3 : Internal_Entity;
Let_Result_2 : Internal_Entity_Generic_Decl;
Scope_Result_2 : Internal_Entity_Generic_Decl;
Match_Result : Internal_Entity_Generic_Decl;
Scope_Result_3 : Internal_Entity_Generic_Decl;
Result_Var : Internal_Entity_Generic_Decl;
            procedure Finalizer_Scope_881 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_881;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 5360 '<at at ast.py:11102>' Get_Result /tmp/lal-23.0.0/ada/ast.py:11102
--# expr-start 5359 '<FieldAccess for all_env_elements_internal at ast.py:11100>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11100
--# expr-start 5358 '<FieldAccess for renaming_name at ast.py:11100>' Fld /tmp/lal-23.0.0/ada/ast.py:11100
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericRenamingDecl.renaming_name'
Fld := Libadalang.Implementation.Dispatcher_Generic_Renaming_Decl_P_Renaming_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5358
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start Name.all_env_elements_internal
Fld_1 := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Fld.Node, Seq => True, Seq_From => Cast_Result, Categories => (Inherited_Primitives => False, Nocat => True), E_Info => Fld.Info);
--# end
--# expr-done 5359
Get_Result := Get (Self, Fld_1, 0, True); 
--# expr-done 5360
Var_Expr := Get_Result;
if Var_Expr /= No_Entity then
   --# scope-start
--# expr-start 5362 '<Match at ast.py:11102>' Match_Result /tmp/lal-23.0.0/ada/ast.py:11102
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Var_Expr; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Generic_Package_Decl .. Ada_Generic_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Generic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind gd Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Generic_Package_Renaming_Decl .. Ada_Generic_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Generic_Renaming_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind grd Match_1
--# expr-start 5361 '<FieldAccess for resolve at ast.py:11104>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11104
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericRenamingDecl.resolve
Fld_2 := Libadalang.Implementation.Generic_Renaming_Decl_P_Resolve (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 5361
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_For_Loop_Var_Decl | Ada_Generic_Package_Instantiation .. Ada_Generic_Subp_Instantiation | Ada_Label_Decl .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Generic_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 5362
Scope_Result_3 := Match_Result;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := No_Entity_Generic_Decl;
end if;
      Property_Result := Result_Var;
   --# end
      Finalizer_Scope_881;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_881;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Renaming_Decl_P_Resolve;
--# end
--# property-start GenericRenamingDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:11111
pragma Warnings (Off, "is not referenced");
 function Generic_Renaming_Decl_P_Xref_Entry_Point
  (Node : Bare_Generic_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Renaming_Decl := Bare_Generic_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Renaming_Decl_P_Xref_Entry_Point;
--# end
--# property-start GenericRenamingDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:11112
pragma Warnings (Off, "is not referenced");
 function Generic_Renaming_Decl_P_Xref_Equation
  (Node : Bare_Generic_Renaming_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Generic_Renaming_Decl := Bare_Generic_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Renaming_Decl :=
     Internal_Entity_Generic_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_883 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
            procedure Finalizer_Scope_883 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_883;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5364 '<FieldAccess for xref_no_overloading at ast.py:11112>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11112
--# expr-start 5363 '<FieldAccess for renaming_name at ast.py:11112>' Fld /tmp/lal-23.0.0/ada/ast.py:11112
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericRenamingDecl.renaming_name'
Fld := Libadalang.Implementation.Dispatcher_Generic_Renaming_Decl_P_Renaming_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5363
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 5364
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_883;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_883;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Renaming_Decl_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Generic_Package_Renaming_Decl
   --
      procedure Generic_Package_Renaming_Decl_Pre_Env_Actions
        (Self            : Bare_Generic_Package_Renaming_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_87 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_88 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:11130");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_89 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:11132");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_90 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_91 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_93 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_92 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_95 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_94 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Generic_Package_Renaming_Decl
        (Self : Bare_Generic_Package_Renaming_Decl
         ; Generic_Package_Renaming_Decl_F_Name : Bare_Defining_Name
         ; Generic_Package_Renaming_Decl_F_Renames : Bare_Name
         ; Generic_Package_Renaming_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Generic_Package_Renaming_Decl_F_Name := Generic_Package_Renaming_Decl_F_Name;
            Self.Generic_Package_Renaming_Decl_F_Renames := Generic_Package_Renaming_Decl_F_Renames;
            Self.Generic_Package_Renaming_Decl_F_Aspects := Generic_Package_Renaming_Decl_F_Aspects;
      end Initialize_Fields_For_Generic_Package_Renaming_Decl;
   function Generic_Package_Renaming_Decl_F_Name
     (Node : Bare_Generic_Package_Renaming_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Generic_Package_Renaming_Decl_F_Name;
   end;
   function Generic_Package_Renaming_Decl_F_Renames
     (Node : Bare_Generic_Package_Renaming_Decl) return Bare_Name
   is
   begin
         return Node.Generic_Package_Renaming_Decl_F_Renames;
   end;
--# property-start GenericPackageRenamingDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:11123
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Renaming_Decl_P_Defining_Names
  (Node : Bare_Generic_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Renaming_Decl :=
     Internal_Entity_Generic_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_884 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_884 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_884;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5365 '<FieldAccess for name at ast.py:11123>' Fld /tmp/lal-23.0.0/ada/ast.py:11123
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Generic_Package_Renaming_Decl_F_Name, Info => Ent.Info);
--# expr-done 5365
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_884;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_884;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Renaming_Decl_P_Defining_Names;
--# end
--# property-start GenericPackageRenamingDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:11124
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Renaming_Decl_P_Defining_Env
  (Node : Bare_Generic_Package_Renaming_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Renaming_Decl :=
     Internal_Entity_Generic_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_885 with Inline_Always;
      Fld : Internal_Entity_Generic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_885 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_885;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5367 '<FieldAccess for defining_env at ast.py:11124>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11124
--# expr-start 5366 '<FieldAccess for resolve at ast.py:11124>' Fld /tmp/lal-23.0.0/ada/ast.py:11124
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericRenamingDecl.resolve
Fld := Libadalang.Implementation.Generic_Renaming_Decl_P_Resolve (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5366
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 5367
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_885;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_885;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Renaming_Decl_P_Defining_Env;
--# end
--# property-start GenericPackageRenamingDecl.renaming_name /tmp/lal-23.0.0/ada/ast.py:11125
pragma Warnings (Off, "is not referenced");
 function Generic_Package_Renaming_Decl_P_Renaming_Name
  (Node : Bare_Generic_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Renaming_Decl :=
     Internal_Entity_Generic_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Name;
      Fld : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5368 '<FieldAccess for renames at ast.py:11125>' Fld /tmp/lal-23.0.0/ada/ast.py:11125
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Generic_Package_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 5368
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Package_Renaming_Decl_P_Renaming_Name;
--# end
--# property-start GenericPackageRenamingDecl._env_do_87 /tmp/lal-23.0.0/ada/ast.py:11128
pragma Warnings (Off, "is not referenced");
 function Env_Do_87
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5369 '<FieldAccess for env_hook at ast.py:11128>' Fld /tmp/lal-23.0.0/ada/ast.py:11128
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5369
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_87;
--# end
--# property-start GenericPackageRenamingDecl._initial_env_88 /tmp/lal-23.0.0/ada/ast.py:11130
pragma Warnings (Off, "is not referenced");
 function Initial_Env_88
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1557 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1557 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1557;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5370 '<FieldAccess for child_decl_initial_env at ast.py:11130>' Fld /tmp/lal-23.0.0/ada/ast.py:11130
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self);
--# end
--# expr-done 5370
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1557;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1557;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_88;
--# end
--# property-start GenericPackageRenamingDecl._env_mappings_89 /tmp/lal-23.0.0/ada/ast.py:11132
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_89
  (Node : Bare_Generic_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Package_Renaming_Decl :=
     Internal_Entity_Generic_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1558 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Generic_Package_Renaming_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1558 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1558;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5373 '<New EnvAssoc at ast.py:11132>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:11132
--# expr-start 5371 '<New DesignatedEnv at ast.py:11132>' New_Struct /tmp/lal-23.0.0/ada/ast.py:11132
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5371
--# expr-start 5372 '<FieldAccess for name_symbol at ast.py:11133>' Fld /tmp/lal-23.0.0/ada/ast.py:11133
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 5372
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5373
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1558;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1558;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_89;
--# end
--# property-start GenericPackageRenamingDecl._env_trans_parent_90 /tmp/lal-23.0.0/ada/ast.py:11127
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_90
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_90;
--# end
--# property-start GenericPackageRenamingDecl._env_do_91 /tmp/lal-23.0.0/ada/ast.py:11139
pragma Warnings (Off, "is not referenced");
 function Env_Do_91
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1560 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1560 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1560;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5374 '<FieldAccess for populate_dependent_units at ast.py:11139>' Fld /tmp/lal-23.0.0/ada/ast.py:11139
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5374
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1560;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1560;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_91;
--# end
--# property-start GenericPackageRenamingDecl._ref_env_nodes_92 /tmp/lal-23.0.0/ada/ast.py:11142
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_92
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1561 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1561 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1561;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5375 '<FieldAccess for top_level_use_package_clauses at ast.py:11142>' Fld /tmp/lal-23.0.0/ada/ast.py:11142
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5375
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1561;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1561;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_92;
--# end
--# property-start GenericPackageRenamingDecl._ref_cond_93 /tmp/lal-23.0.0/ada/ast.py:11144
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_93
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5377 '<IsA LibraryItem, Subunit at ast.py:11144>' Is_A /tmp/lal-23.0.0/ada/ast.py:11144
--# expr-start 5376 '<parent at ast.py:11144>' Fld /tmp/lal-23.0.0/ada/ast.py:11144
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5376
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5377
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_93;
--# end
--# property-start GenericPackageRenamingDecl._ref_env_nodes_94 /tmp/lal-23.0.0/ada/ast.py:11147
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_94
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1563 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1563 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1563;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5378 '<FieldAccess for top_level_use_type_clauses at ast.py:11147>' Fld /tmp/lal-23.0.0/ada/ast.py:11147
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5378
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1563;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1563;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_94;
--# end
--# property-start GenericPackageRenamingDecl._ref_cond_95 /tmp/lal-23.0.0/ada/ast.py:11149
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_95
  (Node : Bare_Generic_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Package_Renaming_Decl := Bare_Generic_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5380 '<IsA LibraryItem, Subunit at ast.py:11149>' Is_A /tmp/lal-23.0.0/ada/ast.py:11149
--# expr-start 5379 '<parent at ast.py:11149>' Fld /tmp/lal-23.0.0/ada/ast.py:11149
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5379
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5380
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_95;
--# end
   --
   --  Primitives for Bare_Generic_Subp_Renaming_Decl
   --
      procedure Generic_Subp_Renaming_Decl_Pre_Env_Actions
        (Self            : Bare_Generic_Subp_Renaming_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_96 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_97 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:11169");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_98 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:11171");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_99 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_100 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_102 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_101 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_104 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_103 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Generic_Subp_Renaming_Decl
        (Self : Bare_Generic_Subp_Renaming_Decl
         ; Generic_Subp_Renaming_Decl_F_Kind : Bare_Subp_Kind
         ; Generic_Subp_Renaming_Decl_F_Name : Bare_Defining_Name
         ; Generic_Subp_Renaming_Decl_F_Renames : Bare_Name
         ; Generic_Subp_Renaming_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Generic_Subp_Renaming_Decl_F_Kind := Generic_Subp_Renaming_Decl_F_Kind;
            Self.Generic_Subp_Renaming_Decl_F_Name := Generic_Subp_Renaming_Decl_F_Name;
            Self.Generic_Subp_Renaming_Decl_F_Renames := Generic_Subp_Renaming_Decl_F_Renames;
            Self.Generic_Subp_Renaming_Decl_F_Aspects := Generic_Subp_Renaming_Decl_F_Aspects;
      end Initialize_Fields_For_Generic_Subp_Renaming_Decl;
   function Generic_Subp_Renaming_Decl_F_Kind
     (Node : Bare_Generic_Subp_Renaming_Decl) return Bare_Subp_Kind
   is
   begin
         return Node.Generic_Subp_Renaming_Decl_F_Kind;
   end;
   function Generic_Subp_Renaming_Decl_F_Name
     (Node : Bare_Generic_Subp_Renaming_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Generic_Subp_Renaming_Decl_F_Name;
   end;
   function Generic_Subp_Renaming_Decl_F_Renames
     (Node : Bare_Generic_Subp_Renaming_Decl) return Bare_Name
   is
   begin
         return Node.Generic_Subp_Renaming_Decl_F_Renames;
   end;
--# property-start GenericSubpRenamingDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:11197
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Renaming_Decl_P_Defining_Names
  (Node : Bare_Generic_Subp_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Renaming_Decl :=
     Internal_Entity_Generic_Subp_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_887 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_887 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_887;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5381 '<FieldAccess for name at ast.py:11197>' Fld /tmp/lal-23.0.0/ada/ast.py:11197
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Generic_Subp_Renaming_Decl_F_Name, Info => Ent.Info);
--# expr-done 5381
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_887;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_887;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Renaming_Decl_P_Defining_Names;
--# end
--# property-start GenericSubpRenamingDecl.renaming_name /tmp/lal-23.0.0/ada/ast.py:11198
pragma Warnings (Off, "is not referenced");
 function Generic_Subp_Renaming_Decl_P_Renaming_Name
  (Node : Bare_Generic_Subp_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Renaming_Decl :=
     Internal_Entity_Generic_Subp_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Name;
      Fld : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5382 '<FieldAccess for renames at ast.py:11198>' Fld /tmp/lal-23.0.0/ada/ast.py:11198
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Generic_Subp_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 5382
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Generic_Subp_Renaming_Decl_P_Renaming_Name;
--# end
--# property-start GenericSubpRenamingDecl._env_do_96 /tmp/lal-23.0.0/ada/ast.py:11167
pragma Warnings (Off, "is not referenced");
 function Env_Do_96
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5383 '<FieldAccess for env_hook at ast.py:11167>' Fld /tmp/lal-23.0.0/ada/ast.py:11167
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5383
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_96;
--# end
--# property-start GenericSubpRenamingDecl._initial_env_97 /tmp/lal-23.0.0/ada/ast.py:11169
pragma Warnings (Off, "is not referenced");
 function Initial_Env_97
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1566 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1566 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1566;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5384 '<FieldAccess for child_decl_initial_env at ast.py:11169>' Fld /tmp/lal-23.0.0/ada/ast.py:11169
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self);
--# end
--# expr-done 5384
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1566;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1566;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_97;
--# end
--# property-start GenericSubpRenamingDecl._env_mappings_98 /tmp/lal-23.0.0/ada/ast.py:11171
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_98
  (Node : Bare_Generic_Subp_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Generic_Subp_Renaming_Decl :=
     Internal_Entity_Generic_Subp_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1567 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Generic_Subp_Renaming_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1567 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1567;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5387 '<New EnvAssoc at ast.py:11171>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:11171
--# expr-start 5385 '<New DesignatedEnv at ast.py:11171>' New_Struct /tmp/lal-23.0.0/ada/ast.py:11171
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5385
--# expr-start 5386 '<FieldAccess for name_symbol at ast.py:11172>' Fld /tmp/lal-23.0.0/ada/ast.py:11172
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 5386
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5387
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1567;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1567;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_98;
--# end
--# property-start GenericSubpRenamingDecl._env_trans_parent_99 /tmp/lal-23.0.0/ada/ast.py:11166
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_99
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_99;
--# end
--# property-start GenericSubpRenamingDecl._env_do_100 /tmp/lal-23.0.0/ada/ast.py:11178
pragma Warnings (Off, "is not referenced");
 function Env_Do_100
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1569 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1569 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1569;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5388 '<FieldAccess for populate_dependent_units at ast.py:11178>' Fld /tmp/lal-23.0.0/ada/ast.py:11178
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5388
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1569;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1569;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_100;
--# end
--# property-start GenericSubpRenamingDecl._ref_env_nodes_101 /tmp/lal-23.0.0/ada/ast.py:11181
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_101
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1570 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1570 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1570;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5389 '<FieldAccess for top_level_use_package_clauses at ast.py:11181>' Fld /tmp/lal-23.0.0/ada/ast.py:11181
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5389
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1570;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1570;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_101;
--# end
--# property-start GenericSubpRenamingDecl._ref_cond_102 /tmp/lal-23.0.0/ada/ast.py:11183
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_102
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5391 '<IsA LibraryItem, Subunit at ast.py:11183>' Is_A /tmp/lal-23.0.0/ada/ast.py:11183
--# expr-start 5390 '<parent at ast.py:11183>' Fld /tmp/lal-23.0.0/ada/ast.py:11183
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5390
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5391
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_102;
--# end
--# property-start GenericSubpRenamingDecl._ref_env_nodes_103 /tmp/lal-23.0.0/ada/ast.py:11186
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_103
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1572 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1572 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1572;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5392 '<FieldAccess for top_level_use_type_clauses at ast.py:11186>' Fld /tmp/lal-23.0.0/ada/ast.py:11186
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5392
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1572;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1572;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_103;
--# end
--# property-start GenericSubpRenamingDecl._ref_cond_104 /tmp/lal-23.0.0/ada/ast.py:11188
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_104
  (Node : Bare_Generic_Subp_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Generic_Subp_Renaming_Decl := Bare_Generic_Subp_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5394 '<IsA LibraryItem, Subunit at ast.py:11188>' Is_A /tmp/lal-23.0.0/ada/ast.py:11188
--# expr-start 5393 '<parent at ast.py:11188>' Fld /tmp/lal-23.0.0/ada/ast.py:11188
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5393
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5394
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_104;
--# end
   --
   --  Primitives for Bare_Label_Decl
   --
      procedure Label_Decl_Pre_Env_Actions
        (Self            : Bare_Label_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_152 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:19950");
         Dec_Ref (Mapping.Dest_Env);
      end;
      end;
      procedure Initialize_Fields_For_Label_Decl
        (Self : Bare_Label_Decl
         ; Label_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Self.Label_Decl_F_Name := Label_Decl_F_Name;
      end Initialize_Fields_For_Label_Decl;
   function Label_Decl_F_Name
     (Node : Bare_Label_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Label_Decl_F_Name;
   end;
--# property-start LabelDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:19948
pragma Warnings (Off, "is not referenced");
 function Label_Decl_P_Defining_Names
  (Node : Bare_Label_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Label_Decl := Bare_Label_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Label_Decl :=
     Internal_Entity_Label_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1406 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1406 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1406;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5395 '<FieldAccess for name at ast.py:19948>' Fld /tmp/lal-23.0.0/ada/ast.py:19948
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Label_Decl_F_Name, Info => Ent.Info);
--# expr-done 5395
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1406;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1406;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Label_Decl_P_Defining_Names;
--# end
--# property-start LabelDecl._env_mappings_152 /tmp/lal-23.0.0/ada/ast.py:19950
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_152
  (Node : Bare_Label_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Label_Decl := Bare_Label_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1621 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Label_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1621 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1621;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5398 '<New EnvAssoc at ast.py:19950>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:19950
--# expr-start 5396 '<New DesignatedEnv at ast.py:19950>' New_Struct /tmp/lal-23.0.0/ada/ast.py:19950
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5396
--# expr-start 5397 '<FieldAccess for name_symbol at ast.py:19950>' Fld /tmp/lal-23.0.0/ada/ast.py:19950
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 5397
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5398
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1621;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1621;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_152;
--# end
   --
   --  Primitives for Bare_Named_Stmt_Decl
   --
      procedure Initialize_Fields_For_Named_Stmt_Decl
        (Self : Bare_Named_Stmt_Decl
         ; Named_Stmt_Decl_F_Name : Bare_Defining_Name
        ) is
      begin
            Self.Named_Stmt_Decl_F_Name := Named_Stmt_Decl_F_Name;
      end Initialize_Fields_For_Named_Stmt_Decl;
   function Named_Stmt_Decl_F_Name
     (Node : Bare_Named_Stmt_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Named_Stmt_Decl_F_Name;
   end;
--# property-start NamedStmtDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:19988
pragma Warnings (Off, "is not referenced");
 function Named_Stmt_Decl_P_Defining_Names
  (Node : Bare_Named_Stmt_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Named_Stmt_Decl := Bare_Named_Stmt_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Named_Stmt_Decl :=
     Internal_Entity_Named_Stmt_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1409 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1409 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1409;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5399 '<FieldAccess for name at ast.py:19988>' Fld /tmp/lal-23.0.0/ada/ast.py:19988
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Named_Stmt_Decl_F_Name, Info => Ent.Info);
--# expr-done 5399
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1409;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1409;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Named_Stmt_Decl_P_Defining_Names;
--# end
--# property-start NamedStmtDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:19989
pragma Warnings (Off, "is not referenced");
 function Named_Stmt_Decl_P_Defining_Env
  (Node : Bare_Named_Stmt_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Named_Stmt_Decl := Bare_Named_Stmt_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1410 with Inline_Always;
      Fld : Bare_Ada_Node;
Cast_Result : Bare_Named_Stmt;
Fld_1 : Bare_Composite_Stmt;
Fld_2 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1410 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_1410;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5403 '<FieldAccess for children_env at ast.py:19989>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19989
--# expr-start 5402 '<FieldAccess for stmt at ast.py:19989>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19989
--# expr-start 5401 '<Cast to NamedStmt at ast.py:19989>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19989
--# expr-start 5400 '<parent at ast.py:19989>' Fld /tmp/lal-23.0.0/ada/ast.py:19989
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5400
   if Fld = null
      or else Fld.Kind in Ada_Named_Stmt_Range
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5401
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Cast_Result.Named_Stmt_F_Stmt;
--# expr-done 5402
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Fld_1);
--# expr-done 5403
      Property_Result := Fld_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1410;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1410;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Named_Stmt_Decl_P_Defining_Env;
--# end
   --
   --  Primitives for Bare_Number_Decl
   --
      procedure Number_Decl_Pre_Env_Actions
        (Self            : Bare_Number_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_43 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10181");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Number_Decl
        (Self : Bare_Number_Decl
         ; Number_Decl_F_Ids : Bare_Defining_Name_List
         ; Number_Decl_F_Expr : Bare_Expr
        ) is
      begin
            Self.Number_Decl_F_Ids := Number_Decl_F_Ids;
            Self.Number_Decl_F_Expr := Number_Decl_F_Expr;
      end Initialize_Fields_For_Number_Decl;
   function Number_Decl_F_Ids
     (Node : Bare_Number_Decl) return Bare_Defining_Name_List
   is
   begin
         return Node.Number_Decl_F_Ids;
   end;
   function Number_Decl_F_Expr
     (Node : Bare_Number_Decl) return Bare_Expr
   is
   begin
         return Node.Number_Decl_F_Expr;
   end;
--# property-start NumberDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:10179
pragma Warnings (Off, "is not referenced");
 function Number_Decl_P_Defining_Names
  (Node : Bare_Number_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Number_Decl :=
     Internal_Entity_Number_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_809 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_List;
Fld_1 : Bare_Defining_Name_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Item_190 : Internal_Entity_Defining_Name;
Bare_Item_190 : Bare_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_809 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_809;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5405 '<Map at ast.py:10179>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10179
   --# expr-start 5404 '<FieldAccess for ids at ast.py:10179>' Fld /tmp/lal-23.0.0/ada/ast.py:10179
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name_List (Node => Ent.Node.Number_Decl_F_Ids, Info => Ent.Info);
--# expr-done 5404
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Defining_Name_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld_1;
      begin
         for Untyped_Item_190 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_190 := Untyped_Item_190; 
Is_Null := Bare_Item_190 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_190); 
   If_Result := As_Entity;
end if;
                  Item_190 := If_Result; 
   --# scope-start
               --# bind id Item_190
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Item_190;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5405
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_809;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_809;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Number_Decl_P_Defining_Names;
--# end
--# property-start NumberDecl.expr_type /tmp/lal-23.0.0/ada/ast.py:10184
pragma Warnings (Off, "is not referenced");
 function Number_Decl_P_Expr_Type
  (Node : Bare_Number_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Number_Decl :=
     Internal_Entity_Number_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5413 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5412 '<Cast to BaseTypeDecl.entity at ast.py:10187>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10187
--# expr-start 5411 '<If at ast.py:10185>' If_Result /tmp/lal-23.0.0/ada/ast.py:10185
--# expr-start 5408 '<FieldAccess for is_int_type at ast.py:10185>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10185
--# expr-start 5407 '<FieldAccess for expression_type at ast.py:10185>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10185
--# expr-start 5406 '<FieldAccess for expr at ast.py:10185>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10185
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Number_Decl_F_Expr, Info => Ent.Info);
--# expr-done 5406
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_3 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 5407
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_int_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Int_Type (Node => Fld_3.Node, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 5408
if Fld_4 then
   --# expr-start 5409 '<FieldAccess for universal_int_type at ast.py:10186>' Fld /tmp/lal-23.0.0/ada/ast.py:10186
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 5409
   If_Result := Fld;
else
   --# expr-start 5410 '<FieldAccess for universal_real_type at ast.py:10187>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10187
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 5410
   If_Result := Fld_1;
end if;
--# expr-done 5411
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 5412
Let_Result := Cast_Result; 
--# end
--# expr-done 5413
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Number_Decl_P_Expr_Type;
--# end
--# property-start NumberDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:10189
pragma Warnings (Off, "is not referenced");
 function Number_Decl_P_Xref_Entry_Point
  (Node : Bare_Number_Decl
  )
   return Boolean
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Number_Decl_P_Xref_Entry_Point;
--# end
--# property-start NumberDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:10191
pragma Warnings (Off, "is not referenced");
 function Number_Decl_P_Is_Static_Decl
  (Node : Bare_Number_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Number_Decl_P_Is_Static_Decl;
--# end
--# property-start NumberDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:10193
pragma Warnings (Off, "is not referenced");
 function Number_Decl_P_Xref_Equation
  (Node : Bare_Number_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Number_Decl :=
     Internal_Entity_Number_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_813 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Bare_Expr;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_6 : Internal_Entity_Expr;
Fld_7 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_8 : Internal_Entity_Expr;
Fld_9 : Logic_Equation;
And_Pred_1 : Logic_Equation;
            procedure Finalizer_Scope_813 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_813;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5428 '<And at ast.py:10194>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:10194
--# expr-start 5425 '<And at ast.py:10194>' And_Pred /tmp/lal-23.0.0/ada/ast.py:10194
--# expr-start 5422 '<Or at ast.py:10194>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:10194
--# expr-start 5417 '<Bind at ast.py:10195>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:10195
--# expr-start 5415 '<FieldAccess for expected_type_var at ast.py:10195>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10195
--# expr-start 5414 '<FieldAccess for expr at ast.py:10195>' Fld /tmp/lal-23.0.0/ada/ast.py:10195
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Number_Decl_F_Expr;
--# expr-done 5414
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 5415
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 5416 '<FieldAccess for universal_int_type at ast.py:10195>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10195
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 5416
Bind_Result := Solver.Create_Assign (Fld_1, Fld_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10195") else null)); 
--# expr-done 5417
--# expr-start 5421 '<Bind at ast.py:10196>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:10196
--# expr-start 5419 '<FieldAccess for expected_type_var at ast.py:10196>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10196
--# expr-start 5418 '<FieldAccess for expr at ast.py:10196>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10196
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Number_Decl_F_Expr;
--# expr-done 5418
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_3);
--# expr-done 5419
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 5420 '<FieldAccess for universal_real_type at ast.py:10196>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10196
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld_5 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 5420
Bind_Result_1 := Solver.Create_Assign (Fld_4, Fld_5, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10196") else null)); 
--# expr-done 5421
Or_Pred := Create_Or (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10194") else null)); 
--# expr-done 5422
--# expr-start 5424 '<FieldAccess for sub_equation at ast.py:10198>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10198
--# expr-start 5423 '<FieldAccess for expr at ast.py:10198>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10198
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Ent.Node.Number_Decl_F_Expr, Info => Ent.Info);
--# expr-done 5423
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_7 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_6.Node, Env => Env, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 5424
And_Pred := Create_And (Or_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10194") else null)); 
--# expr-done 5425
--# expr-start 5427 '<FieldAccess for matches_expected_type at ast.py:10199>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10199
--# expr-start 5426 '<FieldAccess for expr at ast.py:10199>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10199
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Ent.Node.Number_Decl_F_Expr, Info => Ent.Info);
--# expr-done 5426
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_9 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_8.Node, Origin => Origin);
--# end
--# expr-done 5427
And_Pred_1 := Create_And (And_Pred, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10194") else null)); 
--# expr-done 5428
      Property_Result := And_Pred_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_813;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_813;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Number_Decl_P_Xref_Equation;
--# end
--# property-start NumberDecl.is_constant_object /tmp/lal-23.0.0/ada/ast.py:10202
pragma Warnings (Off, "is not referenced");
 function Number_Decl_P_Is_Constant_Object
  (Node : Bare_Number_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Number_Decl_P_Is_Constant_Object;
--# end
--# property-start NumberDecl._env_mappings_43 /tmp/lal-23.0.0/ada/ast.py:10181
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_43
  (Node : Bare_Number_Decl
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Number_Decl := Bare_Number_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1512 with Inline_Always;
      Fld : Bare_Defining_Name_List;
Cast_Expr : Bare_Number_Decl;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1512 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1512;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5430 '<FieldAccess for env_mappings at ast.py:10181>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10181
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5429 '<FieldAccess for ids at ast.py:10181>' Fld /tmp/lal-23.0.0/ada/ast.py:10181
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Number_Decl_F_Ids;
--# expr-done 5429
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start AdaNode.env_mappings
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Mappings (Node => Self, Defining_Names => Fld, Value => Cast_Result);
--# end
--# expr-done 5430
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1512;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1512;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_43;
--# end
   --
   --  Primitives for Bare_Object_Decl
   --
      procedure Object_Decl_Pre_Env_Actions
        (Self            : Bare_Object_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mappings : Internal_Env_Assoc_Array_Access :=
            Libadalang.Implementation.Env_Mappings_44 (Node => 
Self);
      begin
         for Mapping of Mappings.Items loop
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10221");
         end loop;
         Dec_Ref (Mappings);
      end;
      end;
      procedure Initialize_Fields_For_Object_Decl
        (Self : Bare_Object_Decl
         ; Object_Decl_F_Ids : Bare_Defining_Name_List
         ; Object_Decl_F_Has_Aliased : Bare_Aliased_Node
         ; Object_Decl_F_Has_Constant : Bare_Constant_Node
         ; Object_Decl_F_Mode : Bare_Mode
         ; Object_Decl_F_Type_Expr : Bare_Type_Expr
         ; Object_Decl_F_Default_Expr : Bare_Expr
         ; Object_Decl_F_Renaming_Clause : Bare_Renaming_Clause
         ; Object_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Object_Decl_F_Ids := Object_Decl_F_Ids;
            Self.Object_Decl_F_Has_Aliased := Object_Decl_F_Has_Aliased;
            Self.Object_Decl_F_Has_Constant := Object_Decl_F_Has_Constant;
            Self.Object_Decl_F_Mode := Object_Decl_F_Mode;
            Self.Object_Decl_F_Type_Expr := Object_Decl_F_Type_Expr;
            Self.Object_Decl_F_Default_Expr := Object_Decl_F_Default_Expr;
            Self.Object_Decl_F_Renaming_Clause := Object_Decl_F_Renaming_Clause;
            Self.Object_Decl_F_Aspects := Object_Decl_F_Aspects;
      end Initialize_Fields_For_Object_Decl;
   function Object_Decl_F_Ids
     (Node : Bare_Object_Decl) return Bare_Defining_Name_List
   is
   begin
         return Node.Object_Decl_F_Ids;
   end;
   function Object_Decl_F_Has_Aliased
     (Node : Bare_Object_Decl) return Bare_Aliased_Node
   is
   begin
         return Node.Object_Decl_F_Has_Aliased;
   end;
   function Object_Decl_F_Has_Constant
     (Node : Bare_Object_Decl) return Bare_Constant_Node
   is
   begin
         return Node.Object_Decl_F_Has_Constant;
   end;
   function Object_Decl_F_Mode
     (Node : Bare_Object_Decl) return Bare_Mode
   is
   begin
         return Node.Object_Decl_F_Mode;
   end;
   function Object_Decl_F_Type_Expr
     (Node : Bare_Object_Decl) return Bare_Type_Expr
   is
   begin
         return Node.Object_Decl_F_Type_Expr;
   end;
   function Object_Decl_F_Default_Expr
     (Node : Bare_Object_Decl) return Bare_Expr
   is
   begin
         return Node.Object_Decl_F_Default_Expr;
   end;
   function Object_Decl_F_Renaming_Clause
     (Node : Bare_Object_Decl) return Bare_Renaming_Clause
   is
   begin
         return Node.Object_Decl_F_Renaming_Clause;
   end;
--# property-start ObjectDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:10223
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Defining_Names
  (Node : Bare_Object_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_815 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_List;
Fld_1 : Bare_Defining_Name_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Item_191 : Internal_Entity_Defining_Name;
Bare_Item_191 : Bare_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_815 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_815;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5432 '<Map at ast.py:10223>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10223
   --# expr-start 5431 '<FieldAccess for ids at ast.py:10223>' Fld /tmp/lal-23.0.0/ada/ast.py:10223
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name_List (Node => Ent.Node.Object_Decl_F_Ids, Info => Ent.Info);
--# expr-done 5431
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Defining_Name_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld_1;
      begin
         for Untyped_Item_191 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_191 := Untyped_Item_191; 
Is_Null := Bare_Item_191 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_191); 
   If_Result := As_Entity;
end if;
                  Item_191 := If_Result; 
   --# scope-start
               --# bind id Item_191
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Item_191;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5432
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_815;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_815;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Defining_Names;
--# end
--# property-start ObjectDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:10224
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Defining_Env
  (Node : Bare_Object_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_816 with Inline_Always;
      Fld : Internal_Entity_Type_Expr;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_816 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_816;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5434 '<FieldAccess for defining_env at ast.py:10224>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10224
--# expr-start 5433 '<FieldAccess for type_expr at ast.py:10224>' Fld /tmp/lal-23.0.0/ada/ast.py:10224
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Object_Decl_F_Type_Expr, Info => Ent.Info);
--# expr-done 5433
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.defining_env
Fld_1 := Libadalang.Implementation.Type_Expr_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 5434
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_816;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_816;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Defining_Env;
--# end
--# property-start ObjectDecl.type_expression /tmp/lal-23.0.0/ada/ast.py:10225
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Type_Expression
  (Node : Bare_Object_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Expr
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Expr;
      Fld : Internal_Entity_Type_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5435 '<FieldAccess for type_expr at ast.py:10225>' Fld /tmp/lal-23.0.0/ada/ast.py:10225
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Object_Decl_F_Type_Expr, Info => Ent.Info);
--# expr-done 5435
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Type_Expression;
--# end
--# property-start ObjectDecl.is_constant_object /tmp/lal-23.0.0/ada/ast.py:10228
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Is_Constant_Object
  (Node : Bare_Object_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Constant_Node;
Var_Expr_1 : Internal_Entity_Mode;
Var_Expr_2 : Internal_Entity_Renaming_Clause;
Fld : Internal_Entity_Constant_Node;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Fld_2 : Internal_Entity_Mode;
Fld_3 : Bare_Ada_Node;
Is_A : Boolean;
Is_A_1 : Boolean;
If_Result : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_1 : Boolean;
Fld_4 : Internal_Entity_Renaming_Clause;
Fld_5 : Internal_Entity_Name;
Fld_6 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_2 : Boolean;
Fld_7 : Internal_Entity_Type_Expr;
Fld_8 : Internal_Entity_Base_Type_Decl;
Is_A_2 : Boolean;
If_Result_3 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5448 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5436 '<FieldAccess for has_constant at ast.py:10230>' Fld /tmp/lal-23.0.0/ada/ast.py:10230
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Constant_Node (Node => Ent.Node.Object_Decl_F_Has_Constant, Info => Ent.Info);
--# expr-done 5436
Var_Expr := Fld;
if Var_Expr /= No_Entity_Constant_Node then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 5437 '<FieldAccess for as_bool at ast.py:10230>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10230
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Constant.as_bool'
Fld_1 := Libadalang.Implementation.Dispatcher_Constant_Node_P_As_Bool (Node => Var_Expr.Node);
--# end
--# expr-done 5437
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   If_Result_1 := True;
else
--# expr-start 5438 '<FieldAccess for mode at ast.py:10233>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10233
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Mode (Node => Ent.Node.Object_Decl_F_Mode, Info => Ent.Info);
--# expr-done 5438
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity_Mode then
   --# scope-start
   --# bind m Var_Expr_1
--# expr-start 5440 '<IsA GenericFormalObjDecl at ast.py:10235>' Is_A /tmp/lal-23.0.0/ada/ast.py:10235
--# expr-start 5439 '<parent at ast.py:10235>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10235
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Parent; 
--# expr-done 5439
Is_A := Fld_3 /= null 
and then Fld_3.Kind in Ada_Generic_Formal_Obj_Decl_Range; 
--# expr-done 5440
if Is_A then
   --# expr-start 5441 '<IsA Mode.In, Mode.Default at ast.py:10236>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:10236
Is_A_1 := Var_Expr_1.Node /= null 
and then Var_Expr_1.Node.Kind in Ada_Mode_In_Range | Ada_Mode_Default_Range; 
--# expr-done 5441
   If_Result := Is_A_1;
else
   If_Result := False;
end if;
Scope_Result_1 := If_Result;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_1 := Result_Var_1;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
--# expr-start 5442 '<FieldAccess for renaming_clause at ast.py:10240>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10240
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Object_Decl_F_Renaming_Clause, Info => Ent.Info);
--# expr-done 5442
Var_Expr_2 := Fld_4;
if Var_Expr_2 /= No_Entity_Renaming_Clause then
   --# scope-start
--# expr-start 5444 '<FieldAccess for is_constant at ast.py:10240>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10240
--# expr-start 5443 '<FieldAccess for renamed_object at ast.py:10240>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10240
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Var_Expr_2.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr_2.Info);
--# expr-done 5443
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.is_constant'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Is_Constant (Node => Fld_5.Node, E_Info => Fld_5.Info);
--# end
--# expr-done 5444
Scope_Result_2 := Fld_6;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
   If_Result_2 := Result_Var_2;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 5447 '<IsA ProtectedTypeDecl at ast.py:10243>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:10243
--# expr-start 5446 '<FieldAccess for designated_type_decl at ast.py:10243>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10243
--# expr-start 5445 '<FieldAccess for type_expr at ast.py:10243>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10243
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Object_Decl_F_Type_Expr, Info => Ent.Info);
--# expr-done 5445
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.designated_type_decl
Fld_8 := Libadalang.Implementation.Type_Expr_P_Designated_Type_Decl (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 5446
Is_A_2 := Fld_8.Node /= null 
and then Fld_8.Node.Kind in Ada_Protected_Type_Decl_Range; 
--# expr-done 5447
   If_Result_3 := Is_A_2;
end if;
Let_Result := If_Result_3; 
--# end
--# expr-done 5448
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Is_Constant_Object;
--# end
--# property-start ObjectDecl.is_static_decl /tmp/lal-23.0.0/ada/ast.py:10247
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Is_Static_Decl
  (Node : Bare_Object_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Renaming_Clause;
Fld : Bare_Constant_Node;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Fld_4 : Internal_Entity_Renaming_Clause;
Fld_5 : Internal_Entity_Name;
Fld_6 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5456 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5450 '<FieldAccess for as_bool at ast.py:10249>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10249
--# expr-start 5449 '<FieldAccess for has_constant at ast.py:10249>' Fld /tmp/lal-23.0.0/ada/ast.py:10249
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Object_Decl_F_Has_Constant;
--# expr-done 5449
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Constant.as_bool'
Fld_1 := Libadalang.Implementation.Dispatcher_Constant_Node_P_As_Bool (Node => Fld);
--# end
--# expr-done 5450
if Fld_1 then
--# expr-start 5451 '<FieldAccess for default_expr at ast.py:10249>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10249
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Object_Decl_F_Default_Expr, Info => Ent.Info);
--# expr-done 5451
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind expr Var_Expr
--# expr-start 5452 '<FieldAccess for is_static_expr at ast.py:10250>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10250
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_3 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 5452
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_1 := True;
else
--# expr-start 5453 '<FieldAccess for renaming_clause at ast.py:10252>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10252
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Object_Decl_F_Renaming_Clause, Info => Ent.Info);
--# expr-done 5453
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= No_Entity_Renaming_Clause then
   --# scope-start
--# expr-start 5455 '<FieldAccess for is_static_expr at ast.py:10252>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10252
--# expr-start 5454 '<FieldAccess for renamed_object at ast.py:10252>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10252
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr_1.Info);
--# expr-done 5454
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_6 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_5.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_5.Info);
--# end
--# expr-done 5455
Scope_Result_1 := Fld_6;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_1 := Result_Var_1;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 5456
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Is_Static_Decl;
--# end
--# property-start ObjectDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:10256
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Xref_Equation
  (Node : Bare_Object_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_820 with Inline_Always;
            procedure Finalizer_Scope_2566 with Inline_Always;
            procedure Finalizer_Scope_2567 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Renaming_Clause;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_7 : Internal_Entity_Renaming_Clause;
Fld_8 : Internal_Entity_Name;
Fld_9 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_10 : Internal_Entity_Name;
Fld_11 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_12 : Internal_Entity_Name;
Fld_13 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_820 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_820;
            procedure Finalizer_Scope_2566 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2566;
            procedure Finalizer_Scope_2567 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_11);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_13);
                     Dec_Ref (And_Pred_4);
            end Finalizer_Scope_2567;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5479 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5457 '<FieldAccess for expr_type at ast.py:10257>' Fld /tmp/lal-23.0.0/ada/ast.py:10257
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 5457
Block_Var := Fld; 
--# bind typ Block_Var
--# expr-start 5478 '<And at ast.py:10259>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:10259
--# expr-start 5467 '<And at ast.py:10259>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:10259
--# expr-start 5459 '<FieldAccess for sub_equation at ast.py:10259>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10259
--# expr-start 5458 '<FieldAccess for type_expr at ast.py:10259>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10259
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Object_Decl_F_Type_Expr, Info => Ent.Info);
--# expr-done 5458
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_2 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 5459
--# expr-start 5460 '<FieldAccess for default_expr at ast.py:10260>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10260
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Object_Decl_F_Default_Expr, Info => Ent.Info);
--# expr-done 5460
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind de Var_Expr
--# expr-start 5466 '<And at ast.py:10262>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:10262
--# expr-start 5464 '<And at ast.py:10262>' And_Pred /tmp/lal-23.0.0/ada/ast.py:10262
--# expr-start 5462 '<Bind at ast.py:10262>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:10262
--# expr-start 5461 '<FieldAccess for expected_type_var at ast.py:10262>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10262
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 5461
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10262") else null)); 
--# expr-done 5462
--# expr-start 5463 '<FieldAccess for sub_equation at ast.py:10263>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10263
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 5463
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10262") else null)); 
--# expr-done 5464
--# expr-start 5465 '<FieldAccess for matches_expected_assign_type at ast.py:10264>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10264
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 5465
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10262") else null)); 
--# expr-done 5466
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2566;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10265") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (Fld_2, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10259") else null)); 
--# expr-done 5467
--# expr-start 5468 '<FieldAccess for renaming_clause at ast.py:10267>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:10267
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Object_Decl_F_Renaming_Clause, Info => Ent.Info);
--# expr-done 5468
Var_Expr_1 := Fld_7;
if Var_Expr_1 /= No_Entity_Renaming_Clause then
   --# scope-start
   --# bind rc Var_Expr_1
--# expr-start 5477 '<And at ast.py:10269>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:10269
--# expr-start 5474 '<And at ast.py:10269>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:10269
--# expr-start 5471 '<Bind at ast.py:10269>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:10269
--# expr-start 5470 '<FieldAccess for expected_type_var at ast.py:10269>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:10269
--# expr-start 5469 '<FieldAccess for renamed_object at ast.py:10269>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:10269
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr_1.Info);
--# expr-done 5469
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_8.Node);
--# expr-done 5470
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
Cast_Expr_1 := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_9, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10269") else null)); 
--# expr-done 5471
--# expr-start 5473 '<FieldAccess for sub_equation at ast.py:10270>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:10270
--# expr-start 5472 '<FieldAccess for renamed_object at ast.py:10270>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:10270
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr_1.Info);
--# expr-done 5472
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_11 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_10.Node, Env => Env, Origin => Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 5473
And_Pred_3 := Create_And (Bind_Result_1, Fld_11, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10269") else null)); 
--# expr-done 5474
--# expr-start 5476 '<FieldAccess for matches_expected_assign_type at ast.py:10271>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:10271
--# expr-start 5475 '<FieldAccess for renamed_object at ast.py:10271>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:10271
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr_1.Info);
--# expr-done 5475
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_13 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Fld_12.Node, Origin => Origin);
--# end
--# expr-done 5476
And_Pred_4 := Create_And (And_Pred_3, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10269") else null)); 
--# expr-done 5477
Scope_Result_1 := And_Pred_4;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2567;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10272") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_5 := Create_And (And_Pred_2, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:10259") else null)); 
--# expr-done 5478
Let_Result := And_Pred_5; Inc_Ref (Let_Result);
--# end
--# expr-done 5479
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_820;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_820;
               Finalizer_Scope_2566;
               Finalizer_Scope_2567;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Xref_Equation;
--# end
--# property-start ObjectDecl.next_part_for_name /tmp/lal-23.0.0/ada/ast.py:10277
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Next_Part_For_Name
  (Node : Bare_Object_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_821 with Inline_Always;
            procedure Finalizer_Scope_2568 with Inline_Always;
      Var_Expr : Bare_Private_Part;
Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Base_Package_Decl;
Fld_2 : Bare_Private_Part;
Fld_3 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_4 : Boolean;
Fld_5 : Bare_Constant_Node;
Fld_6 : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_821 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_821;
            procedure Finalizer_Scope_2568 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2568;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5491 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5490 '<If at ast.py:10278>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:10278
--# expr-start 5480 '<FieldAccess for is_in_public_part at ast.py:10279>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10279
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_in_public_part
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Is_In_Public_Part (Node => Ent.Node);
--# end
--# expr-done 5480
if Fld_4 then
   --# expr-start 5482 '<FieldAccess for as_bool at ast.py:10279>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10279
--# expr-start 5481 '<FieldAccess for has_constant at ast.py:10279>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10279
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Object_Decl_F_Has_Constant;
--# expr-done 5481
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Constant.as_bool'
Fld_6 := Libadalang.Implementation.Dispatcher_Constant_Node_P_As_Bool (Node => Fld_5);
--# end
--# expr-done 5482
   If_Result := Fld_6;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 5489 '<Cast to BasicDecl at ast.py:10283>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:10283
--# expr-start 5488 '<EnvGet at ast.py:10280>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:10280
--# expr-start 5486 '<FieldAccess for private_part at ast.py:10281>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10281
--# expr-start 5485 '<Cast to BasePackageDecl at ast.py:10281>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10281
--# expr-start 5484 '<parent at ast.py:10280>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10280
--# expr-start 5483 '<FieldAccess for declarative_scope at ast.py:10280>' Fld /tmp/lal-23.0.0/ada/ast.py:10280
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Self);
--# end
--# expr-done 5483
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 5484
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Base_Package_Decl
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5485
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Base_Package_Decl_F_Private_Part;
--# expr-done 5486
Var_Expr := Fld_2;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 5487 '<FieldAccess for children_env at ast.py:10281>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10281
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 5487
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2568;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 5488
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 5489
   If_Result_1 := Cast_Result_1;
else
   If_Result_1 := No_Entity_Basic_Decl;
end if;
--# expr-done 5490
Let_Result := If_Result_1; 
--# end
--# expr-done 5491
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_821;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_821;
               Finalizer_Scope_2568;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Next_Part_For_Name;
--# end
--# property-start ObjectDecl.previous_part_for_name /tmp/lal-23.0.0/ada/ast.py:10288
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Previous_Part_For_Name
  (Node : Bare_Object_Decl
      ; Sym : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sym Sym
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_822 with Inline_Always;
      Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Base_Package_Decl;
Fld_2 : Bare_Public_Part;
Fld_3 : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_4 : Boolean;
Fld_5 : Bare_Constant_Node;
Fld_6 : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_822 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_822;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5503 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5502 '<If at ast.py:10289>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:10289
--# expr-start 5492 '<FieldAccess for is_in_private_part at ast.py:10290>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:10290
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5492
if Fld_4 then
   --# expr-start 5494 '<FieldAccess for as_bool at ast.py:10290>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:10290
--# expr-start 5493 '<FieldAccess for has_constant at ast.py:10290>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:10290
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Object_Decl_F_Has_Constant;
--# expr-done 5493
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Constant.as_bool'
Fld_6 := Libadalang.Implementation.Dispatcher_Constant_Node_P_As_Bool (Node => Fld_5);
--# end
--# expr-done 5494
   If_Result := Fld_6;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 5501 '<Cast to BasicDecl at ast.py:10294>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:10294
--# expr-start 5500 '<EnvGet at ast.py:10291>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:10291
--# expr-start 5499 '<FieldAccess for children_env at ast.py:10292>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:10292
--# expr-start 5498 '<FieldAccess for public_part at ast.py:10292>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10292
--# expr-start 5497 '<Cast to BasePackageDecl at ast.py:10292>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10292
--# expr-start 5496 '<parent at ast.py:10291>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10291
--# expr-start 5495 '<FieldAccess for declarative_scope at ast.py:10291>' Fld /tmp/lal-23.0.0/ada/ast.py:10291
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Self);
--# end
--# expr-done 5495
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 5496
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Base_Package_Decl
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5497
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Base_Package_Decl_F_Public_Part;
--# expr-done 5498
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Children_Env (Node => Fld_2);
--# expr-done 5499
Env_Get_Result := AST_Envs.Get_First (Self => Fld_3, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 5500
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 5501
   If_Result_1 := Cast_Result_1;
else
   If_Result_1 := No_Entity_Basic_Decl;
end if;
--# expr-done 5502
Let_Result := If_Result_1; 
--# end
--# expr-done 5503
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_822;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_822;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Previous_Part_For_Name;
--# end
--# property-start ObjectDecl.private_part_decl /tmp/lal-23.0.0/ada/ast.py:10299
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Private_Part_Decl
  (Node : Bare_Object_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Defining_Name;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5507 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5506 '<FieldAccess for next_part_for_name at ast.py:10304>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10304
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5505 '<FieldAccess for name_symbol at ast.py:10305>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10305
--# expr-start 5504 '<FieldAccess for defining_name_or_raise at ast.py:10305>' Fld /tmp/lal-23.0.0/ada/ast.py:10305
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5504
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 5505
--# property-call-start '[dispatcher]BasicDecl.next_part_for_name'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Name (Node => Ent.Node, Sym => Fld_1, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 5506
Let_Result := Fld_2; 
--# end
--# expr-done 5507
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Private_Part_Decl;
--# end
--# property-start ObjectDecl.public_part_decl /tmp/lal-23.0.0/ada/ast.py:10309
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Public_Part_Decl
  (Node : Bare_Object_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Defining_Name;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5511 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5510 '<FieldAccess for previous_part_for_name at ast.py:10314>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10314
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5509 '<FieldAccess for name_symbol at ast.py:10315>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10315
--# expr-start 5508 '<FieldAccess for defining_name_or_raise at ast.py:10315>' Fld /tmp/lal-23.0.0/ada/ast.py:10315
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name_or_raise
Fld := Libadalang.Implementation.Basic_Decl_P_Defining_Name_Or_Raise (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5508
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 5509
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_name'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Name (Node => Ent.Node, Sym => Fld_1, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 5510
Let_Result := Fld_2; 
--# end
--# expr-done 5511
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Public_Part_Decl;
--# end
--# property-start ObjectDecl.next_part_for_decl /tmp/lal-23.0.0/ada/ast.py:10319
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Next_Part_For_Decl
  (Node : Bare_Object_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5513 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5512 '<FieldAccess for private_part_decl at ast.py:10320>' Fld /tmp/lal-23.0.0/ada/ast.py:10320
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ObjectDecl.private_part_decl
Fld := Libadalang.Implementation.Object_Decl_P_Private_Part_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5512
Let_Result := Fld; 
--# end
--# expr-done 5513
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Next_Part_For_Decl;
--# end
--# property-start ObjectDecl.previous_part_for_decl /tmp/lal-23.0.0/ada/ast.py:10323
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Previous_Part_For_Decl
  (Node : Bare_Object_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Object_Decl :=
     Internal_Entity_Object_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5515 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5514 '<FieldAccess for public_part_decl at ast.py:10324>' Fld /tmp/lal-23.0.0/ada/ast.py:10324
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ObjectDecl.public_part_decl
Fld := Libadalang.Implementation.Object_Decl_P_Public_Part_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5514
Let_Result := Fld; 
--# end
--# expr-done 5515
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Previous_Part_For_Decl;
--# end
--# property-start ObjectDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:10326
pragma Warnings (Off, "is not referenced");
 function Object_Decl_P_Xref_Entry_Point
  (Node : Bare_Object_Decl
  )
   return Boolean
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Object_Decl_P_Xref_Entry_Point;
--# end
--# property-start ObjectDecl._env_mappings_44 /tmp/lal-23.0.0/ada/ast.py:10221
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_44
  (Node : Bare_Object_Decl
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Object_Decl := Bare_Object_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1513 with Inline_Always;
      Fld : Bare_Defining_Name_List;
Cast_Expr : Bare_Object_Decl;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_1513 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1513;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5517 '<FieldAccess for env_mappings at ast.py:10221>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10221
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5516 '<FieldAccess for ids at ast.py:10221>' Fld /tmp/lal-23.0.0/ada/ast.py:10221
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Object_Decl_F_Ids;
--# expr-done 5516
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start AdaNode.env_mappings
Fld_1 := Libadalang.Implementation.Ada_Node_P_Env_Mappings (Node => Self, Defining_Names => Fld, Value => Cast_Result);
--# end
--# expr-done 5517
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1513;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1513;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_44;
--# end
   --
   --  Primitives for Bare_Extended_Return_Stmt_Object_Decl
   --
      procedure Initialize_Fields_For_Extended_Return_Stmt_Object_Decl
        (Self : Bare_Extended_Return_Stmt_Object_Decl
         ; Object_Decl_F_Ids : Bare_Defining_Name_List
         ; Object_Decl_F_Has_Aliased : Bare_Aliased_Node
         ; Object_Decl_F_Has_Constant : Bare_Constant_Node
         ; Object_Decl_F_Mode : Bare_Mode
         ; Object_Decl_F_Type_Expr : Bare_Type_Expr
         ; Object_Decl_F_Default_Expr : Bare_Expr
         ; Object_Decl_F_Renaming_Clause : Bare_Renaming_Clause
         ; Object_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Object_Decl
              (Self, Object_Decl_F_Ids, Object_Decl_F_Has_Aliased, Object_Decl_F_Has_Constant, Object_Decl_F_Mode, Object_Decl_F_Type_Expr, Object_Decl_F_Default_Expr, Object_Decl_F_Renaming_Clause, Object_Decl_F_Aspects);
      end Initialize_Fields_For_Extended_Return_Stmt_Object_Decl;
   --
   --  Primitives for Bare_No_Type_Object_Renaming_Decl
   --
      procedure Initialize_Fields_For_No_Type_Object_Renaming_Decl
        (Self : Bare_No_Type_Object_Renaming_Decl
         ; Object_Decl_F_Ids : Bare_Defining_Name_List
         ; Object_Decl_F_Has_Aliased : Bare_Aliased_Node
         ; Object_Decl_F_Has_Constant : Bare_Constant_Node
         ; Object_Decl_F_Mode : Bare_Mode
         ; Object_Decl_F_Type_Expr : Bare_Type_Expr
         ; Object_Decl_F_Default_Expr : Bare_Expr
         ; Object_Decl_F_Renaming_Clause : Bare_Renaming_Clause
         ; Object_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Initialize_Fields_For_Object_Decl
              (Self, Object_Decl_F_Ids, Object_Decl_F_Has_Aliased, Object_Decl_F_Has_Constant, Object_Decl_F_Mode, Object_Decl_F_Type_Expr, Object_Decl_F_Default_Expr, Object_Decl_F_Renaming_Clause, Object_Decl_F_Aspects);
      end Initialize_Fields_For_No_Type_Object_Renaming_Decl;
--# property-start NoTypeObjectRenamingDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:10393
pragma Warnings (Off, "is not referenced");
 function No_Type_Object_Renaming_Decl_P_Xref_Equation
  (Node : Bare_No_Type_Object_Renaming_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_No_Type_Object_Renaming_Decl := Bare_No_Type_Object_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_No_Type_Object_Renaming_Decl :=
     Internal_Entity_No_Type_Object_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_833 with Inline_Always;
      Fld : Internal_Entity_Renaming_Clause;
Fld_1 : Internal_Entity_Name;
Fld_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_833 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_833;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5521 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5520 '<FieldAccess for sub_equation at ast.py:10394>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10394
--# expr-start 5519 '<FieldAccess for renamed_object at ast.py:10394>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10394
--# expr-start 5518 '<FieldAccess for renaming_clause at ast.py:10394>' Fld /tmp/lal-23.0.0/ada/ast.py:10394
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Object_Decl_F_Renaming_Clause, Info => Ent.Info);
--# expr-done 5518
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Fld.Node.Renaming_Clause_F_Renamed_Object, Info => Fld.Info);
--# expr-done 5519
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_2 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 5520
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 5521
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_833;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_833;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end No_Type_Object_Renaming_Decl_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Package_Renaming_Decl
   --
      procedure Package_Renaming_Decl_Pre_Env_Actions
        (Self            : Bare_Package_Renaming_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Dummy : Boolean;
      begin
         Dummy := Libadalang.Implementation.Env_Do_78 (Node => 
Self);
      end;
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_79 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:11057");
      end;
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_80 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:11059");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_81 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      declare
         Dummy : Bare_Compilation_Unit_Array_Access;
      begin
         Dummy := Libadalang.Implementation.Env_Do_82 (Node => 
Self);
         Dec_Ref (Dummy);
      end;
      if Libadalang.Implementation.Ref_Cond_84 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_83 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      if Libadalang.Implementation.Ref_Cond_86 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_85 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Package_Renaming_Decl
        (Self : Bare_Package_Renaming_Decl
         ; Package_Renaming_Decl_F_Name : Bare_Defining_Name
         ; Package_Renaming_Decl_F_Renames : Bare_Renaming_Clause
         ; Package_Renaming_Decl_F_Aspects : Bare_Aspect_Spec
        ) is
      begin
            Self.Package_Renaming_Decl_F_Name := Package_Renaming_Decl_F_Name;
            Self.Package_Renaming_Decl_F_Renames := Package_Renaming_Decl_F_Renames;
            Self.Package_Renaming_Decl_F_Aspects := Package_Renaming_Decl_F_Aspects;
      end Initialize_Fields_For_Package_Renaming_Decl;
   function Package_Renaming_Decl_F_Name
     (Node : Bare_Package_Renaming_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Package_Renaming_Decl_F_Name;
   end;
   function Package_Renaming_Decl_F_Renames
     (Node : Bare_Package_Renaming_Decl) return Bare_Renaming_Clause
   is
   begin
         return Node.Package_Renaming_Decl_F_Renames;
   end;
--# property-start PackageRenamingDecl.renamed_package /tmp/lal-23.0.0/ada/ast.py:11024
pragma Warnings (Off, "is not referenced");
 function Package_Renaming_Decl_P_Renamed_Package
  (Node : Bare_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Renaming_Decl :=
     Internal_Entity_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_874 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Block_Var_1 : Internal_Entity_Array_Access;
Var_Expr : Internal_Entity;
Fld : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Renaming_Clause;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_874 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_874;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5531 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5522 '<FieldAccess for node_env at ast.py:11032>' Fld /tmp/lal-23.0.0/ada/ast.py:11032
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 5522
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind node_env Block_Var
--# expr-start 5524 '<EnvGet at ast.py:11033>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:11033
--# expr-start 5523 '<Symbol __dummy at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Dummy); 
--# expr-done 5523
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Block_Var, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 5524
Block_Var_1 := Env_Get_Result; Inc_Ref (Block_Var_1);
--# expr-start 5530 '<bind at ast.py:11037>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:11037
Bound_Env := Block_Var; Inc_Ref (Bound_Env);
--# expr-start 5528 '<at at ast.py:11039>' Get_Result /tmp/lal-23.0.0/ada/ast.py:11039
--# expr-start 5527 '<FieldAccess for env_elements at ast.py:11039>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11039
--# expr-start 5526 '<FieldAccess for renamed_object at ast.py:11039>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11039
--# expr-start 5525 '<FieldAccess for renames at ast.py:11039>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11039
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Package_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 5525
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Fld_1.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_1.Info);
--# expr-done 5526
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_3 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Fld_2.Node, Env => Bound_Env, No_Visibility => False, E_Info => Fld_2.Info);
--# end
--# expr-done 5527
Get_Result := Get (Self, Fld_3, 0, True); 
--# expr-done 5528
Var_Expr := Get_Result;
if Var_Expr /= No_Entity then
   --# scope-start
--# expr-start 5529 '<Cast to BasicDecl at ast.py:11039>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11039
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 5529
Scope_Result := Cast_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Dyn_Var_Bind_Result := Result_Var; 
--# expr-done 5530
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 5531
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_874;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_874;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Renaming_Decl_P_Renamed_Package;
--# end
--# property-start PackageRenamingDecl.final_renamed_package /tmp/lal-23.0.0/ada/ast.py:11043
pragma Warnings (Off, "is not referenced");
 function Package_Renaming_Decl_P_Final_Renamed_Package
  (Node : Bare_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Renaming_Decl :=
     Internal_Entity_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Package_Renaming_Decl;
Fld : Internal_Entity_Basic_Decl;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Package_Renaming_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5535 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5532 '<FieldAccess for renamed_package at ast.py:11048>' Fld /tmp/lal-23.0.0/ada/ast.py:11048
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start PackageRenamingDecl.renamed_package
Fld := Libadalang.Implementation.Package_Renaming_Decl_P_Renamed_Package (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5532
Block_Var := Fld; 
--# bind pkg Block_Var
--# expr-start 5533 '<Cast to PackageRenamingDecl at ast.py:11049>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11049
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Package_Renaming_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Package_Renaming_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Package_Renaming_Decl;
   end if;
--# expr-done 5533
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Package_Renaming_Decl then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 5534 '<FieldAccess for final_renamed_package at ast.py:11050>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11050
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start PackageRenamingDecl.final_renamed_package
Fld_1 := Libadalang.Implementation.Package_Renaming_Decl_P_Final_Renamed_Package (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 5534
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := Block_Var;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 5535
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Renaming_Decl_P_Final_Renamed_Package;
--# end
--# property-start PackageRenamingDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:11080
pragma Warnings (Off, "is not referenced");
 function Package_Renaming_Decl_P_Defining_Names
  (Node : Bare_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Renaming_Decl :=
     Internal_Entity_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_876 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_876 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_876;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5536 '<FieldAccess for name at ast.py:11080>' Fld /tmp/lal-23.0.0/ada/ast.py:11080
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Package_Renaming_Decl_F_Name, Info => Ent.Info);
--# expr-done 5536
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_876;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_876;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Renaming_Decl_P_Defining_Names;
--# end
--# property-start PackageRenamingDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:11081
pragma Warnings (Off, "is not referenced");
 function Package_Renaming_Decl_P_Defining_Env
  (Node : Bare_Package_Renaming_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Renaming_Decl :=
     Internal_Entity_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_877 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_877 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_877;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5538 '<FieldAccess for defining_env at ast.py:11081>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11081
--# expr-start 5537 '<FieldAccess for renamed_package at ast.py:11081>' Fld /tmp/lal-23.0.0/ada/ast.py:11081
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start PackageRenamingDecl.renamed_package
Fld := Libadalang.Implementation.Package_Renaming_Decl_P_Renamed_Package (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5537
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 5538
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_877;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_877;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Renaming_Decl_P_Defining_Env;
--# end
--# property-start PackageRenamingDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:11083
pragma Warnings (Off, "is not referenced");
 function Package_Renaming_Decl_P_Xref_Entry_Point
  (Node : Bare_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Renaming_Decl_P_Xref_Entry_Point;
--# end
--# property-start PackageRenamingDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:11084
pragma Warnings (Off, "is not referenced");
 function Package_Renaming_Decl_P_Xref_Equation
  (Node : Bare_Package_Renaming_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Renaming_Decl :=
     Internal_Entity_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_879 with Inline_Always;
      Fld : Internal_Entity_Renaming_Clause;
Fld_1 : Internal_Entity_Name;
Fld_2 : Logic_Equation;
            procedure Finalizer_Scope_879 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_879;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5541 '<FieldAccess for xref_no_overloading at ast.py:11085>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11085
--# expr-start 5540 '<FieldAccess for renamed_object at ast.py:11085>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11085
--# expr-start 5539 '<FieldAccess for renames at ast.py:11085>' Fld /tmp/lal-23.0.0/ada/ast.py:11085
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Renaming_Clause (Node => Ent.Node.Package_Renaming_Decl_F_Renames, Info => Ent.Info);
--# expr-done 5539
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Fld.Node.Renaming_Clause_F_Renamed_Object, Info => Fld.Info);
--# expr-done 5540
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_2 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 5541
      Property_Result := Fld_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_879;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_879;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Package_Renaming_Decl_P_Xref_Equation;
--# end
--# property-start PackageRenamingDecl._env_do_78 /tmp/lal-23.0.0/ada/ast.py:11055
pragma Warnings (Off, "is not referenced");
 function Env_Do_78
  (Node : Bare_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5542 '<FieldAccess for env_hook at ast.py:11055>' Fld /tmp/lal-23.0.0/ada/ast.py:11055
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.env_hook
Fld := Libadalang.Implementation.Ada_Node_P_Env_Hook (Node => Self);
--# end
--# expr-done 5542
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_78;
--# end
--# property-start PackageRenamingDecl._initial_env_79 /tmp/lal-23.0.0/ada/ast.py:11057
pragma Warnings (Off, "is not referenced");
 function Initial_Env_79
  (Node : Bare_Package_Renaming_Decl
  )
   return Internal_Designated_Env
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1548 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1548 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1548;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5543 '<FieldAccess for child_decl_initial_env at ast.py:11057>' Fld /tmp/lal-23.0.0/ada/ast.py:11057
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.child_decl_initial_env
Fld := Libadalang.Implementation.Basic_Decl_P_Child_Decl_Initial_Env (Node => Self);
--# end
--# expr-done 5543
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1548;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1548;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_79;
--# end
--# property-start PackageRenamingDecl._env_mappings_80 /tmp/lal-23.0.0/ada/ast.py:11059
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_80
  (Node : Bare_Package_Renaming_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Package_Renaming_Decl :=
     Internal_Entity_Package_Renaming_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1549 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Package_Renaming_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1549 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1549;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5546 '<New EnvAssoc at ast.py:11059>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:11059
--# expr-start 5544 '<New DesignatedEnv at ast.py:11059>' New_Struct /tmp/lal-23.0.0/ada/ast.py:11059
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5544
--# expr-start 5545 '<FieldAccess for name_symbol at ast.py:11060>' Fld /tmp/lal-23.0.0/ada/ast.py:11060
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 5545
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5546
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1549;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1549;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_80;
--# end
--# property-start PackageRenamingDecl._env_trans_parent_81 /tmp/lal-23.0.0/ada/ast.py:11054
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_81
  (Node : Bare_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_81;
--# end
--# property-start PackageRenamingDecl._env_do_82 /tmp/lal-23.0.0/ada/ast.py:11066
pragma Warnings (Off, "is not referenced");
 function Env_Do_82
  (Node : Bare_Package_Renaming_Decl
  )
   return Bare_Compilation_Unit_Array_Access
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1551 with Inline_Always;
      Fld : Bare_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1551 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1551;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5547 '<FieldAccess for populate_dependent_units at ast.py:11066>' Fld /tmp/lal-23.0.0/ada/ast.py:11066
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.populate_dependent_units
Fld := Libadalang.Implementation.Basic_Decl_P_Populate_Dependent_Units (Node => Self);
--# end
--# expr-done 5547
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1551;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1551;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Do_82;
--# end
--# property-start PackageRenamingDecl._ref_env_nodes_83 /tmp/lal-23.0.0/ada/ast.py:11069
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_83
  (Node : Bare_Package_Renaming_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1552 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1552 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1552;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5548 '<FieldAccess for top_level_use_package_clauses at ast.py:11069>' Fld /tmp/lal-23.0.0/ada/ast.py:11069
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Package_Clauses (Node => Self);
--# end
--# expr-done 5548
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1552;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1552;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_83;
--# end
--# property-start PackageRenamingDecl._ref_cond_84 /tmp/lal-23.0.0/ada/ast.py:11071
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_84
  (Node : Bare_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5550 '<IsA LibraryItem, Subunit at ast.py:11071>' Is_A /tmp/lal-23.0.0/ada/ast.py:11071
--# expr-start 5549 '<parent at ast.py:11071>' Fld /tmp/lal-23.0.0/ada/ast.py:11071
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5549
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5550
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_84;
--# end
--# property-start PackageRenamingDecl._ref_env_nodes_85 /tmp/lal-23.0.0/ada/ast.py:11074
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_85
  (Node : Bare_Package_Renaming_Decl
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1554 with Inline_Always;
      Fld : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1554 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1554;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5551 '<FieldAccess for top_level_use_type_clauses at ast.py:11074>' Fld /tmp/lal-23.0.0/ada/ast.py:11074
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_use_type_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_Use_Type_Clauses (Node => Self);
--# end
--# expr-done 5551
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1554;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1554;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_85;
--# end
--# property-start PackageRenamingDecl._ref_cond_86 /tmp/lal-23.0.0/ada/ast.py:11076
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_86
  (Node : Bare_Package_Renaming_Decl
  )
   return Boolean
is
   Self : Bare_Package_Renaming_Decl := Bare_Package_Renaming_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5553 '<IsA LibraryItem, Subunit at ast.py:11076>' Is_A /tmp/lal-23.0.0/ada/ast.py:11076
--# expr-start 5552 '<parent at ast.py:11076>' Fld /tmp/lal-23.0.0/ada/ast.py:11076
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5552
Is_A := Fld /= null 
and then Fld.Kind in Ada_Library_Item_Range | Ada_Subunit_Range; 
--# expr-done 5553
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_86;
--# end
   --
   --  Primitives for Bare_Single_Protected_Decl
   --
      procedure Single_Protected_Decl_Pre_Env_Actions
        (Self            : Bare_Single_Protected_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_40 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10014");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_41 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_42 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Single_Protected_Decl
        (Self : Bare_Single_Protected_Decl
         ; Single_Protected_Decl_F_Name : Bare_Defining_Name
         ; Single_Protected_Decl_F_Aspects : Bare_Aspect_Spec
         ; Single_Protected_Decl_F_Interfaces : Bare_Parent_List
         ; Single_Protected_Decl_F_Definition : Bare_Protected_Def
        ) is
      begin
            Self.Single_Protected_Decl_F_Name := Single_Protected_Decl_F_Name;
            Self.Single_Protected_Decl_F_Aspects := Single_Protected_Decl_F_Aspects;
            Self.Single_Protected_Decl_F_Interfaces := Single_Protected_Decl_F_Interfaces;
            Self.Single_Protected_Decl_F_Definition := Single_Protected_Decl_F_Definition;
      end Initialize_Fields_For_Single_Protected_Decl;
   function Single_Protected_Decl_F_Name
     (Node : Bare_Single_Protected_Decl) return Bare_Defining_Name
   is
   begin
         return Node.Single_Protected_Decl_F_Name;
   end;
   function Single_Protected_Decl_F_Interfaces
     (Node : Bare_Single_Protected_Decl) return Bare_Parent_List
   is
   begin
         return Node.Single_Protected_Decl_F_Interfaces;
   end;
   function Single_Protected_Decl_F_Definition
     (Node : Bare_Single_Protected_Decl) return Bare_Protected_Def
   is
   begin
         return Node.Single_Protected_Decl_F_Definition;
   end;
--# property-start SingleProtectedDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:9990
pragma Warnings (Off, "is not referenced");
 function Single_Protected_Decl_P_Defining_Names
  (Node : Bare_Single_Protected_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Protected_Decl :=
     Internal_Entity_Single_Protected_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_798 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_798 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_798;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5554 '<FieldAccess for name at ast.py:9990>' Fld /tmp/lal-23.0.0/ada/ast.py:9990
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Defining_Name (Node => Ent.Node.Single_Protected_Decl_F_Name, Info => Ent.Info);
--# expr-done 5554
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_798;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_798;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Protected_Decl_P_Defining_Names;
--# end
--# property-start SingleProtectedDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:9992
pragma Warnings (Off, "is not referenced");
 function Single_Protected_Decl_P_Defining_Env
  (Node : Bare_Single_Protected_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Protected_Decl :=
     Internal_Entity_Single_Protected_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_799 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_799 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_799;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5555 '<FieldAccess for children_env at ast.py:9992>' Fld /tmp/lal-23.0.0/ada/ast.py:9992
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 5555
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_799;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_799;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Protected_Decl_P_Defining_Env;
--# end
--# property-start SingleProtectedDecl.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:9994
pragma Warnings (Off, "is not referenced");
 function Single_Protected_Decl_P_Xref_Entry_Point
  (Node : Bare_Single_Protected_Decl
  )
   return Boolean
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Protected_Decl_P_Xref_Entry_Point;
--# end
--# property-start SingleProtectedDecl.xref_equation /tmp/lal-23.0.0/ada/ast.py:9997
pragma Warnings (Off, "is not referenced");
 function Single_Protected_Decl_P_Xref_Equation
  (Node : Bare_Single_Protected_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Protected_Decl :=
     Internal_Entity_Single_Protected_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_801 with Inline_Always;
            procedure Finalizer_Scope_2571 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Item_192 : Internal_Entity_Name;
Bare_Item_192 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_801 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_801;
            procedure Finalizer_Scope_2571 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2571;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5560 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5559 '<LogicAll at ast.py:9998>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:9998
--# expr-start 5558 '<Map at ast.py:9998>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9998
   --# expr-start 5556 '<FieldAccess for interfaces at ast.py:9998>' Fld /tmp/lal-23.0.0/ada/ast.py:9998
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Single_Protected_Decl_F_Interfaces, Info => Ent.Info);
--# expr-done 5556
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_192 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_192 := Untyped_Item_192; 
Is_Null := Bare_Item_192 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_192); 
   If_Result := As_Entity;
end if;
                  Item_192 := If_Result; 
   --# scope-start
               --# bind ifc Item_192
      --# expr-start 5557 '<FieldAccess for xref_equation at ast.py:9998>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9998
      if Item_192.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Item_192.Node, Env => Env, Origin => Origin, E_Info => Item_192.Info);
--# end
--# expr-done 5557
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2571;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5558
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9998") else null)); 
--# expr-done 5559
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 5560
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_801;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_801;
               Finalizer_Scope_2571;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Protected_Decl_P_Xref_Equation;
--# end
--# property-start SingleProtectedDecl.env_names /tmp/lal-23.0.0/ada/ast.py:10001
pragma Warnings (Off, "is not referenced");
 function Single_Protected_Decl_P_Env_Names
  (Node : Bare_Single_Protected_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_802 with Inline_Always;
            procedure Finalizer_Scope_2572 with Inline_Always;
      Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_802 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_802;
            procedure Finalizer_Scope_2572 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2572;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5563 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5561 '<FieldAccess for top_level_env_name at ast.py:10002>' Fld /tmp/lal-23.0.0/ada/ast.py:10002
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 5561
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 5562 '<to_symbol at ast.py:10003>' Sym /tmp/lal-23.0.0/ada/ast.py:10003
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 5562
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Sym;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2572;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 5563
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_802;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_802;
               Finalizer_Scope_2572;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Protected_Decl_P_Env_Names;
--# end
--# property-start SingleProtectedDecl.declarative_parts /tmp/lal-23.0.0/ada/ast.py:10007
pragma Warnings (Off, "is not referenced");
 function Single_Protected_Decl_P_Declarative_Parts
  (Node : Bare_Single_Protected_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Declarative_Part_Array_Access
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Protected_Decl :=
     Internal_Entity_Single_Protected_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_803 with Inline_Always;
            procedure Finalizer_Scope_2573 with Inline_Always;
      Block_Var : Internal_Entity_Protected_Def;
Var_Expr : Internal_Entity_Declarative_Part;
Fld : Internal_Entity_Protected_Def;
Fld_1 : Internal_Entity_Public_Part;
Cast_Result : Internal_Entity_Declarative_Part;
Singleton : Internal_Entity_Declarative_Part_Array_Access;
Fld_2 : Internal_Entity_Private_Part;
Cast_Result_1 : Internal_Entity_Declarative_Part;
Singleton_1 : Internal_Entity_Declarative_Part_Array_Access;
Scope_Result : Internal_Entity_Declarative_Part_Array_Access;
Result_Var : Internal_Entity_Declarative_Part_Array_Access;
Concat_Result : Internal_Entity_Declarative_Part_Array_Access;
Let_Result : Internal_Entity_Declarative_Part_Array_Access;
            procedure Finalizer_Scope_803 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_803;
            procedure Finalizer_Scope_2573 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2573;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5570 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5564 '<FieldAccess for definition at ast.py:10008>' Fld /tmp/lal-23.0.0/ada/ast.py:10008
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Protected_Def (Node => Ent.Node.Single_Protected_Decl_F_Definition, Info => Ent.Info);
--# expr-done 5564
Block_Var := Fld; 
--# bind pdef Block_Var
--# expr-start 5569 '<Concat at ast.py:10009>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:10009
--# expr-start 5566 '<Cast to DeclarativePart at ast.py:10009>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10009
--# expr-start 5565 '<FieldAccess for public_part at ast.py:10009>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10009
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Public_Part (Node => Block_Var.Node.Protected_Def_F_Public_Part, Info => Block_Var.Info);
--# expr-done 5565
      Cast_Result := Create_Internal_Entity_Declarative_Part
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
--# expr-done 5566
                Singleton := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
--# expr-start 5568 '<Cast to DeclarativePart at ast.py:10010>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:10010
--# expr-start 5567 '<FieldAccess for private_part at ast.py:10010>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10010
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Private_Part (Node => Block_Var.Node.Protected_Def_F_Private_Part, Info => Block_Var.Info);
--# expr-done 5567
      Cast_Result_1 := Create_Internal_Entity_Declarative_Part
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# expr-done 5568
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Declarative_Part then
   --# scope-start
                Singleton_1 := Create_Internal_Entity_Declarative_Part_Array (Items_Count => 1);
                Singleton_1.Items (1) := Var_Expr;
Scope_Result := Singleton_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2573;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Declarative_Part_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result := Concat (Singleton, Result_Var); 
--# expr-done 5569
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5570
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_803;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_803;
               Finalizer_Scope_2573;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Protected_Decl_P_Declarative_Parts;
--# end
--# property-start SingleProtectedDecl._env_mappings_40 /tmp/lal-23.0.0/ada/ast.py:10014
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_40
  (Node : Bare_Single_Protected_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Env_Assoc
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Protected_Decl :=
     Internal_Entity_Single_Protected_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1509 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Single_Protected_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1509 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1509;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5573 '<New EnvAssoc at ast.py:10014>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10014
--# expr-start 5571 '<New DesignatedEnv at ast.py:10014>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10014
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5571
--# expr-start 5572 '<FieldAccess for name_symbol at ast.py:10014>' Fld /tmp/lal-23.0.0/ada/ast.py:10014
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 5572
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5573
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1509;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1509;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_40;
--# end
--# property-start SingleProtectedDecl._env_trans_parent_41 /tmp/lal-23.0.0/ada/ast.py:10013
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_41
  (Node : Bare_Single_Protected_Decl
  )
   return Boolean
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_41;
--# end
--# property-start SingleProtectedDecl._env_names_42 /tmp/lal-23.0.0/ada/ast.py:10015
pragma Warnings (Off, "is not referenced");
 function Env_Names_42
  (Node : Bare_Single_Protected_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Single_Protected_Decl := Bare_Single_Protected_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1511 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1511 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1511;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5574 '<FieldAccess for env_names at ast.py:10015>' Fld /tmp/lal-23.0.0/ada/ast.py:10015
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleProtectedDecl.env_names
Fld := Libadalang.Implementation.Single_Protected_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 5574
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1511;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1511;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_42;
--# end
   --
   --  Primitives for Bare_Single_Task_Decl
   --
      procedure Single_Task_Decl_Pre_Env_Actions
        (Self            : Bare_Single_Task_Decl;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_37 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:9976");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_38 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_39 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Single_Task_Decl
        (Self : Bare_Single_Task_Decl
         ; Single_Task_Decl_F_Task_Type : Bare_Single_Task_Type_Decl
        ) is
      begin
            Self.Single_Task_Decl_F_Task_Type := Single_Task_Decl_F_Task_Type;
      end Initialize_Fields_For_Single_Task_Decl;
   function Single_Task_Decl_F_Task_Type
     (Node : Bare_Single_Task_Decl) return Bare_Single_Task_Type_Decl
   is
   begin
         return Node.Single_Task_Decl_F_Task_Type;
   end;
--# property-start SingleTaskDecl.defining_names /tmp/lal-23.0.0/ada/ast.py:9964
pragma Warnings (Off, "is not referenced");
 function Single_Task_Decl_P_Defining_Names
  (Node : Bare_Single_Task_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Task_Decl :=
     Internal_Entity_Single_Task_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_794 with Inline_Always;
      Fld : Internal_Entity_Single_Task_Type_Decl;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_794 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_794;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5576 '<FieldAccess for defining_names at ast.py:9964>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9964
--# expr-start 5575 '<FieldAccess for task_type at ast.py:9964>' Fld /tmp/lal-23.0.0/ada/ast.py:9964
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Single_Task_Type_Decl (Node => Ent.Node.Single_Task_Decl_F_Task_Type, Info => Ent.Info);
--# expr-done 5575
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 5576
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_794;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_794;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Task_Decl_P_Defining_Names;
--# end
--# property-start SingleTaskDecl.expr_type /tmp/lal-23.0.0/ada/ast.py:9965
pragma Warnings (Off, "is not referenced");
 function Single_Task_Decl_P_Expr_Type
  (Node : Bare_Single_Task_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Task_Decl :=
     Internal_Entity_Single_Task_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Single_Task_Type_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 5577 '<FieldAccess for task_type at ast.py:9965>' Fld /tmp/lal-23.0.0/ada/ast.py:9965
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Single_Task_Type_Decl (Node => Ent.Node.Single_Task_Decl_F_Task_Type, Info => Ent.Info);
--# expr-done 5577
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Task_Decl_P_Expr_Type;
--# end
--# property-start SingleTaskDecl.defining_env /tmp/lal-23.0.0/ada/ast.py:9967
pragma Warnings (Off, "is not referenced");
 function Single_Task_Decl_P_Defining_Env
  (Node : Bare_Single_Task_Decl
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
         := False
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Task_Decl :=
     Internal_Entity_Single_Task_Decl'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_796 with Inline_Always;
      Fld : Internal_Entity_Single_Task_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_796 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_796;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5579 '<FieldAccess for defining_env at ast.py:9967>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9967
--# expr-start 5578 '<FieldAccess for task_type at ast.py:9967>' Fld /tmp/lal-23.0.0/ada/ast.py:9967
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Single_Task_Type_Decl (Node => Ent.Node.Single_Task_Decl_F_Task_Type, Info => Ent.Info);
--# expr-done 5578
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 5579
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_796;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_796;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Task_Decl_P_Defining_Env;
--# end
--# property-start SingleTaskDecl.env_names /tmp/lal-23.0.0/ada/ast.py:9970
pragma Warnings (Off, "is not referenced");
 function Single_Task_Decl_P_Env_Names
  (Node : Bare_Single_Task_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_797 with Inline_Always;
            procedure Finalizer_Scope_2574 with Inline_Always;
      Var_Expr : String_Type;
Fld : String_Type;
Sym : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_797 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_797;
            procedure Finalizer_Scope_2574 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2574;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5582 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5580 '<FieldAccess for top_level_env_name at ast.py:9971>' Fld /tmp/lal-23.0.0/ada/ast.py:9971
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Self);
--# end
--# expr-done 5580
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= Empty_String then
   --# scope-start
   --# bind fqn Var_Expr
--# expr-start 5581 '<to_symbol at ast.py:9972>' Sym /tmp/lal-23.0.0/ada/ast.py:9972
Sym := String_To_Symbol (Self, Self.Unit.Context, Var_Expr); 
--# expr-done 5581
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Sym;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2574;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 5582
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_797;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_797;
               Finalizer_Scope_2574;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Task_Decl_P_Env_Names;
--# end
--# property-start SingleTaskDecl._env_mappings_37 /tmp/lal-23.0.0/ada/ast.py:9976
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_37
  (Node : Bare_Single_Task_Decl
  )
   return Internal_Env_Assoc
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1506 with Inline_Always;
      Fld : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Single_Task_Decl;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1506 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1506;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5585 '<New EnvAssoc at ast.py:9976>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:9976
--# expr-start 5583 '<New DesignatedEnv at ast.py:9976>' New_Struct /tmp/lal-23.0.0/ada/ast.py:9976
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5583
--# expr-start 5584 '<FieldAccess for name_symbol at ast.py:9976>' Fld /tmp/lal-23.0.0/ada/ast.py:9976
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Self);
--# end
--# expr-done 5584
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5585
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1506;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1506;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_37;
--# end
--# property-start SingleTaskDecl._env_trans_parent_38 /tmp/lal-23.0.0/ada/ast.py:9975
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_38
  (Node : Bare_Single_Task_Decl
  )
   return Boolean
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_38;
--# end
--# property-start SingleTaskDecl._env_names_39 /tmp/lal-23.0.0/ada/ast.py:9977
pragma Warnings (Off, "is not referenced");
 function Env_Names_39
  (Node : Bare_Single_Task_Decl
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Single_Task_Decl := Bare_Single_Task_Decl (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1508 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1508 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1508;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5586 '<FieldAccess for env_names at ast.py:9977>' Fld /tmp/lal-23.0.0/ada/ast.py:9977
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTaskDecl.env_names
Fld := Libadalang.Implementation.Single_Task_Decl_P_Env_Names (Node => Self);
--# end
--# expr-done 5586
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1508;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1508;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_39;
--# end
   --
   --  Primitives for Bare_Case_Stmt_Alternative
   --
      procedure Initialize_Fields_For_Case_Stmt_Alternative
        (Self : Bare_Case_Stmt_Alternative
         ; Case_Stmt_Alternative_F_Choices : Bare_Alternatives_List
         ; Case_Stmt_Alternative_F_Stmts : Bare_Stmt_List
        ) is
      begin
            Self.Case_Stmt_Alternative_F_Choices := Case_Stmt_Alternative_F_Choices;
            Self.Case_Stmt_Alternative_F_Stmts := Case_Stmt_Alternative_F_Stmts;
      end Initialize_Fields_For_Case_Stmt_Alternative;
   function Case_Stmt_Alternative_F_Choices
     (Node : Bare_Case_Stmt_Alternative) return Bare_Alternatives_List
   is
   begin
         return Node.Case_Stmt_Alternative_F_Choices;
   end;
   function Case_Stmt_Alternative_F_Stmts
     (Node : Bare_Case_Stmt_Alternative) return Bare_Stmt_List
   is
   begin
         return Node.Case_Stmt_Alternative_F_Stmts;
   end;
--# property-start CaseStmtAlternative.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:20129
pragma Warnings (Off, "is not referenced");
 function Case_Stmt_Alternative_P_Xref_Entry_Point
  (Node : Bare_Case_Stmt_Alternative
  )
   return Boolean
is
   Self : Bare_Case_Stmt_Alternative := Bare_Case_Stmt_Alternative (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Case_Stmt_Alternative_P_Xref_Entry_Point;
--# end
--# property-start CaseStmtAlternative.xref_equation /tmp/lal-23.0.0/ada/ast.py:20132
pragma Warnings (Off, "is not referenced");
 function Case_Stmt_Alternative_P_Xref_Equation
  (Node : Bare_Case_Stmt_Alternative
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Case_Stmt_Alternative := Bare_Case_Stmt_Alternative (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Case_Stmt_Alternative :=
     Internal_Entity_Case_Stmt_Alternative'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1418 with Inline_Always;
            procedure Finalizer_Scope_2575 with Inline_Always;
            procedure Finalizer_Scope_2576 with Inline_Always;
            procedure Finalizer_Scope_2578 with Inline_Always;
            procedure Finalizer_Scope_2579 with Inline_Always;
      Block_Var : Internal_Entity_Case_Stmt;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Match_0 : Internal_Entity_Expr;
Match_1 : Internal_Entity_Subtype_Indication;
Match_2 : Internal_Entity_Others_Designator;
Match_3 : Internal_Entity;
Var_Expr : Internal_Entity_Name;
Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Case_Stmt;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Alternatives_List;
Fld_5 : Bare_Alternatives_List;
Fld_6 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Expr : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_7 : Logic_Equation;
Fld_8 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_9 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_10 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Cast_Expr_2 : Internal_Entity_Expr;
Cast_Result_3 : Internal_Entity_Name;
Fld_11 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Is_Null_1 : Boolean;
Not_Val : Boolean;
If_Result_1 : Logic_Equation;
Fld_12 : Logic_Equation;
True_Rel : Logic_Equation;
Match_Prefix : Internal_Entity;
Cast_Result_4 : Internal_Entity_Expr;
Let_Result : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_5 : Internal_Entity_Subtype_Indication;
Let_Result_1 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_6 : Internal_Entity_Others_Designator;
Let_Result_2 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Cast_Result_7 : Internal_Entity;
Let_Result_3 : Logic_Equation;
Scope_Result_4 : Logic_Equation;
Match_Result : Logic_Equation;
Item_193 : Internal_Entity;
Bare_Item_193 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result_4 : Logic_Equation;
            procedure Finalizer_Scope_1418 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1418;
            procedure Finalizer_Scope_2575 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_2575;
            procedure Finalizer_Scope_2576 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_10);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result_1);
            end Finalizer_Scope_2576;
            procedure Finalizer_Scope_2578 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2578;
            procedure Finalizer_Scope_2579 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_2579;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5610 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 5589 '<Cast to CaseStmt at ast.py:20133>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20133
--# expr-start 5588 '<parent at ast.py:20133>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20133
--# expr-start 5587 '<parent at ast.py:20133>' Fld /tmp/lal-23.0.0/ada/ast.py:20133
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 5587
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 5588
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Case_Stmt_Range
   then
      Cast_Result := Create_Internal_Entity_Case_Stmt
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5589
Block_Var := Cast_Result; 
--# bind case_stmt Block_Var
--# expr-start 5591 '<FieldAccess for expression_type at ast.py:20136>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20136
--# expr-start 5590 '<FieldAccess for expr at ast.py:20136>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20136
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Block_Var.Node.Case_Stmt_F_Expr, Info => Block_Var.Info);
--# expr-done 5590
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_3 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 5591
Block_Var_1 := Fld_3; 
--# bind selected_type Block_Var_1
--# expr-start 5609 '<LogicAll at ast.py:20138>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:20138
--# expr-start 5608 '<Map at ast.py:20138>' Map_Result /tmp/lal-23.0.0/ada/ast.py:20138
   --# expr-start 5592 '<FieldAccess for choices at ast.py:20138>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20138
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Alternatives_List (Node => Ent.Node.Case_Stmt_Alternative_F_Choices, Info => Ent.Info);
--# expr-done 5592
Fld_5 := Fld_4.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_5 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_5;
      begin
         for Untyped_Item_193 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_193 := Untyped_Item_193; 
Is_Null := Bare_Item_193 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_6 := Fld_4.Info;
As_Entity := (Info => Fld_6, Node => Bare_Item_193); 
   If_Result := As_Entity;
end if;
                  Item_193 := If_Result; 
   --# scope-start
               --# bind c Item_193
      --# expr-start 5607 '<Match at ast.py:20138>' Match_Result /tmp/lal-23.0.0/ada/ast.py:20138
      if Item_193.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_193; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Abstract_State_Decl_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_4; 
--# bind e Match_0
--# expr-start 5605 '<If at ast.py:20141>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:20141
--# expr-start 5596 '<Not at ast.py:20142>' Not_Val /tmp/lal-23.0.0/ada/ast.py:20142
--# expr-start 5595 '<IsNull at ast.py:20142>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:20142
--# expr-start 5593 '<Cast to Name at ast.py:20142>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:20142
Cast_Expr_2 := Match_0; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Name
   then
      Cast_Result_3 := Create_Internal_Entity_Name
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_3 := No_Entity_Name;
   end if;
--# expr-done 5593
Var_Expr := Cast_Result_3;
if Var_Expr /= No_Entity_Name then
   --# scope-start
--# expr-start 5594 '<FieldAccess for name_designated_type at ast.py:20142>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:20142
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_11 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 5594
Scope_Result := Fld_11;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Is_Null_1 := Result_Var.Node = null; 
--# expr-done 5595
Not_Val := not (Is_Null_1); 
--# expr-done 5596
if Not_Val then
   --# expr-start 5598 '<FieldAccess for xref_no_overloading at ast.py:20144>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:20144
--# expr-start 5597 '<Cast to Name at ast.py:20144>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:20144
Cast_Expr := Match_0; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 5597
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_7 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_1.Node, Env => Env, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 5598
   If_Result_1 := Fld_7;
else
   --# expr-start 5604 '<And at ast.py:20146>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:20146
--# expr-start 5602 '<And at ast.py:20146>' And_Pred /tmp/lal-23.0.0/ada/ast.py:20146
--# expr-start 5600 '<Bind at ast.py:20146>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:20146
--# expr-start 5599 '<FieldAccess for expected_type_var at ast.py:20146>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:20146
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Match_0.Node);
--# expr-done 5599
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Cast_Expr_1 := Block_Var_1; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result := Solver.Create_Assign (Fld_8, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20146") else null)); 
--# expr-done 5600
--# expr-start 5601 '<FieldAccess for sub_equation at ast.py:20147>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:20147
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_9 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_0.Node, Env => Env, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 5601
And_Pred := Create_And (Bind_Result, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20146") else null)); 
--# expr-done 5602
--# expr-start 5603 '<FieldAccess for matches_expected_type at ast.py:20148>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:20148
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_10 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Match_0.Node, Origin => Origin);
--# end
--# expr-done 5603
And_Pred_1 := Create_And (And_Pred, Fld_10, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20146") else null)); 
--# expr-done 5604
   If_Result_1 := And_Pred_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 5605
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
Scope_Result_1 := Let_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2576;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_5; 
--# bind t Match_1
--# expr-start 5606 '<FieldAccess for xref_equation at ast.py:20152>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:20152
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_12 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Match_1.Node, Env => Env, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 5606
Let_Result_1 := Fld_12; Inc_Ref (Let_Result_1);
--# end
Scope_Result_2 := Let_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2578;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Others_Designator =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Others_Designator
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_6; 
--# bind _ Match_2
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20154") else null)); 
Let_Result_2 := True_Rel; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2579;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Null_Component_Decl | Ada_Overriding_Not_Overriding .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_7; 
--# bind _ Match_3
Let_Result_3 := raise Property_Error with "Should not happen"; Inc_Ref (Let_Result_3);
--# end
Scope_Result_4 := Let_Result_3;
   Inc_Ref (Scope_Result_4);
   --# end
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
end case;
--# expr-done 5607
         declare
            Item_To_Append : constant Logic_Equation := Match_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2575;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5608
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20138") else null)); 
--# expr-done 5609
Let_Result_4 := Logic_Boolean_Op; Inc_Ref (Let_Result_4);
--# end
--# expr-done 5610
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1418;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1418;
               Finalizer_Scope_2575;
               Finalizer_Scope_2576;
               Finalizer_Scope_2578;
               Finalizer_Scope_2579;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Case_Stmt_Alternative_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Compilation_Unit
   --
      procedure Initialize_Fields_For_Compilation_Unit
        (Self : Bare_Compilation_Unit
         ; Compilation_Unit_F_Prelude : Bare_Ada_Node_List
         ; Compilation_Unit_F_Body : Bare_Ada_Node
         ; Compilation_Unit_F_Pragmas : Bare_Pragma_Node_List
        ) is
      begin
            Self.Compilation_Unit_F_Prelude := Compilation_Unit_F_Prelude;
            Self.Compilation_Unit_F_Body := Compilation_Unit_F_Body;
            Self.Compilation_Unit_F_Pragmas := Compilation_Unit_F_Pragmas;
      Self.Compilation_Unit_No_Env := Empty_Env;
      end Initialize_Fields_For_Compilation_Unit;
   function Compilation_Unit_F_Prelude
     (Node : Bare_Compilation_Unit) return Bare_Ada_Node_List
   is
   begin
         return Node.Compilation_Unit_F_Prelude;
   end;
   function Compilation_Unit_F_Body
     (Node : Bare_Compilation_Unit) return Bare_Ada_Node
   is
   begin
         return Node.Compilation_Unit_F_Body;
   end;
   function Compilation_Unit_F_Pragmas
     (Node : Bare_Compilation_Unit) return Bare_Pragma_Node_List
   is
   begin
         return Node.Compilation_Unit_F_Pragmas;
   end;
--# property-start CompilationUnit.syntactic_fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:18961
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Syntactic_Fully_Qualified_Name
  (Node : Bare_Compilation_Unit
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1353 with Inline_Always;
            procedure Finalizer_Scope_1771 with Inline_Always;
            procedure Finalizer_Scope_1772 with Inline_Always;
            procedure Finalizer_Scope_1773 with Inline_Always;
      Match_0 : Internal_Entity_Library_Item;
Match_1 : Internal_Entity_Subunit;
Match_2 : Internal_Entity;
Var_Expr : Internal_Entity_Defining_Name;
As_Entity : Internal_Entity_Compilation_Unit;
Is_Null : Boolean;
If_Result : Internal_Entity_Compilation_Unit;
Fld : Internal_Entity;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Defining_Name;
Fld_3 : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Fld_4 : Internal_Entity_Name;
Fld_5 : Symbol_Type_Array_Access;
Fld_6 : Internal_Entity_Body_Node;
Fld_7 : Internal_Entity_Defining_Name;
Fld_8 : Symbol_Type_Array_Access;
Concat_Result : Symbol_Type_Array_Access;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Library_Item;
Let_Result : Symbol_Type_Array_Access;
Scope_Result_1 : Symbol_Type_Array_Access;
Cast_Result_1 : Internal_Entity_Subunit;
Let_Result_1 : Symbol_Type_Array_Access;
Scope_Result_2 : Symbol_Type_Array_Access;
Cast_Result_2 : Internal_Entity;
Let_Result_2 : Symbol_Type_Array_Access;
Scope_Result_3 : Symbol_Type_Array_Access;
Match_Result : Symbol_Type_Array_Access;
Let_Result_3 : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1353 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_1353;
            procedure Finalizer_Scope_1771 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1771;
            procedure Finalizer_Scope_1772 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_1772;
            procedure Finalizer_Scope_1773 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_1773;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5623 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 5622 '<Match at ast.py:18965>' Match_Result /tmp/lal-23.0.0/ada/ast.py:18965
--# expr-start 5612 '<FieldAccess for body at ast.py:18965>' Fld /tmp/lal-23.0.0/ada/ast.py:18965
--# expr-start 5611 '<as_bare_entity at ast.py:18965>' If_Result /tmp/lal-23.0.0/ada/ast.py:18965
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Compilation_Unit;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 5611
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => If_Result.Node.Compilation_Unit_F_Body, Info => If_Result.Info);
--# expr-done 5612
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Library_Item
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind li Match_0
--# expr-start 5614 '<FieldAccess for defining_name at ast.py:18966>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18966
--# expr-start 5613 '<FieldAccess for item at ast.py:18966>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18966
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Basic_Decl (Node => Match_0.Node.Library_Item_F_Item, Info => Match_0.Info);
--# expr-done 5613
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 5614
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 5615 '<FieldAccess for as_symbol_array at ast.py:18966>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18966
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Var_Expr.Node);
--# end
--# expr-done 5615
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_1772;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
Scope_Result_1 := Let_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_1771;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subunit
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind su Match_1
--# expr-start 5621 '<Concat at ast.py:18967>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:18967
--# expr-start 5617 '<FieldAccess for as_symbol_array at ast.py:18967>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18967
--# expr-start 5616 '<FieldAccess for name at ast.py:18967>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18967
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Match_1.Node.Subunit_F_Name, Info => Match_1.Info);
--# expr-done 5616
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld_4.Node);
--# end
--# expr-done 5617
--# expr-start 5620 '<FieldAccess for as_symbol_array at ast.py:18968>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18968
--# expr-start 5619 '<FieldAccess for defining_name at ast.py:18968>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18968
--# expr-start 5618 '<FieldAccess for body at ast.py:18968>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18968
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Body_Node (Node => Match_1.Node.Subunit_F_Body, Info => Match_1.Info);
--# expr-done 5618
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 5619
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld_7.Node);
--# end
--# expr-done 5620
Concat_Result := Concat (Fld_5, Fld_8); 
--# expr-done 5621
Let_Result_1 := Concat_Result; Inc_Ref (Let_Result_1);
--# end
Scope_Result_2 := Let_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_1773;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error with "Unexpected CompilationUnit.f_body attribute"; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
end case;
--# expr-done 5622
Let_Result_3 := Match_Result; Inc_Ref (Let_Result_3);
--# end
--# expr-done 5623
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1353;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1353;
               Finalizer_Scope_1771;
               Finalizer_Scope_1772;
               Finalizer_Scope_1773;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Syntactic_Fully_Qualified_Name;
--# end
--# property-start CompilationUnit.unit_kind /tmp/lal-23.0.0/ada/ast.py:18976
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Unit_Kind
  (Node : Bare_Compilation_Unit
  )
   return Analysis_Unit_Kind
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Analysis_Unit_Kind;
      Match_0 : Bare_Library_Item;
Match_1 : Bare_Subunit;
Match_2 : Bare_Ada_Node;
Match_0_1 : Bare_Body_Node;
Match_1_1 : Bare_Basic_Decl;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Basic_Decl;
Match_Prefix : Bare_Basic_Decl;
Cast_Result : Bare_Body_Node;
Let_Result : Analysis_Unit_Kind;
Scope_Result : Analysis_Unit_Kind;
Cast_Result_1 : Bare_Basic_Decl;
Let_Result_1 : Analysis_Unit_Kind;
Scope_Result_1 : Analysis_Unit_Kind;
Match_Result : Analysis_Unit_Kind;
Match_Prefix_1 : Bare_Ada_Node;
Cast_Result_2 : Bare_Library_Item;
Let_Result_2 : Analysis_Unit_Kind;
Scope_Result_2 : Analysis_Unit_Kind;
Cast_Result_3 : Bare_Subunit;
Let_Result_3 : Analysis_Unit_Kind;
Scope_Result_3 : Analysis_Unit_Kind;
Cast_Result_4 : Bare_Ada_Node;
Let_Result_4 : Analysis_Unit_Kind;
Scope_Result_4 : Analysis_Unit_Kind;
Match_Result_1 : Analysis_Unit_Kind;
Let_Result_5 : Analysis_Unit_Kind;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5628 '<Block at ???>' Let_Result_5 None
--# scope-start
--# expr-start 5627 '<Match at ast.py:18980>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:18980
--# expr-start 5624 '<FieldAccess for body at ast.py:18980>' Fld /tmp/lal-23.0.0/ada/ast.py:18980
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Compilation_Unit_F_Body;
--# expr-done 5624
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Fld; 
case Ada_Ada_Node (Match_Prefix_1.Kind) is
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix_1;
Match_0 := Cast_Result_2; 
--# bind li Match_0
--# expr-start 5626 '<Match at ast.py:18981>' Match_Result /tmp/lal-23.0.0/ada/ast.py:18981
--# expr-start 5625 '<FieldAccess for item at ast.py:18981>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18981
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Match_0.Library_Item_F_Item;
--# expr-done 5625
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_1; 
case Ada_Basic_Decl (Match_Prefix.Kind) is
         when Ada_Expr_Function .. Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0_1 := Cast_Result; 
--# bind _ Match_0_1
Let_Result := Unit_Body; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl .. Ada_Synthetic_Subp_Decl | Ada_Entry_Index_Spec .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1_1 := Cast_Result_1; 
--# bind _ Match_1_1
Let_Result_1 := Unit_Specification; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 5626
Let_Result_2 := Match_Result; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result_1 := Scope_Result_2; 
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix_1;
Match_1 := Cast_Result_3; 
--# bind _ Match_1
Let_Result_3 := Unit_Body; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result_1 := Scope_Result_3; 
         when Ada_Abort_Absent .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix_1;
Match_2 := Cast_Result_4; 
--# bind _ Match_2
Let_Result_4 := raise Property_Error with "Unexpected CompilationUnit.f_body attribute"; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result_1 := Scope_Result_4; 
end case;
--# expr-done 5627
Let_Result_5 := Match_Result_1; 
--# end
--# expr-done 5628
      Property_Result := Let_Result_5;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Unit_Kind;
--# end
--# property-start CompilationUnit.withed_units /tmp/lal-23.0.0/ada/ast.py:18993
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Withed_Units
  (Node : Bare_Compilation_Unit
  )
   return Internal_Entity_Compilation_Unit_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1355 with Inline_Always;
      Fld : Bare_Name_Array_Access;
Fld_1 : Bare_Compilation_Unit;
As_Entity : Internal_Entity_Compilation_Unit;
Is_Null : Boolean;
If_Result : Internal_Entity_Compilation_Unit;
Map_Result : Internal_Entity_Compilation_Unit_Array_Access;
Let_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1355 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1355;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Compilation_Unit_Compilation_Unit_P_Withed_Units,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Compilation_Unit,
                                As_Bare_Compilation_Unit => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Compilation_Unit_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 5633 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5632 '<Map at ast.py:19000>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19000
   --# expr-start 5629 '<FieldAccess for top_level_with_package_clauses at ast.py:19000>' Fld /tmp/lal-23.0.0/ada/ast.py:19000
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.top_level_with_package_clauses
Fld := Libadalang.Implementation.Ada_Node_P_Top_Level_With_Package_Clauses (Node => Self);
--# end
--# expr-done 5629
      declare
         Map_Result_Vec : Internal_Entity_Compilation_Unit_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Name_Array_Access := Fld;
      begin
         for Item_194 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_194
      --# expr-start 5631 '<as_bare_entity at ast.py:19004>' If_Result /tmp/lal-23.0.0/ada/ast.py:19004
--# expr-start 5630 '<FieldAccess for withed_unit_helper at ast.py:19004>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19004
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.withed_unit_helper
Fld_1 := Libadalang.Implementation.Ada_Node_P_Withed_Unit_Helper (Node => Self, Unit_Name => Item_194);
--# end
--# expr-done 5630
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Compilation_Unit;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 5631
         declare
            Item_To_Append : constant Internal_Entity_Compilation_Unit := If_Result;
         begin
            Internal_Entity_Compilation_Unit_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Compilation_Unit_Array
           (Items_Count => Natural (Internal_Entity_Compilation_Unit_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Compilation_Unit_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Compilation_Unit_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Compilation_Unit_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5632
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5633
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1355;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Compilation_Unit_Array_Access,
                        As_Internal_Entity_Compilation_Unit_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1355;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Withed_Units;
--# end
--# property-start CompilationUnit.imported_units /tmp/lal-23.0.0/ada/ast.py:19009
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Imported_Units
  (Node : Bare_Compilation_Unit
  )
   return Internal_Entity_Compilation_Unit_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1356 with Inline_Always;
            procedure Finalizer_Scope_2582 with Inline_Always;
            procedure Finalizer_Scope_2583 with Inline_Always;
            procedure Finalizer_Scope_2584 with Inline_Always;
            procedure Finalizer_Scope_2585 with Inline_Always;
            procedure Finalizer_Scope_2586 with Inline_Always;
            procedure Finalizer_Scope_2587 with Inline_Always;
      Var_Expr : Internal_Entity_Compilation_Unit_Array_Access;
Var_Expr_1 : Bare_Base_Subp_Body;
Var_Expr_2 : Internal_Entity_Basic_Decl;
Var_Expr_3 : Bare_Ada_Node;
Var_Expr_4 : Lexical_Env := Empty_Env;
Var_Expr_5 : Bare_Basic_Decl;
Fld : Internal_Entity_Compilation_Unit_Array_Access;
Fld_1 : Bare_Basic_Decl;
Cast_Result : Bare_Base_Subp_Body;
As_Entity : Internal_Entity_Base_Subp_Body;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Subp_Body;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Bare_Compilation_Unit;
As_Entity_1 : Internal_Entity_Compilation_Unit;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Compilation_Unit;
Singleton : Internal_Entity_Compilation_Unit_Array_Access;
Scope_Result : Internal_Entity_Compilation_Unit_Array_Access;
Result_Var : Internal_Entity_Compilation_Unit_Array_Access;
Scope_Result_1 : Internal_Entity_Compilation_Unit_Array_Access;
Result_Var_1 : Internal_Entity_Compilation_Unit_Array_Access;
Scope_Result_2 : Internal_Entity_Compilation_Unit_Array_Access;
Fld_4 : Bare_Basic_Decl;
Fld_5 : Lexical_Env := Empty_Env;
Scope_Result_3 : Lexical_Env := Empty_Env;
Result_Var_2 : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Scope_Result_4 : Bare_Ada_Node;
Result_Var_3 : Bare_Ada_Node;
Fld_6 : Bare_Compilation_Unit;
As_Entity_2 : Internal_Entity_Compilation_Unit;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity_Compilation_Unit;
Singleton_1 : Internal_Entity_Compilation_Unit_Array_Access;
Scope_Result_5 : Internal_Entity_Compilation_Unit_Array_Access;
Result_Var_4 : Internal_Entity_Compilation_Unit_Array_Access;
Result_Var_5 : Internal_Entity_Compilation_Unit_Array_Access;
Concat_Result : Internal_Entity_Compilation_Unit_Array_Access;
Let_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1356 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Result_Var_4);
                     Dec_Ref (Result_Var_5);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1356;
            procedure Finalizer_Scope_2582 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2582;
            procedure Finalizer_Scope_2583 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2583;
            procedure Finalizer_Scope_2584 is
            begin
                     Dec_Ref (Var_Expr);
            end Finalizer_Scope_2584;
            procedure Finalizer_Scope_2585 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2585;
            procedure Finalizer_Scope_2586 is
            begin
                     Dec_Ref (Var_Expr_4);
            end Finalizer_Scope_2586;
            procedure Finalizer_Scope_2587 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2587;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Compilation_Unit_Compilation_Unit_P_Imported_Units,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Compilation_Unit,
                                As_Bare_Compilation_Unit => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Compilation_Unit_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 5647 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5646 '<Concat at ast.py:19014>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:19014
--# expr-start 5634 '<FieldAccess for withed_units at ast.py:19014>' Fld /tmp/lal-23.0.0/ada/ast.py:19014
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.withed_units
Fld := Libadalang.Implementation.Compilation_Unit_P_Withed_Units (Node => Self);
--# end
--# expr-done 5634
--# expr-start 5636 '<Cast to BaseSubpBody at ast.py:19019>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19019
--# expr-start 5635 '<FieldAccess for decl at ast.py:19019>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19019
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Self);
--# end
--# expr-done 5635
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Base_Subp_Body
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5636
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind subp Var_Expr_1
--# expr-start 5638 '<FieldAccess for subp_previous_part at ast.py:19023>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19023
--# expr-start 5637 '<as_bare_entity at ast.py:19023>' If_Result /tmp/lal-23.0.0/ada/ast.py:19023
Is_Null := Var_Expr_1 = null; 
if Is_Null then
   If_Result := No_Entity_Base_Subp_Body;
else
As_Entity := (Info => No_Entity_Info, Node => Var_Expr_1); 
   If_Result := As_Entity;
end if;
--# expr-done 5637
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.subp_previous_part
Fld_2 := Libadalang.Implementation.Body_Node_P_Subp_Previous_Part (Node => If_Result.Node, Imprecise_Fallback => False, E_Info => If_Result.Info);
--# end
--# expr-done 5638
Var_Expr_2 := Fld_2;
if Var_Expr_2 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind pp Var_Expr_2
--# expr-start 5640 '<as_bare_entity at ast.py:19025>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19025
--# expr-start 5639 '<FieldAccess for enclosing_compilation_unit at ast.py:19025>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19025
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld_3 := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Var_Expr_2.Node);
--# end
--# expr-done 5639
Is_Null_1 := Fld_3 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Compilation_Unit;
else
As_Entity_1 := (Info => No_Entity_Info, Node => Fld_3); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 5640
                Singleton := Create_Internal_Entity_Compilation_Unit_Array (Items_Count => 1);
                Singleton.Items (1) := If_Result_1;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2583;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Compilation_Unit_Array_Type;
end if;
      Inc_Ref (Result_Var);
Scope_Result_1 := Result_Var;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2582;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Compilation_Unit_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Var_Expr := Result_Var_1;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Compilation_Unit_Array_Type then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_2 := Var_Expr;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2584;
   Result_Var_5 := Scope_Result_2;
else
--# expr-start 5641 '<FieldAccess for decl at ast.py:19027>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19027
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_4 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Self);
--# end
--# expr-done 5641
Var_Expr_5 := Fld_4;
if Var_Expr_5 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 5642 '<FieldAccess for node_env at ast.py:19027>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19027
      if Var_Expr_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Node_Env (Node => Var_Expr_5);
--# expr-done 5642
Scope_Result_3 := Fld_5;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2585;
   Result_Var_2 := Scope_Result_3;
else
   Result_Var_2 := Empty_Env;
end if;
      Inc_Ref (Result_Var_2);
Var_Expr_4 := Result_Var_2;
      Inc_Ref (Var_Expr_4);
if Var_Expr_4 /= Empty_Env then
   --# scope-start
--# expr-start 5643 '<env_node at ast.py:19027>' Env_Node /tmp/lal-23.0.0/ada/ast.py:19027
Env_Node := AST_Envs.Env_Node (Var_Expr_4); 
--# expr-done 5643
Scope_Result_4 := Env_Node;
   --# end
      Finalizer_Scope_2586;
   Result_Var_3 := Scope_Result_4;
else
   Result_Var_3 := No_Bare_Ada_Node;
end if;
Var_Expr_3 := Result_Var_3;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind n Var_Expr_3
--# expr-start 5645 '<as_bare_entity at ast.py:19029>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:19029
--# expr-start 5644 '<FieldAccess for enclosing_compilation_unit at ast.py:19029>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19029
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.enclosing_compilation_unit
Fld_6 := Libadalang.Implementation.Ada_Node_P_Enclosing_Compilation_Unit (Node => Var_Expr_3);
--# end
--# expr-done 5644
Is_Null_2 := Fld_6 = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity_Compilation_Unit;
else
As_Entity_2 := (Info => No_Entity_Info, Node => Fld_6); 
   If_Result_2 := As_Entity_2;
end if;
--# expr-done 5645
                Singleton_1 := Create_Internal_Entity_Compilation_Unit_Array (Items_Count => 1);
                Singleton_1.Items (1) := If_Result_2;
Scope_Result_5 := Singleton_1;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2587;
   Result_Var_4 := Scope_Result_5;
else
   Result_Var_4 := No_Internal_Entity_Compilation_Unit_Array_Type;
end if;
      Inc_Ref (Result_Var_4);
   Result_Var_5 := Result_Var_4;
end if;
      Inc_Ref (Result_Var_5);
Concat_Result := Concat (Fld, Result_Var_5); 
--# expr-done 5646
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5647
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1356;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Compilation_Unit_Array_Access,
                        As_Internal_Entity_Compilation_Unit_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1356;
               Finalizer_Scope_2582;
               Finalizer_Scope_2583;
               Finalizer_Scope_2584;
               Finalizer_Scope_2585;
               Finalizer_Scope_2586;
               Finalizer_Scope_2587;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Imported_Units;
--# end
--# property-start CompilationUnit.unit_dependencies_helper /tmp/lal-23.0.0/ada/ast.py:19034
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Unit_Dependencies_Helper
  (Node : Bare_Compilation_Unit
      ; Visited : Internal_Entity_Compilation_Unit_Array_Access
      ; To_Visit : Internal_Entity_Compilation_Unit_Array_Access
  )
   return Internal_Entity_Compilation_Unit_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind visited Visited
   --# bind to_visit To_Visit
   Property_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1357 with Inline_Always;
            procedure Finalizer_Scope_2588 with Inline_Always;
      Block_Var : Internal_Entity_Compilation_Unit_Array_Access;
Block_Var_1 : Internal_Entity_Compilation_Unit_Array_Access;
Block_Var_2 : Internal_Entity_Compilation_Unit_Array_Access;
Concat_Result : Internal_Entity_Compilation_Unit_Array_Access;
Fld : Internal_Entity_Compilation_Unit_Array_Access;
Map_Result : Internal_Entity_Compilation_Unit_Array_Access;
Unique_Array : Internal_Entity_Compilation_Unit_Array_Access;
Cast_Expr : Internal_Entity_Compilation_Unit;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Compilation_Unit;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result : Boolean;
Not_Val : Boolean;
Map_Result_1 : Internal_Entity_Compilation_Unit_Array_Access;
Fld_1 : Internal_Entity_Compilation_Unit_Array_Access;
Len : Integer;
Comp_Result : Boolean;
If_Result : Internal_Entity_Compilation_Unit_Array_Access;
Let_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1357 is
            begin
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1357;
            procedure Finalizer_Scope_2588 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_2588;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5659 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5648 '<Concat at ast.py:19043>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:19043
Concat_Result := Concat (Visited, To_Visit); 
--# expr-done 5648
Block_Var := Concat_Result; Inc_Ref (Block_Var);
--# bind now_visited Block_Var
--# expr-start 5651 '<unique at ast.py:19044>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:19044
--# expr-start 5650 '<Mapcat at ast.py:19044>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19044
      declare
         Map_Result_Vec : Internal_Entity_Compilation_Unit_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Compilation_Unit_Array_Access := To_Visit;
      begin
         for Item_195 of
               Collection.Items
         loop
   --# scope-start
               --# bind c Item_195
      --# expr-start 5649 '<FieldAccess for imported_units at ast.py:19044>' Fld /tmp/lal-23.0.0/ada/ast.py:19044
      if Item_195.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.imported_units
Fld := Libadalang.Implementation.Compilation_Unit_P_Imported_Units (Node => Item_195.Node);
--# end
--# expr-done 5649
         for Item_To_Append of
               Fld.Items
         loop
            Internal_Entity_Compilation_Unit_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2588;
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Compilation_Unit_Array
           (Items_Count => Natural (Internal_Entity_Compilation_Unit_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Compilation_Unit_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Compilation_Unit_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Compilation_Unit_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5650
Unique_Array := Make_Unique (Map_Result); 
--# expr-done 5651
Block_Var_1 := Unique_Array; Inc_Ref (Block_Var_1);
--# bind new_imports Block_Var_1
--# expr-start 5655 '<Filter at ast.py:19046>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:19046
      declare
         Map_Result_1_Vec : Internal_Entity_Compilation_Unit_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Compilation_Unit_Array_Access := Block_Var_1;
      begin
         for Item_196 of
               Collection.Items
         loop
   --# scope-start
               --# bind c Item_196
         --# expr-start 5654 '<Not at ast.py:19046>' Not_Val /tmp/lal-23.0.0/ada/ast.py:19046
--# expr-start 5653 '<Contains at ast.py:19046>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:19046
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Compilation_Unit_Array_Access := Block_Var;
      begin
         for Item_197 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_197
      --# expr-start 5652 '<Eq at ???>' Is_Equiv None
Cast_Expr := Item_197; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Item_196; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 5652
      Quantifier_Result := Is_Equiv;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 5653
Not_Val := not (Quantifier_Result); 
--# expr-done 5654
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Compilation_Unit := Item_196;
         begin
            Internal_Entity_Compilation_Unit_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Compilation_Unit_Array
           (Items_Count => Natural (Internal_Entity_Compilation_Unit_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Compilation_Unit_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Compilation_Unit_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Compilation_Unit_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 5655
Block_Var_2 := Map_Result_1; Inc_Ref (Block_Var_2);
--# bind to_visit_next Block_Var_2
--# expr-start 5658 '<If at ast.py:19048>' If_Result /tmp/lal-23.0.0/ada/ast.py:19048
--# expr-start 5656 '<length at ast.py:19049>' Len /tmp/lal-23.0.0/ada/ast.py:19049
Len := Length (Block_Var_2); 
--# expr-done 5656
Comp_Result := Len > 0; 
if Comp_Result then
   --# expr-start 5657 '<FieldAccess for unit_dependencies_helper at ast.py:19050>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19050
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.unit_dependencies_helper
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Unit_Dependencies_Helper (Node => Self, Visited => Block_Var, To_Visit => Block_Var_2);
--# end
--# expr-done 5657
   If_Result := Fld_1;
else
   If_Result := Block_Var;
end if;
      Inc_Ref (If_Result);
--# expr-done 5658
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5659
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1357;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1357;
               Finalizer_Scope_2588;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Unit_Dependencies_Helper;
--# end
--# property-start CompilationUnit.unit_dependencies /tmp/lal-23.0.0/ada/ast.py:19056
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Unit_Dependencies
  (Node : Bare_Compilation_Unit
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Compilation_Unit_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Compilation_Unit :=
     Internal_Entity_Compilation_Unit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1358 with Inline_Always;
      Singleton : Internal_Entity_Compilation_Unit_Array_Access;
Fld : Internal_Entity_Compilation_Unit_Array_Access;
Unique_Array : Internal_Entity_Compilation_Unit_Array_Access;
Fld_1 : Bare_Compilation_Unit;
Cast_Result : Bare_Compilation_Unit;
Is_Equal : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Compilation_Unit_Array_Access;
Let_Result : Internal_Entity_Compilation_Unit_Array_Access;
            procedure Finalizer_Scope_1358 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Fld);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1358;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Compilation_Unit_Compilation_Unit_P_Unit_Dependencies,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Compilation_Unit,
                                As_Bare_Compilation_Unit => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Compilation_Unit_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 5666 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5665 '<Filter at ast.py:19066>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19066
   --# expr-start 5661 '<unique at ast.py:19066>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:19066
--# expr-start 5660 '<FieldAccess for unit_dependencies_helper at ast.py:19063>' Fld /tmp/lal-23.0.0/ada/ast.py:19063
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
                Singleton := Create_Internal_Entity_Compilation_Unit_Array (Items_Count => 1);
                Singleton.Items (1) := Ent;
--# property-call-start CompilationUnit.unit_dependencies_helper
Fld := Libadalang.Implementation.Compilation_Unit_P_Unit_Dependencies_Helper (Node => Self, Visited => No_Internal_Entity_Compilation_Unit_Array_Type, To_Visit => Singleton);
--# end
--# expr-done 5660
Unique_Array := Make_Unique (Fld); 
--# expr-done 5661
      declare
         Map_Result_Vec : Internal_Entity_Compilation_Unit_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Compilation_Unit_Array_Access := Unique_Array;
      begin
         for Item_198 of
               Collection.Items
         loop
   --# scope-start
               --# bind u Item_198
         --# expr-start 5664 '<Not at ast.py:19068>' Not_Val /tmp/lal-23.0.0/ada/ast.py:19068
--# expr-start 5663 '<Eq at ast.py:19068>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19068
--# expr-start 5662 '<FieldAccess for node at ast.py:19068>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19068
Fld_1 := Item_198.Node;
--# expr-done 5662
      Cast_Result := Fld_1;
Is_Equal := Cast_Result = Self; 
--# expr-done 5663
Not_Val := not (Is_Equal); 
--# expr-done 5664
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity_Compilation_Unit := Item_198;
         begin
            Internal_Entity_Compilation_Unit_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Compilation_Unit_Array
           (Items_Count => Natural (Internal_Entity_Compilation_Unit_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Compilation_Unit_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Compilation_Unit_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Compilation_Unit_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5665
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5666
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1358;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Compilation_Unit_Array_Access,
                        As_Internal_Entity_Compilation_Unit_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1358;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Unit_Dependencies;
--# end
--# property-start CompilationUnit.decl /tmp/lal-23.0.0/ada/ast.py:19073
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Decl
  (Node : Bare_Compilation_Unit
  )
   return Bare_Basic_Decl
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Decl;
      Match_0 : Bare_Library_Item;
Match_1 : Bare_Subunit;
Match_2 : Bare_Ada_Node;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Basic_Decl;
Fld_2 : Bare_Body_Node;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Library_Item;
Let_Result : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Cast_Result_1 : Bare_Subunit;
Cast_Result_2 : Bare_Basic_Decl;
Let_Result_1 : Bare_Basic_Decl;
Scope_Result_1 : Bare_Basic_Decl;
Cast_Result_3 : Bare_Ada_Node;
Let_Result_2 : Bare_Basic_Decl;
Scope_Result_2 : Bare_Basic_Decl;
Match_Result : Bare_Basic_Decl;
Let_Result_3 : Bare_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5671 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 5670 '<Match at ast.py:19077>' Match_Result /tmp/lal-23.0.0/ada/ast.py:19077
--# expr-start 5667 '<FieldAccess for body at ast.py:19077>' Fld /tmp/lal-23.0.0/ada/ast.py:19077
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Compilation_Unit_F_Body;
--# expr-done 5667
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind li Match_0
--# expr-start 5668 '<FieldAccess for item at ast.py:19078>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19078
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Match_0.Library_Item_F_Item;
--# expr-done 5668
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind su Match_1
--# expr-start 5669 '<FieldAccess for body at ast.py:19079>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19079
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Match_1.Subunit_F_Body;
--# expr-done 5669
      Cast_Result_2 := Fld_2;
Let_Result_1 := Cast_Result_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := No_Bare_Ada_Node; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 5670
Let_Result_3 := Match_Result; 
--# end
--# expr-done 5671
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Decl;
--# end
--# property-start CompilationUnit.is_preelaborable_impl /tmp/lal-23.0.0/ada/ast.py:19085
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Is_Preelaborable_Impl
  (Node : Bare_Compilation_Unit
      ; From_Body : Boolean
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Compilation_Unit :=
     Internal_Entity_Compilation_Unit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind from_body From_Body
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Subunit;
Match_1 : Internal_Entity_Library_Item;
Match_2 : Internal_Entity;
Match_0_1 : Internal_Entity_Subp_Decl;
Match_1_1 : Internal_Entity_Generic_Subp_Decl;
Match_2_1 : Internal_Entity_Subp_Body;
Match_3 : Internal_Entity_Package_Decl;
Match_4 : Internal_Entity_Generic_Package_Decl;
Match_5 : Internal_Entity_Package_Body;
Match_6 : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity;
Fld_3 : Internal_Entity;
Cast_Result : Internal_Entity_Compilation_Unit;
Fld_4 : Boolean;
Fld_5 : Internal_Entity_Basic_Decl;
Fld_6 : Boolean;
Fld_7 : Internal_Entity_Basic_Decl;
Fld_8 : Boolean;
Fld_9 : Boolean;
Fld_10 : Internal_Entity_Basic_Decl;
Fld_11 : Internal_Entity;
Fld_12 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Compilation_Unit;
Fld_13 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Fld_14 : Boolean;
Fld_15 : Internal_Entity_Generic_Package_Internal;
Fld_16 : Boolean;
Fld_17 : Internal_Entity_Basic_Decl;
Fld_18 : Internal_Unit;
Fld_19 : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Compilation_Unit;
Fld_20 : Boolean;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Subp_Decl;
Let_Result : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_4 : Internal_Entity_Generic_Subp_Decl;
Let_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_5 : Internal_Entity_Subp_Body;
Let_Result_2 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_6 : Internal_Entity_Package_Decl;
Let_Result_3 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_7 : Internal_Entity_Generic_Package_Decl;
Let_Result_4 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_8 : Internal_Entity_Package_Body;
Let_Result_5 : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_9 : Internal_Entity_Basic_Decl;
Let_Result_6 : Boolean;
Scope_Result_7 : Boolean;
Match_Result : Boolean;
Match_Prefix_1 : Internal_Entity;
Cast_Result_10 : Internal_Entity_Subunit;
Let_Result_7 : Boolean;
Scope_Result_8 : Boolean;
Cast_Result_11 : Internal_Entity_Library_Item;
Let_Result_8 : Boolean;
Scope_Result_9 : Boolean;
Cast_Result_12 : Internal_Entity;
Let_Result_9 : Boolean;
Scope_Result_10 : Boolean;
Match_Result_1 : Boolean;
Let_Result_10 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5699 '<Block at ???>' Let_Result_10 None
--# scope-start
--# expr-start 5698 '<Match at ast.py:19093>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:19093
--# expr-start 5672 '<FieldAccess for body at ast.py:19093>' Fld /tmp/lal-23.0.0/ada/ast.py:19093
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Compilation_Unit_F_Body, Info => Ent.Info);
--# expr-done 5672
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Fld; 
case Ada_Ada_Node (Match_Prefix_1.Node.Kind) is
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity_Subunit
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_0 := Cast_Result_10; 
--# bind su Match_0
--# expr-start 5677 '<FieldAccess for is_preelaborable_impl at ast.py:19097>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19097
--# expr-start 5676 '<Cast to CompilationUnit at ast.py:19097>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19097
--# expr-start 5675 '<parent at ast.py:19097>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19097
--# expr-start 5674 '<parent at ast.py:19097>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19097
--# expr-start 5673 '<FieldAccess for body_root at ast.py:19097>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19097
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.body_root
Fld_1 := Libadalang.Implementation.Subunit_P_Body_Root (Node => Match_0.Node);
--# end
--# expr-done 5673
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 5674
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Parent (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# expr-done 5675
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Create_Internal_Entity_Compilation_Unit
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5676
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.is_preelaborable_impl
Fld_4 := Libadalang.Implementation.Compilation_Unit_P_Is_Preelaborable_Impl (Node => Cast_Result.Node, From_Body => True, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result.Info);
--# end
--# expr-done 5677
Let_Result_7 := Fld_4; 
--# end
Scope_Result_8 := Let_Result_7;
   --# end
            Match_Result_1 := Scope_Result_8; 
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Create_Internal_Entity_Library_Item
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_1 := Cast_Result_11; 
--# bind li Match_1
--# expr-start 5697 '<Match at ast.py:19101>' Match_Result /tmp/lal-23.0.0/ada/ast.py:19101
--# expr-start 5678 '<FieldAccess for item at ast.py:19101>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19101
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Basic_Decl (Node => Match_1.Node.Library_Item_F_Item, Info => Match_1.Info);
--# expr-done 5678
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_5; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0_1 := Cast_Result_3; 
--# bind subp_decl Match_0_1
--# expr-start 5679 '<FieldAccess for does_aspects_make_preelaborable at ast.py:19103>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19103
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.does_aspects_make_preelaborable
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Does_Aspects_Make_Preelaborable (Node => Match_0_1.Node, From_Body => From_Body, E_Info => Match_0_1.Info);
--# end
--# expr-done 5679
Let_Result := Fld_6; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Generic_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Generic_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1_1 := Cast_Result_4; 
--# bind gen_subp_decl Match_1_1
--# expr-start 5681 '<FieldAccess for does_aspects_make_preelaborable at ast.py:19107>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19107
--# expr-start 5680 '<FieldAccess for decl at ast.py:19106>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19106
      if Match_1_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericDecl.decl'
Fld_7 := Libadalang.Implementation.Dispatcher_Generic_Decl_P_Decl (Node => Match_1_1.Node, E_Info => Match_1_1.Info);
--# end
--# expr-done 5680
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.does_aspects_make_preelaborable
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Does_Aspects_Make_Preelaborable (Node => Fld_7.Node, From_Body => From_Body, E_Info => Fld_7.Info);
--# end
--# expr-done 5681
Let_Result_1 := Fld_8; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Subp_Body =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Subp_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2_1 := Cast_Result_5; 
--# bind subp_body Match_2_1
--# expr-start 5682 '<FieldAccess for does_aspects_make_preelaborable at ast.py:19112>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:19112
      if Match_2_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.does_aspects_make_preelaborable
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Does_Aspects_Make_Preelaborable (Node => Match_2_1.Node, From_Body => False, E_Info => Match_2_1.Info);
--# end
--# expr-done 5682
if Fld_9 then
   If_Result := True;
else
--# expr-start 5683 '<FieldAccess for decl_part at ast.py:19116>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:19116
      if Match_2_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld_10 := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Match_2_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_2_1.Info);
--# end
--# expr-done 5683
Var_Expr := Fld_10;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind dp Var_Expr
--# expr-start 5687 '<FieldAccess for is_preelaborable_impl at ast.py:19117>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:19117
--# expr-start 5686 '<Cast to CompilationUnit at ast.py:19118>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:19118
--# expr-start 5685 '<parent at ast.py:19117>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:19117
--# expr-start 5684 '<parent at ast.py:19117>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:19117
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Parent (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# expr-done 5684
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Parent (Node => Fld_11.Node, E_Info => Fld_11.Info);
--# expr-done 5685
   if Fld_12.Node = null
      or else Fld_12.Node.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Compilation_Unit
        (Node => Fld_12.Node,
         Info => Fld_12.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5686
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.is_preelaborable_impl
Fld_13 := Libadalang.Implementation.Compilation_Unit_P_Is_Preelaborable_Impl (Node => Cast_Result_1.Node, From_Body => True, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 5687
Scope_Result := Fld_13;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
Let_Result_2 := If_Result; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_6; 
--# bind pkg_decl Match_3
--# expr-start 5688 '<FieldAccess for does_aspects_make_preelaborable at ast.py:19123>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:19123
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.does_aspects_make_preelaborable
Fld_14 := Libadalang.Implementation.Basic_Decl_P_Does_Aspects_Make_Preelaborable (Node => Match_3.Node, From_Body => From_Body, E_Info => Match_3.Info);
--# end
--# expr-done 5688
Let_Result_3 := Fld_14; 
--# end
Scope_Result_4 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Generic_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Generic_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_7; 
--# bind gen_pkg_decl Match_4
--# expr-start 5690 '<FieldAccess for does_aspects_make_preelaborable at ast.py:19127>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:19127
--# expr-start 5689 '<FieldAccess for package_decl at ast.py:19126>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:19126
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Generic_Package_Internal (Node => Match_4.Node.Generic_Package_Decl_F_Package_Decl, Info => Match_4.Info);
--# expr-done 5689
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.does_aspects_make_preelaborable
Fld_16 := Libadalang.Implementation.Basic_Decl_P_Does_Aspects_Make_Preelaborable (Node => Fld_15.Node, From_Body => From_Body, E_Info => Fld_15.Info);
--# end
--# expr-done 5690
Let_Result_4 := Fld_16; 
--# end
Scope_Result_5 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Package_Body =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Package_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_8; 
--# bind pkg_body Match_5
--# expr-start 5696 '<FieldAccess for is_preelaborable_impl at ast.py:19132>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:19132
--# expr-start 5695 '<Cast to CompilationUnit at ast.py:19133>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:19133
--# expr-start 5694 '<as_bare_entity at ast.py:19132>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19132
--# expr-start 5693 '<FieldAccess for root at ast.py:19132>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:19132
--# expr-start 5692 '<FieldAccess for unit at ast.py:19132>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:19132
--# expr-start 5691 '<FieldAccess for decl_part at ast.py:19132>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:19132
      if Match_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld_17 := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Match_5.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_5.Info);
--# end
--# expr-done 5691
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Libadalang.Implementation.Unit (Node => Fld_17.Node);
--# expr-done 5692
      if Fld_18 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Fld_18.Ast_Root;
--# expr-done 5693
Is_Null := Fld_19 = null; 
if Is_Null then
   If_Result_1 := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_19); 
   If_Result_1 := As_Entity;
end if;
--# expr-done 5694
   if If_Result_1.Node = null
      or else If_Result_1.Node.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Compilation_Unit
        (Node => If_Result_1.Node,
         Info => If_Result_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5695
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.is_preelaborable_impl
Fld_20 := Libadalang.Implementation.Compilation_Unit_P_Is_Preelaborable_Impl (Node => Cast_Result_2.Node, From_Body => True, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 5696
Let_Result_5 := Fld_20; 
--# end
Scope_Result_6 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Abstract_State_Decl .. Ada_Generic_Package_Internal | Ada_Discrete_Base_Subtype_Decl .. Ada_Concrete_Formal_Subp_Decl | Ada_Entry_Decl .. Ada_Null_Subp_Decl | Ada_Subp_Renaming_Decl .. Ada_Entry_Body | Ada_Protected_Body .. Ada_For_Loop_Var_Decl | Ada_Generic_Package_Instantiation .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_6 := Cast_Result_9; 
--# bind _ Match_6
Let_Result_6 := False; 
--# end
Scope_Result_7 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_7; 
end case;
--# expr-done 5697
Let_Result_8 := Match_Result; 
--# end
Scope_Result_9 := Let_Result_8;
   --# end
            Match_Result_1 := Scope_Result_9; 
         when Ada_Abort_Absent .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_12 := Create_Internal_Entity
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_2 := Cast_Result_12; 
--# bind _ Match_2
Let_Result_9 := False; 
--# end
Scope_Result_10 := Let_Result_9;
   --# end
            Match_Result_1 := Scope_Result_10; 
end case;
--# expr-done 5698
Let_Result_10 := Match_Result_1; 
--# end
--# expr-done 5699
      Property_Result := Let_Result_10;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Is_Preelaborable_Impl;
--# end
--# property-start CompilationUnit.is_preelaborable /tmp/lal-23.0.0/ada/ast.py:19145
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Is_Preelaborable
  (Node : Bare_Compilation_Unit
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Compilation_Unit :=
     Internal_Entity_Compilation_Unit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5701 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5700 '<FieldAccess for is_preelaborable_impl at ast.py:19149>' Fld /tmp/lal-23.0.0/ada/ast.py:19149
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.is_preelaborable_impl
Fld := Libadalang.Implementation.Compilation_Unit_P_Is_Preelaborable_Impl (Node => Ent.Node, From_Body => False, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 5700
Let_Result := Fld; 
--# end
--# expr-done 5701
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Is_Preelaborable;
--# end
--# property-start CompilationUnit.self_restrictions /tmp/lal-23.0.0/ada/ast.py:19152
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Self_Restrictions
  (Node : Bare_Compilation_Unit
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1362 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Assoc;
Var_Expr_1 : Internal_Entity_Pragma_Node;
As_Entity : Internal_Entity_Compilation_Unit;
Is_Null : Boolean;
If_Result : Internal_Entity_Compilation_Unit;
Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Bare_Ada_Node_List;
Fld_2 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Pragma_Node;
Fld_3 : Internal_Entity_Base_Assoc_List;
Fld_4 : Bare_Base_Assoc_List;
Fld_5 : Internal_Entity_Info;
Get_Result : Bare_Base_Assoc;
As_Entity_2 : Internal_Entity_Base_Assoc;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity_Base_Assoc;
Fld_6 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Base_Id;
Fld_7 : Symbol_Type;
Item_199 : Internal_Entity;
Bare_Item_199 : Bare_Ada_Node;
Cast_Expr_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Pragma_Node;
Fld_8 : Internal_Entity_Identifier;
Fld_9 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Map_Result : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1362 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1362;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5715 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5714 '<FilterMap at ast.py:19158>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19158
   --# expr-start 5703 '<FieldAccess for prelude at ast.py:19158>' Fld /tmp/lal-23.0.0/ada/ast.py:19158
--# expr-start 5702 '<as_bare_entity at ast.py:19158>' If_Result /tmp/lal-23.0.0/ada/ast.py:19158
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Compilation_Unit;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 5702
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => If_Result.Node.Compilation_Unit_F_Prelude, Info => If_Result.Info);
--# expr-done 5703
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Symbol_Type_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Symbol_Type_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_1;
      begin
         for Untyped_Item_199 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_199 := Untyped_Item_199; 
Is_Null_1 := Bare_Item_199 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_2 := Fld.Info;
As_Entity_1 := (Info => Fld_2, Node => Bare_Item_199); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_199 := If_Result_1; 
   --# scope-start
               --# bind n Item_199
--# expr-start 5704 '<Cast to Pragma at ast.py:19162>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:19162
Cast_Expr_1 := Item_199; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Pragma_Node_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Pragma_Node
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Pragma_Node;
   end if;
--# expr-done 5704
Var_Expr_1 := Cast_Result_2;
if Var_Expr_1 /= No_Entity_Pragma_Node then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 5708 '<Eq at ast.py:19163>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19163
--# expr-start 5706 '<FieldAccess for name_symbol at ast.py:19163>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:19163
--# expr-start 5705 '<FieldAccess for id at ast.py:19163>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19163
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Identifier (Node => Var_Expr_1.Node.Pragma_Node_F_Id, Info => Var_Expr_1.Info);
--# expr-done 5705
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_9 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_8.Node);
--# end
--# expr-done 5706
--# expr-start 5707 '<Symbol Restrictions at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Restrictions); 
--# expr-done 5707
Is_Equal := Fld_9 = Sym; 
--# expr-done 5708
Scope_Result_1 := Is_Equal;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
         if Result_Var_1 then
      --# expr-start 5713 '<FieldAccess for name_symbol at ast.py:19160>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19160
--# expr-start 5712 '<Cast to BaseId at ast.py:19160>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:19160
--# expr-start 5710 '<FieldAccess for args at ast.py:19160>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19160
--# expr-start 5709 '<Cast to Pragma at ast.py:19160>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19160
Cast_Expr := Item_199; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Pragma_Node_Range
   then
      Cast_Result := Create_Internal_Entity_Pragma_Node
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Pragma_Node;
   end if;
--# expr-done 5709
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Base_Assoc_List (Node => Cast_Result.Node.Pragma_Node_F_Args, Info => Cast_Result.Info);
--# expr-done 5710
Fld_4 := Fld_3.Node;
Get_Result := Get (Self, Fld_4, 0, True); 
Is_Null_2 := Get_Result = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity_Base_Assoc;
else
Fld_5 := Fld_3.Info;
As_Entity_2 := (Info => Fld_5, Node => Get_Result); 
   If_Result_2 := As_Entity_2;
end if;
Var_Expr := If_Result_2;
if Var_Expr /= No_Entity_Base_Assoc then
   --# scope-start
--# expr-start 5711 '<FieldAccess for assoc_expr at ast.py:19160>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19160
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 5711
Scope_Result := Fld_6;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Expr;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Base_Id
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Id
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result_1 := No_Entity_Base_Id;
   end if;
--# expr-done 5712
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Cast_Result_1.Node);
--# end
--# expr-done 5713
         declare
            Item_To_Append : constant Symbol_Type := Fld_7;
         begin
            Symbol_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Symbol_Type_Array
           (Items_Count => Natural (Symbol_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Symbol_Type_Vectors.Get
              (Map_Result_Vec,
               I + Symbol_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Symbol_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5714
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5715
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1362;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1362;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Self_Restrictions;
--# end
--# property-start CompilationUnit.other_part /tmp/lal-23.0.0/ada/ast.py:19168
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Other_Part
  (Node : Bare_Compilation_Unit
  )
   return Internal_Entity_Compilation_Unit
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Compilation_Unit;
            procedure Finalizer_Scope_1363 with Inline_Always;
      Block_Var : Analysis_Unit_Kind;
Var_Expr : Bare_Compilation_Unit;
Fld : Analysis_Unit_Kind;
Is_Equal : Boolean;
If_Result : Analysis_Unit_Kind;
Fld_1 : Symbol_Type_Array_Access;
Fld_2 : Bare_Compilation_Unit;
As_Entity : Internal_Entity_Compilation_Unit;
Is_Null : Boolean;
If_Result_1 : Internal_Entity_Compilation_Unit;
Scope_Result : Internal_Entity_Compilation_Unit;
Result_Var : Internal_Entity_Compilation_Unit;
Let_Result : Internal_Entity_Compilation_Unit;
            procedure Finalizer_Scope_1363 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1363;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5722 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5718 '<If at ast.py:19173>' If_Result /tmp/lal-23.0.0/ada/ast.py:19173
--# expr-start 5717 '<Eq at ast.py:19174>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19174
--# expr-start 5716 '<FieldAccess for unit_kind at ast.py:19174>' Fld /tmp/lal-23.0.0/ada/ast.py:19174
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.unit_kind
Fld := Libadalang.Implementation.Compilation_Unit_P_Unit_Kind (Node => Self);
--# end
--# expr-done 5716
Is_Equal := Fld = Unit_Specification; 
--# expr-done 5717
if Is_Equal then
   If_Result := Unit_Body;
else
   If_Result := Unit_Specification;
end if;
--# expr-done 5718
Block_Var := If_Result; 
--# bind other_kind Block_Var
--# expr-start 5720 '<FieldAccess for designated_compilation_unit at ast.py:19178>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19178
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5719 '<FieldAccess for syntactic_fully_qualified_name at ast.py:19179>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19179
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.syntactic_fully_qualified_name
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Syntactic_Fully_Qualified_Name (Node => Self);
--# end
--# expr-done 5719
--# property-call-start AdaNode.designated_compilation_unit
Fld_2 := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Fld_1, Kind => Block_Var, Not_Found_Is_Error => False);
--# end
--# expr-done 5720
Var_Expr := Fld_2;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 5721 '<as_bare_entity at ast.py:19182>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19182
Is_Null := Var_Expr = null; 
if Is_Null then
   If_Result_1 := No_Entity_Compilation_Unit;
else
As_Entity := (Info => No_Entity_Info, Node => Var_Expr); 
   If_Result_1 := As_Entity;
end if;
--# expr-done 5721
Scope_Result := If_Result_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Compilation_Unit;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 5722
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1363;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1363;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Other_Part;
--# end
--# property-start CompilationUnit.has_restriction /tmp/lal-23.0.0/ada/ast.py:19185
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Has_Restriction
  (Node : Bare_Compilation_Unit
      ; Name : Symbol_Type
  )
   return Boolean
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind name Name
   Property_Result : Boolean;
            procedure Finalizer_Scope_2610 with Inline_Always;
            procedure Finalizer_Scope_2612 with Inline_Always;
      Match_0 : Bare_Library_Item;
Match_1 : Bare_Subunit;
Match_2 : Bare_Ada_Node;
Var_Expr : Internal_Entity_Compilation_Unit;
Var_Expr_1 : Internal_Entity_Compilation_Unit;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld : Bare_Ada_Node;
Fld_1 : Symbol_Type_Array_Access;
Is_Equal_1 : Boolean;
Quantifier_Result : Boolean;
Fld_2 : Internal_Entity_Compilation_Unit;
Fld_3 : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Is_Equal_2 : Boolean;
Quantifier_Result_1 : Boolean;
If_Result : Boolean;
Fld_4 : Internal_Entity_Compilation_Unit;
Fld_5 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Library_Item;
Let_Result : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_1 : Bare_Subunit;
Let_Result_1 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_2 : Bare_Ada_Node;
Let_Result_2 : Boolean;
Scope_Result_4 : Boolean;
Match_Result : Boolean;
If_Result_1 : Boolean;
Let_Result_3 : Boolean;
            procedure Finalizer_Scope_2610 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2610;
            procedure Finalizer_Scope_2612 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2612;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5737 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 5736 '<Cond at ast.py:19194>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19194
--# expr-start 5724 '<Eq at ast.py:19195>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19195
--# expr-start 5723 '<Symbol No_Elaboration_Code at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_No_Elaboration_Code); 
--# expr-done 5723
Is_Equal := Name = Sym; 
--# expr-done 5724
if Is_Equal then
   --# expr-start 5735 '<Match at ast.py:19197>' Match_Result /tmp/lal-23.0.0/ada/ast.py:19197
--# expr-start 5725 '<FieldAccess for body at ast.py:19197>' Fld /tmp/lal-23.0.0/ada/ast.py:19197
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Compilation_Unit_F_Body;
--# expr-done 5725
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Library_Item =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind _ Match_0
--# expr-start 5728 '<Contains at ast.py:19201>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:19201
   --# expr-start 5726 '<FieldAccess for self_restrictions at ast.py:19201>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19201
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.self_restrictions
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Self_Restrictions (Node => Self);
--# end
--# expr-done 5726
      Quantifier_Result := False;
      declare
         Collection : constant Symbol_Type_Array_Access := Fld_1;
      begin
         for Item_200 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_200
      --# expr-start 5727 '<Eq at ???>' Is_Equal_1 None
Is_Equal_1 := Item_200 = Name; 
--# expr-done 5727
      Quantifier_Result := Is_Equal_1;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 5728
if Quantifier_Result then
   If_Result := True;
else
   --# expr-start 5732 '<Contains at ast.py:19202>' Quantifier_Result_1 /tmp/lal-23.0.0/ada/ast.py:19202
--# expr-start 5729 '<FieldAccess for other_part at ast.py:19202>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19202
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.other_part
Fld_2 := Libadalang.Implementation.Compilation_Unit_P_Other_Part (Node => Self);
--# end
--# expr-done 5729
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Compilation_Unit then
   --# scope-start
--# expr-start 5730 '<FieldAccess for self_restrictions at ast.py:19202>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19202
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.self_restrictions
Fld_3 := Libadalang.Implementation.Compilation_Unit_P_Self_Restrictions (Node => Var_Expr.Node);
--# end
--# expr-done 5730
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2612;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Quantifier_Result_1 := False;
      declare
         Collection : constant Symbol_Type_Array_Access := Result_Var;
      begin
         for Item_201 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_201
      --# expr-start 5731 '<Eq at ???>' Is_Equal_2 None
Is_Equal_2 := Item_201 = Name; 
--# expr-done 5731
      Quantifier_Result_1 := Is_Equal_2;
   --# end
               exit when Quantifier_Result_1;
         end loop;
      end;
--# expr-done 5732
   If_Result := Quantifier_Result_1;
end if;
Let_Result := If_Result; 
--# end
Scope_Result_2 := Let_Result;
   --# end
      Finalizer_Scope_2610;
            Match_Result := Scope_Result_2; 
         when Ada_Subunit =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind su Match_1
--# expr-start 5733 '<FieldAccess for root_unit at ast.py:19206>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19206
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.root_unit
Fld_4 := Libadalang.Implementation.Subunit_P_Root_Unit (Node => Match_1);
--# end
--# expr-done 5733
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= No_Entity_Compilation_Unit then
   --# scope-start
--# expr-start 5734 '<FieldAccess for has_restriction at ast.py:19206>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19206
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.has_restriction
Fld_5 := Libadalang.Implementation.Compilation_Unit_P_Has_Restriction (Node => Var_Expr_1.Node, Name => Name);
--# end
--# expr-done 5734
Scope_Result_1 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Let_Result_1 := Result_Var_1; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Abort_Absent .. Ada_Iter_Type_Of | Ada_Limited_Absent .. Ada_Subp_Kind_Procedure | Ada_Synchronized_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := raise Property_Error with "Unexpected CompilationUnit.f_body attribute"; 
--# end
Scope_Result_4 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_4; 
end case;
--# expr-done 5735
   If_Result_1 := Match_Result;
else
   If_Result_1 := raise Property_Error with "Unsupported restriction";
end if;
--# expr-done 5736
Let_Result_3 := If_Result_1; 
--# end
--# expr-done 5737
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2610;
               Finalizer_Scope_2612;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Has_Restriction;
--# end
--# property-start CompilationUnit.is_text_io_child /tmp/lal-23.0.0/ada/ast.py:19217
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Is_Text_Io_Child
  (Node : Bare_Compilation_Unit
  )
   return Boolean
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
            procedure Finalizer_Scope_1365 with Inline_Always;
      Block_Var : Symbol_Type_Array_Access;
Fld : Symbol_Type_Array_Access;
Len : Integer;
Is_Equal : Boolean;
Get_Result : Symbol_Type;
Sym : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Get_Result_1 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_2 : Boolean;
Get_Result_2 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_1 : Boolean;
Get_Result_3 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_1365 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_1365;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5753 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5738 '<FieldAccess for syntactic_fully_qualified_name at ast.py:19222>' Fld /tmp/lal-23.0.0/ada/ast.py:19222
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.syntactic_fully_qualified_name
Fld := Libadalang.Implementation.Compilation_Unit_P_Syntactic_Fully_Qualified_Name (Node => Self);
--# end
--# expr-done 5738
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind name_parts Block_Var
--# expr-start 5740 '<Eq at ast.py:19224>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19224
--# expr-start 5739 '<length at ast.py:19224>' Len /tmp/lal-23.0.0/ada/ast.py:19224
Len := Length (Block_Var); 
--# expr-done 5739
Is_Equal := Len = 3; 
--# expr-done 5740
if Is_Equal then
   --# expr-start 5743 '<Eq at ast.py:19225>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:19225
--# expr-start 5741 '<at at ast.py:19225>' Get_Result /tmp/lal-23.0.0/ada/ast.py:19225
Get_Result := Get (Self, Block_Var, 0, True); 
--# expr-done 5741
--# expr-start 5742 '<Symbol ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada_264); 
--# expr-done 5742
Is_Equal_1 := Get_Result = Sym; 
--# expr-done 5743
   If_Result := Is_Equal_1;
else
   If_Result := False;
end if;
if If_Result then
--# expr-start 5746 '<Eq at ast.py:19226>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:19226
--# expr-start 5744 '<at at ast.py:19226>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:19226
Get_Result_1 := Get (Self, Block_Var, 1, True); 
--# expr-done 5744
--# expr-start 5745 '<Symbol text_io at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Text_Io); 
--# expr-done 5745
Is_Equal_2 := Get_Result_1 = Sym_1; 
--# expr-done 5746
if Is_Equal_2 then
   If_Result_1 := True;
else
   --# expr-start 5749 '<Eq at ast.py:19226>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:19226
--# expr-start 5747 '<at at ast.py:19226>' Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:19226
Get_Result_2 := Get (Self, Block_Var, 1, True); 
--# expr-done 5747
--# expr-start 5748 '<Symbol wide_text_io at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Text_Io); 
--# expr-done 5748
Is_Equal_3 := Get_Result_2 = Sym_2; 
--# expr-done 5749
   If_Result_1 := Is_Equal_3;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 5752 '<Eq at ast.py:19226>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:19226
--# expr-start 5750 '<at at ast.py:19226>' Get_Result_3 /tmp/lal-23.0.0/ada/ast.py:19226
Get_Result_3 := Get (Self, Block_Var, 1, True); 
--# expr-done 5750
--# expr-start 5751 '<Symbol wide_wide_text_io at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Text_Io); 
--# expr-done 5751
Is_Equal_4 := Get_Result_3 = Sym_3; 
--# expr-done 5752
   If_Result_2 := Is_Equal_4;
end if;
   If_Result_3 := If_Result_2;
else
   If_Result_3 := False;
end if;
Let_Result := If_Result_3; 
--# end
--# expr-done 5753
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1365;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1365;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Is_Text_Io_Child;
--# end
--# property-start CompilationUnit.local_config_pragmas /tmp/lal-23.0.0/ada/ast.py:19245
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Local_Config_Pragmas
  (Node : Bare_Compilation_Unit
  )
   return Bare_Pragma_Node_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1367 with Inline_Always;
      Fld : Bare_Ada_Node_List;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Pragma_Node;
Item_202 : Bare_Ada_Node;
Is_A : Boolean;
Map_Result : Bare_Pragma_Node_Array_Access;
Let_Result : Bare_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1367 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1367;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5758 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5757 '<FilterMap at ast.py:19250>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19250
   --# expr-start 5754 '<FieldAccess for prelude at ast.py:19250>' Fld /tmp/lal-23.0.0/ada/ast.py:19250
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Compilation_Unit_F_Prelude;
--# expr-done 5754
      declare
         Map_Result_Vec : Bare_Pragma_Node_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Bare_Pragma_Node_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld;
      begin
         for Untyped_Item_202 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_202 := Untyped_Item_202; 
   --# scope-start
               --# bind n Item_202
         --# expr-start 5755 '<IsA Pragma at ast.py:19252>' Is_A /tmp/lal-23.0.0/ada/ast.py:19252
Is_A := Item_202 /= null 
and then Item_202.Kind in Ada_Pragma_Node_Range; 
--# expr-done 5755
         if Is_A then
      --# expr-start 5756 '<Cast to Pragma at ast.py:19251>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19251
Cast_Expr := Item_202; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Pragma_Node_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5756
         declare
            Item_To_Append : constant Bare_Pragma_Node := Cast_Result;
         begin
            Bare_Pragma_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Pragma_Node_Array
           (Items_Count => Natural (Bare_Pragma_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Pragma_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Pragma_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Pragma_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5757
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5758
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1367;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1367;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Local_Config_Pragmas;
--# end
--# property-start CompilationUnit.sources_config_pragmas /tmp/lal-23.0.0/ada/ast.py:19256
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Sources_Config_Pragmas
  (Node : Bare_Compilation_Unit
  )
   return Bare_Pragma_Node_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1368 with Inline_Always;
            procedure Finalizer_Scope_2618 with Inline_Always;
            procedure Finalizer_Scope_2619 with Inline_Always;
      Block_Var : Bare_Pragma_Node_Array_Access;
Block_Var_1 : Bare_Pragma_Node_Array_Access;
Var_Expr : Internal_Entity_Compilation_Unit;
Var_Expr_1 : Internal_Entity_Compilation_Unit;
Fld : Bare_Pragma_Node_Array_Access;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
Fld_2 : Internal_Entity_Compilation_Unit;
Fld_3 : Bare_Pragma_Node_Array_Access;
Scope_Result : Bare_Pragma_Node_Array_Access;
Result_Var : Bare_Pragma_Node_Array_Access;
Fld_4 : Bare_Ada_Node;
Is_A_1 : Boolean;
Fld_5 : Bare_Ada_Node;
Cast_Result : Bare_Subunit;
Fld_6 : Internal_Entity_Compilation_Unit;
Fld_7 : Bare_Pragma_Node_Array_Access;
Scope_Result_1 : Bare_Pragma_Node_Array_Access;
Result_Var_1 : Bare_Pragma_Node_Array_Access;
If_Result : Bare_Pragma_Node_Array_Access;
If_Result_1 : Bare_Pragma_Node_Array_Access;
Concat_Result : Bare_Pragma_Node_Array_Access;
Let_Result : Bare_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1368 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1368;
            procedure Finalizer_Scope_2618 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2618;
            procedure Finalizer_Scope_2619 is
            begin
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_2619;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5772 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5759 '<FieldAccess for local_config_pragmas at ast.py:19262>' Fld /tmp/lal-23.0.0/ada/ast.py:19262
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.local_config_pragmas
Fld := Libadalang.Implementation.Compilation_Unit_P_Local_Config_Pragmas (Node => Self);
--# end
--# expr-done 5759
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind current_unit Block_Var
--# expr-start 5770 '<Cond at ast.py:19266>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:19266
--# expr-start 5761 '<IsA LibraryItem at ast.py:19269>' Is_A /tmp/lal-23.0.0/ada/ast.py:19269
--# expr-start 5760 '<FieldAccess for body at ast.py:19269>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19269
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Compilation_Unit_F_Body;
--# expr-done 5760
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Library_Item_Range; 
--# expr-done 5761
if Is_A then
--# expr-start 5762 '<FieldAccess for other_part at ast.py:19270>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19270
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.other_part
Fld_2 := Libadalang.Implementation.Compilation_Unit_P_Other_Part (Node => Self);
--# end
--# expr-done 5762
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Compilation_Unit then
   --# scope-start
--# expr-start 5763 '<FieldAccess for local_config_pragmas at ast.py:19270>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19270
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.local_config_pragmas
Fld_3 := Libadalang.Implementation.Compilation_Unit_P_Local_Config_Pragmas (Node => Var_Expr.Node);
--# end
--# expr-done 5763
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2618;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Pragma_Node_Array_Type;
end if;
      Inc_Ref (Result_Var);
   If_Result_1 := Result_Var;
else
--# expr-start 5765 '<IsA Subunit at ast.py:19274>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:19274
--# expr-start 5764 '<FieldAccess for body at ast.py:19274>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19274
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Compilation_Unit_F_Body;
--# expr-done 5764
Is_A_1 := Fld_4 /= null 
and then Fld_4.Kind in Ada_Subunit_Range; 
--# expr-done 5765
if Is_A_1 then
--# expr-start 5768 '<FieldAccess for root_unit at ast.py:19275>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19275
--# expr-start 5767 '<Cast to Subunit at ast.py:19275>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19275
--# expr-start 5766 '<FieldAccess for body at ast.py:19275>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19275
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Compilation_Unit_F_Body;
--# expr-done 5766
   if Fld_5 = null
      or else Fld_5.Kind in Ada_Subunit_Range
   then
      Cast_Result := Fld_5;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5767
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.root_unit
Fld_6 := Libadalang.Implementation.Subunit_P_Root_Unit (Node => Cast_Result);
--# end
--# expr-done 5768
Var_Expr_1 := Fld_6;
if Var_Expr_1 /= No_Entity_Compilation_Unit then
   --# scope-start
--# expr-start 5769 '<FieldAccess for sources_config_pragmas at ast.py:19275>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19275
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.sources_config_pragmas
Fld_7 := Libadalang.Implementation.Compilation_Unit_P_Sources_Config_Pragmas (Node => Var_Expr_1.Node);
--# end
--# expr-done 5769
Scope_Result_1 := Fld_7;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2619;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Bare_Pragma_Node_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
   If_Result := Result_Var_1;
else
   If_Result := No_Bare_Pragma_Node_Array_Type;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 5770
Block_Var_1 := If_Result_1; Inc_Ref (Block_Var_1);
--# bind related_units Block_Var_1
--# expr-start 5771 '<Concat at ast.py:19281>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:19281
Concat_Result := Concat (Block_Var, Block_Var_1); 
--# expr-done 5771
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5772
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1368;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1368;
               Finalizer_Scope_2618;
               Finalizer_Scope_2619;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Sources_Config_Pragmas;
--# end
--# property-start CompilationUnit.all_config_pragmas /tmp/lal-23.0.0/ada/ast.py:19284
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_All_Config_Pragmas
  (Node : Bare_Compilation_Unit
  )
   return Internal_Entity_Pragma_Node_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1369 with Inline_Always;
      Fld : Bare_Pragma_Node_Array_Access;
Fld_1 : Bare_Pragma_Node_Array_Access;
Concat_Result : Bare_Pragma_Node_Array_Access;
As_Entity : Internal_Entity_Pragma_Node;
Is_Null : Boolean;
If_Result : Internal_Entity_Pragma_Node;
Map_Result : Internal_Entity_Pragma_Node_Array_Access;
Let_Result : Internal_Entity_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1369 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1369;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5778 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5777 '<Map at ast.py:19295>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19295
   --# expr-start 5775 '<Concat at ast.py:19294>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:19294
--# expr-start 5773 '<FieldAccess for sources_config_pragmas at ast.py:19294>' Fld /tmp/lal-23.0.0/ada/ast.py:19294
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.sources_config_pragmas
Fld := Libadalang.Implementation.Compilation_Unit_P_Sources_Config_Pragmas (Node => Self);
--# end
--# expr-done 5773
--# expr-start 5774 '<FieldAccess for external_config_pragmas at ast.py:19294>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19294
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Compilation_Unit_P_External_Config_Pragmas (Node => Self);
--# expr-done 5774
Concat_Result := Concat (Fld, Fld_1); 
--# expr-done 5775
      declare
         Map_Result_Vec : Internal_Entity_Pragma_Node_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Pragma_Node_Array_Access := Concat_Result;
      begin
         for Item_203 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_203
      --# expr-start 5776 '<as_bare_entity at ast.py:19295>' If_Result /tmp/lal-23.0.0/ada/ast.py:19295
Is_Null := Item_203 = null; 
if Is_Null then
   If_Result := No_Entity_Pragma_Node;
else
As_Entity := (Info => No_Entity_Info, Node => Item_203); 
   If_Result := As_Entity;
end if;
--# expr-done 5776
         declare
            Item_To_Append : constant Internal_Entity_Pragma_Node := If_Result;
         begin
            Internal_Entity_Pragma_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Pragma_Node_Array
           (Items_Count => Natural (Internal_Entity_Pragma_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Pragma_Node_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Pragma_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Pragma_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5777
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5778
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1369;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1369;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_All_Config_Pragmas;
--# end
--# property-start CompilationUnit.config_pragmas /tmp/lal-23.0.0/ada/ast.py:19299
pragma Warnings (Off, "is not referenced");
 function Compilation_Unit_P_Config_Pragmas
  (Node : Bare_Compilation_Unit
      ; Name : Symbol_Type
  )
   return Internal_Entity_Pragma_Node_Array_Access
is
   Self : Bare_Compilation_Unit := Bare_Compilation_Unit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind name Name
   Property_Result : Internal_Entity_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1370 with Inline_Always;
      Fld : Internal_Entity_Pragma_Node_Array_Access;
Fld_1 : Internal_Entity_Identifier;
Fld_2 : Symbol_Type;
Is_Equal : Boolean;
Map_Result : Internal_Entity_Pragma_Node_Array_Access;
Let_Result : Internal_Entity_Pragma_Node_Array_Access;
            procedure Finalizer_Scope_1370 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1370;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5784 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5783 '<Filter at ast.py:19308>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19308
   --# expr-start 5779 '<FieldAccess for all_config_pragmas at ast.py:19308>' Fld /tmp/lal-23.0.0/ada/ast.py:19308
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.all_config_pragmas
Fld := Libadalang.Implementation.Compilation_Unit_P_All_Config_Pragmas (Node => Self);
--# end
--# expr-done 5779
      declare
         Map_Result_Vec : Internal_Entity_Pragma_Node_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Pragma_Node_Array_Access := Fld;
      begin
         for Item_204 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_204
         --# expr-start 5782 '<Eq at ast.py:19309>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19309
--# expr-start 5781 '<FieldAccess for name_symbol at ast.py:19309>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19309
--# expr-start 5780 '<FieldAccess for id at ast.py:19309>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19309
      if Item_204.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Identifier (Node => Item_204.Node.Pragma_Node_F_Id, Info => Item_204.Info);
--# expr-done 5780
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_1.Node);
--# end
--# expr-done 5781
Is_Equal := Fld_2 = Name; 
--# expr-done 5782
         if Is_Equal then
         declare
            Item_To_Append : constant Internal_Entity_Pragma_Node := Item_204;
         begin
            Internal_Entity_Pragma_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Pragma_Node_Array
           (Items_Count => Natural (Internal_Entity_Pragma_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Pragma_Node_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Pragma_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Pragma_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5783
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 5784
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1370;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1370;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Compilation_Unit_P_Config_Pragmas;
--# end
   --
   --  Primitives for Bare_Component_Clause
   --
      procedure Initialize_Fields_For_Component_Clause
        (Self : Bare_Component_Clause
         ; Component_Clause_F_Id : Bare_Identifier
         ; Component_Clause_F_Position : Bare_Expr
         ; Component_Clause_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Component_Clause_F_Id := Component_Clause_F_Id;
            Self.Component_Clause_F_Position := Component_Clause_F_Position;
            Self.Component_Clause_F_Range := Component_Clause_F_Range;
      end Initialize_Fields_For_Component_Clause;
   function Component_Clause_F_Id
     (Node : Bare_Component_Clause) return Bare_Identifier
   is
   begin
         return Node.Component_Clause_F_Id;
   end;
   function Component_Clause_F_Position
     (Node : Bare_Component_Clause) return Bare_Expr
   is
   begin
         return Node.Component_Clause_F_Position;
   end;
   function Component_Clause_F_Range
     (Node : Bare_Component_Clause) return Bare_Range_Spec
   is
   begin
         return Node.Component_Clause_F_Range;
   end;
--# property-start ComponentClause.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:9906
pragma Warnings (Off, "is not referenced");
 function Component_Clause_P_Xref_Entry_Point
  (Node : Bare_Component_Clause
  )
   return Boolean
is
   Self : Bare_Component_Clause := Bare_Component_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Clause_P_Xref_Entry_Point;
--# end
--# property-start ComponentClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:9909
pragma Warnings (Off, "is not referenced");
 function Component_Clause_P_Xref_Equation
  (Node : Bare_Component_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Component_Clause := Bare_Component_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_Clause :=
     Internal_Entity_Component_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_791 with Inline_Always;
      Block_Var : Internal_Entity_Record_Rep_Clause;
Block_Var_1 : Lexical_Env := Empty_Env;
Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Record_Rep_Clause;
Fld_2 : Internal_Entity_Name;
Fld_3 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Identifier;
Fld_5 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
Fld_6 : Internal_Entity_Expr;
Fld_7 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_8 : Internal_Entity_Range_Spec;
Fld_9 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_791 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_791;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5799 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5787 '<Cast to RecordRepClause at ast.py:9912>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9912
--# expr-start 5786 '<parent at ast.py:9912>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9912
--# expr-start 5785 '<parent at ast.py:9912>' Fld /tmp/lal-23.0.0/ada/ast.py:9912
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 5785
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 5786
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Record_Rep_Clause_Range
   then
      Cast_Result := Create_Internal_Entity_Record_Rep_Clause
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5787
Block_Var := Cast_Result; 
--# bind rep_clause Block_Var
--# expr-start 5789 '<FieldAccess for designated_env_no_overloading at ast.py:9916>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9916
--# expr-start 5788 '<FieldAccess for name at ast.py:9916>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9916
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Block_Var.Node.Record_Rep_Clause_F_Name, Info => Block_Var.Info);
--# expr-done 5788
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env_no_overloading'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env_No_Overloading (Node => Fld_2.Node, Env => Env, Origin => Origin, No_Visibility => False, E_Info => Fld_2.Info);
--# end
--# expr-done 5789
Block_Var_1 := Fld_3; Inc_Ref (Block_Var_1);
--# bind record_env Block_Var_1
--# expr-start 5798 '<And at ast.py:9918>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:9918
--# expr-start 5795 '<And at ast.py:9918>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9918
--# expr-start 5792 '<bind at ast.py:9920>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:9920
Bound_Env := Block_Var_1; Inc_Ref (Bound_Env);
--# expr-start 5791 '<FieldAccess for xref_equation at ast.py:9920>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9920
--# expr-start 5790 '<FieldAccess for id at ast.py:9920>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9920
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Ent.Node.Component_Clause_F_Id, Info => Ent.Info);
--# expr-done 5790
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_5 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_4.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 5791
Dyn_Var_Bind_Result := Fld_5; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 5792
--# expr-start 5794 '<FieldAccess for sub_equation at ast.py:9921>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9921
--# expr-start 5793 '<FieldAccess for position at ast.py:9921>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9921
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Ent.Node.Component_Clause_F_Position, Info => Ent.Info);
--# expr-done 5793
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_7 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_6.Node, Env => Env, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 5794
And_Pred := Create_And (Dyn_Var_Bind_Result, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9918") else null)); 
--# expr-done 5795
--# expr-start 5797 '<FieldAccess for sub_equation at ast.py:9922>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9922
--# expr-start 5796 '<FieldAccess for range at ast.py:9922>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9922
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Component_Clause_F_Range, Info => Ent.Info);
--# expr-done 5796
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_9 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_8.Node, Env => Env, Origin => Origin, E_Info => Fld_8.Info);
--# end
--# expr-done 5797
And_Pred_1 := Create_And (And_Pred, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9918") else null)); 
--# expr-done 5798
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5799
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_791;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_791;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Clause_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Component_Def
   --
      procedure Initialize_Fields_For_Component_Def
        (Self : Bare_Component_Def
         ; Component_Def_F_Has_Aliased : Bare_Aliased_Node
         ; Component_Def_F_Has_Constant : Bare_Constant_Node
         ; Component_Def_F_Type_Expr : Bare_Type_Expr
        ) is
      begin
            Self.Component_Def_F_Has_Aliased := Component_Def_F_Has_Aliased;
            Self.Component_Def_F_Has_Constant := Component_Def_F_Has_Constant;
            Self.Component_Def_F_Type_Expr := Component_Def_F_Type_Expr;
      end Initialize_Fields_For_Component_Def;
   function Component_Def_F_Has_Aliased
     (Node : Bare_Component_Def) return Bare_Aliased_Node
   is
   begin
         return Node.Component_Def_F_Has_Aliased;
   end;
   function Component_Def_F_Has_Constant
     (Node : Bare_Component_Def) return Bare_Constant_Node
   is
   begin
         return Node.Component_Def_F_Has_Constant;
   end;
   function Component_Def_F_Type_Expr
     (Node : Bare_Component_Def) return Bare_Type_Expr
   is
   begin
         return Node.Component_Def_F_Type_Expr;
   end;
--# property-start ComponentDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8382
pragma Warnings (Off, "is not referenced");
 function Component_Def_P_Xref_Equation
  (Node : Bare_Component_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Component_Def := Bare_Component_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Component_Def :=
     Internal_Entity_Component_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_648 with Inline_Always;
      Fld : Internal_Entity_Type_Expr;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_648 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_648;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5802 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5801 '<FieldAccess for sub_equation at ast.py:8383>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8383
--# expr-start 5800 '<FieldAccess for type_expr at ast.py:8383>' Fld /tmp/lal-23.0.0/ada/ast.py:8383
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Type_Expr (Node => Ent.Node.Component_Def_F_Type_Expr, Info => Ent.Info);
--# expr-done 5800
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 5801
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5802
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_648;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_648;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Component_Def_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Constant_Node
   --
--# property-start '[dispatcher]Constant.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Constant_Node_P_As_Bool
  (Node : Bare_Constant_Node
  )
   return Boolean
is
   Self : Bare_Constant_Node := Bare_Constant_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Constant_Node (Self.Kind) is
               when Ada_Constant_Absent =>
                  --# property-call-start Constant.Absent.as_bool
                  Property_Result := Constant_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Constant_Present =>
                  --# property-call-start Constant.Present.as_bool
                  Property_Result := Constant_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Constant_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Constant_Absent
   --
--# property-start Constant.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5013
pragma Warnings (Off, "is not referenced");
 function Constant_Absent_P_As_Bool
  (Node : Bare_Constant_Absent
  )
   return Boolean
is
   Self : Bare_Constant_Absent := Bare_Constant_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constant_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Constant_Present
   --
--# property-start Constant.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5013
pragma Warnings (Off, "is not referenced");
 function Constant_Present_P_As_Bool
  (Node : Bare_Constant_Present
  )
   return Boolean
is
   Self : Bare_Constant_Present := Bare_Constant_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constant_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Constraint
   --
--# property-start Constraint.subtype /tmp/lal-23.0.0/ada/ast.py:7889
pragma Warnings (Off, "is not referenced");
 function Constraint_P_Subtype
  (Node : Bare_Constraint
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Constraint := Bare_Constraint (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Subtype_Indication;
As_Entity : Internal_Entity_Subtype_Indication;
Is_Null : Boolean;
If_Result : Internal_Entity_Subtype_Indication;
Fld_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5808 '<bind at ast.py:7889>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:7889
--# expr-start 5803 '<FieldAccess for origin_node at ast.py:7890>' Fld /tmp/lal-23.0.0/ada/ast.py:7890
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 5803
Bound_Origin := Fld; 
--# expr-start 5807 '<FieldAccess for designated_type at ast.py:7892>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7892
--# expr-start 5806 '<as_entity at ast.py:7892>' If_Result /tmp/lal-23.0.0/ada/ast.py:7892
--# expr-start 5805 '<Cast to SubtypeIndication at ast.py:7891>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7891
--# expr-start 5804 '<parent at ast.py:7891>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7891
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Parent; 
--# expr-done 5804
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Subtype_Indication_Range
   then
      Cast_Result := Fld_1;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5805
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Subtype_Indication;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 5806
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => If_Result.Node, Origin => Bound_Origin, E_Info => If_Result.Info);
--# end
--# expr-done 5807
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 5808
      Property_Result := Dyn_Var_Bind_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constraint_P_Subtype;
--# end
--# property-start Constraint.is_static /tmp/lal-23.0.0/ada/ast.py:7896
pragma Warnings (Off, "is not referenced");
 function Constraint_P_Is_Static
  (Node : Bare_Constraint
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Constraint := Bare_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Constraint :=
     Internal_Entity_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Range_Constraint;
Match_1 : Internal_Entity_Composite_Constraint;
Match_2 : Internal_Entity_Digits_Constraint;
Match_3 : Internal_Entity_Delta_Constraint;
Match_0_1 : Internal_Entity_Subtype_Indication;
Match_1_1 : Internal_Entity_Expr;
Match_2_1 : Internal_Entity;
Var_Expr : Internal_Entity_Range_Spec;
Var_Expr_1 : Internal_Entity_Range_Spec;
Fld : Internal_Entity_Range_Spec;
Fld_1 : Internal_Entity_Expr;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Assoc_List;
Fld_4 : Bare_Assoc_List;
Fld_5 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Cast_Expr : Internal_Entity_Basic_Assoc;
Cast_Result : Internal_Entity_Composite_Constraint_Assoc;
Fld_6 : Internal_Entity;
Fld_7 : Boolean;
Fld_8 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result_1 : Internal_Entity_Subtype_Indication;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_2 : Internal_Entity_Expr;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_3 : Internal_Entity;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
Item_205 : Internal_Entity_Basic_Assoc;
Bare_Item_205 : Bare_Basic_Assoc;
Quantifier_Result : Boolean;
Fld_9 : Internal_Entity_Assoc_List;
Fld_10 : Bare_Assoc_List;
Fld_11 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Assoc;
Fld_12 : Internal_Entity_Expr;
Fld_13 : Boolean;
Item_206 : Internal_Entity_Basic_Assoc;
Bare_Item_206 : Bare_Basic_Assoc;
Quantifier_Result_1 : Boolean;
Fld_14 : Boolean;
If_Result_2 : Boolean;
Fld_15 : Internal_Entity_Range_Spec;
Fld_16 : Internal_Entity_Expr;
Fld_17 : Boolean;
Scope_Result_3 : Boolean;
Result_Var : Boolean;
Fld_18 : Internal_Entity_Range_Spec;
Fld_19 : Internal_Entity_Expr;
Fld_20 : Boolean;
Scope_Result_4 : Boolean;
Result_Var_1 : Boolean;
Match_Prefix_1 : Internal_Entity_Constraint;
Cast_Result_4 : Internal_Entity_Range_Constraint;
Let_Result_3 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_5 : Internal_Entity_Composite_Constraint;
Let_Result_4 : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_6 : Internal_Entity_Digits_Constraint;
Let_Result_5 : Boolean;
Scope_Result_7 : Boolean;
Cast_Result_7 : Internal_Entity_Delta_Constraint;
Let_Result_6 : Boolean;
Scope_Result_8 : Boolean;
Match_Result_1 : Boolean;
Let_Result_7 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5832 '<Block at ???>' Let_Result_7 None
--# scope-start
--# expr-start 5831 '<Match at ast.py:7897>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:7897
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Ent; 
case Ada_Constraint (Match_Prefix_1.Node.Kind) is
         when Ada_Range_Constraint =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Range_Constraint
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_0 := Cast_Result_4; 
--# bind rc Match_0
--# expr-start 5811 '<FieldAccess for is_static_expr at ast.py:7898>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7898
--# expr-start 5810 '<FieldAccess for range at ast.py:7898>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7898
--# expr-start 5809 '<FieldAccess for range at ast.py:7898>' Fld /tmp/lal-23.0.0/ada/ast.py:7898
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Range_Spec (Node => Match_0.Node.Range_Constraint_F_Range, Info => Match_0.Info);
--# expr-done 5809
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Expr (Node => Fld.Node.Range_Spec_F_Range, Info => Fld.Info);
--# expr-done 5810
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_2 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_1.Info);
--# end
--# expr-done 5811
Let_Result_3 := Fld_2; 
--# end
Scope_Result_5 := Let_Result_3;
   --# end
            Match_Result_1 := Scope_Result_5; 
         when Ada_Composite_Constraint =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Composite_Constraint
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_1 := Cast_Result_5; 
--# bind cc Match_1
--# expr-start 5824 '<If at ast.py:7899>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:7899
--# expr-start 5812 '<FieldAccess for is_index_constraint at ast.py:7900>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7900
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompositeConstraint.is_index_constraint
Fld_14 := Libadalang.Implementation.Composite_Constraint_P_Is_Index_Constraint (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 5812
if Fld_14 then
   --# expr-start 5819 '<AllQuantifier at ast.py:7901>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:7901
   --# expr-start 5813 '<FieldAccess for constraints at ast.py:7901>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7901
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Assoc_List (Node => Match_1.Node.Composite_Constraint_F_Constraints, Info => Match_1.Info);
--# expr-done 5813
Fld_4 := Fld_3.Node;
      Quantifier_Result := True;
      if Fld_4 = null then
      null;
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_4;
      begin
         for Untyped_Item_205 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_205 := Untyped_Item_205; 
Is_Null := Bare_Item_205 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_5 := Fld_3.Info;
As_Entity := (Info => Fld_5, Node => Bare_Item_205); 
   If_Result := As_Entity;
end if;
                  Item_205 := If_Result; 
   --# scope-start
               --# bind c Item_205
      --# expr-start 5818 '<Match at ast.py:7903>' Match_Result /tmp/lal-23.0.0/ada/ast.py:7903
--# expr-start 5815 '<FieldAccess for constraint_expr at ast.py:7902>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7902
--# expr-start 5814 '<Cast to CompositeConstraintAssoc at ast.py:7902>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7902
Cast_Expr := Item_205; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Composite_Constraint_Assoc_Range
   then
      Cast_Result := Create_Internal_Entity_Composite_Constraint_Assoc
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Composite_Constraint_Assoc;
   end if;
--# expr-done 5814
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity (Node => Cast_Result.Node.Composite_Constraint_Assoc_F_Constraint_Expr, Info => Cast_Result.Info);
--# expr-done 5815
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_6; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0_1 := Cast_Result_1; 
--# bind st Match_0_1
--# expr-start 5816 '<FieldAccess for is_static_subtype at ast.py:7904>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7904
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.is_static_subtype
Fld_7 := Libadalang.Implementation.Subtype_Indication_P_Is_Static_Subtype (Node => Match_0_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_0_1.Info);
--# end
--# expr-done 5816
Let_Result := Fld_7; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1_1 := Cast_Result_2; 
--# bind e Match_1_1
--# expr-start 5817 '<FieldAccess for is_static_expr at ast.py:7905>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7905
      if Match_1_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_8 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Match_1_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_1_1.Info);
--# end
--# expr-done 5817
Let_Result_1 := Fld_8; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2_1 := Cast_Result_3; 
--# bind _ Match_2_1
Let_Result_2 := False; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 5818
      Quantifier_Result := Match_Result;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 5819
   If_Result_2 := Quantifier_Result;
else
   --# expr-start 5823 '<AllQuantifier at ast.py:7909>' Quantifier_Result_1 /tmp/lal-23.0.0/ada/ast.py:7909
   --# expr-start 5820 '<FieldAccess for constraints at ast.py:7909>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7909
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Assoc_List (Node => Match_1.Node.Composite_Constraint_F_Constraints, Info => Match_1.Info);
--# expr-done 5820
Fld_10 := Fld_9.Node;
      Quantifier_Result_1 := True;
      if Fld_10 = null then
      null;
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_10;
      begin
         for Untyped_Item_206 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_206 := Untyped_Item_206; 
Is_Null_1 := Bare_Item_206 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Assoc;
else
Fld_11 := Fld_9.Info;
As_Entity_1 := (Info => Fld_11, Node => Bare_Item_206); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_206 := If_Result_1; 
   --# scope-start
               --# bind c Item_206
      --# expr-start 5822 '<FieldAccess for is_static_expr at ast.py:7910>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7910
--# expr-start 5821 '<FieldAccess for expr at ast.py:7910>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7910
      if Item_206.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_12 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_206.Node, E_Info => Item_206.Info);
--# end
--# expr-done 5821
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_13 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_12.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_12.Info);
--# end
--# expr-done 5822
      Quantifier_Result_1 := Fld_13;
   --# end
               exit when not Quantifier_Result_1;
         end loop;
      end;
      end if;
--# expr-done 5823
   If_Result_2 := Quantifier_Result_1;
end if;
--# expr-done 5824
Let_Result_4 := If_Result_2; 
--# end
Scope_Result_6 := Let_Result_4;
   --# end
            Match_Result_1 := Scope_Result_6; 
         when Ada_Digits_Constraint =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Digits_Constraint
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_2 := Cast_Result_6; 
--# bind dc Match_2
--# expr-start 5825 '<FieldAccess for range at ast.py:7913>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:7913
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Range_Spec (Node => Match_2.Node.Digits_Constraint_F_Range, Info => Match_2.Info);
--# expr-done 5825
Var_Expr := Fld_15;
if Var_Expr /= No_Entity_Range_Spec then
   --# scope-start
   --# bind range Var_Expr
--# expr-start 5827 '<FieldAccess for is_static_expr at ast.py:7914>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7914
--# expr-start 5826 '<FieldAccess for range at ast.py:7914>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7914
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 5826
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_17 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_16.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_16.Info);
--# end
--# expr-done 5827
Scope_Result_3 := Fld_17;
   --# end
   Result_Var := Scope_Result_3;
else
   Result_Var := True;
end if;
Let_Result_5 := Result_Var; 
--# end
Scope_Result_7 := Let_Result_5;
   --# end
            Match_Result_1 := Scope_Result_7; 
         when Ada_Delta_Constraint =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Delta_Constraint
        (Node => Match_Prefix_1.Node,
         Info => Match_Prefix_1.Info);
Match_3 := Cast_Result_7; 
--# bind dc Match_3
--# expr-start 5828 '<FieldAccess for range at ast.py:7917>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7917
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Range_Spec (Node => Match_3.Node.Delta_Constraint_F_Range, Info => Match_3.Info);
--# expr-done 5828
Var_Expr_1 := Fld_18;
if Var_Expr_1 /= No_Entity_Range_Spec then
   --# scope-start
   --# bind range Var_Expr_1
--# expr-start 5830 '<FieldAccess for is_static_expr at ast.py:7918>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:7918
--# expr-start 5829 '<FieldAccess for range at ast.py:7918>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:7918
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Expr (Node => Var_Expr_1.Node.Range_Spec_F_Range, Info => Var_Expr_1.Info);
--# expr-done 5829
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_20 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_19.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_19.Info);
--# end
--# expr-done 5830
Scope_Result_4 := Fld_20;
   --# end
   Result_Var_1 := Scope_Result_4;
else
   Result_Var_1 := True;
end if;
Let_Result_6 := Result_Var_1; 
--# end
Scope_Result_8 := Let_Result_6;
   --# end
            Match_Result_1 := Scope_Result_8; 
end case;
--# expr-done 5831
Let_Result_7 := Match_Result_1; 
--# end
--# expr-done 5832
      Property_Result := Let_Result_7;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Constraint_P_Is_Static;
--# end
   --
   --  Primitives for Bare_Composite_Constraint
   --
      procedure Initialize_Fields_For_Composite_Constraint
        (Self : Bare_Composite_Constraint
         ; Composite_Constraint_F_Constraints : Bare_Assoc_List
        ) is
      begin
            Self.Composite_Constraint_F_Constraints := Composite_Constraint_F_Constraints;
      end Initialize_Fields_For_Composite_Constraint;
   function Composite_Constraint_F_Constraints
     (Node : Bare_Composite_Constraint) return Bare_Assoc_List
   is
   begin
         return Node.Composite_Constraint_F_Constraints;
   end;
--# property-start CompositeConstraint.is_index_constraint /tmp/lal-23.0.0/ada/ast.py:7981
pragma Warnings (Off, "is not referenced");
 function Composite_Constraint_P_Is_Index_Constraint
  (Node : Bare_Composite_Constraint
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Composite_Constraint := Bare_Composite_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Composite_Constraint :=
     Internal_Entity_Composite_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Boolean;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5840 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5834 '<FieldAccess for is_array_type at ast.py:7986>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7986
--# expr-start 5833 '<FieldAccess for subtype at ast.py:7986>' Fld /tmp/lal-23.0.0/ada/ast.py:7986
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.subtype
Fld := Libadalang.Implementation.Constraint_P_Subtype (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5833
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_array_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Is_Array_Type (Node => Fld.Node, Origin => No_Bare_Ada_Node, E_Info => Fld.Info);
--# end
--# expr-done 5834
if Fld_1 then
   If_Result_1 := True;
else
--# expr-start 5836 '<FieldAccess for is_access_type at ast.py:7987>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7987
--# expr-start 5835 '<FieldAccess for subtype at ast.py:7987>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7987
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.subtype
Fld_2 := Libadalang.Implementation.Constraint_P_Subtype (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5835
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Fld_2.Node, Origin => No_Bare_Ada_Node, E_Info => Fld_2.Info);
--# end
--# expr-done 5836
if Fld_3 then
   --# expr-start 5839 '<FieldAccess for is_array_type at ast.py:7988>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7988
--# expr-start 5838 '<FieldAccess for accessed_type at ast.py:7988>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7988
--# expr-start 5837 '<FieldAccess for subtype at ast.py:7988>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7988
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.subtype
Fld_4 := Libadalang.Implementation.Constraint_P_Subtype (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5837
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Fld_4.Node, Origin => No_Bare_Ada_Node, E_Info => Fld_4.Info);
--# end
--# expr-done 5838
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_array_type
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Is_Array_Type (Node => Fld_5.Node, Origin => No_Bare_Ada_Node, E_Info => Fld_5.Info);
--# end
--# expr-done 5839
   If_Result := Fld_6;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 5840
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Composite_Constraint_P_Is_Index_Constraint;
--# end
--# property-start CompositeConstraint.is_discriminant_constraint /tmp/lal-23.0.0/ada/ast.py:7992
pragma Warnings (Off, "is not referenced");
 function Composite_Constraint_P_Is_Discriminant_Constraint
  (Node : Bare_Composite_Constraint
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Composite_Constraint := Bare_Composite_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Composite_Constraint :=
     Internal_Entity_Composite_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5843 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5842 '<Not at ast.py:7996>' Not_Val /tmp/lal-23.0.0/ada/ast.py:7996
--# expr-start 5841 '<FieldAccess for is_index_constraint at ast.py:7996>' Fld /tmp/lal-23.0.0/ada/ast.py:7996
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompositeConstraint.is_index_constraint
Fld := Libadalang.Implementation.Composite_Constraint_P_Is_Index_Constraint (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5841
Not_Val := not (Fld); 
--# expr-done 5842
Let_Result := Not_Val; 
--# end
--# expr-done 5843
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Composite_Constraint_P_Is_Discriminant_Constraint;
--# end
--# property-start CompositeConstraint.xref_equation /tmp/lal-23.0.0/ada/ast.py:7999
pragma Warnings (Off, "is not referenced");
 function Composite_Constraint_P_Xref_Equation
  (Node : Bare_Composite_Constraint
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Composite_Constraint := Bare_Composite_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Composite_Constraint :=
     Internal_Entity_Composite_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_601 with Inline_Always;
            procedure Finalizer_Scope_2633 with Inline_Always;
            procedure Finalizer_Scope_2634 with Inline_Always;
            procedure Finalizer_Scope_2635 with Inline_Always;
            procedure Finalizer_Scope_2636 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Ex : Internal_Entity;
Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Bare_Base_Id;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Assoc_List;
Fld_2 : Bare_Assoc_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Cast_Expr : Internal_Entity_Basic_Assoc;
Cast_Result : Internal_Entity_Composite_Constraint_Assoc;
Fld_4 : Internal_Entity;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Expr;
Fld_5 : Logic_Var;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Fld_8 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
Item_207 : Internal_Entity_Basic_Assoc;
Bare_Item_207 : Bare_Basic_Assoc;
Index_208 : Integer;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_9 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_10 : Internal_Entity_Assoc_List;
Fld_11 : Internal_Param_Match_Array_Access;
Fld_12 : Internal_Single_Actual;
Fld_13 : Internal_Entity_Basic_Assoc;
Fld_14 : Internal_Entity_Expr;
Fld_15 : Logic_Var;
Fld_16 : Internal_Entity_Defining_Name;
Fld_17 : Internal_Entity_Base_Formal_Param_Decl;
Fld_18 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_19 : Internal_Single_Actual;
Fld_20 : Internal_Entity_Basic_Assoc;
Fld_21 : Internal_Entity_Expr;
Fld_22 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_23 : Internal_Single_Actual;
Fld_24 : Internal_Entity_Basic_Assoc;
Fld_25 : Internal_Entity_Expr;
Fld_26 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_27 : Internal_Single_Actual;
Fld_28 : Bare_Base_Id;
Fld_29 : Logic_Var;
Fld_30 : Internal_Entity_Defining_Name;
Fld_31 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
Fld_32 : Boolean;
If_Result_1 : Logic_Equation;
Let_Result_1 : Logic_Equation;
            procedure Finalizer_Scope_601 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_601;
            procedure Finalizer_Scope_2633 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_8);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_2633;
            procedure Finalizer_Scope_2634 is
            begin
                     Dec_Ref (Bind_Result);
            end Finalizer_Scope_2634;
            procedure Finalizer_Scope_2635 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_22);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_26);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_2635;
            procedure Finalizer_Scope_2636 is
            begin
                     Dec_Ref (Bind_Result_2);
            end Finalizer_Scope_2636;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5890 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 5844 '<FieldAccess for subtype at ast.py:8000>' Fld /tmp/lal-23.0.0/ada/ast.py:8000
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.subtype
Fld := Libadalang.Implementation.Constraint_P_Subtype (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5844
Block_Var := Fld; 
--# bind typ Block_Var
--# expr-start 5889 '<If at ast.py:8001>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:8001
--# expr-start 5845 '<FieldAccess for is_index_constraint at ast.py:8002>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:8002
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompositeConstraint.is_index_constraint
Fld_32 := Libadalang.Implementation.Composite_Constraint_P_Is_Index_Constraint (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5845
if Fld_32 then
   --# expr-start 5858 '<LogicAll at ast.py:8003>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8003
--# expr-start 5857 '<Map at ast.py:8003>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8003
   --# expr-start 5846 '<FieldAccess for constraints at ast.py:8003>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8003
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Composite_Constraint_F_Constraints, Info => Ent.Info);
--# expr-done 5846
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
         Index_208 := 0;
      declare
         Collection : constant Bare_Assoc_List := Fld_2;
      begin
         for Untyped_Item_207 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_207 := Untyped_Item_207; 
Is_Null := Bare_Item_207 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_207); 
   If_Result := As_Entity;
end if;
                  Item_207 := If_Result; 
   --# scope-start
               --# bind c Item_207
               --# bind i Index_208
      --# expr-start 5856 '<Let at ast.py:8003>' Let_Result /tmp/lal-23.0.0/ada/ast.py:8003
--# scope-start
--# expr-start 5848 '<FieldAccess for constraint_expr at ast.py:8004>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8004
--# expr-start 5847 '<Cast to CompositeConstraintAssoc at ast.py:8004>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8004
Cast_Expr := Item_207; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Composite_Constraint_Assoc_Range
   then
      Cast_Result := Create_Internal_Entity_Composite_Constraint_Assoc
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Composite_Constraint_Assoc;
   end if;
--# expr-done 5847
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity (Node => Cast_Result.Node.Composite_Constraint_Assoc_F_Constraint_Expr, Info => Cast_Result.Info);
--# expr-done 5848
Ex := Fld_4; 
--# bind ex Ex
--# expr-start 5855 '<And at ast.py:8024>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8024
--# expr-start 5849 '<Cast to Expr at ast.py:8024>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:8024
Cast_Expr_1 := Ex; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Expr
   then
      Cast_Result_1 := Create_Internal_Entity_Expr
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Expr;
   end if;
--# expr-done 5849
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 5853 '<Bind at ast.py:8026>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:8026
--# expr-start 5850 '<FieldAccess for expected_type_var at ast.py:8026>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8026
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 5850
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 5852 '<FieldAccess for base_subtype at ast.py:8026>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:8026
--# expr-start 5851 '<FieldAccess for index_type at ast.py:8026>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8026
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.index_type
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Index_Type (Node => Block_Var.Node, Dim => Index_208, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 5851
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_7 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Fld_6.Node, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 5852
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8026") else null)); 
--# expr-done 5853
Scope_Result := Bind_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2634;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8027") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
--# expr-start 5854 '<FieldAccess for sub_equation at ast.py:8028>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:8028
      if Ex.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_8 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Ex.Node, Env => Env, Origin => Origin, E_Info => Ex.Info);
--# end
--# expr-done 5854
And_Pred := Create_And (Result_Var, Fld_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8024") else null)); 
--# expr-done 5855
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5856
         declare
            Item_To_Append : constant Logic_Equation := Let_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2633;
               Index_208 := Index_208 + 1;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5857
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8003") else null)); 
--# expr-done 5858
   If_Result_1 := Logic_Boolean_Op;
else
   --# expr-start 5888 '<LogicAll at ast.py:8034>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:8034
--# expr-start 5887 '<Map at ast.py:8034>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:8034
   --# expr-start 5861 '<FieldAccess for match_formals at ast.py:8032>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:8032
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 5859 '<FieldAccess for discriminants_list at ast.py:8033>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:8033
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 5859
--# expr-start 5860 '<FieldAccess for constraints at ast.py:8033>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:8033
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Composite_Constraint_F_Constraints, Info => Ent.Info);
--# expr-done 5860
--# property-call-start AdaNode.match_formals
Fld_11 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Fld_9, Params => Fld_10, Is_Dottable_Subp => False);
--# end
--# expr-done 5861
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_11;
      begin
         for Item_209 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_209
      --# expr-start 5886 '<And at ast.py:8036>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5879 '<And at ast.py:8036>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5874 '<And at ast.py:8036>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5869 '<Bind at ast.py:8036>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5865 '<FieldAccess for expected_type_var at ast.py:8036>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5864 '<FieldAccess for expr at ast.py:8036>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5863 '<FieldAccess for assoc at ast.py:8036>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:8036
--# expr-start 5862 '<FieldAccess for actual at ast.py:8036>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:8036
Fld_12 := Item_209.Actual;
--# expr-done 5862
Fld_13 := Fld_12.Assoc;
--# expr-done 5863
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_14 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_13.Node, E_Info => Fld_13.Info);
--# end
--# expr-done 5864
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_14.Node);
--# expr-done 5865
Fld_15.Value := No_Entity;
Entity_Vars.Reset (Fld_15);
--# expr-start 5868 '<FieldAccess for formal_type at ast.py:8037>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:8037
--# expr-start 5867 '<FieldAccess for formal_decl at ast.py:8037>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:8037
--# expr-start 5866 '<FieldAccess for formal at ast.py:8037>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:8037
Fld_16 := Item_209.Formal;
--# expr-done 5866
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_17 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_16.Node, E_Info => Fld_16.Info);
--# end
--# expr-done 5867
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_18 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_17.Node, Origin => Origin, E_Info => Fld_17.Info);
--# end
--# expr-done 5868
      Cast_Result_3 := Create_Internal_Entity
        (Node => Fld_18.Node,
         Info => Fld_18.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_15, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8036") else null)); 
--# expr-done 5869
--# expr-start 5873 '<FieldAccess for sub_equation at ast.py:8038>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:8038
--# expr-start 5872 '<FieldAccess for expr at ast.py:8038>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:8038
--# expr-start 5871 '<FieldAccess for assoc at ast.py:8038>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:8038
--# expr-start 5870 '<FieldAccess for actual at ast.py:8038>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:8038
Fld_19 := Item_209.Actual;
--# expr-done 5870
Fld_20 := Fld_19.Assoc;
--# expr-done 5871
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_21 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_20.Node, E_Info => Fld_20.Info);
--# end
--# expr-done 5872
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_22 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_21.Node, Env => Env, Origin => Origin, E_Info => Fld_21.Info);
--# end
--# expr-done 5873
And_Pred_1 := Create_And (Bind_Result_1, Fld_22, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8036") else null)); 
--# expr-done 5874
--# expr-start 5878 '<FieldAccess for matches_expected_formal_type at ast.py:8039>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:8039
--# expr-start 5877 '<FieldAccess for expr at ast.py:8039>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:8039
--# expr-start 5876 '<FieldAccess for assoc at ast.py:8039>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:8039
--# expr-start 5875 '<FieldAccess for actual at ast.py:8039>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:8039
Fld_23 := Item_209.Actual;
--# expr-done 5875
Fld_24 := Fld_23.Assoc;
--# expr-done 5876
      if Fld_24.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_25 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_24.Node, E_Info => Fld_24.Info);
--# end
--# expr-done 5877
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_26 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_25.Node, Origin => Origin);
--# end
--# expr-done 5878
And_Pred_2 := Create_And (And_Pred_1, Fld_26, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8036") else null)); 
--# expr-done 5879
--# expr-start 5881 '<FieldAccess for name at ast.py:8040>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:8040
--# expr-start 5880 '<FieldAccess for actual at ast.py:8040>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:8040
Fld_27 := Item_209.Actual;
--# expr-done 5880
Fld_28 := Fld_27.Name;
--# expr-done 5881
Var_Expr_1 := Fld_28;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind name Var_Expr_1
--# expr-start 5885 '<Bind at ast.py:8041>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:8041
--# expr-start 5882 '<FieldAccess for ref_var at ast.py:8041>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:8041
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_29 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Var_Expr_1);
--# end
--# expr-done 5882
Fld_29.Value := No_Entity;
Entity_Vars.Reset (Fld_29);
--# expr-start 5884 '<FieldAccess for formal_decl at ast.py:8041>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:8041
--# expr-start 5883 '<FieldAccess for formal at ast.py:8041>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:8041
Fld_30 := Item_209.Formal;
--# expr-done 5883
      if Fld_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_31 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_30.Node, E_Info => Fld_30.Info);
--# end
--# expr-done 5884
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_31.Node,
         Info => Fld_31.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_29, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8041") else null)); 
--# expr-done 5885
Scope_Result_1 := Bind_Result_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2636;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8042") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_3 := Create_And (And_Pred_2, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8036") else null)); 
--# expr-done 5886
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2635;
         end loop;
      end;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 5887
Logic_Boolean_Op_1 := Solver.Create_All (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8034") else null)); 
--# expr-done 5888
   If_Result_1 := Logic_Boolean_Op_1;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 5889
Let_Result_1 := If_Result_1; Inc_Ref (Let_Result_1);
--# end
--# expr-done 5890
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_601;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_601;
               Finalizer_Scope_2633;
               Finalizer_Scope_2634;
               Finalizer_Scope_2635;
               Finalizer_Scope_2636;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Composite_Constraint_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Delta_Constraint
   --
      procedure Initialize_Fields_For_Delta_Constraint
        (Self : Bare_Delta_Constraint
         ; Delta_Constraint_F_Digits : Bare_Expr
         ; Delta_Constraint_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Delta_Constraint_F_Digits := Delta_Constraint_F_Digits;
            Self.Delta_Constraint_F_Range := Delta_Constraint_F_Range;
      end Initialize_Fields_For_Delta_Constraint;
   function Delta_Constraint_F_Digits
     (Node : Bare_Delta_Constraint) return Bare_Expr
   is
   begin
         return Node.Delta_Constraint_F_Digits;
   end;
   function Delta_Constraint_F_Range
     (Node : Bare_Delta_Constraint) return Bare_Range_Spec
   is
   begin
         return Node.Delta_Constraint_F_Range;
   end;
--# property-start DeltaConstraint.xref_equation /tmp/lal-23.0.0/ada/ast.py:7962
pragma Warnings (Off, "is not referenced");
 function Delta_Constraint_P_Xref_Equation
  (Node : Bare_Delta_Constraint
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Delta_Constraint := Bare_Delta_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Delta_Constraint :=
     Internal_Entity_Delta_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_598 with Inline_Always;
            procedure Finalizer_Scope_2637 with Inline_Always;
      Var_Expr : Internal_Entity_Range_Spec;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Range_Spec;
Fld_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
            procedure Finalizer_Scope_598 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_598;
            procedure Finalizer_Scope_2637 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2637;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5895 '<And at ast.py:7963>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7963
--# expr-start 5892 '<FieldAccess for sub_equation at ast.py:7963>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7963
--# expr-start 5891 '<FieldAccess for digits at ast.py:7963>' Fld /tmp/lal-23.0.0/ada/ast.py:7963
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Delta_Constraint_F_Digits, Info => Ent.Info);
--# expr-done 5891
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 5892
--# expr-start 5893 '<FieldAccess for range at ast.py:7963>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7963
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Delta_Constraint_F_Range, Info => Ent.Info);
--# expr-done 5893
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Range_Spec then
   --# scope-start
   --# bind range Var_Expr
--# expr-start 5894 '<FieldAccess for sub_equation at ast.py:7964>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7964
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 5894
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2637;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7965") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7963") else null)); 
--# expr-done 5895
      Property_Result := And_Pred;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_598;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_598;
               Finalizer_Scope_2637;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Delta_Constraint_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Digits_Constraint
   --
      procedure Initialize_Fields_For_Digits_Constraint
        (Self : Bare_Digits_Constraint
         ; Digits_Constraint_F_Digits : Bare_Expr
         ; Digits_Constraint_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Digits_Constraint_F_Digits := Digits_Constraint_F_Digits;
            Self.Digits_Constraint_F_Range := Digits_Constraint_F_Range;
      end Initialize_Fields_For_Digits_Constraint;
   function Digits_Constraint_F_Digits
     (Node : Bare_Digits_Constraint) return Bare_Expr
   is
   begin
         return Node.Digits_Constraint_F_Digits;
   end;
   function Digits_Constraint_F_Range
     (Node : Bare_Digits_Constraint) return Bare_Range_Spec
   is
   begin
         return Node.Digits_Constraint_F_Range;
   end;
--# property-start DigitsConstraint.xref_equation /tmp/lal-23.0.0/ada/ast.py:7947
pragma Warnings (Off, "is not referenced");
 function Digits_Constraint_P_Xref_Equation
  (Node : Bare_Digits_Constraint
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Digits_Constraint := Bare_Digits_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Digits_Constraint :=
     Internal_Entity_Digits_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_597 with Inline_Always;
            procedure Finalizer_Scope_2638 with Inline_Always;
      Var_Expr : Internal_Entity_Range_Spec;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Range_Spec;
Fld_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
            procedure Finalizer_Scope_597 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_597;
            procedure Finalizer_Scope_2638 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2638;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5900 '<And at ast.py:7948>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7948
--# expr-start 5897 '<FieldAccess for sub_equation at ast.py:7948>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7948
--# expr-start 5896 '<FieldAccess for digits at ast.py:7948>' Fld /tmp/lal-23.0.0/ada/ast.py:7948
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Digits_Constraint_F_Digits, Info => Ent.Info);
--# expr-done 5896
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 5897
--# expr-start 5898 '<FieldAccess for range at ast.py:7948>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7948
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Digits_Constraint_F_Range, Info => Ent.Info);
--# expr-done 5898
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Range_Spec then
   --# scope-start
   --# bind range Var_Expr
--# expr-start 5899 '<FieldAccess for sub_equation at ast.py:7949>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7949
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 5899
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2638;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7950") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7948") else null)); 
--# expr-done 5900
      Property_Result := And_Pred;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_597;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_597;
               Finalizer_Scope_2638;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Digits_Constraint_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Range_Constraint
   --
      procedure Initialize_Fields_For_Range_Constraint
        (Self : Bare_Range_Constraint
         ; Range_Constraint_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Range_Constraint_F_Range := Range_Constraint_F_Range;
      end Initialize_Fields_For_Range_Constraint;
   function Range_Constraint_F_Range
     (Node : Bare_Range_Constraint) return Bare_Range_Spec
   is
   begin
         return Node.Range_Constraint_F_Range;
   end;
--# property-start RangeConstraint.xref_equation /tmp/lal-23.0.0/ada/ast.py:7931
pragma Warnings (Off, "is not referenced");
 function Range_Constraint_P_Xref_Equation
  (Node : Bare_Range_Constraint
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Range_Constraint := Bare_Range_Constraint (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Range_Constraint :=
     Internal_Entity_Range_Constraint'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_596 with Inline_Always;
      Fld : Bare_Range_Spec;
Fld_1 : Bare_Expr;
Fld_2 : Logic_Var;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Internal_Entity_Range_Spec;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Internal_Entity_Range_Spec;
Fld_8 : Internal_Entity_Expr;
Fld_9 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_596 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_596;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5914 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5913 '<And at ast.py:7932>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:7932
--# expr-start 5909 '<And at ast.py:7932>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7932
--# expr-start 5906 '<Bind at ast.py:7933>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:7933
--# expr-start 5903 '<FieldAccess for expected_type_var at ast.py:7933>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7933
--# expr-start 5902 '<FieldAccess for range at ast.py:7933>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7933
--# expr-start 5901 '<FieldAccess for range at ast.py:7933>' Fld /tmp/lal-23.0.0/ada/ast.py:7933
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Range_Constraint_F_Range;
--# expr-done 5901
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Range_Spec_F_Range;
--# expr-done 5902
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_1);
--# expr-done 5903
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 5905 '<FieldAccess for base_subtype at ast.py:7934>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7934
--# expr-start 5904 '<FieldAccess for subtype at ast.py:7934>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7934
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.subtype
Fld_3 := Libadalang.Implementation.Constraint_P_Subtype (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5904
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_4 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Fld_3.Node, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 5905
      Cast_Result := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Bind_Result := Solver.Create_Assign (Fld_2, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7933") else null)); 
--# expr-done 5906
--# expr-start 5908 '<FieldAccess for sub_equation at ast.py:7935>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7935
--# expr-start 5907 '<FieldAccess for range at ast.py:7935>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7935
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Range_Constraint_F_Range, Info => Ent.Info);
--# expr-done 5907
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_6 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_5.Node, Env => Env, Origin => Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 5908
And_Pred := Create_And (Bind_Result, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7932") else null)); 
--# expr-done 5909
--# expr-start 5912 '<FieldAccess for matches_expected_type at ast.py:7936>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7936
--# expr-start 5911 '<FieldAccess for range at ast.py:7936>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7936
--# expr-start 5910 '<FieldAccess for range at ast.py:7936>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7936
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Range_Constraint_F_Range, Info => Ent.Info);
--# expr-done 5910
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Fld_7.Node.Range_Spec_F_Range, Info => Fld_7.Info);
--# expr-done 5911
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_9 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_8.Node, Origin => Origin);
--# end
--# expr-done 5912
And_Pred_1 := Create_And (And_Pred, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7932") else null)); 
--# expr-done 5913
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5914
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_596;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_596;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Range_Constraint_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Declarative_Part
   --
      procedure Initialize_Fields_For_Declarative_Part
        (Self : Bare_Declarative_Part
         ; Declarative_Part_F_Decls : Bare_Ada_Node_List
        ) is
      begin
            Self.Declarative_Part_F_Decls := Declarative_Part_F_Decls;
      end Initialize_Fields_For_Declarative_Part;
   function Declarative_Part_F_Decls
     (Node : Bare_Declarative_Part) return Bare_Ada_Node_List
   is
   begin
         return Node.Declarative_Part_F_Decls;
   end;
--# property-start DeclarativePart.use_clauses_envs /tmp/lal-23.0.0/ada/ast.py:10406
pragma Warnings (Off, "is not referenced");
 function Declarative_Part_P_Use_Clauses_Envs
  (Node : Bare_Declarative_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Declarative_Part := Bare_Declarative_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Declarative_Part :=
     Internal_Entity_Declarative_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_834 with Inline_Always;
            procedure Finalizer_Scope_2502 with Inline_Always;
      Fld : Internal_Entity_Ada_Node_List;
Fld_1 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Use_Clause;
Fld_2 : Lexical_Env := Empty_Env;
Is_A : Boolean;
Map_Result : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_834 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_834;
            procedure Finalizer_Scope_2502 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2502;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5922 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5921 '<env_group at ast.py:10414>' Group_Env /tmp/lal-23.0.0/ada/ast.py:10414
--# expr-start 5920 '<FilterMap at ast.py:10411>' Map_Result /tmp/lal-23.0.0/ada/ast.py:10411
   --# expr-start 5916 '<children at ast.py:10411>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10411
--# expr-start 5915 '<FieldAccess for decls at ast.py:10411>' Fld /tmp/lal-23.0.0/ada/ast.py:10411
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Ada_Node_List (Node => Ent.Node.Declarative_Part_F_Decls, Info => Ent.Info);
--# expr-done 5915
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 5916
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_1;
      begin
         for Item_210 of
               Collection.Items
         loop
   --# scope-start
               --# bind u Item_210
         --# expr-start 5917 '<IsA UseClause at ast.py:10413>' Is_A /tmp/lal-23.0.0/ada/ast.py:10413
Is_A := Item_210.Node /= null 
and then Item_210.Node.Kind in Ada_Use_Clause; 
--# expr-done 5917
         if Is_A then
      --# expr-start 5919 '<FieldAccess for used_envs at ast.py:10412>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:10412
--# expr-start 5918 '<Cast to UseClause at ast.py:10412>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10412
Cast_Expr := Item_210; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Use_Clause
   then
      Cast_Result := Create_Internal_Entity_Use_Clause
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Use_Clause;
   end if;
--# expr-done 5918
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UseClause.used_envs
Fld_2 := Libadalang.Implementation.Use_Clause_P_Used_Envs (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 5919
         declare
            Item_To_Append : constant Lexical_Env := Fld_2;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
      Finalizer_Scope_2502;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 5920
Group_Env := Group (Map_Result, No_Metadata); 
--# expr-done 5921
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
--# expr-done 5922
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_834;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_834;
               Finalizer_Scope_2502;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Declarative_Part_P_Use_Clauses_Envs;
--# end
   --
   --  Primitives for Bare_Private_Part
   --
      procedure Private_Part_Pre_Env_Actions
        (Self            : Bare_Private_Part;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_45 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:10441");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_46 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            Libadalang.Implementation.Env_Names_47 (Node => 
Self);
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Private_Part
        (Self : Bare_Private_Part
         ; Declarative_Part_F_Decls : Bare_Ada_Node_List
        ) is
      begin
            Initialize_Fields_For_Declarative_Part
              (Self, Declarative_Part_F_Decls);
      end Initialize_Fields_For_Private_Part;
--# property-start PrivatePart.env_names /tmp/lal-23.0.0/ada/ast.py:10422
pragma Warnings (Off, "is not referenced");
 function Private_Part_P_Env_Names
  (Node : Bare_Private_Part
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Private_Part := Bare_Private_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_835 with Inline_Always;
            procedure Finalizer_Scope_2639 with Inline_Always;
            procedure Finalizer_Scope_2640 with Inline_Always;
      Var_Expr : Bare_Base_Package_Decl;
Var_Expr_1 : String_Type;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Base_Package_Decl;
Fld_1 : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Sym : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Scope_Result : Symbol_Type_Array_Access;
Result_Var : Symbol_Type_Array_Access;
Scope_Result_1 : Symbol_Type_Array_Access;
Result_Var_1 : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_835 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_835;
            procedure Finalizer_Scope_2639 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2639;
            procedure Finalizer_Scope_2640 is
            begin
                     Dec_Ref (Var_Expr_1);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Array_Lit);
            end Finalizer_Scope_2640;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5930 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5924 '<Cast to BasePackageDecl at ast.py:10428>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:10428
--# expr-start 5923 '<parent at ast.py:10428>' Fld /tmp/lal-23.0.0/ada/ast.py:10428
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5923
   if Fld = null
      or else Fld.Kind in Ada_Base_Package_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5924
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind pkg Var_Expr
--# expr-start 5925 '<FieldAccess for top_level_env_name at ast.py:10429>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10429
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.top_level_env_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Top_Level_Env_Name (Node => Var_Expr);
--# end
--# expr-done 5925
Var_Expr_1 := Fld_1;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= Empty_String then
   --# scope-start
   --# bind name Var_Expr_1
--# expr-start 5929 '<ArrayLiteral at ast.py:10430>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:10430
--# expr-start 5928 '<to_symbol at ast.py:10431>' Sym /tmp/lal-23.0.0/ada/ast.py:10431
--# expr-start 5927 '<Concat at ast.py:10431>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:10431
--# expr-start 5926 '<String at ast.py:10431>' Str /tmp/lal-23.0.0/ada/ast.py:10431
Str := Create_String (".__privatepart"); 
--# expr-done 5926
Concat_Result := Concat_String (Var_Expr_1, Str); 
--# expr-done 5927
Sym := String_To_Symbol (Self, Self.Unit.Context, Concat_Result); 
--# expr-done 5928
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym)); 
--# expr-done 5929
Scope_Result := Array_Lit;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2640;
   Result_Var := Scope_Result;
else
   Result_Var := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var);
Scope_Result_1 := Result_Var;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2639;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Symbol_Type_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5930
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_835;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_835;
               Finalizer_Scope_2639;
               Finalizer_Scope_2640;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Part_P_Env_Names;
--# end
--# property-start PrivatePart.immediate_declarative_region /tmp/lal-23.0.0/ada/ast.py:10437
pragma Warnings (Off, "is not referenced");
 function Private_Part_P_Immediate_Declarative_Region
  (Node : Bare_Private_Part
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Private_Part := Bare_Private_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Private_Part :=
     Internal_Entity_Private_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_836 with Inline_Always;
      Fld : Internal_Entity;
Fld_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_836 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_836;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5933 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5932 '<FieldAccess for immediate_declarative_region at ast.py:10438>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:10438
--# expr-start 5931 '<FieldAccess for semantic_parent at ast.py:10438>' Fld /tmp/lal-23.0.0/ada/ast.py:10438
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5931
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.immediate_declarative_region'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Immediate_Declarative_Region (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 5932
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5933
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_836;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_836;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Part_P_Immediate_Declarative_Region;
--# end
--# property-start PrivatePart._env_mappings_45 /tmp/lal-23.0.0/ada/ast.py:10441
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_45
  (Node : Bare_Private_Part
  )
   return Internal_Env_Assoc
is
   Self : Bare_Private_Part := Bare_Private_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1514 with Inline_Always;
      Sym : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Expr : Bare_Private_Part;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1514 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1514;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5936 '<New EnvAssoc at ast.py:10441>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:10441
--# expr-start 5934 '<New DesignatedEnv at ast.py:10441>' New_Struct /tmp/lal-23.0.0/ada/ast.py:10441
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 5934
--# expr-start 5935 '<Symbol __privatepart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Privatepart); 
--# expr-done 5935
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Sym, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 5936
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1514;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1514;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_45;
--# end
--# property-start PrivatePart._env_trans_parent_46 /tmp/lal-23.0.0/ada/ast.py:10440
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_46
  (Node : Bare_Private_Part
  )
   return Boolean
is
   Self : Bare_Private_Part := Bare_Private_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_46;
--# end
--# property-start PrivatePart._env_names_47 /tmp/lal-23.0.0/ada/ast.py:10442
pragma Warnings (Off, "is not referenced");
 function Env_Names_47
  (Node : Bare_Private_Part
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Private_Part := Bare_Private_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1516 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1516 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1516;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5937 '<FieldAccess for env_names at ast.py:10442>' Fld /tmp/lal-23.0.0/ada/ast.py:10442
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start PrivatePart.env_names
Fld := Libadalang.Implementation.Private_Part_P_Env_Names (Node => Self);
--# end
--# expr-done 5937
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1516;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1516;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Names_47;
--# end
   --
   --  Primitives for Bare_Public_Part
   --
      procedure Initialize_Fields_For_Public_Part
        (Self : Bare_Public_Part
         ; Declarative_Part_F_Decls : Bare_Ada_Node_List
        ) is
      begin
            Initialize_Fields_For_Declarative_Part
              (Self, Declarative_Part_F_Decls);
      end Initialize_Fields_For_Public_Part;
   --
   --  Primitives for Bare_Elsif_Expr_Part
   --
      procedure Initialize_Fields_For_Elsif_Expr_Part
        (Self : Bare_Elsif_Expr_Part
         ; Elsif_Expr_Part_F_Cond_Expr : Bare_Expr
         ; Elsif_Expr_Part_F_Then_Expr : Bare_Expr
        ) is
      begin
            Self.Elsif_Expr_Part_F_Cond_Expr := Elsif_Expr_Part_F_Cond_Expr;
            Self.Elsif_Expr_Part_F_Then_Expr := Elsif_Expr_Part_F_Then_Expr;
      end Initialize_Fields_For_Elsif_Expr_Part;
   function Elsif_Expr_Part_F_Cond_Expr
     (Node : Bare_Elsif_Expr_Part) return Bare_Expr
   is
   begin
         return Node.Elsif_Expr_Part_F_Cond_Expr;
   end;
   function Elsif_Expr_Part_F_Then_Expr
     (Node : Bare_Elsif_Expr_Part) return Bare_Expr
   is
   begin
         return Node.Elsif_Expr_Part_F_Then_Expr;
   end;
   --
   --  Primitives for Bare_Elsif_Stmt_Part
   --
      procedure Initialize_Fields_For_Elsif_Stmt_Part
        (Self : Bare_Elsif_Stmt_Part
         ; Elsif_Stmt_Part_F_Cond_Expr : Bare_Expr
         ; Elsif_Stmt_Part_F_Stmts : Bare_Stmt_List
        ) is
      begin
            Self.Elsif_Stmt_Part_F_Cond_Expr := Elsif_Stmt_Part_F_Cond_Expr;
            Self.Elsif_Stmt_Part_F_Stmts := Elsif_Stmt_Part_F_Stmts;
      end Initialize_Fields_For_Elsif_Stmt_Part;
   function Elsif_Stmt_Part_F_Cond_Expr
     (Node : Bare_Elsif_Stmt_Part) return Bare_Expr
   is
   begin
         return Node.Elsif_Stmt_Part_F_Cond_Expr;
   end;
   function Elsif_Stmt_Part_F_Stmts
     (Node : Bare_Elsif_Stmt_Part) return Bare_Stmt_List
   is
   begin
         return Node.Elsif_Stmt_Part_F_Stmts;
   end;
--# property-start ElsifStmtPart.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:19929
pragma Warnings (Off, "is not referenced");
 function Elsif_Stmt_Part_P_Xref_Entry_Point
  (Node : Bare_Elsif_Stmt_Part
  )
   return Boolean
is
   Self : Bare_Elsif_Stmt_Part := Bare_Elsif_Stmt_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Elsif_Stmt_Part_P_Xref_Entry_Point;
--# end
--# property-start ElsifStmtPart.xref_equation /tmp/lal-23.0.0/ada/ast.py:19932
pragma Warnings (Off, "is not referenced");
 function Elsif_Stmt_Part_P_Xref_Equation
  (Node : Bare_Elsif_Stmt_Part
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Elsif_Stmt_Part := Bare_Elsif_Stmt_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Elsif_Stmt_Part :=
     Internal_Entity_Elsif_Stmt_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1405 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Bare_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1405 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1405;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5948 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5947 '<And at ast.py:19934>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19934
--# expr-start 5944 '<And at ast.py:19934>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19934
--# expr-start 5941 '<Bind at ast.py:19934>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19934
--# expr-start 5939 '<FieldAccess for expected_type_var at ast.py:19934>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19934
--# expr-start 5938 '<FieldAccess for cond_expr at ast.py:19934>' Fld /tmp/lal-23.0.0/ada/ast.py:19934
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Elsif_Stmt_Part_F_Cond_Expr;
--# expr-done 5938
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 5939
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 5940 '<FieldAccess for bool_type at ast.py:19934>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19934
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 5940
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19934") else null)); 
--# expr-done 5941
--# expr-start 5943 '<FieldAccess for sub_equation at ast.py:19935>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19935
--# expr-start 5942 '<FieldAccess for cond_expr at ast.py:19935>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19935
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Elsif_Stmt_Part_F_Cond_Expr, Info => Ent.Info);
--# expr-done 5942
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 5943
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19934") else null)); 
--# expr-done 5944
--# expr-start 5946 '<FieldAccess for matches_expected_formal_prim_type at ast.py:19936>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19936
--# expr-start 5945 '<FieldAccess for cond_expr at ast.py:19936>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19936
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Elsif_Stmt_Part_F_Cond_Expr;
--# expr-done 5945
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_5, Origin => Origin);
--# end
--# expr-done 5946
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19934") else null)); 
--# expr-done 5947
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 5948
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1405;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1405;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Elsif_Stmt_Part_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Expr
   --
      procedure Initialize_Fields_For_Expr
        (Self : Bare_Expr
        ) is
      begin
      Self.Expr_Logic_Vars := System.Null_Address;
      end Initialize_Fields_For_Expr;
--# property-start Expr.type_val /tmp/lal-23.0.0/ada/ast.py:11578
pragma Warnings (Off, "is not referenced");
 function Expr_P_Type_Val
  (Node : Bare_Expr
  )
   return Internal_Entity
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity;
      Fld : Logic_Var;
Is_Logic_Var_Defined : Boolean;
Eq_Solution : Internal_Entity;
If_Result : Internal_Entity;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 5950 '<get_value at ast.py:11578>' If_Result /tmp/lal-23.0.0/ada/ast.py:11578
--# expr-start 5949 '<FieldAccess for type_var at ast.py:11578>' Fld /tmp/lal-23.0.0/ada/ast.py:11578
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5949
Is_Logic_Var_Defined := Entity_Vars.Is_Defined (Fld); 
if Is_Logic_Var_Defined then
Eq_Solution := Entity_Vars.Get_Value (Fld); 
   If_Result := Eq_Solution;
else
   If_Result := No_Entity;
end if;
--# expr-done 5950
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Type_Val;
--# end
--# property-start Expr.expression_type /tmp/lal-23.0.0/ada/ast.py:11580
pragma Warnings (Off, "is not referenced");
 function Expr_P_Expression_Type
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity;
Fld : Logic_Var;
Fld_1 : Internal_Logic_Val_Result;
Fld_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5954 '<Cast to BaseTypeDecl at ast.py:11582>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:11582
--# expr-start 5953 '<FieldAccess for value at ast.py:11582>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11582
--# expr-start 5952 '<FieldAccess for logic_val at ast.py:11581>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11581
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 5951 '<FieldAccess for type_var at ast.py:11581>' Fld /tmp/lal-23.0.0/ada/ast.py:11581
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5951
--# property-call-start AdaNode.logic_val
Fld_1 := Libadalang.Implementation.Ada_Node_P_Logic_Val (Node => Self, From_Node => Cast_Result, Lvar => Fld);
--# end
--# expr-done 5952
Fld_2 := Fld_1.Value;
--# expr-done 5953
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5954
      Property_Result := Cast_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Expression_Type;
--# end
--# property-start Expr.expected_expression_type /tmp/lal-23.0.0/ada/ast.py:11590
pragma Warnings (Off, "is not referenced");
 function Expr_P_Expected_Expression_Type
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity;
Fld : Logic_Var;
Fld_1 : Internal_Logic_Val_Result;
Fld_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5958 '<Cast to BaseTypeDecl at ast.py:11592>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:11592
--# expr-start 5957 '<FieldAccess for value at ast.py:11592>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11592
--# expr-start 5956 '<FieldAccess for logic_val at ast.py:11591>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11591
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 5955 '<FieldAccess for expected_type_var at ast.py:11591>' Fld /tmp/lal-23.0.0/ada/ast.py:11591
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 5955
--# property-call-start AdaNode.logic_val
Fld_1 := Libadalang.Implementation.Ada_Node_P_Logic_Val (Node => Self, From_Node => Cast_Result, Lvar => Fld);
--# end
--# expr-done 5956
Fld_2 := Fld_1.Value;
--# expr-done 5957
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 5958
      Property_Result := Cast_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Expected_Expression_Type;
--# end
--# property-start Expr.xref_stop_resolution /tmp/lal-23.0.0/ada/ast.py:11600
pragma Warnings (Off, "is not referenced");
 function Expr_P_Xref_Stop_Resolution
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_For_Loop_Spec;
Fld : Bare_Ada_Node;
Cast_Result : Bare_For_Loop_Spec;
Fld_1 : Bare_Expr;
Cast_Result_1 : Bare_Expr;
Is_Equal : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 5960 '<Cast to ForLoopSpec at ast.py:11605>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11605
--# expr-start 5959 '<parent at ast.py:11605>' Fld /tmp/lal-23.0.0/ada/ast.py:11605
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 5959
   if Fld = null
      or else Fld.Kind in Ada_For_Loop_Spec_Range
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 5960
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind spec Var_Expr
--# expr-start 5962 '<Eq at ast.py:11606>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:11606
--# expr-start 5961 '<FieldAccess for iter_filter at ast.py:11606>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11606
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr.For_Loop_Spec_F_Iter_Filter;
--# expr-done 5961
      Cast_Result_1 := Fld_1;
Is_Equal := Cast_Result_1 = Self; 
--# expr-done 5962
Scope_Result := Is_Equal;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      Property_Result := Result_Var;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Xref_Stop_Resolution;
--# end
--# property-start '[dispatcher]Expr.has_context_free_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_Has_Context_Free_Type
  (Node : Bare_Expr
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr | Ada_Box_Expr .. Ada_Case_Expr_Alternative | Ada_Contract_Cases | Ada_Membership_Expr | Ada_Call_Expr .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Reduce_Attribute_Ref | Ada_Identifier .. Ada_Op_Xor | Ada_Int_Literal .. Ada_Update_Attribute_Ref | Ada_Quantified_Expr =>
                  --# property-call-start Expr.has_context_free_type
                  Property_Result := Expr_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Allocator =>
                  --# property-call-start Allocator.has_context_free_type
                  Property_Result := Allocator_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Aggregate .. Ada_Null_Record_Aggregate =>
                  --# property-call-start BaseAggregate.has_context_free_type
                  Property_Result := Base_Aggregate_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Bin_Op =>
                  --# property-call-start BinOp.has_context_free_type
                  Property_Result := Bin_Op_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Relation_Op =>
                  --# property-call-start RelationOp.has_context_free_type
                  Property_Result := Relation_Op_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Concat_Op =>
                  --# property-call-start ConcatOp.has_context_free_type
                  Property_Result := Concat_Op_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Concat_Operand =>
                  --# property-call-start ConcatOperand.has_context_free_type
                  Property_Result := Concat_Operand_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Case_Expr =>
                  --# property-call-start CaseExpr.has_context_free_type
                  Property_Result := Case_Expr_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_If_Expr =>
                  --# property-call-start IfExpr.has_context_free_type
                  Property_Result := If_Expr_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Decl_Expr =>
                  --# property-call-start DeclExpr.has_context_free_type
                  Property_Result := Decl_Expr_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.has_context_free_type
                  Property_Result := Attribute_Ref_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.has_context_free_type
                  Property_Result := Dotted_Name_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Char_Literal =>
                  --# property-call-start CharLiteral.has_context_free_type
                  Property_Result := Char_Literal_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_String_Literal =>
                  --# property-call-start StringLiteral.has_context_free_type
                  Property_Result := String_Literal_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Null_Literal =>
                  --# property-call-start NullLiteral.has_context_free_type
                  Property_Result := Null_Literal_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Paren_Expr =>
                  --# property-call-start ParenExpr.has_context_free_type
                  Property_Result := Paren_Expr_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Raise_Expr =>
                  --# property-call-start RaiseExpr.has_context_free_type
                  Property_Result := Raise_Expr_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
               when Ada_Un_Op =>
                  --# property-call-start UnOp.has_context_free_type
                  Property_Result := Un_Op_P_Has_Context_Free_Type
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_Has_Context_Free_Type;
--# end
--# property-start Expr.matches_expected_type /tmp/lal-23.0.0/ada/ast.py:11626
pragma Warnings (Off, "is not referenced");
 function Expr_P_Matches_Expected_Type
  (Node : Bare_Expr
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_920 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_920 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_920;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5966 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5965 '<Predicate on BaseTypeDecl.matching_type at ast.py:11627>' Pred /tmp/lal-23.0.0/ada/ast.py:11627
--# expr-start 5963 '<FieldAccess for type_var at ast.py:11629>' Fld /tmp/lal-23.0.0/ada/ast.py:11629
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5963
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 5964 '<FieldAccess for expected_type_var at ast.py:11630>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11630
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 5964
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_N_Predicate ((Fld, Fld_1), Create_Base_Type_Decl_P_Matching_Type_0_Predicate (Origin)); 
--# expr-done 5965
Let_Result := Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5966
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_920;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_920;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Matches_Expected_Type;
--# end
--# property-start Expr.matches_expected_assign_type /tmp/lal-23.0.0/ada/ast.py:11634
pragma Warnings (Off, "is not referenced");
 function Expr_P_Matches_Expected_Assign_Type
  (Node : Bare_Expr
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_921 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_921 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_921;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5970 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5969 '<Predicate on BaseTypeDecl.matching_assign_type at ast.py:11635>' Pred /tmp/lal-23.0.0/ada/ast.py:11635
--# expr-start 5967 '<FieldAccess for type_var at ast.py:11637>' Fld /tmp/lal-23.0.0/ada/ast.py:11637
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5967
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 5968 '<FieldAccess for expected_type_var at ast.py:11638>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11638
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 5968
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_N_Predicate ((Fld, Fld_1), Create_Base_Type_Decl_P_Matching_Assign_Type_0_Predicate (Origin)); 
--# expr-done 5969
Let_Result := Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5970
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_921;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_921;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Matches_Expected_Assign_Type;
--# end
--# property-start Expr.matches_expected_formal_type /tmp/lal-23.0.0/ada/ast.py:11642
pragma Warnings (Off, "is not referenced");
 function Expr_P_Matches_Expected_Formal_Type
  (Node : Bare_Expr
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_922 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_922 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_922;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5974 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5973 '<Predicate on BaseTypeDecl.matching_formal_type at ast.py:11643>' Pred /tmp/lal-23.0.0/ada/ast.py:11643
--# expr-start 5971 '<FieldAccess for type_var at ast.py:11645>' Fld /tmp/lal-23.0.0/ada/ast.py:11645
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5971
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 5972 '<FieldAccess for expected_type_var at ast.py:11646>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11646
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 5972
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_N_Predicate ((Fld, Fld_1), Create_Base_Type_Decl_P_Matching_Formal_Type_0_Predicate (Origin)); 
--# expr-done 5973
Let_Result := Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5974
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_922;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_922;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Matches_Expected_Formal_Type;
--# end
--# property-start Expr.matches_expected_formal_prim_type /tmp/lal-23.0.0/ada/ast.py:11650
pragma Warnings (Off, "is not referenced");
 function Expr_P_Matches_Expected_Formal_Prim_Type
  (Node : Bare_Expr
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_923 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_923 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_923;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5978 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5977 '<Predicate on BaseTypeDecl.matching_formal_prim_type at ast.py:11651>' Pred /tmp/lal-23.0.0/ada/ast.py:11651
--# expr-start 5975 '<FieldAccess for type_var at ast.py:11653>' Fld /tmp/lal-23.0.0/ada/ast.py:11653
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5975
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 5976 '<FieldAccess for expected_type_var at ast.py:11654>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11654
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 5976
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_N_Predicate ((Fld, Fld_1), Create_Base_Type_Decl_P_Matching_Formal_Prim_Type_0_Predicate (Origin)); 
--# expr-done 5977
Let_Result := Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5978
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_923;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_923;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Matches_Expected_Formal_Prim_Type;
--# end
--# property-start Expr.matches_expected_prefix_type /tmp/lal-23.0.0/ada/ast.py:11658
pragma Warnings (Off, "is not referenced");
 function Expr_P_Matches_Expected_Prefix_Type
  (Node : Bare_Expr
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_924 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_924 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_924;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 5982 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 5981 '<Predicate on BaseTypeDecl.matching_prefix_type at ast.py:11659>' Pred /tmp/lal-23.0.0/ada/ast.py:11659
--# expr-start 5979 '<FieldAccess for type_var at ast.py:11661>' Fld /tmp/lal-23.0.0/ada/ast.py:11661
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 5979
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 5980 '<FieldAccess for expected_type_var at ast.py:11662>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11662
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 5980
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_N_Predicate ((Fld, Fld_1), Create_Base_Type_Decl_P_Matching_Prefix_Type_0_Predicate (Origin)); 
--# expr-done 5981
Let_Result := Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 5982
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_924;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_924;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Matches_Expected_Prefix_Type;
--# end
--# property-start Expr.is_dynamically_tagged /tmp/lal-23.0.0/ada/ast.py:11667
pragma Warnings (Off, "is not referenced");
 function Expr_P_Is_Dynamically_Tagged
  (Node : Bare_Expr
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
            procedure Finalizer_Scope_2646 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Match_0 : Internal_Entity_Qual_Expr;
Match_1 : Internal_Entity_Name;
Match_2 : Internal_Entity_Cond_Expr;
Match_3 : Internal_Entity_Decl_Expr;
Match_4 : Internal_Entity_Paren_Expr;
Match_5 : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Fld_6 : Internal_Entity_Expr;
Fld_7 : Boolean;
Fld_8 : Boolean;
Fld_9 : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result : Internal_Entity_Base_Subp_Spec;
Fld_10 : Boolean;
Fld_11 : Boolean;
If_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_2 : Boolean;
Fld_12 : Internal_Entity_Expr_Array_Access;
Fld_13 : Boolean;
Quantifier_Result : Boolean;
Fld_14 : Internal_Entity_Expr;
Fld_15 : Boolean;
Fld_16 : Internal_Entity_Expr;
Fld_17 : Boolean;
Match_Prefix : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Qual_Expr;
Let_Result : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_2 : Internal_Entity_Name;
Let_Result_1 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_3 : Internal_Entity_Cond_Expr;
Let_Result_2 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_4 : Internal_Entity_Decl_Expr;
Let_Result_3 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_5 : Internal_Entity_Paren_Expr;
Let_Result_4 : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_6 : Internal_Entity_Expr;
Let_Result_5 : Boolean;
Scope_Result_7 : Boolean;
Match_Result : Boolean;
If_Result_3 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result_6 : Boolean;
            procedure Finalizer_Scope_2646 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2646;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6005 '<Block at ???>' Let_Result_6 None
--# scope-start
--# expr-start 6004 '<bind at ast.py:11673>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:11673
--# expr-start 5983 '<FieldAccess for origin_node at ast.py:11673>' Fld /tmp/lal-23.0.0/ada/ast.py:11673
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 5983
Bound_Origin := Fld; 
--# expr-start 5985 '<FieldAccess for is_classwide at ast.py:11674>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11674
--# expr-start 5984 '<FieldAccess for expression_type at ast.py:11674>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11674
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_1 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5984
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 5985
if Fld_2 then
   If_Result := True;
else
--# expr-start 5987 '<FieldAccess for accessed_type at ast.py:11675>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11675
--# expr-start 5986 '<FieldAccess for expression_type at ast.py:11675>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11675
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_3 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 5986
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Fld_3.Node, Origin => Bound_Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 5987
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 5988 '<FieldAccess for is_classwide at ast.py:11675>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:11675
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 5988
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
if If_Result then
   If_Result_3 := True;
else
   --# expr-start 6003 '<Match at ast.py:11677>' Match_Result /tmp/lal-23.0.0/ada/ast.py:11677
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Expr (Match_Prefix.Node.Kind) is
         when Ada_Qual_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Qual_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind qual_expr Match_0
--# expr-start 5990 '<FieldAccess for is_dynamically_tagged at ast.py:11679>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:11679
--# expr-start 5989 '<FieldAccess for suffix at ast.py:11679>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:11679
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Match_0.Node.Qual_Expr_F_Suffix, Info => Match_0.Info);
--# expr-done 5989
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dynamically_tagged
Fld_7 := Libadalang.Implementation.Expr_P_Is_Dynamically_Tagged (Node => Fld_6.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_6.Info);
--# end
--# expr-done 5990
Let_Result := Fld_7; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Attribute_Ref .. Ada_Explicit_Deref | Ada_Reduce_Attribute_Ref .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind n Match_1
--# expr-start 5991 '<FieldAccess for is_direct_call at ast.py:11685>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:11685
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_direct_call
Fld_8 := Libadalang.Implementation.Name_P_Is_Direct_Call (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 5991
if Fld_8 then
--# expr-start 5993 '<Cast to BaseSubpSpec at ast.py:11686>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11686
--# expr-start 5992 '<FieldAccess for called_subp_spec at ast.py:11686>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:11686
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_9 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 5992
   if Fld_9.Node = null
      or else Fld_9.Node.Kind in Ada_Base_Subp_Spec
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   else
         Cast_Result := No_Entity_Base_Subp_Spec;
   end if;
--# expr-done 5993
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr_1
--# expr-start 5994 '<FieldAccess for has_controlling_result at ast.py:11688>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:11688
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.has_controlling_result
Fld_10 := Libadalang.Implementation.Base_Subp_Spec_P_Has_Controlling_Result (Node => Var_Expr_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 5994
if Fld_10 then
   --# expr-start 5995 '<FieldAccess for has_dynamic_controlling_operand at ast.py:11689>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:11689
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.has_dynamic_controlling_operand
Fld_11 := Libadalang.Implementation.Expr_P_Has_Dynamic_Controlling_Operand (Node => Match_1.Node, Spec => Var_Expr_1, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_1.Info);
--# end
--# expr-done 5995
   If_Result_1 := Fld_11;
else
   If_Result_1 := False;
end if;
Scope_Result_1 := If_Result_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_2 := Result_Var_1;
else
   If_Result_2 := False;
end if;
Let_Result_1 := If_Result_2; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Case_Expr .. Ada_If_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Cond_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind cond_expr Match_2
--# expr-start 5998 '<AllQuantifier at ast.py:11693>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:11693
   --# expr-start 5996 '<FieldAccess for dependent_exprs at ast.py:11693>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:11693
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]CondExpr.dependent_exprs'
Fld_12 := Libadalang.Implementation.Dispatcher_Cond_Expr_P_Dependent_Exprs (Node => Match_2.Node, E_Info => Match_2.Info);
--# end
--# expr-done 5996
      Quantifier_Result := True;
      declare
         Collection : constant Internal_Entity_Expr_Array_Access := Fld_12;
      begin
         for Item_211 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_211
      --# expr-start 5997 '<FieldAccess for is_dynamically_tagged at ast.py:11694>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:11694
      if Item_211.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dynamically_tagged
Fld_13 := Libadalang.Implementation.Expr_P_Is_Dynamically_Tagged (Node => Item_211.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Item_211.Info);
--# end
--# expr-done 5997
      Quantifier_Result := Fld_13;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
--# expr-done 5998
Let_Result_2 := Quantifier_Result; 
--# end
Scope_Result_4 := Let_Result_2;
   --# end
      Finalizer_Scope_2646;
            Match_Result := Scope_Result_4; 
         when Ada_Decl_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Decl_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_4; 
--# bind decl_expr Match_3
--# expr-start 6000 '<FieldAccess for is_dynamically_tagged at ast.py:11698>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:11698
--# expr-start 5999 '<FieldAccess for expr at ast.py:11698>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:11698
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Expr (Node => Match_3.Node.Decl_Expr_F_Expr, Info => Match_3.Info);
--# expr-done 5999
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dynamically_tagged
Fld_15 := Libadalang.Implementation.Expr_P_Is_Dynamically_Tagged (Node => Fld_14.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_14.Info);
--# end
--# expr-done 6000
Let_Result_3 := Fld_15; 
--# end
Scope_Result_5 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Paren_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Paren_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_5; 
--# bind paren_expr Match_4
--# expr-start 6002 '<FieldAccess for is_dynamically_tagged at ast.py:11701>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:11701
--# expr-start 6001 '<FieldAccess for expr at ast.py:11701>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:11701
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Expr (Node => Match_4.Node.Paren_Expr_F_Expr, Info => Match_4.Info);
--# expr-done 6001
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dynamically_tagged
Fld_17 := Libadalang.Implementation.Expr_P_Is_Dynamically_Tagged (Node => Fld_16.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_16.Info);
--# end
--# expr-done 6002
Let_Result_4 := Fld_17; 
--# end
Scope_Result_6 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Concat_Operand | Ada_Contract_Cases | Ada_Membership_Expr | Ada_Quantified_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_6; 
--# bind _ Match_5
Let_Result_5 := False; 
--# end
Scope_Result_7 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_7; 
end case;
--# expr-done 6003
   If_Result_3 := Match_Result;
end if;
Dyn_Var_Bind_Result := If_Result_3; 
--# expr-done 6004
Let_Result_6 := Dyn_Var_Bind_Result; 
--# end
--# expr-done 6005
      Property_Result := Let_Result_6;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2646;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Is_Dynamically_Tagged;
--# end
--# property-start '[dispatcher]Expr.potential_actuals_for_dispatch' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_Potential_Actuals_For_Dispatch
  (Node : Bare_Expr
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Expected_Type_For_Expr_Array_Access
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind spec Spec
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Expected_Type_For_Expr_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Raise_Expr =>
                  --# property-call-start Expr.potential_actuals_for_dispatch
                  Property_Result := Expr_P_Potential_Actuals_For_Dispatch
                    (Self
                        , Spec
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Bin_Op .. Ada_Relation_Op =>
                  --# property-call-start BinOp.potential_actuals_for_dispatch
                  Property_Result := Bin_Op_P_Potential_Actuals_For_Dispatch
                    (Self
                        , Spec
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.potential_actuals_for_dispatch
                  Property_Result := Name_P_Potential_Actuals_For_Dispatch
                    (Self
                        , Spec
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Un_Op =>
                  --# property-call-start UnOp.potential_actuals_for_dispatch
                  Property_Result := Un_Op_P_Potential_Actuals_For_Dispatch
                    (Self
                        , Spec
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_Potential_Actuals_For_Dispatch;
--# end
--# property-start Expr.has_dynamic_controlling_operand /tmp/lal-23.0.0/ada/ast.py:11726
pragma Warnings (Off, "is not referenced");
 function Expr_P_Has_Dynamic_Controlling_Operand
  (Node : Bare_Expr
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind spec Spec
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
            procedure Finalizer_Scope_927 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Expected_Type_For_Expr_Array_Access;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Boolean;
If_Result : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Quantifier_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_927 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_927;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6014 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6013 '<AnyQuantifier at ast.py:11737>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:11737
   --# expr-start 6006 '<FieldAccess for potential_actuals_for_dispatch at ast.py:11737>' Fld /tmp/lal-23.0.0/ada/ast.py:11737
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.potential_actuals_for_dispatch'
Fld := Libadalang.Implementation.Dispatcher_Expr_P_Potential_Actuals_For_Dispatch (Node => Ent.Node, Spec => Spec, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 6006
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Expected_Type_For_Expr_Array_Access := Fld;
      begin
         for Item_212 of
               Collection.Items
         loop
   --# scope-start
               --# bind c Item_212
--# expr-start 6008 '<FieldAccess for get_candidate_type_for_primitive at ast.py:11739>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11739
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6007 '<FieldAccess for expected_type at ast.py:11739>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11739
Fld_1 := Item_212.Expected_Type;
--# expr-done 6007
--# property-call-start BaseSubpSpec.get_candidate_type_for_primitive
Fld_2 := Libadalang.Implementation.Base_Subp_Spec_P_Get_Candidate_Type_For_Primitive (Node => Spec.Node, Type_Expr => Fld_1);
--# end
--# expr-done 6008
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr
--# expr-start 6010 '<FieldAccess for is_tagged_type at ast.py:11745>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11745
--# expr-start 6009 '<FieldAccess for full_view at ast.py:11745>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11745
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.full_view
Fld_3 := Libadalang.Implementation.Base_Type_Decl_P_Full_View (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 6009
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Fld_3.Node, Origin => No_Bare_Ada_Node, E_Info => Fld_3.Info);
--# end
--# expr-done 6010
if Fld_4 then
   --# expr-start 6012 '<FieldAccess for is_dynamically_tagged at ast.py:11746>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:11746
--# expr-start 6011 '<FieldAccess for expr at ast.py:11746>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:11746
Fld_5 := Item_212.Expr;
--# expr-done 6011
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dynamically_tagged
Fld_6 := Libadalang.Implementation.Expr_P_Is_Dynamically_Tagged (Node => Fld_5.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_5.Info);
--# end
--# expr-done 6012
   If_Result := Fld_6;
else
   If_Result := False;
end if;
Scope_Result := If_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      Quantifier_Result := Result_Var;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 6013
Let_Result := Quantifier_Result; 
--# end
--# expr-done 6014
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_927;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_927;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Has_Dynamic_Controlling_Operand;
--# end
--# property-start Expr.parent_candidate_dispatching_call /tmp/lal-23.0.0/ada/ast.py:11752
pragma Warnings (Off, "is not referenced");
 function Expr_P_Parent_Candidate_Dispatching_Call
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
            procedure Finalizer_Scope_2657 with Inline_Always;
      Match_0 : Internal_Entity_Call_Expr;
Match_1 : Internal_Entity_Dotted_Name;
Match_2 : Internal_Entity_Un_Op;
Match_3 : Internal_Entity_Bin_Op;
Match_4 : Internal_Entity_Cond_Expr;
Match_5 : Internal_Entity_Paren_Expr;
Match_6 : Internal_Entity_Qual_Expr;
Match_7 : Internal_Entity_Decl_Expr;
Match_8 : Internal_Entity_Param_Assoc;
Match_9 : Internal_Entity;
Fld : Internal_Entity;
Fld_1 : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Call_Expr;
Cast_Result : Internal_Entity_Expr;
Fld_2 : Internal_Entity_Name;
Cast_Expr_1 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Expr;
Fld_3 : Internal_Entity_Expr;
Cast_Expr_2 : Internal_Entity_Dotted_Name;
Cast_Result_3 : Internal_Entity_Expr;
Fld_4 : Internal_Entity_Base_Id;
Cast_Expr_3 : Internal_Entity_Expr;
Cast_Result_4 : Internal_Entity;
Cast_Result_5 : Internal_Entity;
Is_Equiv_1 : Boolean;
If_Result_1 : Internal_Entity_Expr;
Fld_5 : Internal_Entity_Expr;
Cast_Expr_4 : Internal_Entity_Un_Op;
Cast_Result_6 : Internal_Entity_Expr;
Fld_6 : Internal_Entity_Op;
Cast_Expr_5 : Internal_Entity_Expr;
Cast_Result_7 : Internal_Entity;
Cast_Result_8 : Internal_Entity;
Is_Equiv_2 : Boolean;
If_Result_2 : Internal_Entity_Expr;
Fld_7 : Internal_Entity_Expr;
Cast_Expr_6 : Internal_Entity_Bin_Op;
Cast_Result_9 : Internal_Entity_Expr;
Fld_8 : Internal_Entity_Op;
Cast_Expr_7 : Internal_Entity_Expr;
Cast_Result_10 : Internal_Entity;
Cast_Result_11 : Internal_Entity;
Is_Equiv_3 : Boolean;
If_Result_3 : Internal_Entity_Expr;
Fld_9 : Internal_Entity_Expr;
Fld_10 : Internal_Entity_Expr_Array_Access;
Cast_Expr_8 : Internal_Entity_Expr;
Cast_Result_12 : Internal_Entity;
Cast_Expr_9 : Internal_Entity_Expr;
Cast_Result_13 : Internal_Entity;
Is_Equiv_4 : Boolean;
Quantifier_Result : Boolean;
If_Result_4 : Internal_Entity_Expr;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Internal_Entity_Expr;
Fld_13 : Internal_Entity_Expr;
Fld_14 : Internal_Entity;
Fld_15 : Internal_Entity;
Cast_Result_14 : Internal_Entity_Call_Expr;
Match_Prefix : Internal_Entity;
Cast_Result_15 : Internal_Entity_Call_Expr;
Let_Result : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Cast_Result_16 : Internal_Entity_Dotted_Name;
Let_Result_1 : Internal_Entity_Expr;
Scope_Result_1 : Internal_Entity_Expr;
Cast_Result_17 : Internal_Entity_Un_Op;
Let_Result_2 : Internal_Entity_Expr;
Scope_Result_2 : Internal_Entity_Expr;
Cast_Result_18 : Internal_Entity_Bin_Op;
Let_Result_3 : Internal_Entity_Expr;
Scope_Result_3 : Internal_Entity_Expr;
Cast_Result_19 : Internal_Entity_Cond_Expr;
Let_Result_4 : Internal_Entity_Expr;
Scope_Result_4 : Internal_Entity_Expr;
Cast_Result_20 : Internal_Entity_Paren_Expr;
Let_Result_5 : Internal_Entity_Expr;
Scope_Result_5 : Internal_Entity_Expr;
Cast_Result_21 : Internal_Entity_Qual_Expr;
Let_Result_6 : Internal_Entity_Expr;
Scope_Result_6 : Internal_Entity_Expr;
Cast_Result_22 : Internal_Entity_Decl_Expr;
Let_Result_7 : Internal_Entity_Expr;
Scope_Result_7 : Internal_Entity_Expr;
Cast_Result_23 : Internal_Entity_Param_Assoc;
Cast_Result_24 : Internal_Entity_Expr;
Let_Result_8 : Internal_Entity_Expr;
Scope_Result_8 : Internal_Entity_Expr;
Cast_Result_25 : Internal_Entity;
Let_Result_9 : Internal_Entity_Expr;
Scope_Result_9 : Internal_Entity_Expr;
Match_Result : Internal_Entity_Expr;
Let_Result_10 : Internal_Entity_Expr;
            procedure Finalizer_Scope_2657 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_2657;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6044 '<Block at ???>' Let_Result_10 None
--# scope-start
--# expr-start 6043 '<Match at ast.py:11758>' Match_Result /tmp/lal-23.0.0/ada/ast.py:11758
--# expr-start 6015 '<parent at ast.py:11758>' Fld /tmp/lal-23.0.0/ada/ast.py:11758
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 6015
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_15 := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_15; 
--# bind ce Match_0
--# expr-start 6019 '<If at ast.py:11759>' If_Result /tmp/lal-23.0.0/ada/ast.py:11759
--# expr-start 6017 '<Eq at ast.py:11760>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:11760
Cast_Expr_1 := Ent; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
--# expr-start 6016 '<FieldAccess for name at ast.py:11760>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11760
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Match_0.Node.Call_Expr_F_Name, Info => Match_0.Info);
--# expr-done 6016
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 6017
if Is_Equiv then
   --# expr-start 6018 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11761>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11761
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_1 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 6018
   If_Result := Fld_1;
else
Cast_Expr := Match_0; 
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   If_Result := Cast_Result;
end if;
--# expr-done 6019
Let_Result := If_Result; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_16 := Create_Internal_Entity_Dotted_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_16; 
--# bind dn Match_1
--# expr-start 6023 '<If at ast.py:11764>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:11764
--# expr-start 6021 '<Eq at ast.py:11765>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:11765
Cast_Expr_3 := Ent; 
      Cast_Result_4 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
--# expr-start 6020 '<FieldAccess for suffix at ast.py:11765>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11765
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Base_Id (Node => Match_1.Node.Dotted_Name_F_Suffix, Info => Match_1.Info);
--# expr-done 6020
      Cast_Result_5 := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Is_Equiv_1 := Equivalent (Cast_Result_4, Cast_Result_5); 
--# expr-done 6021
if Is_Equiv_1 then
   --# expr-start 6022 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11766>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11766
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_3 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 6022
   If_Result_1 := Fld_3;
else
Cast_Expr_2 := Match_1; 
      Cast_Result_3 := Create_Internal_Entity_Expr
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   If_Result_1 := Cast_Result_3;
end if;
--# expr-done 6023
Let_Result_1 := If_Result_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_17 := Create_Internal_Entity_Un_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_17; 
--# bind uo Match_2
--# expr-start 6027 '<If at ast.py:11769>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:11769
--# expr-start 6025 '<Eq at ast.py:11770>' Is_Equiv_2 /tmp/lal-23.0.0/ada/ast.py:11770
Cast_Expr_5 := Ent; 
      Cast_Result_7 := Create_Internal_Entity
        (Node => Cast_Expr_5.Node,
         Info => Cast_Expr_5.Info);
--# expr-start 6024 '<FieldAccess for op at ast.py:11770>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:11770
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Op (Node => Match_2.Node.Un_Op_F_Op, Info => Match_2.Info);
--# expr-done 6024
      Cast_Result_8 := Create_Internal_Entity
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
Is_Equiv_2 := Equivalent (Cast_Result_7, Cast_Result_8); 
--# expr-done 6025
if Is_Equiv_2 then
   --# expr-start 6026 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11771>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:11771
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_5 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_2.Node, E_Info => Match_2.Info);
--# end
--# expr-done 6026
   If_Result_2 := Fld_5;
else
Cast_Expr_4 := Match_2; 
      Cast_Result_6 := Create_Internal_Entity_Expr
        (Node => Cast_Expr_4.Node,
         Info => Cast_Expr_4.Info);
   If_Result_2 := Cast_Result_6;
end if;
--# expr-done 6027
Let_Result_2 := If_Result_2; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_18 := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_18; 
--# bind bo Match_3
--# expr-start 6031 '<If at ast.py:11774>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:11774
--# expr-start 6029 '<Eq at ast.py:11775>' Is_Equiv_3 /tmp/lal-23.0.0/ada/ast.py:11775
Cast_Expr_7 := Ent; 
      Cast_Result_10 := Create_Internal_Entity
        (Node => Cast_Expr_7.Node,
         Info => Cast_Expr_7.Info);
--# expr-start 6028 '<FieldAccess for op at ast.py:11775>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:11775
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Op (Node => Match_3.Node.Bin_Op_F_Op, Info => Match_3.Info);
--# expr-done 6028
      Cast_Result_11 := Create_Internal_Entity
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
Is_Equiv_3 := Equivalent (Cast_Result_10, Cast_Result_11); 
--# expr-done 6029
if Is_Equiv_3 then
   --# expr-start 6030 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11776>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:11776
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_7 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_3.Node, E_Info => Match_3.Info);
--# end
--# expr-done 6030
   If_Result_3 := Fld_7;
else
Cast_Expr_6 := Match_3; 
      Cast_Result_9 := Create_Internal_Entity_Expr
        (Node => Cast_Expr_6.Node,
         Info => Cast_Expr_6.Info);
   If_Result_3 := Cast_Result_9;
end if;
--# expr-done 6031
Let_Result_3 := If_Result_3; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Case_Expr .. Ada_If_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_19 := Create_Internal_Entity_Cond_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_19; 
--# bind ce Match_4
--# expr-start 6036 '<If at ast.py:11779>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:11779
--# expr-start 6034 '<Contains at ast.py:11780>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:11780
   --# expr-start 6032 '<FieldAccess for dependent_exprs at ast.py:11780>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:11780
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]CondExpr.dependent_exprs'
Fld_10 := Libadalang.Implementation.Dispatcher_Cond_Expr_P_Dependent_Exprs (Node => Match_4.Node, E_Info => Match_4.Info);
--# end
--# expr-done 6032
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Expr_Array_Access := Fld_10;
      begin
         for Item_213 of
               Collection.Items
         loop
   --# scope-start
               --# bind item Item_213
      --# expr-start 6033 '<Eq at ???>' Is_Equiv_4 None
Cast_Expr_8 := Item_213; 
      Cast_Result_12 := Create_Internal_Entity
        (Node => Cast_Expr_8.Node,
         Info => Cast_Expr_8.Info);
Cast_Expr_9 := Ent; 
      Cast_Result_13 := Create_Internal_Entity
        (Node => Cast_Expr_9.Node,
         Info => Cast_Expr_9.Info);
Is_Equiv_4 := Equivalent (Cast_Result_12, Cast_Result_13); 
--# expr-done 6033
      Quantifier_Result := Is_Equiv_4;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 6034
if Quantifier_Result then
   --# expr-start 6035 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11781>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:11781
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_9 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_4.Node, E_Info => Match_4.Info);
--# end
--# expr-done 6035
   If_Result_4 := Fld_9;
else
   If_Result_4 := No_Entity_Expr;
end if;
--# expr-done 6036
Let_Result_4 := If_Result_4; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
      Finalizer_Scope_2657;
            Match_Result := Scope_Result_4; 
         when Ada_Paren_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_20 := Create_Internal_Entity_Paren_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_20; 
--# bind pe Match_5
--# expr-start 6037 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11784>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:11784
      if Match_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_11 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_5.Node, E_Info => Match_5.Info);
--# end
--# expr-done 6037
Let_Result_5 := Fld_11; 
--# end
Scope_Result_5 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Qual_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_21 := Create_Internal_Entity_Qual_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_6 := Cast_Result_21; 
--# bind qe Match_6
--# expr-start 6038 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11785>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:11785
      if Match_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_12 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_6.Node, E_Info => Match_6.Info);
--# end
--# expr-done 6038
Let_Result_6 := Fld_12; 
--# end
Scope_Result_6 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Decl_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_22 := Create_Internal_Entity_Decl_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_7 := Cast_Result_22; 
--# bind de Match_7
--# expr-start 6039 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11786>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:11786
      if Match_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_13 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Match_7.Node, E_Info => Match_7.Info);
--# end
--# expr-done 6039
Let_Result_7 := Fld_13; 
--# end
Scope_Result_7 := Let_Result_7;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Param_Assoc =>
   --# scope-start
--# scope-start
      Cast_Result_23 := Create_Internal_Entity_Param_Assoc
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_8 := Cast_Result_23; 
--# bind pa Match_8
--# expr-start 6042 '<Cast to CallExpr at ast.py:11787>' Cast_Result_14 /tmp/lal-23.0.0/ada/ast.py:11787
--# expr-start 6041 '<parent at ast.py:11787>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:11787
--# expr-start 6040 '<parent at ast.py:11787>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:11787
      if Match_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Parent (Node => Match_8.Node, E_Info => Match_8.Info);
--# expr-done 6040
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Parent (Node => Fld_14.Node, E_Info => Fld_14.Info);
--# expr-done 6041
   if Fld_15.Node = null
      or else Fld_15.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_14 := Create_Internal_Entity_Call_Expr
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
   else
         Cast_Result_14 := No_Entity_Call_Expr;
   end if;
--# expr-done 6042
      Cast_Result_24 := Create_Internal_Entity_Expr
        (Node => Cast_Result_14.Node,
         Info => Cast_Result_14.Info);
Let_Result_8 := Cast_Result_24; 
--# end
Scope_Result_8 := Let_Result_8;
   --# end
            Match_Result := Scope_Result_8; 
         when Ada_Abort_Absent .. Ada_Iterated_Assoc | Ada_Abstract_State_Decl .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Concat_Operand | Ada_Contract_Cases | Ada_Membership_Expr .. Ada_Attribute_Ref | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Explicit_Deref | Ada_Reduce_Attribute_Ref .. Ada_Update_Attribute_Ref | Ada_Quantified_Expr .. Ada_Raise_Expr | Ada_Handled_Stmts .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_25 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_9 := Cast_Result_25; 
--# bind _ Match_9
Let_Result_9 := No_Entity_Expr; 
--# end
Scope_Result_9 := Let_Result_9;
   --# end
            Match_Result := Scope_Result_9; 
end case;
--# expr-done 6043
Let_Result_10 := Match_Result; 
--# end
--# expr-done 6044
      Property_Result := Let_Result_10;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2657;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Parent_Candidate_Dispatching_Call;
--# end
--# property-start Expr.has_dynamic_context /tmp/lal-23.0.0/ada/ast.py:11793
pragma Warnings (Off, "is not referenced");
 function Expr_P_Has_Dynamic_Context
  (Node : Bare_Expr
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Assign_Stmt;
Var_Expr_1 : Internal_Entity_Expr;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Assign_Stmt;
Fld_1 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Boolean;
If_Result : Boolean;
Scope_Result : Boolean;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Boolean;
Scope_Result_1 : Boolean;
Result_Var : Boolean;
Result_Var_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6053 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6046 '<Cast to AssignStmt at ast.py:11800>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:11800
--# expr-start 6045 '<parent at ast.py:11800>' Fld /tmp/lal-23.0.0/ada/ast.py:11800
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 6045
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Assign_Stmt_Range
   then
      Cast_Result := Create_Internal_Entity_Assign_Stmt
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Assign_Stmt;
   end if;
--# expr-done 6046
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Assign_Stmt then
   --# scope-start
   --# bind a Var_Expr
--# expr-start 6048 '<Eq at ast.py:11805>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:11805
--# expr-start 6047 '<FieldAccess for expr at ast.py:11805>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11805
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Assign_Stmt_F_Expr, Info => Var_Expr.Info);
--# expr-done 6047
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Cast_Expr := Ent; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 6048
if Is_Equiv then
   --# expr-start 6050 '<FieldAccess for is_classwide at ast.py:11806>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11806
--# expr-start 6049 '<FieldAccess for expected_expression_type at ast.py:11806>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11806
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expected_expression_type
Fld_2 := Libadalang.Implementation.Expr_P_Expected_Expression_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 6049
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_classwide'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Classwide (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 6050
   If_Result := Fld_3;
else
   If_Result := False;
end if;
Scope_Result := If_Result;
   --# end
   Result_Var_1 := Scope_Result;
else
--# expr-start 6051 '<FieldAccess for parent_candidate_dispatching_call at ast.py:11812>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11812
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.parent_candidate_dispatching_call
Fld_4 := Libadalang.Implementation.Expr_P_Parent_Candidate_Dispatching_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 6051
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= No_Entity_Expr then
   --# scope-start
--# expr-start 6052 '<FieldAccess for is_dispatching_call at ast.py:11813>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:11813
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.is_dispatching_call'
Fld_5 := Libadalang.Implementation.Dispatcher_Expr_P_Is_Dispatching_Call (Node => Var_Expr_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 6052
Scope_Result_1 := Fld_5;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := False;
end if;
   Result_Var_1 := Result_Var;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 6053
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Has_Dynamic_Context;
--# end
--# property-start Expr.is_dispatching_call_impl /tmp/lal-23.0.0/ada/ast.py:11818
pragma Warnings (Off, "is not referenced");
 function Expr_P_Is_Dispatching_Call_Impl
  (Node : Bare_Expr
      ; Decl : Internal_Entity_Basic_Decl
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind decl Decl
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Base_Subp_Spec;
Is_A : Boolean;
Fld_2 : Boolean;
If_Result : Boolean;
Fld_3 : Boolean;
Fld_4 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6060 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6055 '<FieldAccess for subp_spec_or_null at ast.py:11824>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11824
--# expr-start 6054 '<FieldAccess for canonical_part at ast.py:11824>' Fld /tmp/lal-23.0.0/ada/ast.py:11824
      if Decl.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_part
Fld := Libadalang.Implementation.Basic_Decl_P_Canonical_Part (Node => Decl.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Decl.Info);
--# end
--# expr-done 6054
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Fld.Node, Follow_Generic => True, E_Info => Fld.Info);
--# end
--# expr-done 6055
Block_Var := Fld_1; 
--# bind spec Block_Var
--# expr-start 6056 '<IsA AbstractFormalSubpDecl at ast.py:11828>' Is_A /tmp/lal-23.0.0/ada/ast.py:11828
Is_A := Decl.Node /= null 
and then Decl.Node.Kind in Ada_Abstract_Formal_Subp_Decl_Range; 
--# expr-done 6056
if Is_A then
   If_Result := True;
else
   --# expr-start 6057 '<FieldAccess for has_dynamic_controlling_operand at ast.py:11832>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11832
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.has_dynamic_controlling_operand
Fld_2 := Libadalang.Implementation.Expr_P_Has_Dynamic_Controlling_Operand (Node => Ent.Node, Spec => Block_Var, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 6057
   If_Result := Fld_2;
end if;
if If_Result then
   If_Result_2 := True;
else
--# expr-start 6058 '<FieldAccess for has_controlling_result at ast.py:11838>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11838
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.has_controlling_result
Fld_3 := Libadalang.Implementation.Base_Subp_Spec_P_Has_Controlling_Result (Node => Block_Var.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var.Info);
--# end
--# expr-done 6058
if Fld_3 then
   --# expr-start 6059 '<FieldAccess for has_dynamic_context at ast.py:11838>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11838
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.has_dynamic_context
Fld_4 := Libadalang.Implementation.Expr_P_Has_Dynamic_Context (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 6059
   If_Result_1 := Fld_4;
else
   If_Result_1 := False;
end if;
   If_Result_2 := If_Result_1;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 6060
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Is_Dispatching_Call_Impl;
--# end
--# property-start '[dispatcher]Expr.is_dispatching_call' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_Is_Dispatching_Call
  (Node : Bare_Expr
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Raise_Expr =>
                  --# property-call-start Expr.is_dispatching_call
                  Property_Result := Expr_P_Is_Dispatching_Call
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Bin_Op .. Ada_Relation_Op =>
                  --# property-call-start BinOp.is_dispatching_call
                  Property_Result := Bin_Op_P_Is_Dispatching_Call
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref .. Ada_Identifier | Ada_String_Literal .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.is_dispatching_call
                  Property_Result := Name_P_Is_Dispatching_Call
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Op_Abs .. Ada_Op_Xor =>
                  --# property-call-start Op.is_dispatching_call
                  Property_Result := Op_P_Is_Dispatching_Call
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Un_Op =>
                  --# property-call-start UnOp.is_dispatching_call
                  Property_Result := Un_Op_P_Is_Dispatching_Call
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_Is_Dispatching_Call;
--# end
--# property-start Expr.is_static_expr /tmp/lal-23.0.0/ada/ast.py:11864
pragma Warnings (Off, "is not referenced");
 function Expr_P_Is_Static_Expr
  (Node : Bare_Expr
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Num_Literal;
Match_1 : Internal_Entity_String_Literal;
Match_2 : Internal_Entity_Attribute_Ref;
Match_3 : Internal_Entity_Call_Expr;
Match_4 : Internal_Entity_Qual_Expr;
Match_5 : Internal_Entity_Name;
Match_6 : Internal_Entity_Membership_Expr;
Match_7 : Internal_Entity_Bin_Op;
Match_8 : Internal_Entity_Un_Op;
Match_9 : Internal_Entity_If_Expr;
Match_10 : Internal_Entity_Paren_Expr;
Match_11 : Internal_Entity_Expr;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Var_Expr_3 : Internal_Entity_Basic_Decl;
Var_Expr_4 : Internal_Entity_Assoc_List;
Var_Expr_5 : Internal_Entity_Base_Type_Decl;
Var_Expr_6 : Internal_Entity_Basic_Decl;
Var_Expr_7 : Internal_Entity_Basic_Decl;
Var_Expr_8 : Internal_Entity_Basic_Decl;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Name;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Name;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_6 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Not_Val : Boolean;
Fld_7 : Internal_Entity_Identifier;
Fld_8 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
If_Result : Boolean;
Fld_9 : Internal_Entity_Name;
Fld_10 : Internal_Entity_Base_Type_Decl;
Fld_11 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Fld_12 : Internal_Entity_Identifier;
Fld_13 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
Fld_14 : Internal_Entity_Identifier;
Fld_15 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_16 : Internal_Entity_Identifier;
Fld_17 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_18 : Internal_Entity_Identifier;
Fld_19 : Symbol_Type;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Boolean;
If_Result_5 : Boolean;
Fld_20 : Internal_Entity_Name;
Fld_21 : Internal_Entity_Basic_Decl;
Fld_22 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
Fld_23 : Internal_Entity_Identifier;
Fld_24 : Symbol_Type;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
Fld_25 : Internal_Entity_Identifier;
Fld_26 : Symbol_Type;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_6 : Boolean;
Fld_27 : Internal_Entity_Identifier;
Fld_28 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_7 : Boolean;
Fld_29 : Internal_Entity_Identifier;
Fld_30 : Symbol_Type;
Sym_8 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_8 : Boolean;
If_Result_9 : Boolean;
If_Result_10 : Boolean;
If_Result_11 : Boolean;
Fld_31 : Internal_Entity_Assoc_List;
Saved : Internal_Entity_Assoc_List;
Fld_32 : Bare_Assoc_List;
Fld_33 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result_12 : Internal_Entity_Basic_Assoc;
Fld_34 : Internal_Entity_Expr;
Fld_35 : Boolean;
Item_214 : Internal_Entity_Basic_Assoc;
Bare_Item_214 : Bare_Basic_Assoc;
Quantifier_Result : Boolean;
Scope_Result_4 : Boolean;
Result_Var_4 : Boolean;
If_Result_13 : Boolean;
Fld_36 : Internal_Entity_Name;
Fld_37 : Boolean;
Fld_38 : Internal_Entity_Assoc_List;
Fld_39 : Bare_Assoc_List;
Fld_40 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_14 : Internal_Entity_Basic_Assoc;
Fld_41 : Internal_Entity_Expr;
Fld_42 : Boolean;
Item_215 : Internal_Entity_Basic_Assoc;
Bare_Item_215 : Bare_Basic_Assoc;
Quantifier_Result_1 : Boolean;
If_Result_15 : Boolean;
Fld_43 : Internal_Entity_Name;
Fld_44 : Internal_Entity_Base_Type_Decl;
Fld_45 : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
Fld_46 : Internal_Entity_Expr;
Fld_47 : Boolean;
If_Result_16 : Boolean;
Fld_48 : Internal_Entity_Basic_Decl;
Fld_49 : Boolean;
Scope_Result_6 : Boolean;
Result_Var_6 : Boolean;
Fld_50 : Internal_Entity_Expr;
Fld_51 : Boolean;
Fld_52 : Internal_Entity_Expr_Alternatives_List;
Fld_53 : Bare_Expr_Alternatives_List;
Fld_54 : Internal_Entity_Info;
As_Entity_2 : Internal_Entity_Expr;
Is_Null_2 : Boolean;
If_Result_17 : Internal_Entity_Expr;
Fld_55 : Boolean;
Item_216 : Internal_Entity_Expr;
Bare_Item_216 : Bare_Expr;
Quantifier_Result_2 : Boolean;
If_Result_18 : Boolean;
Fld_56 : Internal_Entity_Expr;
Fld_57 : Boolean;
Fld_58 : Internal_Entity_Expr;
Fld_59 : Boolean;
If_Result_19 : Boolean;
Fld_60 : Internal_Entity_Op;
Fld_61 : Internal_Entity_Basic_Decl;
Fld_62 : Boolean;
Scope_Result_7 : Boolean;
Result_Var_7 : Boolean;
If_Result_20 : Boolean;
Fld_63 : Internal_Entity_Expr;
Fld_64 : Boolean;
Fld_65 : Internal_Entity_Op;
Fld_66 : Internal_Entity_Basic_Decl;
Fld_67 : Boolean;
Scope_Result_8 : Boolean;
Result_Var_8 : Boolean;
If_Result_21 : Boolean;
Fld_68 : Internal_Entity_Expr;
Fld_69 : Boolean;
Fld_70 : Internal_Entity_Expr;
Fld_71 : Boolean;
If_Result_22 : Boolean;
Fld_72 : Internal_Entity_Elsif_Expr_Part_List;
Fld_73 : Bare_Elsif_Expr_Part_List;
Fld_74 : Internal_Entity_Info;
As_Entity_3 : Internal_Entity_Elsif_Expr_Part;
Is_Null_3 : Boolean;
If_Result_23 : Internal_Entity_Elsif_Expr_Part;
Fld_75 : Internal_Entity_Expr;
Fld_76 : Boolean;
Fld_77 : Internal_Entity_Expr;
Fld_78 : Boolean;
If_Result_24 : Boolean;
Item_217 : Internal_Entity_Elsif_Expr_Part;
Bare_Item_217 : Bare_Elsif_Expr_Part;
Quantifier_Result_3 : Boolean;
If_Result_25 : Boolean;
Fld_79 : Internal_Entity_Expr;
Fld_80 : Boolean;
If_Result_26 : Boolean;
Fld_81 : Internal_Entity_Expr;
Fld_82 : Boolean;
Match_Prefix : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Num_Literal;
Let_Result : Boolean;
Scope_Result_9 : Boolean;
Cast_Result_1 : Internal_Entity_String_Literal;
Let_Result_1 : Boolean;
Scope_Result_10 : Boolean;
Cast_Result_2 : Internal_Entity_Attribute_Ref;
Let_Result_2 : Boolean;
Scope_Result_11 : Boolean;
Cast_Result_3 : Internal_Entity_Call_Expr;
Let_Result_3 : Boolean;
Scope_Result_12 : Boolean;
Cast_Result_4 : Internal_Entity_Qual_Expr;
Let_Result_4 : Boolean;
Scope_Result_13 : Boolean;
Cast_Result_5 : Internal_Entity_Name;
Let_Result_5 : Boolean;
Scope_Result_14 : Boolean;
Cast_Result_6 : Internal_Entity_Membership_Expr;
Let_Result_6 : Boolean;
Scope_Result_15 : Boolean;
Cast_Result_7 : Internal_Entity_Bin_Op;
Let_Result_7 : Boolean;
Scope_Result_16 : Boolean;
Cast_Result_8 : Internal_Entity_Un_Op;
Let_Result_8 : Boolean;
Scope_Result_17 : Boolean;
Cast_Result_9 : Internal_Entity_If_Expr;
Let_Result_9 : Boolean;
Scope_Result_18 : Boolean;
Cast_Result_10 : Internal_Entity_Paren_Expr;
Let_Result_10 : Boolean;
Scope_Result_19 : Boolean;
Cast_Result_11 : Internal_Entity_Expr;
Let_Result_11 : Boolean;
Scope_Result_20 : Boolean;
Match_Result : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result_12 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6161 '<Block at ???>' Let_Result_12 None
--# scope-start
--# expr-start 6160 '<bind at ast.py:11869>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:11869
--# expr-start 6061 '<FieldAccess for origin_node at ast.py:11869>' Fld /tmp/lal-23.0.0/ada/ast.py:11869
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 6061
Bound_Origin := Fld; 
--# expr-start 6159 '<Match at ast.py:11869>' Match_Result /tmp/lal-23.0.0/ada/ast.py:11869
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Expr (Match_Prefix.Node.Kind) is
         when Ada_Int_Literal .. Ada_Real_Literal =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Num_Literal
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind _ Match_0
Let_Result := True; 
--# end
Scope_Result_9 := Let_Result;
   --# end
            Match_Result := Scope_Result_9; 
         when Ada_String_Literal =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_String_Literal
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
Let_Result_1 := True; 
--# end
Scope_Result_10 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_10; 
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind ar Match_2
--# expr-start 6063 '<FieldAccess for is_static_expr at ast.py:11873>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:11873
--# expr-start 6062 '<FieldAccess for prefix at ast.py:11873>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:11873
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 6062
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_2 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_1.Info);
--# end
--# expr-done 6063
if Fld_2 then
--# expr-start 6068 '<Not at ast.py:11874>' Not_Val /tmp/lal-23.0.0/ada/ast.py:11874
--# expr-start 6065 '<FieldAccess for name_designated_type at ast.py:11874>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:11874
--# expr-start 6064 '<FieldAccess for prefix at ast.py:11874>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:11874
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 6064
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_4 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# end
--# expr-done 6065
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 6066 '<FieldAccess for root_type at ast.py:11875>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:11875
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.root_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Root_Type (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 6066
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 6067 '<FieldAccess for is_formal at ast.py:11875>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:11875
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_formal
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Is_Formal (Node => Var_Expr.Node);
--# end
--# expr-done 6067
Scope_Result_1 := Fld_6;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Not_Val := not (Result_Var_1); 
--# expr-done 6068
if Not_Val then
   --# expr-start 6072 '<Eq at ast.py:11876>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:11876
--# expr-start 6070 '<FieldAccess for name_symbol at ast.py:11876>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:11876
--# expr-start 6069 '<FieldAccess for attribute at ast.py:11876>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:11876
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6069
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_7.Node);
--# end
--# expr-done 6070
--# expr-start 6071 '<Symbol Base at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Base); 
--# expr-done 6071
Is_Equal := Fld_8 = Sym; 
--# expr-done 6072
   If_Result := Is_Equal;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_5 := True;
else
--# expr-start 6074 '<FieldAccess for name_designated_type at ast.py:11878>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:11878
--# expr-start 6073 '<FieldAccess for prefix at ast.py:11878>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:11878
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 6073
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_10 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_9.Node, E_Info => Fld_9.Info);
--# end
--# expr-done 6074
Var_Expr_2 := Fld_10;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 6075 '<FieldAccess for is_static_decl at ast.py:11879>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:11879
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_11 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Var_Expr_2.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 6075
Scope_Result_2 := Fld_11;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
if Result_Var_2 then
--# expr-start 6079 '<Eq at ast.py:11879>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6077 '<FieldAccess for name_symbol at ast.py:11879>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6076 '<FieldAccess for attribute at ast.py:11879>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:11879
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6076
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_13 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_12.Node);
--# end
--# expr-done 6077
--# expr-start 6078 '<Symbol First at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_First); 
--# expr-done 6078
Is_Equal_1 := Fld_13 = Sym_1; 
--# expr-done 6079
if Is_Equal_1 then
   If_Result_1 := True;
else
   --# expr-start 6083 '<Eq at ast.py:11879>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6081 '<FieldAccess for name_symbol at ast.py:11879>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6080 '<FieldAccess for attribute at ast.py:11879>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:11879
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6080
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_15 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_14.Node);
--# end
--# expr-done 6081
--# expr-start 6082 '<Symbol Last at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Last); 
--# expr-done 6082
Is_Equal_2 := Fld_15 = Sym_2; 
--# expr-done 6083
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 6087 '<Eq at ast.py:11879>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6085 '<FieldAccess for name_symbol at ast.py:11879>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6084 '<FieldAccess for attribute at ast.py:11879>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:11879
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6084
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_17 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_16.Node);
--# end
--# expr-done 6085
--# expr-start 6086 '<Symbol Range at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range); 
--# expr-done 6086
Is_Equal_3 := Fld_17 = Sym_3; 
--# expr-done 6087
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 6091 '<Eq at ast.py:11879>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6089 '<FieldAccess for name_symbol at ast.py:11879>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:11879
--# expr-start 6088 '<FieldAccess for attribute at ast.py:11879>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:11879
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6088
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_19 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_18.Node);
--# end
--# expr-done 6089
--# expr-start 6090 '<Symbol Val at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val); 
--# expr-done 6090
Is_Equal_4 := Fld_19 = Sym_4; 
--# expr-done 6091
   If_Result_3 := Is_Equal_4;
end if;
   If_Result_4 := If_Result_3;
else
   If_Result_4 := False;
end if;
   If_Result_5 := If_Result_4;
end if;
if If_Result_5 then
   If_Result_10 := True;
else
--# expr-start 6093 '<FieldAccess for referenced_decl at ast.py:11883>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:11883
--# expr-start 6092 '<FieldAccess for prefix at ast.py:11883>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:11883
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 6092
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_21 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_20.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_20.Info);
--# end
--# expr-done 6093
Var_Expr_3 := Fld_21;
if Var_Expr_3 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 6094 '<FieldAccess for is_array at ast.py:11883>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:11883
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_array
Fld_22 := Libadalang.Implementation.Basic_Decl_P_Is_Array (Node => Var_Expr_3.Node, Origin => Bound_Origin, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 6094
Scope_Result_3 := Fld_22;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
if Result_Var_3 then
--# expr-start 6098 '<Eq at ast.py:11884>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6096 '<FieldAccess for name_symbol at ast.py:11884>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6095 '<FieldAccess for attribute at ast.py:11884>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:11884
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6095
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_24 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_23.Node);
--# end
--# expr-done 6096
--# expr-start 6097 '<Symbol First at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_First); 
--# expr-done 6097
Is_Equal_5 := Fld_24 = Sym_5; 
--# expr-done 6098
if Is_Equal_5 then
   If_Result_6 := True;
else
   --# expr-start 6102 '<Eq at ast.py:11884>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6100 '<FieldAccess for name_symbol at ast.py:11884>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6099 '<FieldAccess for attribute at ast.py:11884>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:11884
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6099
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_26 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_25.Node);
--# end
--# expr-done 6100
--# expr-start 6101 '<Symbol Last at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Last); 
--# expr-done 6101
Is_Equal_6 := Fld_26 = Sym_6; 
--# expr-done 6102
   If_Result_6 := Is_Equal_6;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 6106 '<Eq at ast.py:11884>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6104 '<FieldAccess for name_symbol at ast.py:11884>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6103 '<FieldAccess for attribute at ast.py:11884>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:11884
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6103
      if Fld_27.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_28 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_27.Node);
--# end
--# expr-done 6104
--# expr-start 6105 '<Symbol Length at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Length); 
--# expr-done 6105
Is_Equal_7 := Fld_28 = Sym_7; 
--# expr-done 6106
   If_Result_7 := Is_Equal_7;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 6110 '<Eq at ast.py:11884>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6108 '<FieldAccess for name_symbol at ast.py:11884>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:11884
--# expr-start 6107 '<FieldAccess for attribute at ast.py:11884>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:11884
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 6107
      if Fld_29.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_30 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_29.Node);
--# end
--# expr-done 6108
--# expr-start 6109 '<Symbol Range at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range); 
--# expr-done 6109
Is_Equal_8 := Fld_30 = Sym_8; 
--# expr-done 6110
   If_Result_8 := Is_Equal_8;
end if;
   If_Result_9 := If_Result_8;
else
   If_Result_9 := False;
end if;
   If_Result_10 := If_Result_9;
end if;
   If_Result_11 := If_Result_10;
else
   If_Result_11 := False;
end if;
if If_Result_11 then
--# expr-start 6111 '<FieldAccess for args at ast.py:11887>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:11887
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Create_Internal_Entity_Assoc_List (Node => Match_2.Node.Attribute_Ref_F_Args, Info => Match_2.Info);
--# expr-done 6111
Var_Expr_4 := Fld_31;
if Var_Expr_4 /= No_Entity_Assoc_List then
   --# scope-start
   --# bind args Var_Expr_4
--# expr-start 6114 '<AllQuantifier at ast.py:11890>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:11890
Saved := Var_Expr_4; 
Fld_32 := Saved.Node;
      Quantifier_Result := True;
      if Fld_32 = null then
      null;
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_32;
      begin
         for Untyped_Item_214 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_214 := Untyped_Item_214; 
Is_Null := Bare_Item_214 = null; 
if Is_Null then
   If_Result_12 := No_Entity_Basic_Assoc;
else
Fld_33 := Saved.Info;
As_Entity := (Info => Fld_33, Node => Bare_Item_214); 
   If_Result_12 := As_Entity;
end if;
                  Item_214 := If_Result_12; 
   --# scope-start
               --# bind arg Item_214
      --# expr-start 6113 '<FieldAccess for is_static_expr at ast.py:11890>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:11890
--# expr-start 6112 '<FieldAccess for expr at ast.py:11890>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:11890
      if Item_214.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_34 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_214.Node, E_Info => Item_214.Info);
--# end
--# expr-done 6112
      if Fld_34.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_35 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_34.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_34.Info);
--# end
--# expr-done 6113
      Quantifier_Result := Fld_35;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 6114
Scope_Result_4 := Quantifier_Result;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := True;
end if;
   If_Result_13 := Result_Var_4;
else
   If_Result_13 := False;
end if;
Let_Result_2 := If_Result_13; 
--# end
Scope_Result_11 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_11; 
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_3; 
--# bind ce Match_3
--# expr-start 6116 '<FieldAccess for is_static_expr at ast.py:11895>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:11895
--# expr-start 6115 '<FieldAccess for name at ast.py:11895>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:11895
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_36 := Create_Internal_Entity_Name (Node => Match_3.Node.Call_Expr_F_Name, Info => Match_3.Info);
--# expr-done 6115
      if Fld_36.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_37 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_36.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_36.Info);
--# end
--# expr-done 6116
if Fld_37 then
   --# expr-start 6120 '<AllQuantifier at ast.py:11896>' Quantifier_Result_1 /tmp/lal-23.0.0/ada/ast.py:11896
   --# expr-start 6117 '<FieldAccess for params at ast.py:11896>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:11896
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_38 := Libadalang.Implementation.Call_Expr_P_Params (Node => Match_3.Node, E_Info => Match_3.Info);
--# end
--# expr-done 6117
Fld_39 := Fld_38.Node;
      Quantifier_Result_1 := True;
      if Fld_39 = null then
      null;
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_39;
      begin
         for Untyped_Item_215 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_215 := Untyped_Item_215; 
Is_Null_1 := Bare_Item_215 = null; 
if Is_Null_1 then
   If_Result_14 := No_Entity_Basic_Assoc;
else
Fld_40 := Fld_38.Info;
As_Entity_1 := (Info => Fld_40, Node => Bare_Item_215); 
   If_Result_14 := As_Entity_1;
end if;
                  Item_215 := If_Result_14; 
   --# scope-start
               --# bind pa Item_215
      --# expr-start 6119 '<FieldAccess for is_static_expr at ast.py:11896>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:11896
--# expr-start 6118 '<FieldAccess for expr at ast.py:11896>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:11896
      if Item_215.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_41 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_215.Node, E_Info => Item_215.Info);
--# end
--# expr-done 6118
      if Fld_41.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_42 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_41.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_41.Info);
--# end
--# expr-done 6119
      Quantifier_Result_1 := Fld_42;
   --# end
               exit when not Quantifier_Result_1;
         end loop;
      end;
      end if;
--# expr-done 6120
   If_Result_15 := Quantifier_Result_1;
else
   If_Result_15 := False;
end if;
Let_Result_3 := If_Result_15; 
--# end
Scope_Result_12 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_12; 
         when Ada_Qual_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Qual_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_4; 
--# bind qe Match_4
--# expr-start 6122 '<FieldAccess for name_designated_type at ast.py:11899>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:11899
--# expr-start 6121 '<FieldAccess for prefix at ast.py:11899>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:11899
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_43 := Create_Internal_Entity_Name (Node => Match_4.Node.Qual_Expr_F_Prefix, Info => Match_4.Info);
--# expr-done 6121
      if Fld_43.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_44 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_43.Node, E_Info => Fld_43.Info);
--# end
--# expr-done 6122
Var_Expr_5 := Fld_44;
if Var_Expr_5 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 6123 '<FieldAccess for is_static_decl at ast.py:11899>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:11899
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_45 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Var_Expr_5.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 6123
Scope_Result_5 := Fld_45;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
if Result_Var_5 then
   --# expr-start 6125 '<FieldAccess for is_static_expr at ast.py:11900>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:11900
--# expr-start 6124 '<FieldAccess for suffix at ast.py:11900>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:11900
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_46 := Create_Internal_Entity_Expr (Node => Match_4.Node.Qual_Expr_F_Suffix, Info => Match_4.Info);
--# expr-done 6124
      if Fld_46.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_47 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_46.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_46.Info);
--# end
--# expr-done 6125
   If_Result_16 := Fld_47;
else
   If_Result_16 := False;
end if;
Let_Result_4 := If_Result_16; 
--# end
Scope_Result_13 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_13; 
         when Ada_Defining_Name .. Ada_Explicit_Deref | Ada_Reduce_Attribute_Ref .. Ada_Op_Xor | Ada_Null_Literal | Ada_Synthetic_Identifier .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_5; 
--# bind n Match_5
--# expr-start 6126 '<FieldAccess for referenced_decl at ast.py:11903>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:11903
      if Match_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_48 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Match_5.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_5.Info);
--# end
--# expr-done 6126
Var_Expr_6 := Fld_48;
if Var_Expr_6 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 6127 '<FieldAccess for is_static_decl at ast.py:11903>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:11903
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_49 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Var_Expr_6.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 6127
Scope_Result_6 := Fld_49;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := False;
end if;
Let_Result_5 := Result_Var_6; 
--# end
Scope_Result_14 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_14; 
         when Ada_Membership_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Membership_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_6 := Cast_Result_6; 
--# bind me Match_6
--# expr-start 6129 '<FieldAccess for is_static_expr at ast.py:11906>' Fld_51 /tmp/lal-23.0.0/ada/ast.py:11906
--# expr-start 6128 '<FieldAccess for expr at ast.py:11906>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:11906
      if Match_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_50 := Create_Internal_Entity_Expr (Node => Match_6.Node.Membership_Expr_F_Expr, Info => Match_6.Info);
--# expr-done 6128
      if Fld_50.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_51 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_50.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_50.Info);
--# end
--# expr-done 6129
if Fld_51 then
   --# expr-start 6132 '<AllQuantifier at ast.py:11906>' Quantifier_Result_2 /tmp/lal-23.0.0/ada/ast.py:11906
   --# expr-start 6130 '<FieldAccess for membership_exprs at ast.py:11906>' Fld_52 /tmp/lal-23.0.0/ada/ast.py:11906
      if Match_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_52 := Create_Internal_Entity_Expr_Alternatives_List (Node => Match_6.Node.Membership_Expr_F_Membership_Exprs, Info => Match_6.Info);
--# expr-done 6130
Fld_53 := Fld_52.Node;
      Quantifier_Result_2 := True;
      if Fld_53 = null then
      null;
      else
      declare
         Collection : constant Bare_Expr_Alternatives_List := Fld_53;
      begin
         for Untyped_Item_216 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_216 := Untyped_Item_216; 
Is_Null_2 := Bare_Item_216 = null; 
if Is_Null_2 then
   If_Result_17 := No_Entity_Expr;
else
Fld_54 := Fld_52.Info;
As_Entity_2 := (Info => Fld_54, Node => Bare_Item_216); 
   If_Result_17 := As_Entity_2;
end if;
                  Item_216 := If_Result_17; 
   --# scope-start
               --# bind e Item_216
      --# expr-start 6131 '<FieldAccess for is_static_expr at ast.py:11907>' Fld_55 /tmp/lal-23.0.0/ada/ast.py:11907
      if Item_216.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_55 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Item_216.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Item_216.Info);
--# end
--# expr-done 6131
      Quantifier_Result_2 := Fld_55;
   --# end
               exit when not Quantifier_Result_2;
         end loop;
      end;
      end if;
--# expr-done 6132
   If_Result_18 := Quantifier_Result_2;
else
   If_Result_18 := False;
end if;
Let_Result_6 := If_Result_18; 
--# end
Scope_Result_15 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_15; 
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_7 := Cast_Result_7; 
--# bind bo Match_7
--# expr-start 6134 '<FieldAccess for is_static_expr at ast.py:11911>' Fld_57 /tmp/lal-23.0.0/ada/ast.py:11911
--# expr-start 6133 '<FieldAccess for left at ast.py:11911>' Fld_56 /tmp/lal-23.0.0/ada/ast.py:11911
      if Match_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_56 := Create_Internal_Entity_Expr (Node => Match_7.Node.Bin_Op_F_Left, Info => Match_7.Info);
--# expr-done 6133
      if Fld_56.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_57 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_56.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_56.Info);
--# end
--# expr-done 6134
if Fld_57 then
   --# expr-start 6136 '<FieldAccess for is_static_expr at ast.py:11912>' Fld_59 /tmp/lal-23.0.0/ada/ast.py:11912
--# expr-start 6135 '<FieldAccess for right at ast.py:11912>' Fld_58 /tmp/lal-23.0.0/ada/ast.py:11912
      if Match_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_58 := Create_Internal_Entity_Expr (Node => Match_7.Node.Bin_Op_F_Right, Info => Match_7.Info);
--# expr-done 6135
      if Fld_58.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_59 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_58.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_58.Info);
--# end
--# expr-done 6136
   If_Result_19 := Fld_59;
else
   If_Result_19 := False;
end if;
if If_Result_19 then
--# expr-start 6138 '<FieldAccess for referenced_decl at ast.py:11913>' Fld_61 /tmp/lal-23.0.0/ada/ast.py:11913
--# expr-start 6137 '<FieldAccess for op at ast.py:11913>' Fld_60 /tmp/lal-23.0.0/ada/ast.py:11913
      if Match_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_60 := Create_Internal_Entity_Op (Node => Match_7.Node.Bin_Op_F_Op, Info => Match_7.Info);
--# expr-done 6137
      if Fld_60.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_61 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_60.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_60.Info);
--# end
--# expr-done 6138
Var_Expr_7 := Fld_61;
if Var_Expr_7 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind decl Var_Expr_7
--# expr-start 6139 '<FieldAccess for is_static_decl at ast.py:11914>' Fld_62 /tmp/lal-23.0.0/ada/ast.py:11914
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_62 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Var_Expr_7.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 6139
Scope_Result_7 := Fld_62;
   --# end
   Result_Var_7 := Scope_Result_7;
else
   Result_Var_7 := True;
end if;
   If_Result_20 := Result_Var_7;
else
   If_Result_20 := False;
end if;
Let_Result_7 := If_Result_20; 
--# end
Scope_Result_16 := Let_Result_7;
   --# end
            Match_Result := Scope_Result_16; 
         when Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity_Un_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_8 := Cast_Result_8; 
--# bind uo Match_8
--# expr-start 6141 '<FieldAccess for is_static_expr at ast.py:11919>' Fld_64 /tmp/lal-23.0.0/ada/ast.py:11919
--# expr-start 6140 '<FieldAccess for expr at ast.py:11919>' Fld_63 /tmp/lal-23.0.0/ada/ast.py:11919
      if Match_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_63 := Create_Internal_Entity_Expr (Node => Match_8.Node.Un_Op_F_Expr, Info => Match_8.Info);
--# expr-done 6140
      if Fld_63.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_64 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_63.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_63.Info);
--# end
--# expr-done 6141
if Fld_64 then
--# expr-start 6143 '<FieldAccess for referenced_decl at ast.py:11920>' Fld_66 /tmp/lal-23.0.0/ada/ast.py:11920
--# expr-start 6142 '<FieldAccess for op at ast.py:11920>' Fld_65 /tmp/lal-23.0.0/ada/ast.py:11920
      if Match_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_65 := Create_Internal_Entity_Op (Node => Match_8.Node.Un_Op_F_Op, Info => Match_8.Info);
--# expr-done 6142
      if Fld_65.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_66 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_65.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_65.Info);
--# end
--# expr-done 6143
Var_Expr_8 := Fld_66;
if Var_Expr_8 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind decl Var_Expr_8
--# expr-start 6144 '<FieldAccess for is_static_decl at ast.py:11921>' Fld_67 /tmp/lal-23.0.0/ada/ast.py:11921
      if Var_Expr_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_67 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Var_Expr_8.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_8.Info);
--# end
--# expr-done 6144
Scope_Result_8 := Fld_67;
   --# end
   Result_Var_8 := Scope_Result_8;
else
   Result_Var_8 := True;
end if;
   If_Result_21 := Result_Var_8;
else
   If_Result_21 := False;
end if;
Let_Result_8 := If_Result_21; 
--# end
Scope_Result_17 := Let_Result_8;
   --# end
            Match_Result := Scope_Result_17; 
         when Ada_If_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_If_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_9 := Cast_Result_9; 
--# bind i Match_9
--# expr-start 6146 '<FieldAccess for is_static_expr at ast.py:11926>' Fld_69 /tmp/lal-23.0.0/ada/ast.py:11926
--# expr-start 6145 '<FieldAccess for cond_expr at ast.py:11926>' Fld_68 /tmp/lal-23.0.0/ada/ast.py:11926
      if Match_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_68 := Create_Internal_Entity_Expr (Node => Match_9.Node.If_Expr_F_Cond_Expr, Info => Match_9.Info);
--# expr-done 6145
      if Fld_68.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_69 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_68.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_68.Info);
--# end
--# expr-done 6146
if Fld_69 then
   --# expr-start 6148 '<FieldAccess for is_static_expr at ast.py:11926>' Fld_71 /tmp/lal-23.0.0/ada/ast.py:11926
--# expr-start 6147 '<FieldAccess for then_expr at ast.py:11926>' Fld_70 /tmp/lal-23.0.0/ada/ast.py:11926
      if Match_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_70 := Create_Internal_Entity_Expr (Node => Match_9.Node.If_Expr_F_Then_Expr, Info => Match_9.Info);
--# expr-done 6147
      if Fld_70.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_71 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_70.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_70.Info);
--# end
--# expr-done 6148
   If_Result_22 := Fld_71;
else
   If_Result_22 := False;
end if;
if If_Result_22 then
   --# expr-start 6154 '<AllQuantifier at ast.py:11927>' Quantifier_Result_3 /tmp/lal-23.0.0/ada/ast.py:11927
   --# expr-start 6149 '<FieldAccess for alternatives at ast.py:11927>' Fld_72 /tmp/lal-23.0.0/ada/ast.py:11927
      if Match_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_72 := Create_Internal_Entity_Elsif_Expr_Part_List (Node => Match_9.Node.If_Expr_F_Alternatives, Info => Match_9.Info);
--# expr-done 6149
Fld_73 := Fld_72.Node;
      Quantifier_Result_3 := True;
      if Fld_73 = null then
      null;
      else
      declare
         Collection : constant Bare_Elsif_Expr_Part_List := Fld_73;
      begin
         for Untyped_Item_217 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_217 := Untyped_Item_217; 
Is_Null_3 := Bare_Item_217 = null; 
if Is_Null_3 then
   If_Result_23 := No_Entity_Elsif_Expr_Part;
else
Fld_74 := Fld_72.Info;
As_Entity_3 := (Info => Fld_74, Node => Bare_Item_217); 
   If_Result_23 := As_Entity_3;
end if;
                  Item_217 := If_Result_23; 
   --# scope-start
               --# bind a Item_217
--# expr-start 6151 '<FieldAccess for is_static_expr at ast.py:11929>' Fld_76 /tmp/lal-23.0.0/ada/ast.py:11929
--# expr-start 6150 '<FieldAccess for cond_expr at ast.py:11929>' Fld_75 /tmp/lal-23.0.0/ada/ast.py:11929
      if Item_217.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_75 := Create_Internal_Entity_Expr (Node => Item_217.Node.Elsif_Expr_Part_F_Cond_Expr, Info => Item_217.Info);
--# expr-done 6150
      if Fld_75.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_76 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_75.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_75.Info);
--# end
--# expr-done 6151
if Fld_76 then
   --# expr-start 6153 '<FieldAccess for is_static_expr at ast.py:11930>' Fld_78 /tmp/lal-23.0.0/ada/ast.py:11930
--# expr-start 6152 '<FieldAccess for then_expr at ast.py:11930>' Fld_77 /tmp/lal-23.0.0/ada/ast.py:11930
      if Item_217.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_77 := Create_Internal_Entity_Expr (Node => Item_217.Node.Elsif_Expr_Part_F_Then_Expr, Info => Item_217.Info);
--# expr-done 6152
      if Fld_77.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_78 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_77.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_77.Info);
--# end
--# expr-done 6153
   If_Result_24 := Fld_78;
else
   If_Result_24 := False;
end if;
      Quantifier_Result_3 := If_Result_24;
   --# end
               exit when not Quantifier_Result_3;
         end loop;
      end;
      end if;
--# expr-done 6154
   If_Result_25 := Quantifier_Result_3;
else
   If_Result_25 := False;
end if;
if If_Result_25 then
   --# expr-start 6156 '<FieldAccess for is_static_expr at ast.py:11932>' Fld_80 /tmp/lal-23.0.0/ada/ast.py:11932
--# expr-start 6155 '<FieldAccess for else_expr at ast.py:11932>' Fld_79 /tmp/lal-23.0.0/ada/ast.py:11932
      if Match_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_79 := Create_Internal_Entity_Expr (Node => Match_9.Node.If_Expr_F_Else_Expr, Info => Match_9.Info);
--# expr-done 6155
      if Fld_79.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_80 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_79.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_79.Info);
--# end
--# expr-done 6156
   If_Result_26 := Fld_80;
else
   If_Result_26 := False;
end if;
Let_Result_9 := If_Result_26; 
--# end
Scope_Result_18 := Let_Result_9;
   --# end
            Match_Result := Scope_Result_18; 
         when Ada_Paren_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity_Paren_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_10 := Cast_Result_10; 
--# bind pe Match_10
--# expr-start 6158 '<FieldAccess for is_static_expr at ast.py:11934>' Fld_82 /tmp/lal-23.0.0/ada/ast.py:11934
--# expr-start 6157 '<FieldAccess for expr at ast.py:11934>' Fld_81 /tmp/lal-23.0.0/ada/ast.py:11934
      if Match_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_81 := Create_Internal_Entity_Expr (Node => Match_10.Node.Paren_Expr_F_Expr, Info => Match_10.Info);
--# expr-done 6157
      if Fld_81.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_82 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_81.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_81.Info);
--# end
--# expr-done 6158
Let_Result_10 := Fld_82; 
--# end
Scope_Result_19 := Let_Result_10;
   --# end
            Match_Result := Scope_Result_19; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Case_Expr | Ada_Contract_Cases .. Ada_Decl_Expr | Ada_Quantified_Expr .. Ada_Raise_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_11 := Cast_Result_11; 
--# bind _ Match_11
Let_Result_11 := False; 
--# end
Scope_Result_20 := Let_Result_11;
   --# end
            Match_Result := Scope_Result_20; 
end case;
--# expr-done 6159
Dyn_Var_Bind_Result := Match_Result; 
--# expr-done 6160
Let_Result_12 := Dyn_Var_Bind_Result; 
--# end
--# expr-done 6161
      Property_Result := Let_Result_12;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Is_Static_Expr;
--# end
--# property-start '[dispatcher]Expr.first_corresponding_decl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_First_Corresponding_Decl
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Un_Op =>
                  --# property-call-start Expr.first_corresponding_decl
                  Property_Result := Expr_P_First_Corresponding_Decl
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.first_corresponding_decl
                  Property_Result := Name_P_First_Corresponding_Decl
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_First_Corresponding_Decl;
--# end
--# property-start Expr.eval_as_int /tmp/lal-23.0.0/ada/ast.py:11948
pragma Warnings (Off, "is not referenced");
 function Expr_P_Eval_As_Int
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Big_Integer_Type
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Big_Integer_Type;
            procedure Finalizer_Scope_934 with Inline_Always;
      Fld : Big_Integer_Type;
Let_Result : Big_Integer_Type;
            procedure Finalizer_Scope_934 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_934;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6163 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6162 '<FieldAccess for eval_as_int_in_env at ast.py:11964>' Fld /tmp/lal-23.0.0/ada/ast.py:11964
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Eval_As_Int_In_Env (Node => Ent.Node, Env => No_Internal_Substitution_Array_Type, E_Info => Ent.Info);
--# expr-done 6162
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 6163
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_934;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_934;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Eval_As_Int;
--# end
--# property-start Expr.eval_as_string /tmp/lal-23.0.0/ada/ast.py:11988
pragma Warnings (Off, "is not referenced");
 function Expr_P_Eval_As_String
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_937 with Inline_Always;
      Fld : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_937 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_937;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6165 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6164 '<FieldAccess for eval_as_string_in_env at ast.py:12004>' Fld /tmp/lal-23.0.0/ada/ast.py:12004
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Eval_As_String_In_Env (Node => Ent.Node, Env => No_Internal_Substitution_Array_Type, E_Info => Ent.Info);
--# expr-done 6164
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 6165
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_937;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_937;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Eval_As_String;
--# end
--# property-start Expr.discrete_range /tmp/lal-23.0.0/ada/ast.py:12028
pragma Warnings (Off, "is not referenced");
 function Expr_P_Discrete_Range
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Match_0 : Internal_Entity_Attribute_Ref;
Match_1 : Internal_Entity_Name;
Match_2 : Internal_Entity_Bin_Op;
Match_3 : Internal_Entity_Expr;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Discrete_Range;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Discrete_Range;
Scope_Result : Internal_Discrete_Range;
Result_Var : Internal_Discrete_Range;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Internal_Entity_Expr;
New_Struct : Internal_Discrete_Range;
Match_Prefix : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Attribute_Ref;
Let_Result : Internal_Discrete_Range;
Scope_Result_1 : Internal_Discrete_Range;
Cast_Result_1 : Internal_Entity_Name;
Let_Result_1 : Internal_Discrete_Range;
Scope_Result_2 : Internal_Discrete_Range;
Cast_Result_2 : Internal_Entity_Bin_Op;
Let_Result_2 : Internal_Discrete_Range;
Scope_Result_3 : Internal_Discrete_Range;
Cast_Result_3 : Internal_Entity_Expr;
Let_Result_3 : Internal_Discrete_Range;
Scope_Result_4 : Internal_Discrete_Range;
Match_Result : Internal_Discrete_Range;
Let_Result_4 : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6174 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 6173 '<Match at ast.py:12032>' Match_Result /tmp/lal-23.0.0/ada/ast.py:12032
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Expr (Match_Prefix.Node.Kind) is
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind ar Match_0
--# expr-start 6167 '<FieldAccess for discrete_range at ast.py:12034>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12034
--# expr-start 6166 '<FieldAccess for prefix at ast.py:12034>' Fld /tmp/lal-23.0.0/ada/ast.py:12034
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Match_0.Node.Attribute_Ref_F_Prefix, Info => Match_0.Info);
--# expr-done 6166
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.discrete_range
Fld_1 := Libadalang.Implementation.Expr_P_Discrete_Range (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 6167
Let_Result := Fld_1; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Call_Expr .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind n Match_1
--# expr-start 6168 '<FieldAccess for name_designated_type at ast.py:12036>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12036
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_2 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 6168
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind dt Var_Expr
--# expr-start 6169 '<FieldAccess for discrete_range at ast.py:12037>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12037
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discrete_range'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discrete_Range (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 6169
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Discrete_Range;
end if;
Let_Result_1 := Result_Var; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind bo Match_2
--# expr-start 6172 '<New DiscreteRange at ast.py:12040>' New_Struct /tmp/lal-23.0.0/ada/ast.py:12040
--# expr-start 6170 '<FieldAccess for right at ast.py:12041>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12041
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Match_2.Node.Bin_Op_F_Right, Info => Match_2.Info);
--# expr-done 6170
--# expr-start 6171 '<FieldAccess for left at ast.py:12041>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12041
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Match_2.Node.Bin_Op_F_Left, Info => Match_2.Info);
--# expr-done 6171
New_Struct := (High_Bound => Fld_5, Low_Bound => Fld_4); 
--# expr-done 6172
Let_Result_2 := New_Struct; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_3; 
--# bind _ Match_3
Let_Result_3 := No_Discrete_Range; 
--# end
Scope_Result_4 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_4; 
end case;
--# expr-done 6173
Let_Result_4 := Match_Result; 
--# end
--# expr-done 6174
      Property_Result := Let_Result_4;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Discrete_Range;
--# end
--# property-start '[dispatcher]Expr.designated_env_no_overloading' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_Designated_Env_No_Overloading
  (Node : Bare_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Un_Op =>
                  --# property-call-start Expr.designated_env_no_overloading
                  Property_Result := Expr_P_Designated_Env_No_Overloading
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.designated_env_no_overloading
                  Property_Result := Dotted_Name_P_Designated_Env_No_Overloading
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.designated_env_no_overloading
                  Property_Result := Base_Id_P_Designated_Env_No_Overloading
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_Designated_Env_No_Overloading;
--# end
--# property-start '[dispatcher]Expr.designated_env' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_Designated_Env
  (Node : Bare_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr .. Ada_Membership_Expr | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name | Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Un_Op =>
                  --# property-call-start Expr.designated_env
                  Property_Result := Expr_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.designated_env
                  Property_Result := Attribute_Ref_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.designated_env
                  Property_Result := Call_Expr_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.designated_env
                  Property_Result := Dotted_Name_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.designated_env
                  Property_Result := Explicit_Deref_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Qual_Expr =>
                  --# property-call-start QualExpr.designated_env
                  Property_Result := Qual_Expr_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.designated_env
                  Property_Result := Base_Id_P_Designated_Env
                    (Self
                        , Env
                        , Origin
                        , No_Visibility
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_Designated_Env;
--# end
--# property-start Expr.env_elements /tmp/lal-23.0.0/ada/ast.py:12071
pragma Warnings (Off, "is not referenced");
 function Expr_P_Env_Elements
  (Node : Bare_Expr
      ; Env : Lexical_Env
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind no_visibility No_Visibility
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_942 with Inline_Always;
      Fld : Internal_Entity_Array_Access;
Fld_1 : Boolean;
Map_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_942 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_942;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6177 '<Filter at ast.py:12072>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12072
   --# expr-start 6175 '<FieldAccess for env_elements_impl at ast.py:12072>' Fld /tmp/lal-23.0.0/ada/ast.py:12072
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6175
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_218 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_218
         --# expr-start 6176 '<FieldAccess for has_visibility at ast.py:12072>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12072
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_visibility
Fld_1 := Libadalang.Implementation.Ada_Node_P_Has_Visibility (Node => Self, Other_Entity => Item_218);
--# end
--# expr-done 6176
         if Fld_1 then
         declare
            Item_To_Append : constant Internal_Entity := Item_218;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6177
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_942;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_942;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Env_Elements;
--# end
--# property-start '[dispatcher]Expr.env_elements_impl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Expr_P_Env_Elements_Impl
  (Node : Bare_Expr
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Expr (Self.Kind) is
               when Ada_Abstract_State_Decl_Expr .. Ada_Membership_Expr | Ada_Discrete_Subtype_Name | Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Un_Op =>
                  --# property-call-start Expr.env_elements_impl
                  Property_Result := Expr_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.env_elements_impl
                  Property_Result := Attribute_Ref_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.env_elements_impl
                  Property_Result := Call_Expr_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.env_elements_impl
                  Property_Result := Defining_Name_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.env_elements_impl
                  Property_Result := Dotted_Name_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.env_elements_impl
                  Property_Result := End_Name_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.env_elements_impl
                  Property_Result := Explicit_Deref_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Qual_Expr =>
                  --# property-call-start QualExpr.env_elements_impl
                  Property_Result := Qual_Expr_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.env_elements_impl
                  Property_Result := Base_Id_P_Env_Elements_Impl
                    (Self
                        , Env
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Expr_P_Env_Elements_Impl;
--# end
--# property-start Expr.matching_nodes /tmp/lal-23.0.0/ada/ast.py:12087
pragma Warnings (Off, "is not referenced");
 function Expr_P_Matching_Nodes
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_944 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_944 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_944;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6181 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6180 '<bind at ast.py:12092>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:12092
--# expr-start 6178 '<FieldAccess for node_env at ast.py:12092>' Fld /tmp/lal-23.0.0/ada/ast.py:12092
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Self);
--# expr-done 6178
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 6179 '<FieldAccess for env_elements at ast.py:12092>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12092
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_1 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Ent.Node, Env => Bound_Env, No_Visibility => False, E_Info => Ent.Info);
--# end
--# expr-done 6179
Dyn_Var_Bind_Result := Fld_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 6180
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 6181
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_944;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_944;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Matching_Nodes;
--# end
--# property-start Expr.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:11611
pragma Warnings (Off, "is not referenced");
 function Expr_P_Has_Context_Free_Type
  (Node : Bare_Expr
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6182 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := True; 
--# end
--# expr-done 6182
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Has_Context_Free_Type;
--# end
 function Expr_P_Potential_Actuals_For_Dispatch
  (Node : Bare_Expr
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Expected_Type_For_Expr_Array_Access
is (raise Property_Error
    with "Property Expr.potential_actuals_for_dispatch not implemented on type "
    & Kind_Name (Node));
--# property-start Expr.is_dispatching_call /tmp/lal-23.0.0/ada/ast.py:11843
pragma Warnings (Off, "is not referenced");
 function Expr_P_Is_Dispatching_Call
  (Node : Bare_Expr
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6183 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := raise Property_Error with "Invalid node type: expected Name, UnOp or BinOp"; 
--# end
--# expr-done 6183
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Is_Dispatching_Call;
--# end
--# property-start Expr.first_corresponding_decl /tmp/lal-23.0.0/ada/ast.py:11940
pragma Warnings (Off, "is not referenced");
 function Expr_P_First_Corresponding_Decl
  (Node : Bare_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
      Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6184 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Basic_Decl; 
--# end
--# expr-done 6184
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_First_Corresponding_Decl;
--# end
--# property-start Expr.designated_env_no_overloading /tmp/lal-23.0.0/ada/ast.py:12048
pragma Warnings (Off, "is not referenced");
 function Expr_P_Designated_Env_No_Overloading
  (Node : Bare_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Expr := Bare_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Expr :=
     Internal_Entity_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_940 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_940 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_940;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6186 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6185 '<FieldAccess for designated_env at ast.py:12055>' Fld /tmp/lal-23.0.0/ada/ast.py:12055
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Ent.Node, Env => Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Ent.Info);
--# end
--# expr-done 6185
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 6186
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_940;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_940;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Expr_P_Designated_Env_No_Overloading;
--# end
 function Expr_P_Designated_Env
  (Node : Bare_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is (raise Property_Error
    with "Property Expr.designated_env not implemented on type "
    & Kind_Name (Node));
 function Expr_P_Env_Elements_Impl
  (Node : Bare_Expr
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is (raise Property_Error
    with "Property Expr.env_elements_impl not implemented on type "
    & Kind_Name (Node));
   --
   --  Primitives for Bare_Abstract_State_Decl_Expr
   --
      procedure Initialize_Fields_For_Abstract_State_Decl_Expr
        (Self : Bare_Abstract_State_Decl_Expr
         ; Abstract_State_Decl_Expr_F_State_Decl : Bare_Ada_Node
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Abstract_State_Decl_Expr_F_State_Decl := Abstract_State_Decl_Expr_F_State_Decl;
      end Initialize_Fields_For_Abstract_State_Decl_Expr;
   function Abstract_State_Decl_Expr_F_State_Decl
     (Node : Bare_Abstract_State_Decl_Expr) return Bare_Ada_Node
   is
   begin
         return Node.Abstract_State_Decl_Expr_F_State_Decl;
   end;
--# property-start AbstractStateDeclExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:20946
pragma Warnings (Off, "is not referenced");
 function Abstract_State_Decl_Expr_P_Xref_Equation
  (Node : Bare_Abstract_State_Decl_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Abstract_State_Decl_Expr := Bare_Abstract_State_Decl_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1467 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_1467 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_1467;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20946") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1467;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1467;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abstract_State_Decl_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Allocator
   --
      procedure Initialize_Fields_For_Allocator
        (Self : Bare_Allocator
         ; Allocator_F_Subpool : Bare_Name
         ; Allocator_F_Type_Or_Expr : Bare_Ada_Node
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Allocator_F_Subpool := Allocator_F_Subpool;
            Self.Allocator_F_Type_Or_Expr := Allocator_F_Type_Or_Expr;
      end Initialize_Fields_For_Allocator;
   function Allocator_F_Subpool
     (Node : Bare_Allocator) return Bare_Name
   is
   begin
         return Node.Allocator_F_Subpool;
   end;
   function Allocator_F_Type_Or_Expr
     (Node : Bare_Allocator) return Bare_Ada_Node
   is
   begin
         return Node.Allocator_F_Type_Or_Expr;
   end;
--# property-start Allocator.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:17961
pragma Warnings (Off, "is not referenced");
 function Allocator_P_Has_Context_Free_Type
  (Node : Bare_Allocator
  )
   return Boolean
is
   Self : Bare_Allocator := Bare_Allocator (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Allocator_P_Has_Context_Free_Type;
--# end
--# property-start Allocator.get_allocated_type /tmp/lal-23.0.0/ada/ast.py:17964
pragma Warnings (Off, "is not referenced");
 function Allocator_P_Get_Allocated_Type
  (Node : Bare_Allocator
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Allocator := Bare_Allocator (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Allocator :=
     Internal_Entity_Allocator'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Subtype_Indication;
Match_1 : Internal_Entity_Qual_Expr;
Match_2 : Internal_Entity;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Subtype_Indication;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Qual_Expr;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6193 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 6192 '<bind at ast.py:17968>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:17968
--# expr-start 6187 '<FieldAccess for origin_node at ast.py:17968>' Fld /tmp/lal-23.0.0/ada/ast.py:17968
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 6187
Bound_Origin := Fld; 
--# expr-start 6191 '<Match at ast.py:17968>' Match_Result /tmp/lal-23.0.0/ada/ast.py:17968
--# expr-start 6188 '<FieldAccess for type_or_expr at ast.py:17968>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17968
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity (Node => Ent.Node.Allocator_F_Type_Or_Expr, Info => Ent.Info);
--# expr-done 6188
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_1; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind t Match_0
--# expr-start 6189 '<FieldAccess for designated_type at ast.py:17969>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17969
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Match_0.Node, Origin => Bound_Origin, E_Info => Match_0.Info);
--# end
--# expr-done 6189
Let_Result := Fld_2; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Qual_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Qual_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind q Match_1
--# expr-start 6190 '<FieldAccess for designated_type at ast.py:17970>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17970
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start QualExpr.designated_type
Fld_3 := Libadalang.Implementation.Qual_Expr_P_Designated_Type (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 6190
Let_Result_1 := Fld_3; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Explicit_Deref | Ada_Reduce_Attribute_Ref .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Base_Type_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 6191
Dyn_Var_Bind_Result := Match_Result; 
--# expr-done 6192
Let_Result_3 := Dyn_Var_Bind_Result; 
--# end
--# expr-done 6193
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Allocator_P_Get_Allocated_Type;
--# end
--# property-start Allocator.xref_equation /tmp/lal-23.0.0/ada/ast.py:17975
pragma Warnings (Off, "is not referenced");
 function Allocator_P_Xref_Equation
  (Node : Bare_Allocator
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Allocator := Bare_Allocator (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Allocator :=
     Internal_Entity_Allocator'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1288 with Inline_Always;
      Fld : Internal_Entity;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity_Base_Type_Decl;
Pred : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1288 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1288;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6204 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6203 '<And at ast.py:17977>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:17977
--# expr-start 6199 '<And at ast.py:17977>' And_Pred /tmp/lal-23.0.0/ada/ast.py:17977
--# expr-start 6195 '<FieldAccess for sub_equation at ast.py:17977>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17977
--# expr-start 6194 '<FieldAccess for type_or_expr at ast.py:17977>' Fld /tmp/lal-23.0.0/ada/ast.py:17977
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Allocator_F_Type_Or_Expr, Info => Ent.Info);
--# expr-done 6194
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 6195
--# expr-start 6198 '<Bind at ast.py:17978>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:17978
--# expr-start 6196 '<FieldAccess for expected_type_var at ast.py:17978>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17978
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6196
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 6197 '<FieldAccess for type_var at ast.py:17978>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17978
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6197
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Bind_Result := Solver.Create_Unify (Fld_2, Fld_3, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17978") else null)); 
--# expr-done 6198
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17977") else null)); 
--# expr-done 6199
--# expr-start 6202 '<Predicate on BaseTypeDecl.matching_allocator_type at ast.py:17979>' Pred /tmp/lal-23.0.0/ada/ast.py:17979
--# expr-start 6200 '<FieldAccess for type_var at ast.py:17980>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17980
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6200
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 6201 '<FieldAccess for get_allocated_type at ast.py:17980>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17980
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Allocator.get_allocated_type
Fld_5 := Libadalang.Implementation.Allocator_P_Get_Allocated_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 6201
Pred := Solver.Create_Predicate (Fld_4, Create_Base_Type_Decl_P_Matching_Allocator_Type_0_Predicate (Fld_5, Origin)); 
--# expr-done 6202
And_Pred_1 := Create_And (And_Pred, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17977") else null)); 
--# expr-done 6203
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6204
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1288;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1288;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Allocator_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Base_Aggregate
   --
      procedure Initialize_Fields_For_Base_Aggregate
        (Self : Bare_Base_Aggregate
         ; Base_Aggregate_F_Ancestor_Expr : Bare_Expr
         ; Base_Aggregate_F_Assocs : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Base_Aggregate_F_Ancestor_Expr := Base_Aggregate_F_Ancestor_Expr;
            Self.Base_Aggregate_F_Assocs := Base_Aggregate_F_Assocs;
      end Initialize_Fields_For_Base_Aggregate;
   function Base_Aggregate_F_Ancestor_Expr
     (Node : Bare_Base_Aggregate) return Bare_Expr
   is
   begin
         return Node.Base_Aggregate_F_Ancestor_Expr;
   end;
   function Base_Aggregate_F_Assocs
     (Node : Bare_Base_Aggregate) return Bare_Assoc_List
   is
   begin
         return Node.Base_Aggregate_F_Assocs;
   end;
--# property-start BaseAggregate.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12828
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Has_Context_Free_Type
  (Node : Bare_Base_Aggregate
  )
   return Boolean
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Has_Context_Free_Type;
--# end
--# property-start BaseAggregate.xref_equation /tmp/lal-23.0.0/ada/ast.py:12831
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Xref_Equation
  (Node : Bare_Base_Aggregate
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_978 with Inline_Always;
            procedure Finalizer_Scope_2699 with Inline_Always;
            procedure Finalizer_Scope_2700 with Inline_Always;
      Block_Var : Logic_Equation;
Var_Expr : Internal_Entity_Expr;
True_Rel : Logic_Equation;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
Sym : Symbol_Type;
Fld_4 : Boolean;
Sym_1 : Symbol_Type;
Fld_5 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Fld_6 : Boolean;
If_Result_1 : Boolean;
Sym_3 : Symbol_Type;
Fld_7 : Boolean;
If_Result_2 : Boolean;
Sym_4 : Symbol_Type;
Fld_8 : Boolean;
If_Result_3 : Boolean;
Sym_5 : Symbol_Type;
Fld_9 : Boolean;
If_Result_4 : Boolean;
Fld_10 : Boolean;
If_Result_5 : Boolean;
If_Result_6 : Logic_Equation;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_13 : Internal_Entity_Assoc_List;
Fld_14 : Bare_Assoc_List;
Fld_15 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result_7 : Internal_Entity_Basic_Assoc;
Fld_16 : Logic_Equation;
Item_219 : Internal_Entity_Basic_Assoc;
Bare_Item_219 : Bare_Basic_Assoc;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_978 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_978;
            procedure Finalizer_Scope_2699 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2699;
            procedure Finalizer_Scope_2700 is
            begin
                     Dec_Ref (Fld_16);
            end Finalizer_Scope_2700;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6235 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6226 '<If at ast.py:12837>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:12837
--# expr-start 6206 '<FieldAccess for in_aspect at ast.py:12841>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12841
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6205 '<Symbol Global at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Global); 
--# expr-done 6205
--# property-call-start AdaNode.in_aspect
Fld_4 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym);
--# end
--# expr-done 6206
if Fld_4 then
   If_Result := True;
else
   --# expr-start 6208 '<FieldAccess for in_aspect at ast.py:12841>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12841
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6207 '<Symbol Refined_Global at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Global); 
--# expr-done 6207
--# property-call-start AdaNode.in_aspect
Fld_5 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym_1);
--# end
--# expr-done 6208
   If_Result := Fld_5;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 6210 '<FieldAccess for in_aspect at ast.py:12842>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12842
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6209 '<Symbol Depends at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Depends); 
--# expr-done 6209
--# property-call-start AdaNode.in_aspect
Fld_6 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym_2);
--# end
--# expr-done 6210
   If_Result_1 := Fld_6;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 6212 '<FieldAccess for in_aspect at ast.py:12842>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12842
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6211 '<Symbol Refined_Depends at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Depends); 
--# expr-done 6211
--# property-call-start AdaNode.in_aspect
Fld_7 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym_3);
--# end
--# expr-done 6212
   If_Result_2 := Fld_7;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 6214 '<FieldAccess for in_aspect at ast.py:12843>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12843
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6213 '<Symbol Test_Case at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Test_Case); 
--# expr-done 6213
--# property-call-start AdaNode.in_aspect
Fld_8 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym_4);
--# end
--# expr-done 6214
   If_Result_3 := Fld_8;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 6216 '<FieldAccess for in_aspect at ast.py:12843>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12843
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6215 '<Symbol Refined_State at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_State); 
--# expr-done 6215
--# property-call-start AdaNode.in_aspect
Fld_9 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym_5);
--# end
--# expr-done 6216
   If_Result_4 := Fld_9;
end if;
if If_Result_4 then
   If_Result_5 := True;
else
   --# expr-start 6217 '<FieldAccess for is_contract_cases_base_aggregate at ast.py:12847>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12847
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.is_contract_cases_base_aggregate
Fld_10 := Libadalang.Implementation.Base_Aggregate_P_Is_Contract_Cases_Base_Aggregate (Node => Self);
--# end
--# expr-done 6217
   If_Result_5 := Fld_10;
end if;
if If_Result_5 then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12848") else null)); 
   If_Result_6 := True_Rel;
else
   --# expr-start 6225 '<bind at ast.py:12849>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:12849
--# expr-start 6218 '<FieldAccess for origin_node at ast.py:12850>' Fld /tmp/lal-23.0.0/ada/ast.py:12850
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 6218
Bound_Origin := Fld; 
--# expr-start 6224 '<And at ast.py:12851>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12851
--# expr-start 6220 '<Predicate on BaseTypeDecl.is_array_or_rec at ast.py:12851>' Pred /tmp/lal-23.0.0/ada/ast.py:12851
--# expr-start 6219 '<FieldAccess for expected_type_var at ast.py:12851>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12851
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6219
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_Predicate (Fld_1, Create_Base_Type_Decl_P_Is_Array_Or_Rec_0_Predicate (Bound_Origin)); 
--# expr-done 6220
--# expr-start 6223 '<Bind at ast.py:12852>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12852
--# expr-start 6221 '<FieldAccess for expected_type_var at ast.py:12852>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12852
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6221
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 6222 '<FieldAccess for type_var at ast.py:12852>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12852
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6222
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Bind_Result := Solver.Create_Unify (Fld_2, Fld_3, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12852") else null)); 
--# expr-done 6223
And_Pred := Create_And (Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12851") else null)); 
--# expr-done 6224
Dyn_Var_Bind_Result := And_Pred; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 6225
   If_Result_6 := Dyn_Var_Bind_Result;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 6226
Block_Var := If_Result_6; Inc_Ref (Block_Var);
--# bind type_constraint Block_Var
--# expr-start 6234 '<And at ast.py:12856>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12856
--# expr-start 6229 '<And at ast.py:12856>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12856
--# expr-start 6227 '<FieldAccess for ancestor_expr at ast.py:12856>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12856
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Expr (Node => Ent.Node.Base_Aggregate_F_Ancestor_Expr, Info => Ent.Info);
--# expr-done 6227
Var_Expr := Fld_11;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind ae Var_Expr
--# expr-start 6228 '<FieldAccess for sub_equation at ast.py:12857>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12857
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_12 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 6228
Scope_Result := Fld_12;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2699;
   Result_Var := Scope_Result;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12857") else null)); 
   Result_Var := True_Rel_1;
end if;
      Inc_Ref (Result_Var);
And_Pred_1 := Create_And (Block_Var, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12856") else null)); 
--# expr-done 6229
--# expr-start 6233 '<LogicAll at ast.py:12858>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:12858
--# expr-start 6232 '<Map at ast.py:12858>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12858
   --# expr-start 6230 '<FieldAccess for assocs at ast.py:12858>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12858
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Base_Aggregate_F_Assocs, Info => Ent.Info);
--# expr-done 6230
Fld_14 := Fld_13.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_14 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_14;
      begin
         for Untyped_Item_219 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_219 := Untyped_Item_219; 
Is_Null := Bare_Item_219 = null; 
if Is_Null then
   If_Result_7 := No_Entity_Basic_Assoc;
else
Fld_15 := Fld_13.Info;
As_Entity := (Info => Fld_15, Node => Bare_Item_219); 
   If_Result_7 := As_Entity;
end if;
                  Item_219 := If_Result_7; 
   --# scope-start
               --# bind assoc Item_219
      --# expr-start 6231 '<FieldAccess for sub_equation at ast.py:12859>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12859
      if Item_219.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_16 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_219.Node, Env => Env, Origin => Origin, E_Info => Item_219.Info);
--# end
--# expr-done 6231
         declare
            Item_To_Append : constant Logic_Equation := Fld_16;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2700;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6232
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12858") else null)); 
--# expr-done 6233
And_Pred_2 := Create_And (And_Pred_1, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12856") else null)); 
--# expr-done 6234
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 6235
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_978;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_978;
               Finalizer_Scope_2699;
               Finalizer_Scope_2700;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Xref_Equation;
--# end
--# property-start BaseAggregate.is_contract_cases_base_aggregate /tmp/lal-23.0.0/ada/ast.py:12863
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Is_Contract_Cases_Base_Aggregate
  (Node : Bare_Base_Aggregate
  )
   return Boolean
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Aspect_Assoc;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Aspect_Assoc;
Fld_1 : Bare_Name;
Sym : Symbol_Type;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6241 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6237 '<Cast to AspectAssoc at ast.py:12868>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:12868
--# expr-start 6236 '<parent at ast.py:12868>' Fld /tmp/lal-23.0.0/ada/ast.py:12868
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 6236
   if Fld = null
      or else Fld.Kind in Ada_Aspect_Assoc_Range
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 6237
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind aspect Var_Expr
--# expr-start 6240 '<FieldAccess for name_is at ast.py:12869>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12869
--# expr-start 6238 '<FieldAccess for id at ast.py:12869>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12869
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr.Aspect_Assoc_F_Id;
--# expr-done 6238
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6239 '<Symbol Contract_Cases at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 6239
--# property-call-start Name.name_is
Fld_2 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_1, Sym => Sym);
--# end
--# expr-done 6240
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 6241
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Is_Contract_Cases_Base_Aggregate;
--# end
--# property-start BaseAggregate.multidim_root_aggregate /tmp/lal-23.0.0/ada/ast.py:12874
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Multidim_Root_Aggregate
  (Node : Bare_Base_Aggregate
      ; R : Integer
         := 0
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Multidim_Aggregate_Info
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind r R
   --# bind origin Origin
   Property_Result : Internal_Multidim_Aggregate_Info;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Aggregate;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
New_Struct : Internal_Multidim_Aggregate_Info;
Fld_1 : Integer;
Comp_Result : Boolean;
If_Result : Internal_Multidim_Aggregate_Info;
Scope_Result : Internal_Multidim_Aggregate_Info;
Fld_2 : Internal_Entity;
Fld_3 : Internal_Entity;
Fld_4 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Aggregate;
Arith_Result : Integer;
Fld_5 : Internal_Multidim_Aggregate_Info;
Scope_Result_1 : Internal_Multidim_Aggregate_Info;
Result_Var : Internal_Multidim_Aggregate_Info;
Result_Var_1 : Internal_Multidim_Aggregate_Info;
Let_Result : Internal_Multidim_Aggregate_Info;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Aggregate_Base_Aggregate_P_Multidim_Root_Aggregate,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Aggregate,
                                As_Bare_Base_Aggregate => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Integer,
                                      As_Integer => R);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (4) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Multidim_Aggregate_Info;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 6253 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6243 '<Cast to BaseTypeDecl at ast.py:12881>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:12881
--# expr-start 6242 '<FieldAccess for type_val at ast.py:12881>' Fld /tmp/lal-23.0.0/ada/ast.py:12881
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld := Libadalang.Implementation.Expr_P_Type_Val (Node => Ent.Node);
--# end
--# expr-done 6242
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 6243
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind tv Var_Expr
--# expr-start 6246 '<If at ast.py:12882>' If_Result /tmp/lal-23.0.0/ada/ast.py:12882
--# expr-start 6244 '<FieldAccess for array_ndims at ast.py:12885>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12885
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 6244
Comp_Result := Fld_1 > 1; 
if Comp_Result then
   --# expr-start 6245 '<New MultidimAggregateInfo at ast.py:12886>' New_Struct /tmp/lal-23.0.0/ada/ast.py:12886
New_Struct := (Agg => Ent, Rank => R, Typ => Var_Expr); 
--# expr-done 6245
   If_Result := New_Struct;
else
   If_Result := No_Multidim_Aggregate_Info;
end if;
--# expr-done 6246
Scope_Result := If_Result;
   --# end
   Result_Var_1 := Scope_Result;
else
--# expr-start 6250 '<Cast to Aggregate at ast.py:12894>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:12894
--# expr-start 6249 '<parent at ast.py:12894>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12894
--# expr-start 6248 '<parent at ast.py:12894>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12894
--# expr-start 6247 '<parent at ast.py:12894>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12894
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 6247
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Parent (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# expr-done 6248
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Parent (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# expr-done 6249
   if Fld_4.Node = null
      or else Fld_4.Node.Kind in Ada_Aggregate_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Aggregate
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
   else
         Cast_Result_1 := No_Entity_Aggregate;
   end if;
--# expr-done 6250
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Aggregate then
   --# scope-start
--# expr-start 6252 '<FieldAccess for multidim_root_aggregate at ast.py:12895>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12895
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6251 '<Arithmetic + at ast.py:12895>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:12895
Arith_Result := (R + 1); 
--# expr-done 6251
--# property-call-start BaseAggregate.multidim_root_aggregate
Fld_5 := Libadalang.Implementation.Base_Aggregate_P_Multidim_Root_Aggregate (Node => Var_Expr_1.Node, R => Arith_Result, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 6252
Scope_Result_1 := Fld_5;
   --# end
   Result_Var := Scope_Result_1;
else
   Result_Var := No_Multidim_Aggregate_Info;
end if;
   Result_Var_1 := Result_Var;
end if;
Let_Result := Result_Var_1; 
--# end
--# expr-done 6253
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Multidim_Aggregate_Info,
                        As_Internal_Multidim_Aggregate_Info => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Multidim_Root_Aggregate;
--# end
--# property-start BaseAggregate.all_discriminants /tmp/lal-23.0.0/ada/ast.py:12901
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_All_Discriminants
  (Node : Bare_Base_Aggregate
      ; Origin : Bare_Ada_Node
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_981 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Type_Decl;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Record_Def;
Fld_2 : Internal_Entity_Component_List;
Fld_3 : Internal_Entity_Type_Decl;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_981 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_981;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Aggregate_Base_Aggregate_P_All_Discriminants,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Aggregate,
                                As_Bare_Base_Aggregate => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Formal_Param_Decl_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 6260 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6255 '<Cast to BaseTypeDecl at ast.py:12917>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:12917
--# expr-start 6254 '<FieldAccess for type_val at ast.py:12917>' Fld /tmp/lal-23.0.0/ada/ast.py:12917
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld := Libadalang.Implementation.Expr_P_Type_Val (Node => Self);
--# end
--# expr-done 6254
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 6255
Block_Var := Cast_Result; 
--# bind td Block_Var
--# expr-start 6258 '<FieldAccess for type_decl at ast.py:12918>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12918
--# expr-start 6257 '<FieldAccess for comps at ast.py:12918>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12918
--# expr-start 6256 '<FieldAccess for record_def at ast.py:12918>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12918
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 6256
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseRecordDef.comps
Fld_2 := Libadalang.Implementation.Base_Record_Def_P_Comps (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 6257
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.type_decl
Fld_3 := Libadalang.Implementation.Component_List_P_Type_Decl (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 6258
Block_Var_1 := Fld_3; 
--# bind record_decl Block_Var_1
--# expr-start 6259 '<FieldAccess for discriminants_list at ast.py:12919>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12919
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Block_Var_1.Node, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 6259
Let_Result := Fld_4; Inc_Ref (Let_Result);
--# end
--# expr-done 6260
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_981;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Formal_Param_Decl_Array_Access,
                        As_Internal_Entity_Base_Formal_Param_Decl_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_981;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_All_Discriminants;
--# end
--# property-start BaseAggregate.all_components /tmp/lal-23.0.0/ada/ast.py:12924
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_All_Components
  (Node : Bare_Base_Aggregate
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_982 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Component_List;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Record_Def;
Fld_2 : Internal_Entity_Component_List;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_4 : Internal_Entity_Assoc_List;
Fld_5 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Is_A : Boolean;
If_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_982 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_5);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_982;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Aggregate_Base_Aggregate_P_All_Components,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Aggregate,
                                As_Bare_Base_Aggregate => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) := (Kind => Mmz_Lexical_Env,
                                      As_Lexical_Env => Env);
                  Inc_Ref (Mmz_K.Items (3).As_Lexical_Env);
               Mmz_K.Items (4) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Formal_Param_Decl_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 6270 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6262 '<Cast to BaseTypeDecl at ast.py:12933>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:12933
--# expr-start 6261 '<FieldAccess for type_val at ast.py:12933>' Fld /tmp/lal-23.0.0/ada/ast.py:12933
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld := Libadalang.Implementation.Expr_P_Type_Val (Node => Self);
--# end
--# expr-done 6261
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 6262
Block_Var := Cast_Result; 
--# bind td Block_Var
--# expr-start 6264 '<FieldAccess for comps at ast.py:12934>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12934
--# expr-start 6263 '<FieldAccess for record_def at ast.py:12934>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12934
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.record_def'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Record_Def (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 6263
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseRecordDef.comps
Fld_2 := Libadalang.Implementation.Base_Record_Def_P_Comps (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 6264
Block_Var_1 := Fld_2; 
--# bind comp_list Block_Var_1
--# expr-start 6269 '<If at ast.py:12935>' If_Result /tmp/lal-23.0.0/ada/ast.py:12935
--# expr-start 6265 '<IsA DeltaAggregate at ast.py:12936>' Is_A /tmp/lal-23.0.0/ada/ast.py:12936
Is_A := Ent.Node /= null 
and then Ent.Node.Kind in Ada_Delta_Aggregate_Range; 
--# expr-done 6265
if Is_A then
   --# expr-start 6266 '<FieldAccess for abstract_formal_params_for_delta_assocs at ast.py:12939>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12939
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.abstract_formal_params_for_delta_assocs
Fld_3 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_For_Delta_Assocs (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 6266
   If_Result := Fld_3;
else
   --# expr-start 6268 '<FieldAccess for abstract_formal_params_for_assocs at ast.py:12940>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12940
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6267 '<FieldAccess for assocs at ast.py:12940>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12940
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Base_Aggregate_F_Assocs, Info => Ent.Info);
--# expr-done 6267
--# property-call-start ComponentList.abstract_formal_params_for_assocs
Fld_5 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_For_Assocs (Node => Block_Var_1.Node, Assocs => Fld_4, Env => Env, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 6268
   If_Result := Fld_5;
end if;
      Inc_Ref (If_Result);
--# expr-done 6269
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 6270
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_982;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Formal_Param_Decl_Array_Access,
                        As_Internal_Entity_Base_Formal_Param_Decl_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_982;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_All_Components;
--# end
--# property-start BaseAggregate.matched_discriminants /tmp/lal-23.0.0/ada/ast.py:12945
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Matched_Discriminants
  (Node : Bare_Base_Aggregate
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Match_Array_Access
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_983 with Inline_Always;
      Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_1 : Internal_Entity_Assoc_List;
Fld_2 : Internal_Param_Match_Array_Access;
Let_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_983 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_983;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Aggregate_Base_Aggregate_P_Matched_Discriminants,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Aggregate,
                                As_Bare_Base_Aggregate => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Param_Match_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 6274 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6273 '<FieldAccess for match_formals at ast.py:12954>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12954
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6271 '<FieldAccess for all_discriminants at ast.py:12955>' Fld /tmp/lal-23.0.0/ada/ast.py:12955
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.all_discriminants
Fld := Libadalang.Implementation.Base_Aggregate_P_All_Discriminants (Node => Ent.Node, Origin => Origin);
--# end
--# expr-done 6271
--# expr-start 6272 '<FieldAccess for assocs at ast.py:12955>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12955
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Base_Aggregate_F_Assocs, Info => Ent.Info);
--# expr-done 6272
--# property-call-start AdaNode.match_formals
Fld_2 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Fld, Params => Fld_1, Is_Dottable_Subp => False);
--# end
--# expr-done 6273
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 6274
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_983;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Param_Match_Array_Access,
                        As_Internal_Param_Match_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_983;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Matched_Discriminants;
--# end
--# property-start BaseAggregate.matched_components /tmp/lal-23.0.0/ada/ast.py:12960
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Matched_Components
  (Node : Bare_Base_Aggregate
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Match_Array_Access
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_984 with Inline_Always;
      Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_1 : Internal_Entity_Assoc_List;
Fld_2 : Internal_Param_Match_Array_Access;
Let_Result : Internal_Param_Match_Array_Access;
            procedure Finalizer_Scope_984 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_984;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Aggregate_Base_Aggregate_P_Matched_Components,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Aggregate,
                                As_Bare_Base_Aggregate => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (3) := (Kind => Mmz_Lexical_Env,
                                      As_Lexical_Env => Env);
                  Inc_Ref (Mmz_K.Items (3).As_Lexical_Env);
               Mmz_K.Items (4) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Param_Match_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 6278 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6277 '<FieldAccess for match_formals at ast.py:12969>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12969
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6275 '<FieldAccess for all_components at ast.py:12970>' Fld /tmp/lal-23.0.0/ada/ast.py:12970
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.all_components
Fld := Libadalang.Implementation.Base_Aggregate_P_All_Components (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6275
--# expr-start 6276 '<FieldAccess for assocs at ast.py:12970>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12970
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Base_Aggregate_F_Assocs, Info => Ent.Info);
--# expr-done 6276
--# property-call-start AdaNode.match_formals
Fld_2 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Fld, Params => Fld_1, Is_Dottable_Subp => False);
--# end
--# expr-done 6277
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 6278
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_984;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Param_Match_Array_Access,
                        As_Internal_Param_Match_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_984;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Matched_Components;
--# end
--# property-start BaseAggregate.first_unmatched_formal /tmp/lal-23.0.0/ada/ast.py:12975
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_First_Unmatched_Formal
  (Node : Bare_Base_Aggregate
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_985 with Inline_Always;
            procedure Finalizer_Scope_2704 with Inline_Always;
            procedure Finalizer_Scope_2706 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Fld_2 : Internal_Param_Match_Array_Access;
Fld_3 : Internal_Entity_Defining_Name;
Cast_Result : Internal_Entity;
Cast_Expr : Internal_Entity_Defining_Name;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Quantifier_Result : Boolean;
Not_Val : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_5 : Internal_Entity_Defining_Name_Array_Access;
Fld_6 : Internal_Param_Match_Array_Access;
Fld_7 : Internal_Entity_Defining_Name;
Cast_Result_2 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Defining_Name;
Cast_Result_3 : Internal_Entity;
Is_Equiv_1 : Boolean;
Quantifier_Result_1 : Boolean;
Not_Val_1 : Boolean;
Find_Result_1 : Internal_Entity_Defining_Name;
Is_Null : Boolean;
Not_Val_2 : Boolean;
If_Result : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_985 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_985;
            procedure Finalizer_Scope_2704 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2704;
            procedure Finalizer_Scope_2706 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2706;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6298 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6286 '<Find at ast.py:12986>' Find_Result /tmp/lal-23.0.0/ada/ast.py:12986
   --# expr-start 6280 '<FieldAccess for unpack_formals at ast.py:12986>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12986
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6279 '<FieldAccess for all_discriminants at ast.py:12986>' Fld /tmp/lal-23.0.0/ada/ast.py:12986
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.all_discriminants
Fld := Libadalang.Implementation.Base_Aggregate_P_All_Discriminants (Node => Ent.Node, Origin => Origin);
--# end
--# expr-done 6279
--# property-call-start AdaNode.unpack_formals
Fld_1 := Libadalang.Implementation.Ada_Node_P_Unpack_Formals (Node => Self, Formal_Params => Fld);
--# end
--# expr-done 6280
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_1;
      begin
         for Item_220 of
               Collection.Items
         loop
   --# scope-start
               --# bind f Item_220
      --# expr-start 6285 '<Not at ast.py:12987>' Not_Val /tmp/lal-23.0.0/ada/ast.py:12987
--# expr-start 6284 '<AnyQuantifier at ast.py:12987>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:12987
   --# expr-start 6281 '<FieldAccess for matched_discriminants at ast.py:12987>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12987
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.matched_discriminants
Fld_2 := Libadalang.Implementation.Base_Aggregate_P_Matched_Discriminants (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 6281
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_2;
      begin
         for Item_221 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_221
      --# expr-start 6283 '<Eq at ast.py:12988>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:12988
--# expr-start 6282 '<FieldAccess for formal at ast.py:12988>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12988
Fld_3 := Item_221.Formal;
--# expr-done 6282
      Cast_Result := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Cast_Expr := Item_220; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 6283
      Quantifier_Result := Is_Equiv;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 6284
Not_Val := not (Quantifier_Result); 
--# expr-done 6285
      if Not_Val then
         Find_Result := Item_220;
      end if;
   --# end
      Finalizer_Scope_2704;
               exit when Not_Val;
         end loop;
      end;
--# expr-done 6286
Block_Var := Find_Result; 
--# bind unmatched_discr Block_Var
--# expr-start 6297 '<If at ast.py:12992>' If_Result /tmp/lal-23.0.0/ada/ast.py:12992
--# expr-start 6288 '<Not at ast.py:12993>' Not_Val_2 /tmp/lal-23.0.0/ada/ast.py:12993
--# expr-start 6287 '<IsNull at ast.py:12993>' Is_Null /tmp/lal-23.0.0/ada/ast.py:12993
Is_Null := Block_Var.Node = null; 
--# expr-done 6287
Not_Val_2 := not (Is_Null); 
--# expr-done 6288
if Not_Val_2 then
   If_Result := Block_Var;
else
   --# expr-start 6296 '<Find at ast.py:13002>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:13002
   --# expr-start 6290 '<FieldAccess for unpack_formals at ast.py:13002>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13002
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6289 '<FieldAccess for all_components at ast.py:13002>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13002
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.all_components
Fld_4 := Libadalang.Implementation.Base_Aggregate_P_All_Components (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6289
--# property-call-start AdaNode.unpack_formals
Fld_5 := Libadalang.Implementation.Ada_Node_P_Unpack_Formals (Node => Self, Formal_Params => Fld_4);
--# end
--# expr-done 6290
      Find_Result_1 := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_5;
      begin
         for Item_222 of
               Collection.Items
         loop
   --# scope-start
               --# bind f Item_222
      --# expr-start 6295 '<Not at ast.py:13003>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:13003
--# expr-start 6294 '<AnyQuantifier at ast.py:13003>' Quantifier_Result_1 /tmp/lal-23.0.0/ada/ast.py:13003
   --# expr-start 6291 '<FieldAccess for matched_components at ast.py:13003>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13003
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.matched_components
Fld_6 := Libadalang.Implementation.Base_Aggregate_P_Matched_Components (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6291
      Quantifier_Result_1 := False;
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_6;
      begin
         for Item_223 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_223
      --# expr-start 6293 '<Eq at ast.py:13004>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:13004
--# expr-start 6292 '<FieldAccess for formal at ast.py:13004>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13004
Fld_7 := Item_223.Formal;
--# expr-done 6292
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
Cast_Expr_1 := Item_222; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv_1 := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 6293
      Quantifier_Result_1 := Is_Equiv_1;
   --# end
               exit when Quantifier_Result_1;
         end loop;
      end;
--# expr-done 6294
Not_Val_1 := not (Quantifier_Result_1); 
--# expr-done 6295
      if Not_Val_1 then
         Find_Result_1 := Item_222;
      end if;
   --# end
      Finalizer_Scope_2706;
               exit when Not_Val_1;
         end loop;
      end;
--# expr-done 6296
   If_Result := Find_Result_1;
end if;
--# expr-done 6297
Let_Result := If_Result; 
--# end
--# expr-done 6298
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_985;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_985;
               Finalizer_Scope_2704;
               Finalizer_Scope_2706;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_First_Unmatched_Formal;
--# end
--# property-start BaseAggregate.aggregate_params /tmp/lal-23.0.0/ada/ast.py:13010
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Aggregate_Params
  (Node : Bare_Base_Aggregate
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Actual_Array_Access
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_987 with Inline_Always;
      Fld : Internal_Entity_Assoc_List;
Fld_1 : Internal_Param_Actual_Array_Access;
Let_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_987 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_987;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6301 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6300 '<FieldAccess for zip_with_params at ast.py:13015>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13015
--# expr-start 6299 '<FieldAccess for assocs at ast.py:13015>' Fld /tmp/lal-23.0.0/ada/ast.py:13015
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Base_Aggregate_F_Assocs, Info => Ent.Info);
--# expr-done 6299
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.zip_with_params
Fld_1 := Libadalang.Implementation.Assoc_List_P_Zip_With_Params (Node => Fld.Node, Imprecise_Fallback => False, E_Info => Fld.Info);
--# end
--# expr-done 6300
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6301
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_987;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_987;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Aggregate_Params;
--# end
--# property-start BaseAggregate.is_subaggregate /tmp/lal-23.0.0/ada/ast.py:13018
pragma Warnings (Off, "is not referenced");
 function Base_Aggregate_P_Is_Subaggregate
  (Node : Bare_Base_Aggregate
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Aggregate := Bare_Base_Aggregate (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Aggregate :=
     Internal_Entity_Base_Aggregate'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Block_Var : Boolean;
Fld : Boolean;
Cast_Expr : Bare_Base_Aggregate;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Multidim_Aggregate_Info;
Fld_2 : Integer;
Comp_Result : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6306 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6302 '<FieldAccess for resolve_names_from_closest_entry_point at ast.py:13025>' Fld /tmp/lal-23.0.0/ada/ast.py:13025
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_from_closest_entry_point
Fld := Libadalang.Implementation.Ada_Node_P_Resolve_Names_From_Closest_Entry_Point (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 6302
Block_Var := Fld; 
--# expr-start 6305 '<bind at ast.py:13026>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:13026
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 6304 '<FieldAccess for rank at ast.py:13026>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13026
--# expr-start 6303 '<FieldAccess for multidim_root_aggregate at ast.py:13026>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13026
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseAggregate.multidim_root_aggregate
Fld_1 := Libadalang.Implementation.Base_Aggregate_P_Multidim_Root_Aggregate (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 6303
Fld_2 := Fld_1.Rank;
--# expr-done 6304
Comp_Result := Fld_2 > 0; 
Dyn_Var_Bind_Result := Comp_Result; 
--# expr-done 6305
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 6306
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Aggregate_P_Is_Subaggregate;
--# end
   --
   --  Primitives for Bare_Aggregate
   --
      procedure Initialize_Fields_For_Aggregate
        (Self : Bare_Aggregate
         ; Base_Aggregate_F_Ancestor_Expr : Bare_Expr
         ; Base_Aggregate_F_Assocs : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Base_Aggregate
              (Self, Base_Aggregate_F_Ancestor_Expr, Base_Aggregate_F_Assocs);
      end Initialize_Fields_For_Aggregate;
   --
   --  Primitives for Bare_Bracket_Aggregate
   --
      procedure Initialize_Fields_For_Bracket_Aggregate
        (Self : Bare_Bracket_Aggregate
         ; Base_Aggregate_F_Ancestor_Expr : Bare_Expr
         ; Base_Aggregate_F_Assocs : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Aggregate
              (Self, Base_Aggregate_F_Ancestor_Expr, Base_Aggregate_F_Assocs);
      end Initialize_Fields_For_Bracket_Aggregate;
   --
   --  Primitives for Bare_Delta_Aggregate
   --
      procedure Initialize_Fields_For_Delta_Aggregate
        (Self : Bare_Delta_Aggregate
         ; Base_Aggregate_F_Ancestor_Expr : Bare_Expr
         ; Base_Aggregate_F_Assocs : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Base_Aggregate
              (Self, Base_Aggregate_F_Ancestor_Expr, Base_Aggregate_F_Assocs);
      end Initialize_Fields_For_Delta_Aggregate;
   --
   --  Primitives for Bare_Bracket_Delta_Aggregate
   --
      procedure Initialize_Fields_For_Bracket_Delta_Aggregate
        (Self : Bare_Bracket_Delta_Aggregate
         ; Base_Aggregate_F_Ancestor_Expr : Bare_Expr
         ; Base_Aggregate_F_Assocs : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Delta_Aggregate
              (Self, Base_Aggregate_F_Ancestor_Expr, Base_Aggregate_F_Assocs);
      end Initialize_Fields_For_Bracket_Delta_Aggregate;
   --
   --  Primitives for Bare_Null_Record_Aggregate
   --
      procedure Initialize_Fields_For_Null_Record_Aggregate
        (Self : Bare_Null_Record_Aggregate
         ; Base_Aggregate_F_Ancestor_Expr : Bare_Expr
         ; Base_Aggregate_F_Assocs : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Base_Aggregate
              (Self, Base_Aggregate_F_Ancestor_Expr, Base_Aggregate_F_Assocs);
      end Initialize_Fields_For_Null_Record_Aggregate;
   --
   --  Primitives for Bare_Bin_Op
   --
      procedure Initialize_Fields_For_Bin_Op
        (Self : Bare_Bin_Op
         ; Bin_Op_F_Left : Bare_Expr
         ; Bin_Op_F_Op : Bare_Op
         ; Bin_Op_F_Right : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Bin_Op_F_Left := Bin_Op_F_Left;
            Self.Bin_Op_F_Op := Bin_Op_F_Op;
            Self.Bin_Op_F_Right := Bin_Op_F_Right;
      end Initialize_Fields_For_Bin_Op;
   function Bin_Op_F_Left
     (Node : Bare_Bin_Op) return Bare_Expr
   is
   begin
         return Node.Bin_Op_F_Left;
   end;
   function Bin_Op_F_Op
     (Node : Bare_Bin_Op) return Bare_Op
   is
   begin
         return Node.Bin_Op_F_Op;
   end;
   function Bin_Op_F_Right
     (Node : Bare_Bin_Op) return Bare_Expr
   is
   begin
         return Node.Bin_Op_F_Right;
   end;
--# property-start BinOp.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12232
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Has_Context_Free_Type
  (Node : Bare_Bin_Op
  )
   return Boolean
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Op;
Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6309 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6308 '<IsA Op.AndThen, Op.OrElse at ast.py:12233>' Is_A /tmp/lal-23.0.0/ada/ast.py:12233
--# expr-start 6307 '<FieldAccess for op at ast.py:12233>' Fld /tmp/lal-23.0.0/ada/ast.py:12233
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Bin_Op_F_Op;
--# expr-done 6307
Is_A := Fld /= null 
and then Fld.Kind in Ada_Op_And_Then_Range | Ada_Op_Or_Else_Range; 
--# expr-done 6308
Let_Result := Is_A; 
--# end
--# expr-done 6309
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Has_Context_Free_Type;
--# end
--# property-start BinOp.xref_equation /tmp/lal-23.0.0/ada/ast.py:12236
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Xref_Equation
  (Node : Bare_Bin_Op
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_957 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Bare_Op;
Is_A : Boolean;
Fld_5 : Logic_Equation;
Fld_6 : Bare_Op;
Is_A_1 : Boolean;
Fld_7 : Logic_Equation;
Fld_8 : Logic_Equation;
Fld_9 : Logic_Equation;
Or_Pred : Logic_Equation;
If_Result : Logic_Equation;
If_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_957 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_957;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6326 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6325 '<And at ast.py:12237>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12237
--# expr-start 6314 '<And at ast.py:12237>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12237
--# expr-start 6311 '<FieldAccess for sub_equation at ast.py:12238>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12238
--# expr-start 6310 '<FieldAccess for left at ast.py:12238>' Fld /tmp/lal-23.0.0/ada/ast.py:12238
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Bin_Op_F_Left, Info => Ent.Info);
--# expr-done 6310
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 6311
--# expr-start 6313 '<FieldAccess for sub_equation at ast.py:12239>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12239
--# expr-start 6312 '<FieldAccess for right at ast.py:12239>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12239
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Bin_Op_F_Right, Info => Ent.Info);
--# expr-done 6312
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 6313
And_Pred := Create_And (Fld_1, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12237") else null)); 
--# expr-done 6314
--# expr-start 6324 '<Cond at ast.py:12240>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:12240
--# expr-start 6316 '<IsA Op.DoubleDot at ast.py:12241>' Is_A /tmp/lal-23.0.0/ada/ast.py:12241
--# expr-start 6315 '<FieldAccess for op at ast.py:12241>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12241
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Bin_Op_F_Op;
--# expr-done 6315
Is_A := Fld_4 /= null 
and then Fld_4.Kind in Ada_Op_Double_Dot_Range; 
--# expr-done 6316
if Is_A then
   --# expr-start 6317 '<FieldAccess for double_dot_equation at ast.py:12242>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12242
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BinOp.double_dot_equation
Fld_5 := Libadalang.Implementation.Bin_Op_P_Double_Dot_Equation (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6317
   If_Result_1 := Fld_5;
else
--# expr-start 6319 '<IsA Op.AndThen, Op.OrElse at ast.py:12244>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:12244
--# expr-start 6318 '<FieldAccess for op at ast.py:12244>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12244
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Bin_Op_F_Op;
--# expr-done 6318
Is_A_1 := Fld_6 /= null 
and then Fld_6.Kind in Ada_Op_And_Then_Range | Ada_Op_Or_Else_Range; 
--# expr-done 6319
if Is_A_1 then
   --# expr-start 6320 '<FieldAccess for test_eq at ast.py:12245>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12245
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BinOp.test_eq
Fld_7 := Libadalang.Implementation.Bin_Op_P_Test_Eq (Node => Self, Origin => Origin);
--# end
--# expr-done 6320
   If_Result := Fld_7;
else
   --# expr-start 6323 '<Or at ast.py:12247>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12247
--# expr-start 6321 '<FieldAccess for overload_equation at ast.py:12247>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12247
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BinOp.overload_equation
Fld_8 := Libadalang.Implementation.Bin_Op_P_Overload_Equation (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6321
--# expr-start 6322 '<FieldAccess for no_overload_equation at ast.py:12247>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12247
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BinOp.no_overload_equation'
Fld_9 := Libadalang.Implementation.Dispatcher_Bin_Op_P_No_Overload_Equation (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 6322
Or_Pred := Create_Or (Fld_8, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12247") else null)); 
--# expr-done 6323
   If_Result := Or_Pred;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 6324
And_Pred_1 := Create_And (And_Pred, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12237") else null)); 
--# expr-done 6325
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6326
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_957;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_957;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Xref_Equation;
--# end
--# property-start BinOp.double_dot_equation /tmp/lal-23.0.0/ada/ast.py:12251
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Double_Dot_Equation
  (Node : Bare_Bin_Op
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_958 with Inline_Always;
      True_Rel : Logic_Equation;
Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Or_Pred_1 : Logic_Equation;
Fld_4 : Logic_Var;
Pred : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Logic_Var;
Fld_8 : Bare_Expr;
Fld_9 : Logic_Var;
Bind_Result_3 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_10 : Logic_Var;
Fld_11 : Bare_Expr;
Fld_12 : Logic_Var;
Bind_Result_4 : Logic_Equation;
And_Pred_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_13 : Bare_Expr;
Fld_14 : Logic_Equation;
Fld_15 : Bare_Expr;
Fld_16 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_17 : Logic_Var;
Fld_18 : Logic_Equation;
Or_Pred_2 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_958 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Or_Pred_1);
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_16);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Or_Pred_2);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_958;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6361 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6360 '<And at ast.py:12252>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12252
--# expr-start 6351 '<And at ast.py:12252>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12252
--# expr-start 6334 '<Or at ast.py:12252>' Or_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12252
--# expr-start 6330 '<Or at ast.py:12252>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12252
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12253") else null)); 
--# expr-start 6329 '<Bind at ast.py:12254>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12254
--# expr-start 6327 '<FieldAccess for expected_type_var at ast.py:12254>' Fld /tmp/lal-23.0.0/ada/ast.py:12254
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6327
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 6328 '<FieldAccess for root_int_type at ast.py:12254>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12254
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_int_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Root_Int_Type (Node => Self);
--# end
--# expr-done 6328
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12254") else null)); 
--# expr-done 6329
Or_Pred := Create_Or (True_Rel, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12252") else null)); 
--# expr-done 6330
--# expr-start 6333 '<Bind at ast.py:12255>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12255
--# expr-start 6331 '<FieldAccess for expected_type_var at ast.py:12255>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12255
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6331
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 6332 '<FieldAccess for int_type at ast.py:12255>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12255
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 6332
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_2, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12255") else null)); 
--# expr-done 6333
Or_Pred_1 := Create_Or (Or_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12252") else null)); 
--# expr-done 6334
--# expr-start 6350 '<And at ast.py:12256>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12256
--# expr-start 6345 '<And at ast.py:12256>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12256
--# expr-start 6340 '<And at ast.py:12256>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12256
--# expr-start 6336 '<Predicate on AdaNode.is_not_null at ast.py:12257>' Pred /tmp/lal-23.0.0/ada/ast.py:12257
--# expr-start 6335 '<FieldAccess for expected_type_var at ast.py:12257>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12257
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6335
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Pred := Solver.Create_Predicate (Fld_4, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 6336
--# expr-start 6339 '<Bind at ast.py:12258>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12258
--# expr-start 6337 '<FieldAccess for expected_type_var at ast.py:12258>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12258
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6337
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 6338 '<FieldAccess for type_var at ast.py:12258>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12258
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6338
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
Bind_Result_2 := Solver.Create_Unify (Fld_5, Fld_6, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12258") else null)); 
--# expr-done 6339
And_Pred := Create_And (Pred, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12256") else null)); 
--# expr-done 6340
--# expr-start 6344 '<Bind at ast.py:12259>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:12259
--# expr-start 6341 '<FieldAccess for type_var at ast.py:12259>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12259
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6341
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
--# expr-start 6343 '<FieldAccess for expected_type_var at ast.py:12259>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12259
--# expr-start 6342 '<FieldAccess for left at ast.py:12259>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12259
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Self.Bin_Op_F_Left;
--# expr-done 6342
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_8);
--# expr-done 6343
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
Bind_Result_3 := Solver.Create_Unify (Fld_7, Fld_9, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12259") else null)); 
--# expr-done 6344
And_Pred_1 := Create_And (And_Pred, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12256") else null)); 
--# expr-done 6345
--# expr-start 6349 '<Bind at ast.py:12260>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:12260
--# expr-start 6346 '<FieldAccess for type_var at ast.py:12260>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12260
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6346
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
--# expr-start 6348 '<FieldAccess for expected_type_var at ast.py:12260>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12260
--# expr-start 6347 '<FieldAccess for right at ast.py:12260>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12260
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Self.Bin_Op_F_Right;
--# expr-done 6347
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_11);
--# expr-done 6348
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
Bind_Result_4 := Solver.Create_Unify (Fld_10, Fld_12, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12260") else null)); 
--# expr-done 6349
And_Pred_2 := Create_And (And_Pred_1, Bind_Result_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12256") else null)); 
--# expr-done 6350
And_Pred_3 := Create_And (Or_Pred_1, And_Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12252") else null)); 
--# expr-done 6351
--# expr-start 6359 '<Or at ast.py:12261>' Or_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12261
--# expr-start 6356 '<And at ast.py:12266>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12266
--# expr-start 6353 '<FieldAccess for matches_expected_formal_type at ast.py:12266>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:12266
--# expr-start 6352 '<FieldAccess for left at ast.py:12266>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12266
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Self.Bin_Op_F_Left;
--# expr-done 6352
      if Fld_13 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_14 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_13, Origin => Origin);
--# end
--# expr-done 6353
--# expr-start 6355 '<FieldAccess for matches_expected_formal_type at ast.py:12267>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12267
--# expr-start 6354 '<FieldAccess for right at ast.py:12267>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12267
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Self.Bin_Op_F_Right;
--# expr-done 6354
      if Fld_15 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_16 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_15, Origin => Origin);
--# end
--# expr-done 6355
And_Pred_4 := Create_And (Fld_14, Fld_16, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12266") else null)); 
--# expr-done 6356
--# expr-start 6358 '<FieldAccess for numeric_type_from_operands_equation at ast.py:12271>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12271
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6357 '<FieldAccess for type_var at ast.py:12271>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12271
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6357
--# property-call-start BinOp.numeric_type_from_operands_equation
Fld_18 := Libadalang.Implementation.Bin_Op_P_Numeric_Type_From_Operands_Equation (Node => Ent.Node, Dest_Var => Fld_17, Origin => Origin);
--# end
--# expr-done 6358
Or_Pred_2 := Create_Or (And_Pred_4, Fld_18, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12261") else null)); 
--# expr-done 6359
And_Pred_5 := Create_And (And_Pred_3, Or_Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12252") else null)); 
--# expr-done 6360
Let_Result := And_Pred_5; Inc_Ref (Let_Result);
--# end
--# expr-done 6361
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_958;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_958;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Double_Dot_Equation;
--# end
--# property-start BinOp.test_eq /tmp/lal-23.0.0/ada/ast.py:12275
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Test_Eq
  (Node : Bare_Bin_Op
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_959 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Bare_Expr;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_Expr;
Fld_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_8 : Bare_Expr;
Fld_9 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_10 : Logic_Var;
Fld_11 : Bare_Expr;
Fld_12 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_959 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_959;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6382 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6381 '<And at ast.py:12276>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12276
--# expr-start 6376 '<And at ast.py:12276>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12276
--# expr-start 6373 '<And at ast.py:12276>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12276
--# expr-start 6370 '<And at ast.py:12276>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12276
--# expr-start 6365 '<Bind at ast.py:12277>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12277
--# expr-start 6363 '<FieldAccess for expected_type_var at ast.py:12277>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12277
--# expr-start 6362 '<FieldAccess for left at ast.py:12277>' Fld /tmp/lal-23.0.0/ada/ast.py:12277
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Bin_Op_F_Left;
--# expr-done 6362
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 6363
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 6364 '<FieldAccess for bool_type at ast.py:12277>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12277
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6364
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12277") else null)); 
--# expr-done 6365
--# expr-start 6369 '<Bind at ast.py:12278>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12278
--# expr-start 6367 '<FieldAccess for expected_type_var at ast.py:12278>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12278
--# expr-start 6366 '<FieldAccess for right at ast.py:12278>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12278
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Bin_Op_F_Right;
--# expr-done 6366
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_3);
--# expr-done 6367
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 6368 '<FieldAccess for bool_type at ast.py:12278>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12278
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_5 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6368
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12278") else null)); 
--# expr-done 6369
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12276") else null)); 
--# expr-done 6370
--# expr-start 6372 '<FieldAccess for matches_expected_formal_prim_type at ast.py:12280>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12280
--# expr-start 6371 '<FieldAccess for left at ast.py:12280>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12280
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Bin_Op_F_Left;
--# expr-done 6371
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_7 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_6, Origin => Origin);
--# end
--# expr-done 6372
And_Pred_1 := Create_And (And_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12276") else null)); 
--# expr-done 6373
--# expr-start 6375 '<FieldAccess for matches_expected_formal_prim_type at ast.py:12281>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12281
--# expr-start 6374 '<FieldAccess for right at ast.py:12281>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12281
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Self.Bin_Op_F_Right;
--# expr-done 6374
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_9 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_8, Origin => Origin);
--# end
--# expr-done 6375
And_Pred_2 := Create_And (And_Pred_1, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12276") else null)); 
--# expr-done 6376
--# expr-start 6380 '<Bind at ast.py:12283>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12283
--# expr-start 6377 '<FieldAccess for type_var at ast.py:12283>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12283
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6377
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
--# expr-start 6379 '<FieldAccess for type_var at ast.py:12283>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12283
--# expr-start 6378 '<FieldAccess for left at ast.py:12283>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12283
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Self.Bin_Op_F_Left;
--# expr-done 6378
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_11);
--# expr-done 6379
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
Bind_Result_2 := Solver.Create_Unify (Fld_10, Fld_12, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12283") else null)); 
--# expr-done 6380
And_Pred_3 := Create_And (And_Pred_2, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12276") else null)); 
--# expr-done 6381
Let_Result := And_Pred_3; Inc_Ref (Let_Result);
--# end
--# expr-done 6382
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_959;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_959;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Test_Eq;
--# end
--# property-start BinOp.arguments_eq /tmp/lal-23.0.0/ada/ast.py:12287
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Arguments_Eq
  (Node : Bare_Bin_Op
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind spec Spec
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_960 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Equation;
Get_Result_1 : Internal_Entity_Defining_Name;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Logic_Var;
Fld_8 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
False_Rel : Logic_Equation;
Len : Integer;
Is_Equal : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_960 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_960;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6400 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6383 '<FieldAccess for unpacked_formal_params at ast.py:12288>' Fld /tmp/lal-23.0.0/ada/ast.py:12288
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Spec.Node, E_Info => Spec.Info);
--# end
--# expr-done 6383
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind ps Block_Var
--# expr-start 6399 '<If at ast.py:12289>' If_Result /tmp/lal-23.0.0/ada/ast.py:12289
--# expr-start 6385 '<Eq at ast.py:12290>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:12290
--# expr-start 6384 '<length at ast.py:12290>' Len /tmp/lal-23.0.0/ada/ast.py:12290
Len := Length (Block_Var); 
--# expr-done 6384
Is_Equal := Len = 2; 
--# expr-done 6385
if Is_Equal then
   --# expr-start 6398 '<And at ast.py:12294>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12294
--# expr-start 6394 '<And at ast.py:12294>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12294
--# expr-start 6389 '<FieldAccess for call_argument_equation at ast.py:12294>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12294
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6387 '<FieldAccess for formal_decl at ast.py:12294>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12294
--# expr-start 6386 '<at at ast.py:12294>' Get_Result /tmp/lal-23.0.0/ada/ast.py:12294
Get_Result := Get (Self, Block_Var, 0, True); 
--# expr-done 6386
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 6387
--# expr-start 6388 '<FieldAccess for left at ast.py:12294>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12294
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Bin_Op_F_Left, Info => Ent.Info);
--# expr-done 6388
--# property-call-start BaseFormalParamHolder.call_argument_equation
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Call_Argument_Equation (Node => Spec.Node, Param => Fld_1, Arg => Fld_2, Origin => Origin, E_Info => Spec.Info);
--# end
--# expr-done 6389
--# expr-start 6393 '<FieldAccess for call_argument_equation at ast.py:12298>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12298
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6391 '<FieldAccess for formal_decl at ast.py:12298>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12298
--# expr-start 6390 '<at at ast.py:12298>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:12298
Get_Result_1 := Get (Self, Block_Var, 1, True); 
--# expr-done 6390
      if Get_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_4 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result_1.Node, E_Info => Get_Result_1.Info);
--# end
--# expr-done 6391
--# expr-start 6392 '<FieldAccess for right at ast.py:12298>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12298
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Bin_Op_F_Right, Info => Ent.Info);
--# expr-done 6392
--# property-call-start BaseFormalParamHolder.call_argument_equation
Fld_6 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Call_Argument_Equation (Node => Spec.Node, Param => Fld_4, Arg => Fld_5, Origin => Origin, E_Info => Spec.Info);
--# end
--# expr-done 6393
And_Pred := Create_And (Fld_3, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12294") else null)); 
--# expr-done 6394
--# expr-start 6397 '<Bind at ast.py:12301>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12301
--# expr-start 6395 '<FieldAccess for type_var at ast.py:12301>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12301
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6395
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
--# expr-start 6396 '<FieldAccess for return_type at ast.py:12301>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12301
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_8 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Spec.Node, Origin => Origin, E_Info => Spec.Info);
--# end
--# expr-done 6396
      Cast_Result := Create_Internal_Entity
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
Bind_Result := Solver.Create_Assign (Fld_7, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12301") else null)); 
--# expr-done 6397
And_Pred_1 := Create_And (And_Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12294") else null)); 
--# expr-done 6398
   If_Result := And_Pred_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12303") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 6399
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 6400
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_960;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_960;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Arguments_Eq;
--# end
--# property-start BinOp.entity_eq /tmp/lal-23.0.0/ada/ast.py:12307
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Entity_Eq
  (Node : Bare_Bin_Op
      ; Subp : Internal_Entity_Basic_Decl
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind subp Subp
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_961 with Inline_Always;
      Block_Var : Internal_Entity_Base_Subp_Spec;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Op;
Fld_3 : Logic_Var;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Bare_Op;
Fld_5 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Subp_Spec;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_961 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_961;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6411 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6401 '<FieldAccess for subp_spec_or_null at ast.py:12308>' Fld /tmp/lal-23.0.0/ada/ast.py:12308
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Subp.Node, E_Info => Subp.Info);
--# end
--# expr-done 6401
Block_Var := Fld; 
--# bind spec Block_Var
--# expr-start 6410 '<And at ast.py:12309>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12309
--# expr-start 6406 '<And at ast.py:12309>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12309
--# expr-start 6402 '<FieldAccess for arguments_eq at ast.py:12310>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12310
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BinOp.arguments_eq
Fld_1 := Libadalang.Implementation.Bin_Op_P_Arguments_Eq (Node => Ent.Node, Spec => Block_Var, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6402
--# expr-start 6405 '<Bind at ast.py:12313>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12313
--# expr-start 6404 '<FieldAccess for ref_var at ast.py:12313>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12313
--# expr-start 6403 '<FieldAccess for op at ast.py:12313>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12313
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Bin_Op_F_Op;
--# expr-done 6403
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_2);
--# end
--# expr-done 6404
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Cast_Expr := Subp; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_3, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12313") else null)); 
--# expr-done 6405
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12309") else null)); 
--# expr-done 6406
--# expr-start 6409 '<Bind at ast.py:12314>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12314
--# expr-start 6408 '<FieldAccess for subp_spec_var at ast.py:12314>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12314
--# expr-start 6407 '<FieldAccess for op at ast.py:12314>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12314
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Bin_Op_F_Op;
--# expr-done 6407
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Fld_4);
--# end
--# expr-done 6408
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr_1 := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_5, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12314") else null)); 
--# expr-done 6409
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12309") else null)); 
--# expr-done 6410
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6411
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_961;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_961;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Entity_Eq;
--# end
--# property-start BinOp.overload_equation /tmp/lal-23.0.0/ada/ast.py:12318
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Overload_Equation
  (Node : Bare_Bin_Op
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_962 with Inline_Always;
            procedure Finalizer_Scope_2708 with Inline_Always;
      Fld : Internal_Entity_Op;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
Fld_2 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_962 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_962;
            procedure Finalizer_Scope_2708 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2708;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6417 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6416 '<LogicAny at ast.py:12319>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:12319
--# expr-start 6415 '<Map at ast.py:12319>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12319
   --# expr-start 6413 '<FieldAccess for subprograms at ast.py:12319>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12319
--# expr-start 6412 '<FieldAccess for op at ast.py:12319>' Fld /tmp/lal-23.0.0/ada/ast.py:12319
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Op (Node => Ent.Node.Bin_Op_F_Op, Info => Ent.Info);
--# expr-done 6412
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Op.subprograms
Fld_1 := Libadalang.Implementation.Op_P_Subprograms (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 6413
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Fld_1;
      begin
         for Item_224 of
               Collection.Items
         loop
   --# scope-start
               --# bind subp Item_224
      --# expr-start 6414 '<FieldAccess for entity_eq at ast.py:12320>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12320
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BinOp.entity_eq
Fld_2 := Libadalang.Implementation.Bin_Op_P_Entity_Eq (Node => Ent.Node, Subp => Item_224, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 6414
         declare
            Item_To_Append : constant Logic_Equation := Fld_2;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2708;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6415
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12319") else null)); 
--# expr-done 6416
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 6417
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_962;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_962;
               Finalizer_Scope_2708;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Overload_Equation;
--# end
--# property-start '[dispatcher]BinOp.no_overload_equation' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Bin_Op_P_No_Overload_Equation
  (Node : Bare_Bin_Op
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Logic_Equation;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Bin_Op_Range (Self.Kind) is
               when Ada_Bin_Op =>
                  --# property-call-start BinOp.no_overload_equation
                  Property_Result := Bin_Op_P_No_Overload_Equation
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Relation_Op =>
                  --# property-call-start RelationOp.no_overload_equation
                  Property_Result := Relation_Op_P_No_Overload_Equation
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Bin_Op_P_No_Overload_Equation;
--# end
--# property-start BinOp.numeric_type_from_operands_equation /tmp/lal-23.0.0/ada/ast.py:12388
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Numeric_Type_From_Operands_Equation
  (Node : Bare_Bin_Op
      ; Dest_Var : Logic_Var
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind dest_var Dest_Var
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_964 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : Boolean;
Infer_Left : Logic_Equation;
Infer_Right : Logic_Equation;
Fld : Bare_Expr;
Fld_1 : Boolean;
Fld_2 : Bare_Expr;
Fld_3 : Boolean;
Fld_4 : Bare_Expr;
Fld_5 : Logic_Var;
Fld_6 : Bare_Expr;
Fld_7 : Logic_Var;
Pred : Logic_Equation;
Fld_8 : Bare_Expr;
Fld_9 : Logic_Var;
Fld_10 : Bare_Expr;
Fld_11 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_12 : Bare_Expr;
Fld_13 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_14 : Bare_Expr;
Fld_15 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_16 : Bare_Expr;
Fld_17 : Logic_Var;
Pred_1 : Logic_Equation;
Fld_18 : Bare_Expr;
Fld_19 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_20 : Bare_Expr;
Fld_21 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_22 : Bare_Expr;
Fld_23 : Logic_Var;
Pred_2 : Logic_Equation;
Fld_24 : Bare_Expr;
Fld_25 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Fld_26 : Bare_Expr;
Fld_27 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Or_Pred : Logic_Equation;
Or_Pred_1 : Logic_Equation;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
If_Result_1 : Boolean;
If_Result_2 : Logic_Equation;
Let_Result_1 : Logic_Equation;
            procedure Finalizer_Scope_964 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_13);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_15);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Pred_1);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_21);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Infer_Left);
                     Dec_Ref (Pred_2);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Fld_27);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Infer_Right);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Or_Pred_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_964;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6464 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 6419 '<FieldAccess for has_context_free_type at ast.py:12394>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12394
--# expr-start 6418 '<FieldAccess for left at ast.py:12394>' Fld /tmp/lal-23.0.0/ada/ast.py:12394
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Bin_Op_F_Left;
--# expr-done 6418
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Fld);
--# end
--# expr-done 6419
Block_Var := Fld_1; 
--# bind left_ctx_free Block_Var
--# expr-start 6421 '<FieldAccess for has_context_free_type at ast.py:12395>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12395
--# expr-start 6420 '<FieldAccess for right at ast.py:12395>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12395
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Bin_Op_F_Right;
--# expr-done 6420
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Fld_2);
--# end
--# expr-done 6421
Block_Var_1 := Fld_3; 
--# bind right_ctx_free Block_Var_1
--# expr-start 6463 '<If at ast.py:12396>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:12396
if Block_Var then
   If_Result_1 := Block_Var_1;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 6438 '<And at ast.py:12403>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12403
--# expr-start 6435 '<And at ast.py:12403>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12403
--# expr-start 6432 '<And at ast.py:12403>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12403
--# expr-start 6426 '<Predicate on BaseTypeDecl.one_non_universal at ast.py:12403>' Pred /tmp/lal-23.0.0/ada/ast.py:12403
--# expr-start 6423 '<FieldAccess for type_var at ast.py:12404>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12404
--# expr-start 6422 '<FieldAccess for left at ast.py:12404>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12404
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Bin_Op_F_Left;
--# expr-done 6422
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_4);
--# expr-done 6423
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 6425 '<FieldAccess for type_var at ast.py:12404>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12404
--# expr-start 6424 '<FieldAccess for right at ast.py:12404>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12404
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Bin_Op_F_Right;
--# expr-done 6424
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_6);
--# expr-done 6425
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Pred := Solver.Create_N_Predicate ((Fld_5, Fld_7), Create_Base_Type_Decl_P_One_Non_Universal_0_Predicate); 
--# expr-done 6426
--# expr-start 6431 '<NPropagate at ast.py:12405>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12405
Dest_Var.Value := No_Entity;
Entity_Vars.Reset (Dest_Var);
--# expr-start 6428 '<FieldAccess for type_var at ast.py:12407>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12407
--# expr-start 6427 '<FieldAccess for left at ast.py:12407>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12407
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Self.Bin_Op_F_Left;
--# expr-done 6427
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_8);
--# expr-done 6428
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 6430 '<FieldAccess for type_var at ast.py:12407>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12407
--# expr-start 6429 '<FieldAccess for right at ast.py:12407>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12407
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Bin_Op_F_Right;
--# expr-done 6429
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_10);
--# expr-done 6430
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
Bind_Result := Solver.Create_N_Propagate (Dest_Var, Logic_Functor_632'(N => 2, Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), (1 => Fld_9, 2 => Fld_11), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12405") else null)); 
--# expr-done 6431
And_Pred := Create_And (Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12403") else null)); 
--# expr-done 6432
--# expr-start 6434 '<FieldAccess for matches_expected_formal_type at ast.py:12408>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12408
--# expr-start 6433 '<FieldAccess for left at ast.py:12408>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12408
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.Bin_Op_F_Left;
--# expr-done 6433
      if Fld_12 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_13 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_12, Origin => Origin);
--# end
--# expr-done 6434
And_Pred_1 := Create_And (And_Pred, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12403") else null)); 
--# expr-done 6435
--# expr-start 6437 '<FieldAccess for matches_expected_formal_type at ast.py:12409>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12409
--# expr-start 6436 '<FieldAccess for right at ast.py:12409>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:12409
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Self.Bin_Op_F_Right;
--# expr-done 6436
      if Fld_14 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_15 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_14, Origin => Origin);
--# end
--# expr-done 6437
And_Pred_2 := Create_And (And_Pred_1, Fld_15, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12403") else null)); 
--# expr-done 6438
   If_Result_2 := And_Pred_2;
else
   --# expr-start 6462 '<Let at ast.py:12411>' Let_Result /tmp/lal-23.0.0/ada/ast.py:12411
--# scope-start
--# expr-start 6448 '<And at ast.py:12413>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12413
--# expr-start 6445 '<And at ast.py:12413>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12413
--# expr-start 6441 '<Predicate on BaseTypeDecl.is_not_universal_type at ast.py:12413>' Pred_1 /tmp/lal-23.0.0/ada/ast.py:12413
--# expr-start 6440 '<FieldAccess for type_var at ast.py:12414>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12414
--# expr-start 6439 '<FieldAccess for left at ast.py:12414>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12414
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Self.Bin_Op_F_Left;
--# expr-done 6439
      if Fld_16 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_16);
--# expr-done 6440
Fld_17.Value := No_Entity;
Entity_Vars.Reset (Fld_17);
Pred_1 := Solver.Create_Predicate (Fld_17, Create_Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate); 
--# expr-done 6441
--# expr-start 6444 '<Bind at ast.py:12415>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12415
--# expr-start 6443 '<FieldAccess for type_var at ast.py:12415>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:12415
--# expr-start 6442 '<FieldAccess for left at ast.py:12415>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12415
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Self.Bin_Op_F_Left;
--# expr-done 6442
      if Fld_18 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_18);
--# expr-done 6443
Fld_19.Value := No_Entity;
Entity_Vars.Reset (Fld_19);
Dest_Var.Value := No_Entity;
Entity_Vars.Reset (Dest_Var);
Bind_Result_1 := Solver.Create_Propagate (Fld_19, Dest_Var, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12415") else null)); 
--# expr-done 6444
And_Pred_3 := Create_And (Pred_1, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12413") else null)); 
--# expr-done 6445
--# expr-start 6447 '<FieldAccess for matches_expected_formal_type at ast.py:12417>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:12417
--# expr-start 6446 '<FieldAccess for left at ast.py:12417>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:12417
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Self.Bin_Op_F_Left;
--# expr-done 6446
      if Fld_20 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_21 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_20, Origin => Origin);
--# end
--# expr-done 6447
And_Pred_4 := Create_And (And_Pred_3, Fld_21, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12413") else null)); 
--# expr-done 6448
Infer_Left := And_Pred_4; Inc_Ref (Infer_Left);
--# bind infer_left Infer_Left
--# expr-start 6458 '<And at ast.py:12419>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:12419
--# expr-start 6455 '<And at ast.py:12419>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12419
--# expr-start 6451 '<Predicate on BaseTypeDecl.is_not_universal_type at ast.py:12419>' Pred_2 /tmp/lal-23.0.0/ada/ast.py:12419
--# expr-start 6450 '<FieldAccess for type_var at ast.py:12420>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:12420
--# expr-start 6449 '<FieldAccess for right at ast.py:12420>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:12420
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Self.Bin_Op_F_Right;
--# expr-done 6449
      if Fld_22 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_22);
--# expr-done 6450
Fld_23.Value := No_Entity;
Entity_Vars.Reset (Fld_23);
Pred_2 := Solver.Create_Predicate (Fld_23, Create_Base_Type_Decl_P_Is_Not_Universal_Type_0_Predicate); 
--# expr-done 6451
--# expr-start 6454 '<Bind at ast.py:12421>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12421
--# expr-start 6453 '<FieldAccess for type_var at ast.py:12421>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:12421
--# expr-start 6452 '<FieldAccess for right at ast.py:12421>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:12421
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Self.Bin_Op_F_Right;
--# expr-done 6452
      if Fld_24 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_24);
--# expr-done 6453
Fld_25.Value := No_Entity;
Entity_Vars.Reset (Fld_25);
Dest_Var.Value := No_Entity;
Entity_Vars.Reset (Dest_Var);
Bind_Result_2 := Solver.Create_Propagate (Fld_25, Dest_Var, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12421") else null)); 
--# expr-done 6454
And_Pred_5 := Create_And (Pred_2, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12419") else null)); 
--# expr-done 6455
--# expr-start 6457 '<FieldAccess for matches_expected_formal_type at ast.py:12423>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:12423
--# expr-start 6456 '<FieldAccess for right at ast.py:12423>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:12423
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Self.Bin_Op_F_Right;
--# expr-done 6456
      if Fld_26 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_27 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_26, Origin => Origin);
--# end
--# expr-done 6457
And_Pred_6 := Create_And (And_Pred_5, Fld_27, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12419") else null)); 
--# expr-done 6458
Infer_Right := And_Pred_6; Inc_Ref (Infer_Right);
--# bind infer_right Infer_Right
--# expr-start 6461 '<If at ast.py:12425>' If_Result /tmp/lal-23.0.0/ada/ast.py:12425
if Block_Var then
   --# expr-start 6459 '<Or at ast.py:12426>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12426
Or_Pred := Create_Or (Infer_Left, Infer_Right, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12426") else null)); 
--# expr-done 6459
   If_Result := Or_Pred;
else
   --# expr-start 6460 '<Or at ast.py:12427>' Or_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12427
Or_Pred_1 := Create_Or (Infer_Right, Infer_Left, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12427") else null)); 
--# expr-done 6460
   If_Result := Or_Pred_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 6461
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 6462
   If_Result_2 := Let_Result;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 6463
Let_Result_1 := If_Result_2; Inc_Ref (Let_Result_1);
--# end
--# expr-done 6464
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_964;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_964;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Numeric_Type_From_Operands_Equation;
--# end
--# property-start BinOp.potential_actuals_for_dispatch /tmp/lal-23.0.0/ada/ast.py:12432
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Potential_Actuals_For_Dispatch
  (Node : Bare_Bin_Op
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Expected_Type_For_Expr_Array_Access
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind spec Spec
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Expected_Type_For_Expr_Array_Access;
            procedure Finalizer_Scope_965 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_2 : Internal_Entity_Type_Expr;
Fld_3 : Internal_Entity_Expr;
New_Struct : Internal_Expected_Type_For_Expr;
Get_Result_1 : Internal_Entity_Defining_Name;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl;
Fld_5 : Internal_Entity_Type_Expr;
Fld_6 : Internal_Entity_Expr;
New_Struct_1 : Internal_Expected_Type_For_Expr;
Array_Lit : Internal_Expected_Type_For_Expr_Array_Access;
Let_Result : Internal_Expected_Type_For_Expr_Array_Access;
            procedure Finalizer_Scope_965 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_965;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6477 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6465 '<FieldAccess for unpacked_formal_params at ast.py:12433>' Fld /tmp/lal-23.0.0/ada/ast.py:12433
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Spec.Node, E_Info => Spec.Info);
--# end
--# expr-done 6465
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind params Block_Var
--# expr-start 6476 '<ArrayLiteral at ast.py:12434>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:12434
--# expr-start 6470 '<New ExpectedTypeForExpr at ast.py:12435>' New_Struct /tmp/lal-23.0.0/ada/ast.py:12435
--# expr-start 6468 '<FieldAccess for type_expression at ast.py:12436>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12436
--# expr-start 6467 '<FieldAccess for formal_decl at ast.py:12436>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12436
--# expr-start 6466 '<at at ast.py:12436>' Get_Result /tmp/lal-23.0.0/ada/ast.py:12436
Get_Result := Get (Self, Block_Var, 0, True); 
--# expr-done 6466
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 6467
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 6468
--# expr-start 6469 '<FieldAccess for left at ast.py:12437>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12437
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Bin_Op_F_Left, Info => Ent.Info);
--# expr-done 6469
New_Struct := (Expected_Type => Fld_2, Expr => Fld_3); 
--# expr-done 6470
--# expr-start 6475 '<New ExpectedTypeForExpr at ast.py:12439>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:12439
--# expr-start 6473 '<FieldAccess for type_expression at ast.py:12440>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12440
--# expr-start 6472 '<FieldAccess for formal_decl at ast.py:12440>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12440
--# expr-start 6471 '<at at ast.py:12440>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:12440
Get_Result_1 := Get (Self, Block_Var, 1, True); 
--# expr-done 6471
      if Get_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_4 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result_1.Node, E_Info => Get_Result_1.Info);
--# end
--# expr-done 6472
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_5 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 6473
--# expr-start 6474 '<FieldAccess for right at ast.py:12441>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12441
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Ent.Node.Bin_Op_F_Right, Info => Ent.Info);
--# expr-done 6474
New_Struct_1 := (Expected_Type => Fld_5, Expr => Fld_6); 
--# expr-done 6475
Array_Lit := Create_Internal_Expected_Type_For_Expr_Array (Internal_Internal_Expected_Type_For_Expr_Array'(1 => New_Struct, 2 => New_Struct_1)); 
--# expr-done 6476
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 6477
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_965;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_965;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Potential_Actuals_For_Dispatch;
--# end
--# property-start BinOp.is_dispatching_call /tmp/lal-23.0.0/ada/ast.py:12446
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_Is_Dispatching_Call
  (Node : Bare_Bin_Op
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Op;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6481 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6479 '<FieldAccess for referenced_decl at ast.py:12447>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12447
--# expr-start 6478 '<FieldAccess for op at ast.py:12447>' Fld /tmp/lal-23.0.0/ada/ast.py:12447
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Op (Node => Ent.Node.Bin_Op_F_Op, Info => Ent.Info);
--# expr-done 6478
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_1 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 6479
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind decl Var_Expr
--# expr-start 6480 '<FieldAccess for is_dispatching_call_impl at ast.py:12448>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12448
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dispatching_call_impl
Fld_2 := Libadalang.Implementation.Expr_P_Is_Dispatching_Call_Impl (Node => Ent.Node, Decl => Var_Expr, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 6480
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 6481
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_Is_Dispatching_Call;
--# end
--# property-start BinOp.no_overload_equation /tmp/lal-23.0.0/ada/ast.py:12324
pragma Warnings (Off, "is not referenced");
 function Bin_Op_P_No_Overload_Equation
  (Node : Bare_Bin_Op
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Bin_Op := Bare_Bin_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Bin_Op :=
     Internal_Entity_Bin_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_963 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Bare_Expr;
Fld_2 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_3 : Logic_Var;
Fld_4 : Bare_Expr;
Fld_5 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_Op;
Is_A : Boolean;
Fld_7 : Bare_Expr;
Fld_8 : Logic_Var;
Fld_9 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Fld_10 : Bare_Expr;
Fld_11 : Logic_Var;
Fld_12 : Logic_Var;
Bind_Result_3 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_13 : Bare_Expr;
Fld_14 : Logic_Var;
Fld_15 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_4 : Logic_Equation;
Fld_16 : Bare_Expr;
Fld_17 : Logic_Var;
Fld_18 : Logic_Var;
Bind_Result_5 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_19 : Bare_Op;
Is_A_1 : Boolean;
Fld_20 : Bare_Expr;
Fld_21 : Logic_Var;
Fld_22 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_6 : Logic_Equation;
Fld_23 : Bare_Expr;
Fld_24 : Logic_Var;
Fld_25 : Logic_Var;
Bind_Result_7 : Logic_Equation;
And_Pred_3 : Logic_Equation;
False_Rel : Logic_Equation;
If_Result : Logic_Equation;
If_Result_1 : Logic_Equation;
Or_Pred_1 : Logic_Equation;
Fld_26 : Logic_Var;
Pred : Logic_Equation;
Fld_27 : Logic_Var;
Fld_28 : Logic_Var;
Bind_Result_8 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_29 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_9 : Logic_Equation;
Or_Pred_2 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Fld_30 : Logic_Var;
Pred_1 : Logic_Equation;
Fld_31 : Bare_Expr;
Fld_32 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Fld_33 : Bare_Expr;
Fld_34 : Logic_Equation;
And_Pred_7 : Logic_Equation;
Fld_35 : Logic_Var;
Fld_36 : Logic_Equation;
Or_Pred_3 : Logic_Equation;
And_Pred_8 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_963 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Bind_Result_6);
                     Dec_Ref (Bind_Result_7);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Or_Pred_1);
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result_8);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Bind_Result_9);
                     Dec_Ref (Or_Pred_2);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Pred_1);
                     Dec_Ref (Fld_32);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Fld_34);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (Fld_36);
                     Dec_Ref (Or_Pred_3);
                     Dec_Ref (And_Pred_8);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_963;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6547 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6546 '<And at ast.py:12329>' And_Pred_8 /tmp/lal-23.0.0/ada/ast.py:12329
--# expr-start 6534 '<And at ast.py:12329>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12329
--# expr-start 6524 '<Or at ast.py:12329>' Or_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12329
--# expr-start 6490 '<And at ast.py:12333>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12333
--# expr-start 6485 '<Bind at ast.py:12334>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12334
--# expr-start 6482 '<FieldAccess for type_var at ast.py:12334>' Fld /tmp/lal-23.0.0/ada/ast.py:12334
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6482
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 6484 '<FieldAccess for expected_type_var at ast.py:12334>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12334
--# expr-start 6483 '<FieldAccess for left at ast.py:12334>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12334
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Bin_Op_F_Left;
--# expr-done 6483
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_1);
--# expr-done 6484
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Bind_Result := Solver.Create_Unify (Fld, Fld_2, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12334") else null)); 
--# expr-done 6485
--# expr-start 6489 '<Bind at ast.py:12335>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12335
--# expr-start 6486 '<FieldAccess for type_var at ast.py:12335>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12335
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6486
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 6488 '<FieldAccess for expected_type_var at ast.py:12335>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12335
--# expr-start 6487 '<FieldAccess for right at ast.py:12335>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12335
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Bin_Op_F_Right;
--# expr-done 6487
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_4);
--# expr-done 6488
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result_1 := Solver.Create_Unify (Fld_3, Fld_5, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12335") else null)); 
--# expr-done 6489
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12333") else null)); 
--# expr-done 6490
--# expr-start 6523 '<Cond at ast.py:12339>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:12339
--# expr-start 6492 '<IsA Op.Mult, Op.Div at ast.py:12343>' Is_A /tmp/lal-23.0.0/ada/ast.py:12343
--# expr-start 6491 '<FieldAccess for op at ast.py:12343>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12343
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Bin_Op_F_Op;
--# expr-done 6491
Is_A := Fld_6 /= null 
and then Fld_6.Kind in Ada_Op_Mult_Range | Ada_Op_Div_Range; 
--# expr-done 6492
if Is_A then
   --# expr-start 6511 '<Or at ast.py:12344>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12344
--# expr-start 6501 '<And at ast.py:12345>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12345
--# expr-start 6496 '<Bind at ast.py:12345>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12345
--# expr-start 6494 '<FieldAccess for expected_type_var at ast.py:12345>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12345
--# expr-start 6493 '<FieldAccess for left at ast.py:12345>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12345
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Bin_Op_F_Left;
--# expr-done 6493
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_7);
--# expr-done 6494
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
--# expr-start 6495 '<FieldAccess for int_type at ast.py:12345>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12345
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_9 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 6495
      Cast_Result := Create_Internal_Entity
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_8, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12345") else null)); 
--# expr-done 6496
--# expr-start 6500 '<Bind at ast.py:12346>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:12346
--# expr-start 6498 '<FieldAccess for expected_type_var at ast.py:12346>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12346
--# expr-start 6497 '<FieldAccess for right at ast.py:12346>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12346
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Bin_Op_F_Right;
--# expr-done 6497
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_10);
--# expr-done 6498
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
--# expr-start 6499 '<FieldAccess for type_var at ast.py:12346>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12346
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6499
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
Bind_Result_3 := Solver.Create_Unify (Fld_11, Fld_12, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12346") else null)); 
--# expr-done 6500
And_Pred_1 := Create_And (Bind_Result_2, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12345") else null)); 
--# expr-done 6501
--# expr-start 6510 '<And at ast.py:12348>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12348
--# expr-start 6505 '<Bind at ast.py:12348>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:12348
--# expr-start 6503 '<FieldAccess for expected_type_var at ast.py:12348>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:12348
--# expr-start 6502 '<FieldAccess for right at ast.py:12348>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12348
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Self.Bin_Op_F_Right;
--# expr-done 6502
      if Fld_13 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_13);
--# expr-done 6503
Fld_14.Value := No_Entity;
Entity_Vars.Reset (Fld_14);
--# expr-start 6504 '<FieldAccess for int_type at ast.py:12348>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12348
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_15 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 6504
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
Bind_Result_4 := Solver.Create_Assign (Fld_14, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12348") else null)); 
--# expr-done 6505
--# expr-start 6509 '<Bind at ast.py:12349>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:12349
--# expr-start 6507 '<FieldAccess for expected_type_var at ast.py:12349>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12349
--# expr-start 6506 '<FieldAccess for left at ast.py:12349>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12349
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Self.Bin_Op_F_Left;
--# expr-done 6506
      if Fld_16 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_16);
--# expr-done 6507
Fld_17.Value := No_Entity;
Entity_Vars.Reset (Fld_17);
--# expr-start 6508 '<FieldAccess for type_var at ast.py:12349>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12349
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6508
Fld_18.Value := No_Entity;
Entity_Vars.Reset (Fld_18);
Bind_Result_5 := Solver.Create_Unify (Fld_17, Fld_18, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12349") else null)); 
--# expr-done 6509
And_Pred_2 := Create_And (Bind_Result_4, Bind_Result_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12348") else null)); 
--# expr-done 6510
Or_Pred := Create_Or (And_Pred_1, And_Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12344") else null)); 
--# expr-done 6511
   If_Result_1 := Or_Pred;
else
--# expr-start 6513 '<IsA Op.Pow at ast.py:12354>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:12354
--# expr-start 6512 '<FieldAccess for op at ast.py:12354>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:12354
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Self.Bin_Op_F_Op;
--# expr-done 6512
Is_A_1 := Fld_19 /= null 
and then Fld_19.Kind in Ada_Op_Pow_Range; 
--# expr-done 6513
if Is_A_1 then
   --# expr-start 6522 '<And at ast.py:12355>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12355
--# expr-start 6517 '<Bind at ast.py:12355>' Bind_Result_6 /tmp/lal-23.0.0/ada/ast.py:12355
--# expr-start 6515 '<FieldAccess for expected_type_var at ast.py:12355>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:12355
--# expr-start 6514 '<FieldAccess for right at ast.py:12355>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:12355
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Self.Bin_Op_F_Right;
--# expr-done 6514
      if Fld_20 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_20);
--# expr-done 6515
Fld_21.Value := No_Entity;
Entity_Vars.Reset (Fld_21);
--# expr-start 6516 '<FieldAccess for int_type at ast.py:12355>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:12355
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_22 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 6516
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_22.Node,
         Info => Fld_22.Info);
Bind_Result_6 := Solver.Create_Assign (Fld_21, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12355") else null)); 
--# expr-done 6517
--# expr-start 6521 '<Bind at ast.py:12356>' Bind_Result_7 /tmp/lal-23.0.0/ada/ast.py:12356
--# expr-start 6519 '<FieldAccess for expected_type_var at ast.py:12356>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:12356
--# expr-start 6518 '<FieldAccess for left at ast.py:12356>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:12356
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Self.Bin_Op_F_Left;
--# expr-done 6518
      if Fld_23 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_23);
--# expr-done 6519
Fld_24.Value := No_Entity;
Entity_Vars.Reset (Fld_24);
--# expr-start 6520 '<FieldAccess for type_var at ast.py:12356>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:12356
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6520
Fld_25.Value := No_Entity;
Entity_Vars.Reset (Fld_25);
Bind_Result_7 := Solver.Create_Unify (Fld_24, Fld_25, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12356") else null)); 
--# expr-done 6521
And_Pred_3 := Create_And (Bind_Result_6, Bind_Result_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12355") else null)); 
--# expr-done 6522
   If_Result := And_Pred_3;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12358") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 6523
Or_Pred_1 := Create_Or (And_Pred, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12329") else null)); 
--# expr-done 6524
--# expr-start 6533 '<Or at ast.py:12360>' Or_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12360
--# expr-start 6530 '<And at ast.py:12364>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12364
--# expr-start 6526 '<Predicate on AdaNode.is_not_null at ast.py:12364>' Pred /tmp/lal-23.0.0/ada/ast.py:12364
--# expr-start 6525 '<FieldAccess for expected_type_var at ast.py:12364>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:12364
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6525
Fld_26.Value := No_Entity;
Entity_Vars.Reset (Fld_26);
Pred := Solver.Create_Predicate (Fld_26, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 6526
--# expr-start 6529 '<Bind at ast.py:12365>' Bind_Result_8 /tmp/lal-23.0.0/ada/ast.py:12365
--# expr-start 6527 '<FieldAccess for expected_type_var at ast.py:12365>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:12365
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6527
Fld_27.Value := No_Entity;
Entity_Vars.Reset (Fld_27);
--# expr-start 6528 '<FieldAccess for type_var at ast.py:12365>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:12365
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6528
Fld_28.Value := No_Entity;
Entity_Vars.Reset (Fld_28);
Bind_Result_8 := Solver.Create_Propagate (Fld_27, Fld_28, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12365") else null)); 
--# expr-done 6529
And_Pred_4 := Create_And (Pred, Bind_Result_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12364") else null)); 
--# expr-done 6530
--# expr-start 6532 '<Bind at ast.py:12372>' Bind_Result_9 /tmp/lal-23.0.0/ada/ast.py:12372
--# expr-start 6531 '<FieldAccess for expected_type_var at ast.py:12372>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:12372
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6531
Fld_29.Value := No_Entity;
Entity_Vars.Reset (Fld_29);
Cast_Expr := No_Entity_Base_Type_Decl; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result_9 := Solver.Create_Assign (Fld_29, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12372") else null)); 
--# expr-done 6532
Or_Pred_2 := Create_Or (And_Pred_4, Bind_Result_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12360") else null)); 
--# expr-done 6533
And_Pred_5 := Create_And (Or_Pred_1, Or_Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12329") else null)); 
--# expr-done 6534
--# expr-start 6545 '<Or at ast.py:12373>' Or_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12373
--# expr-start 6542 '<And at ast.py:12376>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:12376
--# expr-start 6539 '<And at ast.py:12376>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:12376
--# expr-start 6536 '<Predicate on AdaNode.is_not_null at ast.py:12376>' Pred_1 /tmp/lal-23.0.0/ada/ast.py:12376
--# expr-start 6535 '<FieldAccess for expected_type_var at ast.py:12376>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:12376
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_30 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6535
Fld_30.Value := No_Entity;
Entity_Vars.Reset (Fld_30);
Pred_1 := Solver.Create_Predicate (Fld_30, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 6536
--# expr-start 6538 '<FieldAccess for matches_expected_formal_type at ast.py:12377>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:12377
--# expr-start 6537 '<FieldAccess for left at ast.py:12377>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:12377
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Self.Bin_Op_F_Left;
--# expr-done 6537
      if Fld_31 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_32 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_31, Origin => Origin);
--# end
--# expr-done 6538
And_Pred_6 := Create_And (Pred_1, Fld_32, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12376") else null)); 
--# expr-done 6539
--# expr-start 6541 '<FieldAccess for matches_expected_formal_type at ast.py:12378>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:12378
--# expr-start 6540 '<FieldAccess for right at ast.py:12378>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:12378
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_33 := Self.Bin_Op_F_Right;
--# expr-done 6540
      if Fld_33 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_34 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_33, Origin => Origin);
--# end
--# expr-done 6541
And_Pred_7 := Create_And (And_Pred_6, Fld_34, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12376") else null)); 
--# expr-done 6542
--# expr-start 6544 '<FieldAccess for numeric_type_from_operands_equation at ast.py:12384>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:12384
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6543 '<FieldAccess for type_var at ast.py:12384>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:12384
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_35 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6543
--# property-call-start BinOp.numeric_type_from_operands_equation
Fld_36 := Libadalang.Implementation.Bin_Op_P_Numeric_Type_From_Operands_Equation (Node => Ent.Node, Dest_Var => Fld_35, Origin => Origin);
--# end
--# expr-done 6544
Or_Pred_3 := Create_Or (And_Pred_7, Fld_36, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12373") else null)); 
--# expr-done 6545
And_Pred_8 := Create_And (And_Pred_5, Or_Pred_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12329") else null)); 
--# expr-done 6546
Let_Result := And_Pred_8; Inc_Ref (Let_Result);
--# end
--# expr-done 6547
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_963;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_963;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Bin_Op_P_No_Overload_Equation;
--# end
   --
   --  Primitives for Bare_Relation_Op
   --
      procedure Initialize_Fields_For_Relation_Op
        (Self : Bare_Relation_Op
         ; Bin_Op_F_Left : Bare_Expr
         ; Bin_Op_F_Op : Bare_Op
         ; Bin_Op_F_Right : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Bin_Op
              (Self, Bin_Op_F_Left, Bin_Op_F_Op, Bin_Op_F_Right);
      end Initialize_Fields_For_Relation_Op;
--# property-start RelationOp.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12748
pragma Warnings (Off, "is not referenced");
 function Relation_Op_P_Has_Context_Free_Type
  (Node : Bare_Relation_Op
  )
   return Boolean
is
   Self : Bare_Relation_Op := Bare_Relation_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Relation_Op_P_Has_Context_Free_Type;
--# end
--# property-start RelationOp.no_overload_equation /tmp/lal-23.0.0/ada/ast.py:12750
pragma Warnings (Off, "is not referenced");
 function Relation_Op_P_No_Overload_Equation
  (Node : Bare_Relation_Op
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Relation_Op := Bare_Relation_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Relation_Op :=
     Internal_Entity_Relation_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_975 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Fld_4 : Bare_Expr;
Fld_5 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_Expr;
Fld_7 : Logic_Var;
Fld_8 : Logic_Equation;
And_Pred_1 : Logic_Equation;
            procedure Finalizer_Scope_975 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_8);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_975;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6560 '<And at ast.py:12751>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12751
--# expr-start 6556 '<And at ast.py:12751>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12751
--# expr-start 6550 '<Bind at ast.py:12751>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12751
--# expr-start 6548 '<FieldAccess for type_var at ast.py:12751>' Fld /tmp/lal-23.0.0/ada/ast.py:12751
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6548
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 6549 '<FieldAccess for bool_type at ast.py:12751>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12751
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6549
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12751") else null)); 
--# expr-done 6550
--# expr-start 6555 '<Bind at ast.py:12752>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12752
--# expr-start 6552 '<FieldAccess for expected_type_var at ast.py:12752>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12752
--# expr-start 6551 '<FieldAccess for left at ast.py:12752>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12752
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Bin_Op_F_Left;
--# expr-done 6551
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2);
--# expr-done 6552
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 6554 '<FieldAccess for expected_type_var at ast.py:12752>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12752
--# expr-start 6553 '<FieldAccess for right at ast.py:12752>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12752
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Bin_Op_F_Right;
--# expr-done 6553
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_4);
--# expr-done 6554
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result_1 := Solver.Create_Unify (Fld_3, Fld_5, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12752") else null)); 
--# expr-done 6555
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12751") else null)); 
--# expr-done 6556
--# expr-start 6559 '<FieldAccess for numeric_type_from_operands_equation at ast.py:12753>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12753
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6558 '<FieldAccess for expected_type_var at ast.py:12754>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12754
--# expr-start 6557 '<FieldAccess for left at ast.py:12754>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12754
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Bin_Op_F_Left;
--# expr-done 6557
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_6);
--# expr-done 6558
--# property-call-start BinOp.numeric_type_from_operands_equation
Fld_8 := Libadalang.Implementation.Bin_Op_P_Numeric_Type_From_Operands_Equation (Node => Ent.Node, Dest_Var => Fld_7, Origin => Origin);
--# end
--# expr-done 6559
And_Pred_1 := Create_And (And_Pred, Fld_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12751") else null)); 
--# expr-done 6560
      Property_Result := And_Pred_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_975;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_975;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Relation_Op_P_No_Overload_Equation;
--# end
   --
   --  Primitives for Bare_Box_Expr
   --
      procedure Initialize_Fields_For_Box_Expr
        (Self : Bare_Box_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
      end Initialize_Fields_For_Box_Expr;
--# property-start BoxExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:15355
pragma Warnings (Off, "is not referenced");
 function Box_Expr_P_Xref_Equation
  (Node : Bare_Box_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Box_Expr := Bare_Box_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1107 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Bind_Result : Logic_Equation;
            procedure Finalizer_Scope_1107 is
            begin
                     Dec_Ref (Bind_Result);
            end Finalizer_Scope_1107;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6563 '<Bind at ast.py:15355>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15355
--# expr-start 6561 '<FieldAccess for type_var at ast.py:15355>' Fld /tmp/lal-23.0.0/ada/ast.py:15355
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6561
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 6562 '<FieldAccess for expected_type_var at ast.py:15355>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15355
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6562
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Bind_Result := Solver.Create_Unify (Fld, Fld_1, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15355") else null)); 
--# expr-done 6563
      Property_Result := Bind_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1107;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1107;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Box_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Case_Expr_Alternative
   --
      procedure Initialize_Fields_For_Case_Expr_Alternative
        (Self : Bare_Case_Expr_Alternative
         ; Case_Expr_Alternative_F_Choices : Bare_Alternatives_List
         ; Case_Expr_Alternative_F_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Case_Expr_Alternative_F_Choices := Case_Expr_Alternative_F_Choices;
            Self.Case_Expr_Alternative_F_Expr := Case_Expr_Alternative_F_Expr;
      end Initialize_Fields_For_Case_Expr_Alternative;
   function Case_Expr_Alternative_F_Choices
     (Node : Bare_Case_Expr_Alternative) return Bare_Alternatives_List
   is
   begin
         return Node.Case_Expr_Alternative_F_Choices;
   end;
   function Case_Expr_Alternative_F_Expr
     (Node : Bare_Case_Expr_Alternative) return Bare_Expr
   is
   begin
         return Node.Case_Expr_Alternative_F_Expr;
   end;
   --
   --  Primitives for Bare_Concat_Op
   --
      procedure Initialize_Fields_For_Concat_Op
        (Self : Bare_Concat_Op
         ; Concat_Op_F_First_Operand : Bare_Expr
         ; Concat_Op_F_Other_Operands : Bare_Concat_Operand_List
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Concat_Op_F_First_Operand := Concat_Op_F_First_Operand;
            Self.Concat_Op_F_Other_Operands := Concat_Op_F_Other_Operands;
      end Initialize_Fields_For_Concat_Op;
   function Concat_Op_F_First_Operand
     (Node : Bare_Concat_Op) return Bare_Expr
   is
   begin
         return Node.Concat_Op_F_First_Operand;
   end;
   function Concat_Op_F_Other_Operands
     (Node : Bare_Concat_Op) return Bare_Concat_Operand_List
   is
   begin
         return Node.Concat_Op_F_Other_Operands;
   end;
--# property-start ConcatOp.operands /tmp/lal-23.0.0/ada/ast.py:12487
pragma Warnings (Off, "is not referenced");
 function Concat_Op_P_Operands
  (Node : Bare_Concat_Op
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr_Array_Access
is
   Self : Bare_Concat_Op := Bare_Concat_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Concat_Op :=
     Internal_Entity_Concat_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr_Array_Access;
            procedure Finalizer_Scope_967 with Inline_Always;
      Fld : Internal_Entity_Expr;
Singleton : Internal_Entity_Expr_Array_Access;
Fld_1 : Internal_Entity_Concat_Operand_List;
Fld_2 : Bare_Concat_Operand_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Concat_Operand;
Is_Null : Boolean;
If_Result : Internal_Entity_Concat_Operand;
Fld_4 : Internal_Entity_Expr;
Item_225 : Internal_Entity_Concat_Operand;
Bare_Item_225 : Bare_Concat_Operand;
Map_Result : Internal_Entity_Expr_Array_Access;
Concat_Result : Internal_Entity_Expr_Array_Access;
            procedure Finalizer_Scope_967 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_967;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6568 '<Concat at ast.py:12488>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:12488
--# expr-start 6564 '<FieldAccess for first_operand at ast.py:12488>' Fld /tmp/lal-23.0.0/ada/ast.py:12488
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Concat_Op_F_First_Operand, Info => Ent.Info);
--# expr-done 6564
                Singleton := Create_Internal_Entity_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
--# expr-start 6567 '<Map at ast.py:12489>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12489
   --# expr-start 6565 '<FieldAccess for other_operands at ast.py:12489>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12489
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Concat_Operand_List (Node => Ent.Node.Concat_Op_F_Other_Operands, Info => Ent.Info);
--# expr-done 6565
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Internal_Entity_Expr_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Expr_Array (0);
      else
      declare
         Collection : constant Bare_Concat_Operand_List := Fld_2;
      begin
         for Untyped_Item_225 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_225 := Untyped_Item_225; 
Is_Null := Bare_Item_225 = null; 
if Is_Null then
   If_Result := No_Entity_Concat_Operand;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_225); 
   If_Result := As_Entity;
end if;
                  Item_225 := If_Result; 
   --# scope-start
               --# bind oo Item_225
      --# expr-start 6566 '<FieldAccess for operand at ast.py:12489>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12489
      if Item_225.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Item_225.Node.Concat_Operand_F_Operand, Info => Item_225.Info);
--# expr-done 6566
         declare
            Item_To_Append : constant Internal_Entity_Expr := Fld_4;
         begin
            Internal_Entity_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Expr_Array
           (Items_Count => Natural (Internal_Entity_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6567
Concat_Result := Concat (Singleton, Map_Result); 
--# expr-done 6568
      Property_Result := Concat_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_967;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_967;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Op_P_Operands;
--# end
--# property-start ConcatOp.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12496
pragma Warnings (Off, "is not referenced");
 function Concat_Op_P_Has_Context_Free_Type
  (Node : Bare_Concat_Op
  )
   return Boolean
is
   Self : Bare_Concat_Op := Bare_Concat_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6569 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 6569
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Op_P_Has_Context_Free_Type;
--# end
--# property-start ConcatOp.xref_equation /tmp/lal-23.0.0/ada/ast.py:12500
pragma Warnings (Off, "is not referenced");
 function Concat_Op_P_Xref_Equation
  (Node : Bare_Concat_Op
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Concat_Op := Bare_Concat_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Concat_Op :=
     Internal_Entity_Concat_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_969 with Inline_Always;
            procedure Finalizer_Scope_2711 with Inline_Always;
            procedure Finalizer_Scope_2712 with Inline_Always;
      Block_Var : Bare_Concat_Operand;
Block_Var_1 : Internal_Entity_Basic_Decl_Array_Access;
Left : Internal_Entity_Expr;
Right : Internal_Entity_Expr;
Spec : Internal_Entity_Base_Subp_Spec;
Fld : Bare_Concat_Operand_List;
Len : Integer;
Arith_Result : Integer;
Fld_1 : Bare_Concat_Operand_List;
Get_Result : Bare_Concat_Operand;
Fld_2 : Internal_Entity_Concat_Operand_List;
Fld_3 : Bare_Concat_Operand_List;
Fld_4 : Internal_Entity_Info;
Get_Result_1 : Bare_Concat_Operand;
As_Entity : Internal_Entity_Concat_Operand;
Is_Null : Boolean;
If_Result : Internal_Entity_Concat_Operand;
Fld_5 : Internal_Entity_Op_Concat;
Fld_6 : Internal_Entity_Basic_Decl_Array_Access;
Fld_7 : Internal_Entity_Expr;
Fld_8 : Logic_Equation;
Fld_9 : Internal_Entity_Concat_Operand_List;
Fld_10 : Bare_Concat_Operand_List;
Fld_11 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Concat_Operand;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Concat_Operand;
Arith_Result_1 : Integer;
Fld_12 : Internal_Entity_Concat_Operand_List;
Fld_13 : Bare_Concat_Operand_List;
Fld_14 : Internal_Entity_Info;
Get_Result_2 : Bare_Concat_Operand;
As_Entity_2 : Internal_Entity_Concat_Operand;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity_Concat_Operand;
Fld_15 : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Concat_Operand;
Cast_Result : Internal_Entity_Expr;
Comp_Result : Boolean;
If_Result_3 : Internal_Entity_Expr;
Fld_16 : Internal_Entity_Expr;
Fld_17 : Logic_Equation;
Fld_18 : Internal_Entity_Base_Subp_Spec;
Fld_19 : Logic_Equation;
Fld_20 : Internal_Entity_Op_Concat;
Fld_21 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_22 : Internal_Entity_Op_Concat;
Fld_23 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Base_Subp_Spec;
Cast_Result_2 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_24 : Logic_Equation;
Or_Pred : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result_1 : Logic_Equation;
Item_226 : Internal_Entity_Concat_Operand;
Bare_Item_226 : Bare_Concat_Operand;
Index_227 : Integer;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_25 : Logic_Var;
Fld_26 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_27 : Logic_Var;
Fld_28 : Logic_Var;
Bind_Result_3 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Let_Result_2 : Logic_Equation;
            procedure Finalizer_Scope_969 is
            begin
                     Dec_Ref (Fld_6);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_969;
            procedure Finalizer_Scope_2711 is
            begin
                     Dec_Ref (Fld_17);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Fld_24);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_2711;
            procedure Finalizer_Scope_2712 is
            begin
                     Dec_Ref (Fld_19);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_2712;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6615 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 6574 '<at at ast.py:12502>' Get_Result /tmp/lal-23.0.0/ada/ast.py:12502
--# expr-start 6570 '<FieldAccess for other_operands at ast.py:12502>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12502
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Concat_Op_F_Other_Operands;
--# expr-done 6570
--# expr-start 6573 '<Arithmetic - at ast.py:12502>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:12502
--# expr-start 6572 '<length at ast.py:12502>' Len /tmp/lal-23.0.0/ada/ast.py:12502
--# expr-start 6571 '<FieldAccess for other_operands at ast.py:12502>' Fld /tmp/lal-23.0.0/ada/ast.py:12502
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Concat_Op_F_Other_Operands;
--# expr-done 6571
Len := Length (Fld); 
--# expr-done 6572
Arith_Result := (Len - 1); 
--# expr-done 6573
Get_Result := Get (Self, Fld_1, Arith_Result, True); 
--# expr-done 6574
Block_Var := Get_Result; 
--# bind last_operand Block_Var
--# expr-start 6577 '<FieldAccess for subprograms at ast.py:12504>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12504
--# expr-start 6576 '<FieldAccess for operator at ast.py:12504>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12504
--# expr-start 6575 '<FieldAccess for other_operands at ast.py:12504>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12504
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Concat_Operand_List (Node => Ent.Node.Concat_Op_F_Other_Operands, Info => Ent.Info);
--# expr-done 6575
Fld_3 := Fld_2.Node;
Get_Result_1 := Get (Self, Fld_3, 0, True); 
Is_Null := Get_Result_1 = null; 
if Is_Null then
   If_Result := No_Entity_Concat_Operand;
else
Fld_4 := Fld_2.Info;
As_Entity := (Info => Fld_4, Node => Get_Result_1); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Op_Concat (Node => If_Result.Node.Concat_Operand_F_Operator, Info => If_Result.Info);
--# expr-done 6576
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Op.subprograms
Fld_6 := Libadalang.Implementation.Op_P_Subprograms (Node => Fld_5.Node, E_Info => Fld_5.Info);
--# end
--# expr-done 6577
Block_Var_1 := Fld_6; Inc_Ref (Block_Var_1);
--# bind concat_subprograms Block_Var_1
--# expr-start 6614 '<And at ast.py:12508>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12508
--# expr-start 6610 '<And at ast.py:12508>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12508
--# expr-start 6606 '<And at ast.py:12508>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12508
--# expr-start 6579 '<FieldAccess for sub_equation at ast.py:12508>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12508
--# expr-start 6578 '<FieldAccess for first_operand at ast.py:12508>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12508
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Expr (Node => Ent.Node.Concat_Op_F_First_Operand, Info => Ent.Info);
--# expr-done 6578
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_8 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_7.Node, Env => Env, Origin => Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 6579
--# expr-start 6605 '<LogicAll at ast.py:12509>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:12509
--# expr-start 6604 '<Map at ast.py:12509>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:12509
   --# expr-start 6580 '<FieldAccess for other_operands at ast.py:12509>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12509
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Concat_Operand_List (Node => Ent.Node.Concat_Op_F_Other_Operands, Info => Ent.Info);
--# expr-done 6580
Fld_10 := Fld_9.Node;
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_10 = null then
      Map_Result_1 := Create_Logic_Equation_Array (0);
      else
         Index_227 := 0;
      declare
         Collection : constant Bare_Concat_Operand_List := Fld_10;
      begin
         for Untyped_Item_226 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_226 := Untyped_Item_226; 
Is_Null_1 := Bare_Item_226 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Concat_Operand;
else
Fld_11 := Fld_9.Info;
As_Entity_1 := (Info => Fld_11, Node => Bare_Item_226); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_226 := If_Result_1; 
   --# scope-start
               --# bind concat_operand Item_226
               --# bind pos Index_227
      --# expr-start 6603 '<Let at ast.py:12510>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:12510
--# scope-start
--# expr-start 6584 '<If at ast.py:12514>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:12514
Comp_Result := Index_227 > 0; 
if Comp_Result then
--# expr-start 6581 '<FieldAccess for other_operands at ast.py:12516>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12516
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Concat_Operand_List (Node => Ent.Node.Concat_Op_F_Other_Operands, Info => Ent.Info);
--# expr-done 6581
Fld_13 := Fld_12.Node;
--# expr-start 6582 '<Arithmetic - at ast.py:12516>' Arith_Result_1 /tmp/lal-23.0.0/ada/ast.py:12516
Arith_Result_1 := (Index_227 - 1); 
--# expr-done 6582
Get_Result_2 := Get (Self, Fld_13, Arith_Result_1, True); 
Is_Null_2 := Get_Result_2 = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity_Concat_Operand;
else
Fld_14 := Fld_12.Info;
As_Entity_2 := (Info => Fld_14, Node => Get_Result_2); 
   If_Result_2 := As_Entity_2;
end if;
Cast_Expr := If_Result_2; 
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   If_Result_3 := Cast_Result;
else
   --# expr-start 6583 '<FieldAccess for first_operand at ast.py:12517>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12517
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Expr (Node => Ent.Node.Concat_Op_F_First_Operand, Info => Ent.Info);
--# expr-done 6583
   If_Result_3 := Fld_15;
end if;
--# expr-done 6584
Left := If_Result_3; 
--# bind left Left
--# expr-start 6585 '<FieldAccess for operand at ast.py:12519>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12519
      if Item_226.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Expr (Node => Item_226.Node.Concat_Operand_F_Operand, Info => Item_226.Info);
--# expr-done 6585
Right := Fld_16; 
--# bind right Right
--# expr-start 6602 '<And at ast.py:12521>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12521
--# expr-start 6586 '<FieldAccess for sub_equation at ast.py:12521>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12521
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_17 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Right.Node, Env => Env, Origin => Origin, E_Info => Right.Info);
--# end
--# expr-done 6586
--# expr-start 6601 '<Or at ast.py:12522>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12522
--# expr-start 6599 '<LogicAny at ast.py:12525>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:12525
--# expr-start 6598 '<Map at ast.py:12525>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12525
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_1;
      begin
         for Item_228 of
               Collection.Items
         loop
   --# scope-start
               --# bind subp Item_228
      --# expr-start 6597 '<Let at ast.py:12526>' Let_Result /tmp/lal-23.0.0/ada/ast.py:12526
--# scope-start
--# expr-start 6587 '<FieldAccess for subp_spec_or_null at ast.py:12527>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12527
      if Item_228.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_18 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Item_228.Node, E_Info => Item_228.Info);
--# end
--# expr-done 6587
Spec := Fld_18; 
--# bind spec Spec
--# expr-start 6596 '<And at ast.py:12529>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12529
--# expr-start 6592 '<And at ast.py:12529>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12529
--# expr-start 6588 '<FieldAccess for arguments_eq at ast.py:12530>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:12530
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ConcatOp.arguments_eq
Fld_19 := Libadalang.Implementation.Concat_Op_P_Arguments_Eq (Node => Ent.Node, Spec => Spec, Left => Left, Op => Item_226, Right => Right, Origin => Origin, Env => Env);
--# end
--# expr-done 6588
--# expr-start 6591 '<Bind at ast.py:12532>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12532
--# expr-start 6590 '<FieldAccess for ref_var at ast.py:12532>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:12532
--# expr-start 6589 '<FieldAccess for operator at ast.py:12532>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:12532
      if Item_226.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Op_Concat (Node => Item_226.Node.Concat_Operand_F_Operator, Info => Item_226.Info);
--# expr-done 6589
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_21 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_20.Node);
--# end
--# expr-done 6590
Fld_21.Value := No_Entity;
Entity_Vars.Reset (Fld_21);
Cast_Expr_1 := Item_228; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result := Solver.Create_Assign (Fld_21, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12532") else null)); 
--# expr-done 6591
And_Pred := Create_And (Fld_19, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12529") else null)); 
--# expr-done 6592
--# expr-start 6595 '<Bind at ast.py:12534>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12534
--# expr-start 6594 '<FieldAccess for subp_spec_var at ast.py:12534>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:12534
--# expr-start 6593 '<FieldAccess for operator at ast.py:12534>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:12534
      if Item_226.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Create_Internal_Entity_Op_Concat (Node => Item_226.Node.Concat_Operand_F_Operator, Info => Item_226.Info);
--# expr-done 6593
      if Fld_22.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_23 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Fld_22.Node);
--# end
--# expr-done 6594
Fld_23.Value := No_Entity;
Entity_Vars.Reset (Fld_23);
Cast_Expr_2 := Spec; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_23, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12534") else null)); 
--# expr-done 6595
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12529") else null)); 
--# expr-done 6596
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6597
         declare
            Item_To_Append : constant Logic_Equation := Let_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2712;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6598
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12525") else null)); 
--# expr-done 6599
--# expr-start 6600 '<FieldAccess for operator_no_subprogram_equation at ast.py:12542>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:12542
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ConcatOp.operator_no_subprogram_equation
Fld_24 := Libadalang.Implementation.Concat_Op_P_Operator_No_Subprogram_Equation (Node => Ent.Node, Left => Left, Op => Item_226, Right => Right, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 6600
Or_Pred := Create_Or (Logic_Boolean_Op, Fld_24, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12522") else null)); 
--# expr-done 6601
And_Pred_2 := Create_And (Fld_17, Or_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12521") else null)); 
--# expr-done 6602
Let_Result_1 := And_Pred_2; Inc_Ref (Let_Result_1);
--# end
--# expr-done 6603
         declare
            Item_To_Append : constant Logic_Equation := Let_Result_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2711;
               Index_227 := Index_227 + 1;
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 6604
Logic_Boolean_Op_1 := Solver.Create_All (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12509") else null)); 
--# expr-done 6605
And_Pred_3 := Create_And (Fld_8, Logic_Boolean_Op_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12508") else null)); 
--# expr-done 6606
--# expr-start 6609 '<Bind at ast.py:12549>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12549
--# expr-start 6607 '<FieldAccess for type_var at ast.py:12549>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:12549
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6607
Fld_25.Value := No_Entity;
Entity_Vars.Reset (Fld_25);
--# expr-start 6608 '<FieldAccess for type_var at ast.py:12549>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:12549
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Block_Var);
--# expr-done 6608
Fld_26.Value := No_Entity;
Entity_Vars.Reset (Fld_26);
Bind_Result_2 := Solver.Create_Unify (Fld_25, Fld_26, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12549") else null)); 
--# expr-done 6609
And_Pred_4 := Create_And (And_Pred_3, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12508") else null)); 
--# expr-done 6610
--# expr-start 6613 '<Bind at ast.py:12550>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:12550
--# expr-start 6611 '<FieldAccess for expected_type_var at ast.py:12550>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:12550
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6611
Fld_27.Value := No_Entity;
Entity_Vars.Reset (Fld_27);
--# expr-start 6612 '<FieldAccess for expected_type_var at ast.py:12550>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:12550
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Block_Var);
--# expr-done 6612
Fld_28.Value := No_Entity;
Entity_Vars.Reset (Fld_28);
Bind_Result_3 := Solver.Create_Unify (Fld_27, Fld_28, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12550") else null)); 
--# expr-done 6613
And_Pred_5 := Create_And (And_Pred_4, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12508") else null)); 
--# expr-done 6614
Let_Result_2 := And_Pred_5; Inc_Ref (Let_Result_2);
--# end
--# expr-done 6615
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_969;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_969;
               Finalizer_Scope_2711;
               Finalizer_Scope_2712;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Op_P_Xref_Equation;
--# end
--# property-start ConcatOp.arguments_eq /tmp/lal-23.0.0/ada/ast.py:12554
pragma Warnings (Off, "is not referenced");
 function Concat_Op_P_Arguments_Eq
  (Node : Bare_Concat_Op
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Left : Internal_Entity_Expr
      ; Op : Internal_Entity_Concat_Operand
      ; Right : Internal_Entity_Expr
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
  )
   return Logic_Equation
is
   Self : Bare_Concat_Op := Bare_Concat_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind spec Spec
   --# bind left Left
   --# bind op Op
   --# bind right Right
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_970 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Base_Formal_Param_Decl;
Fld_2 : Logic_Equation;
Get_Result_1 : Internal_Entity_Defining_Name;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
False_Rel : Logic_Equation;
Len : Integer;
Is_Equal : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_970 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_970;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6631 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6616 '<FieldAccess for unpacked_formal_params at ast.py:12559>' Fld /tmp/lal-23.0.0/ada/ast.py:12559
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Spec.Node, E_Info => Spec.Info);
--# end
--# expr-done 6616
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind ps Block_Var
--# expr-start 6630 '<If at ast.py:12560>' If_Result /tmp/lal-23.0.0/ada/ast.py:12560
--# expr-start 6618 '<Eq at ast.py:12561>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:12561
--# expr-start 6617 '<length at ast.py:12561>' Len /tmp/lal-23.0.0/ada/ast.py:12561
Len := Length (Block_Var); 
--# expr-done 6617
Is_Equal := Len = 2; 
--# expr-done 6618
if Is_Equal then
   --# expr-start 6629 '<And at ast.py:12564>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12564
--# expr-start 6625 '<And at ast.py:12564>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12564
--# expr-start 6621 '<FieldAccess for call_argument_equation at ast.py:12564>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12564
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6620 '<FieldAccess for formal_decl at ast.py:12564>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12564
--# expr-start 6619 '<at at ast.py:12564>' Get_Result /tmp/lal-23.0.0/ada/ast.py:12564
Get_Result := Get (Self, Block_Var, 0, True); 
--# expr-done 6619
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 6620
--# property-call-start BaseFormalParamHolder.call_argument_equation
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Call_Argument_Equation (Node => Spec.Node, Param => Fld_1, Arg => Left, Origin => Origin, E_Info => Spec.Info);
--# end
--# expr-done 6621
--# expr-start 6624 '<FieldAccess for call_argument_equation at ast.py:12567>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12567
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6623 '<FieldAccess for formal_decl at ast.py:12567>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12567
--# expr-start 6622 '<at at ast.py:12567>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:12567
Get_Result_1 := Get (Self, Block_Var, 1, True); 
--# expr-done 6622
      if Get_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_3 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result_1.Node, E_Info => Get_Result_1.Info);
--# end
--# expr-done 6623
--# property-call-start BaseFormalParamHolder.call_argument_equation
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Call_Argument_Equation (Node => Spec.Node, Param => Fld_3, Arg => Right, Origin => Origin, E_Info => Spec.Info);
--# end
--# expr-done 6624
And_Pred := Create_And (Fld_2, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12564") else null)); 
--# expr-done 6625
--# expr-start 6628 '<Bind at ast.py:12570>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12570
--# expr-start 6626 '<FieldAccess for type_var at ast.py:12570>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12570
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6626
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 6627 '<FieldAccess for return_type at ast.py:12570>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12570
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_6 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Spec.Node, Origin => Origin, E_Info => Spec.Info);
--# end
--# expr-done 6627
      Cast_Result := Create_Internal_Entity
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12570") else null)); 
--# expr-done 6628
And_Pred_1 := Create_And (And_Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12564") else null)); 
--# expr-done 6629
   If_Result := And_Pred_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12572") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 6630
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 6631
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_970;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_970;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Op_P_Arguments_Eq;
--# end
--# property-start ConcatOp.operator_no_subprogram_equation /tmp/lal-23.0.0/ada/ast.py:12576
pragma Warnings (Off, "is not referenced");
 function Concat_Op_P_Operator_No_Subprogram_Equation
  (Node : Bare_Concat_Op
      ; Left : Internal_Entity_Expr
      ; Op : Internal_Entity_Concat_Operand
      ; Right : Internal_Entity_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Concat_Op := Bare_Concat_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Concat_Op :=
     Internal_Entity_Concat_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind left Left
   --# bind op Op
   --# bind right Right
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_971 with Inline_Always;
      Fld : Logic_Var;
Pred : Logic_Equation;
Fld_1 : Logic_Var;
Pred_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_2 : Logic_Var;
Pred_2 : Logic_Equation;
Fld_3 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_4 : Logic_Var;
Node_For_Entity : Bare_Base_Type_Decl;
As_Entity : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_7 : Logic_Var;
Fld_8 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_9 : Logic_Var;
Fld_10 : Logic_Var;
Bind_Result_3 : Logic_Equation;
Fld_11 : Logic_Var;
Fld_12 : Logic_Var;
Fld_13 : Logic_Equation;
Or_Pred : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_14 : Logic_Var;
Fld_15 : Logic_Var;
Bind_Result_4 : Logic_Equation;
Fld_16 : Logic_Var;
Fld_17 : Logic_Var;
Fld_18 : Logic_Equation;
Or_Pred_1 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Or_Pred_2 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_971 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Pred_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Pred_2);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Or_Pred_1);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Or_Pred_2);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_971;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6670 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6669 '<And at ast.py:12584>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:12584
--# expr-start 6636 '<And at ast.py:12584>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12584
--# expr-start 6633 '<Predicate on BaseTypeDecl.is_array_def_with_deref_or_null at ast.py:12584>' Pred /tmp/lal-23.0.0/ada/ast.py:12584
--# expr-start 6632 '<FieldAccess for expected_type_var at ast.py:12585>' Fld /tmp/lal-23.0.0/ada/ast.py:12585
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6632
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
Pred := Solver.Create_Predicate (Fld, Create_Base_Type_Decl_P_Is_Array_Def_With_Deref_Or_Null_0_Predicate (Origin)); 
--# expr-done 6633
--# expr-start 6635 '<Predicate on BaseTypeDecl.is_array_def_with_deref at ast.py:12586>' Pred_1 /tmp/lal-23.0.0/ada/ast.py:12586
--# expr-start 6634 '<FieldAccess for type_var at ast.py:12586>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12586
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6634
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred_1 := Solver.Create_Predicate (Fld_1, Create_Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate (Origin)); 
--# expr-done 6635
And_Pred := Create_And (Pred, Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12584") else null)); 
--# expr-done 6636
--# expr-start 6668 '<Or at ast.py:12587>' Or_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12587
--# expr-start 6640 '<And at ast.py:12590>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12590
--# expr-start 6638 '<Predicate on AdaNode.is_not_null at ast.py:12590>' Pred_2 /tmp/lal-23.0.0/ada/ast.py:12590
--# expr-start 6637 '<FieldAccess for expected_type_var at ast.py:12590>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12590
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6637
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Pred_2 := Solver.Create_Predicate (Fld_2, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 6638
--# expr-start 6639 '<FieldAccess for array_concat_expected_type_equation at ast.py:12591>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12591
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ConcatOp.array_concat_expected_type_equation
Fld_3 := Libadalang.Implementation.Concat_Op_P_Array_Concat_Expected_Type_Equation (Node => Ent.Node, Left => Left, Op => Op, Right => Right, Origin => Origin);
--# end
--# expr-done 6639
And_Pred_1 := Create_And (Pred_2, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12590") else null)); 
--# expr-done 6640
--# expr-start 6667 '<And at ast.py:12597>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12597
--# expr-start 6659 '<And at ast.py:12597>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12597
--# expr-start 6651 '<And at ast.py:12597>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12597
--# expr-start 6647 '<And at ast.py:12597>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12597
--# expr-start 6643 '<Bind at ast.py:12597>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12597
--# expr-start 6641 '<FieldAccess for expected_type_var at ast.py:12597>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12597
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6641
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 6642 '<No BaseTypeDecl at ast.py:12597>' Node_For_Entity /tmp/lal-23.0.0/ada/ast.py:12597
Node_For_Entity := No_Bare_Ada_Node;
--# expr-done 6642
Is_Null := Node_For_Entity = null; 
if Is_Null then
   If_Result := No_Entity_Base_Type_Decl;
else
As_Entity := (Info => E_Info, Node => Node_For_Entity); 
   If_Result := As_Entity;
end if;
      Cast_Result := Create_Internal_Entity
        (Node => If_Result.Node,
         Info => If_Result.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12597") else null)); 
--# expr-done 6643
--# expr-start 6646 '<Bind at ast.py:12598>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12598
--# expr-start 6644 '<FieldAccess for type_var at ast.py:12598>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12598
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Left.Node);
--# expr-done 6644
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 6645 '<FieldAccess for expected_type_var at ast.py:12598>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12598
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6645
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
Bind_Result_1 := Solver.Create_Unify (Fld_5, Fld_6, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12598") else null)); 
--# expr-done 6646
And_Pred_2 := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12597") else null)); 
--# expr-done 6647
--# expr-start 6650 '<Bind at ast.py:12599>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12599
--# expr-start 6648 '<FieldAccess for type_var at ast.py:12599>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12599
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Right.Node);
--# expr-done 6648
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
--# expr-start 6649 '<FieldAccess for expected_type_var at ast.py:12599>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12599
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6649
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Bind_Result_2 := Solver.Create_Unify (Fld_7, Fld_8, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12599") else null)); 
--# expr-done 6650
And_Pred_3 := Create_And (And_Pred_2, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12597") else null)); 
--# expr-done 6651
--# expr-start 6658 '<Or at ast.py:12600>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12600
--# expr-start 6654 '<Bind at ast.py:12601>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:12601
--# expr-start 6652 '<FieldAccess for type_var at ast.py:12601>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12601
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Left.Node);
--# expr-done 6652
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 6653 '<FieldAccess for type_var at ast.py:12601>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12601
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6653
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Bind_Result_3 := Solver.Create_Unify (Fld_9, Fld_10, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12601") else null)); 
--# expr-done 6654
--# expr-start 6657 '<FieldAccess for comp_bind at ast.py:12602>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12602
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6655 '<FieldAccess for type_var at ast.py:12602>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12602
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6655
--# expr-start 6656 '<FieldAccess for type_var at ast.py:12602>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12602
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Left.Node);
--# expr-done 6656
--# property-call-start AdaNode.comp_bind
Fld_13 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_11, Right => Fld_12, Origin => Origin);
--# end
--# expr-done 6657
Or_Pred := Create_Or (Bind_Result_3, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12600") else null)); 
--# expr-done 6658
And_Pred_4 := Create_And (And_Pred_3, Or_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12597") else null)); 
--# expr-done 6659
--# expr-start 6666 '<Or at ast.py:12604>' Or_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12604
--# expr-start 6662 '<Bind at ast.py:12605>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:12605
--# expr-start 6660 '<FieldAccess for type_var at ast.py:12605>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:12605
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Right.Node);
--# expr-done 6660
Fld_14.Value := No_Entity;
Entity_Vars.Reset (Fld_14);
--# expr-start 6661 '<FieldAccess for type_var at ast.py:12605>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12605
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6661
Fld_15.Value := No_Entity;
Entity_Vars.Reset (Fld_15);
Bind_Result_4 := Solver.Create_Unify (Fld_14, Fld_15, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12605") else null)); 
--# expr-done 6662
--# expr-start 6665 '<FieldAccess for comp_bind at ast.py:12606>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12606
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6663 '<FieldAccess for type_var at ast.py:12606>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12606
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6663
--# expr-start 6664 '<FieldAccess for type_var at ast.py:12606>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12606
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Right.Node);
--# expr-done 6664
--# property-call-start AdaNode.comp_bind
Fld_18 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_16, Right => Fld_17, Origin => Origin);
--# end
--# expr-done 6665
Or_Pred_1 := Create_Or (Bind_Result_4, Fld_18, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12604") else null)); 
--# expr-done 6666
And_Pred_5 := Create_And (And_Pred_4, Or_Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12597") else null)); 
--# expr-done 6667
Or_Pred_2 := Create_Or (And_Pred_1, And_Pred_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12587") else null)); 
--# expr-done 6668
And_Pred_6 := Create_And (And_Pred, Or_Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12584") else null)); 
--# expr-done 6669
Let_Result := And_Pred_6; Inc_Ref (Let_Result);
--# end
--# expr-done 6670
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_971;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_971;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Op_P_Operator_No_Subprogram_Equation;
--# end
--# property-start ConcatOp.array_concat_expected_type_equation /tmp/lal-23.0.0/ada/ast.py:12612
pragma Warnings (Off, "is not referenced");
 function Concat_Op_P_Array_Concat_Expected_Type_Equation
  (Node : Bare_Concat_Op
      ; Left : Internal_Entity_Expr
      ; Op : Internal_Entity_Concat_Operand
      ; Right : Internal_Entity_Expr
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_Concat_Op := Bare_Concat_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind left Left
   --# bind op Op
   --# bind right Right
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_972 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : Boolean;
Fld : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
Fld_2 : Logic_Var;
Fld_3 : Logic_Var;
Fld_4 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Logic_Var;
Fld_7 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_8 : Logic_Var;
Fld_9 : Logic_Var;
Fld_10 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_11 : Logic_Var;
Fld_12 : Logic_Var;
Bind_Result_3 : Logic_Equation;
Fld_13 : Logic_Var;
Fld_14 : Logic_Var;
Fld_15 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_16 : Logic_Var;
Fld_17 : Logic_Var;
Fld_18 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_19 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_20 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_21 : Logic_Var;
Fld_22 : Logic_Var;
Bind_Result_4 : Logic_Equation;
Fld_23 : Logic_Var;
Fld_24 : Logic_Var;
Bind_Result_5 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Fld_25 : Logic_Var;
Fld_26 : Logic_Var;
Bind_Result_6 : Logic_Equation;
Fld_27 : Logic_Var;
Fld_28 : Logic_Var;
Fld_29 : Logic_Equation;
And_Pred_7 : Logic_Equation;
Fld_30 : Logic_Equation;
And_Pred_8 : Logic_Equation;
Or_Pred_1 : Logic_Equation;
Fld_31 : Logic_Var;
Fld_32 : Logic_Var;
Bind_Result_7 : Logic_Equation;
Fld_33 : Logic_Var;
Fld_34 : Logic_Var;
Fld_35 : Logic_Equation;
Or_Pred_2 : Logic_Equation;
And_Pred_9 : Logic_Equation;
Fld_36 : Logic_Equation;
And_Pred_10 : Logic_Equation;
Fld_37 : Logic_Var;
Fld_38 : Logic_Var;
Bind_Result_8 : Logic_Equation;
Fld_39 : Logic_Var;
Fld_40 : Logic_Var;
Bind_Result_9 : Logic_Equation;
And_Pred_11 : Logic_Equation;
Fld_41 : Logic_Var;
Fld_42 : Logic_Var;
Bind_Result_10 : Logic_Equation;
Fld_43 : Logic_Var;
Fld_44 : Logic_Var;
Fld_45 : Logic_Equation;
And_Pred_12 : Logic_Equation;
Fld_46 : Logic_Equation;
And_Pred_13 : Logic_Equation;
Or_Pred_3 : Logic_Equation;
Fld_47 : Logic_Var;
Fld_48 : Logic_Var;
Bind_Result_11 : Logic_Equation;
Fld_49 : Logic_Var;
Fld_50 : Logic_Var;
Fld_51 : Logic_Equation;
Or_Pred_4 : Logic_Equation;
And_Pred_14 : Logic_Equation;
Fld_52 : Logic_Equation;
And_Pred_15 : Logic_Equation;
Fld_53 : Logic_Var;
Fld_54 : Logic_Var;
Bind_Result_12 : Logic_Equation;
Fld_55 : Logic_Var;
Fld_56 : Logic_Var;
Bind_Result_13 : Logic_Equation;
Fld_57 : Logic_Var;
Fld_58 : Logic_Var;
Fld_59 : Logic_Equation;
Or_Pred_5 : Logic_Equation;
And_Pred_16 : Logic_Equation;
Fld_60 : Logic_Var;
Fld_61 : Logic_Var;
Bind_Result_14 : Logic_Equation;
Fld_62 : Logic_Var;
Fld_63 : Logic_Var;
Fld_64 : Logic_Equation;
Or_Pred_6 : Logic_Equation;
And_Pred_17 : Logic_Equation;
Fld_65 : Logic_Equation;
And_Pred_18 : Logic_Equation;
Fld_66 : Logic_Equation;
And_Pred_19 : Logic_Equation;
If_Result_1 : Logic_Equation;
If_Result_2 : Logic_Equation;
If_Result_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_972 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Fld_15);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_18);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_19);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_20);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Bind_Result_6);
                     Dec_Ref (Fld_29);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (Fld_30);
                     Dec_Ref (And_Pred_8);
                     Dec_Ref (Or_Pred_1);
                     Dec_Ref (Bind_Result_7);
                     Dec_Ref (Fld_35);
                     Dec_Ref (Or_Pred_2);
                     Dec_Ref (And_Pred_9);
                     Dec_Ref (Fld_36);
                     Dec_Ref (And_Pred_10);
                     Dec_Ref (Bind_Result_8);
                     Dec_Ref (Bind_Result_9);
                     Dec_Ref (And_Pred_11);
                     Dec_Ref (Bind_Result_10);
                     Dec_Ref (Fld_45);
                     Dec_Ref (And_Pred_12);
                     Dec_Ref (Fld_46);
                     Dec_Ref (And_Pred_13);
                     Dec_Ref (Or_Pred_3);
                     Dec_Ref (Bind_Result_11);
                     Dec_Ref (Fld_51);
                     Dec_Ref (Or_Pred_4);
                     Dec_Ref (And_Pred_14);
                     Dec_Ref (Fld_52);
                     Dec_Ref (And_Pred_15);
                     Dec_Ref (Bind_Result_12);
                     Dec_Ref (Bind_Result_13);
                     Dec_Ref (Fld_59);
                     Dec_Ref (Or_Pred_5);
                     Dec_Ref (And_Pred_16);
                     Dec_Ref (Bind_Result_14);
                     Dec_Ref (Fld_64);
                     Dec_Ref (Or_Pred_6);
                     Dec_Ref (And_Pred_17);
                     Dec_Ref (Fld_65);
                     Dec_Ref (And_Pred_18);
                     Dec_Ref (Fld_66);
                     Dec_Ref (And_Pred_19);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_972;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6781 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6671 '<FieldAccess for has_context_free_type at ast.py:12621>' Fld /tmp/lal-23.0.0/ada/ast.py:12621
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Left.Node);
--# end
--# expr-done 6671
Block_Var := Fld; 
--# bind left_ctx_free Block_Var
--# expr-start 6672 '<FieldAccess for has_context_free_type at ast.py:12622>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12622
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Right.Node);
--# end
--# expr-done 6672
Block_Var_1 := Fld_1; 
--# bind right_ctx_free Block_Var_1
--# expr-start 6780 '<Cond at ast.py:12627>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:12627
if Block_Var then
   If_Result := Block_Var_1;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 6702 '<Or at ast.py:12629>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12629
--# expr-start 6686 '<And at ast.py:12636>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12636
--# expr-start 6681 '<And at ast.py:12636>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12636
--# expr-start 6676 '<NPropagate at ast.py:12636>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12636
--# expr-start 6673 '<FieldAccess for type_var at ast.py:12636>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12636
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6673
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 6674 '<FieldAccess for type_var at ast.py:12638>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12638
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Left.Node);
--# expr-done 6674
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 6675 '<FieldAccess for type_var at ast.py:12638>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12638
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Right.Node);
--# expr-done 6675
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Bind_Result := Solver.Create_N_Propagate (Fld_2, Logic_Functor_633'(N => 2, Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), (1 => Fld_3, 2 => Fld_4), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12636") else null)); 
--# expr-done 6676
--# expr-start 6680 '<NPropagate at ast.py:12639>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12639
--# expr-start 6677 '<FieldAccess for expected_type_var at ast.py:12639>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12639
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6677
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 6678 '<FieldAccess for type_var at ast.py:12641>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12641
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6678
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 6679 '<FieldAccess for type_var at ast.py:12641>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12641
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Left.Node);
--# expr-done 6679
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result_1 := Solver.Create_N_Propagate (Fld_5, Logic_Functor_634'(N => 2, Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), (1 => Fld_6, 2 => Fld_7), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12639") else null)); 
--# expr-done 6680
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12636") else null)); 
--# expr-done 6681
--# expr-start 6685 '<NPropagate at ast.py:12642>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12642
--# expr-start 6682 '<FieldAccess for expected_type_var at ast.py:12642>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12642
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6682
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
--# expr-start 6683 '<FieldAccess for type_var at ast.py:12644>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12644
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6683
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 6684 '<FieldAccess for type_var at ast.py:12644>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12644
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Right.Node);
--# expr-done 6684
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Bind_Result_2 := Solver.Create_N_Propagate (Fld_8, Logic_Functor_634'(N => 2, Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), (1 => Fld_9, 2 => Fld_10), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12642") else null)); 
--# expr-done 6685
And_Pred_1 := Create_And (And_Pred, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12636") else null)); 
--# expr-done 6686
--# expr-start 6701 '<And at ast.py:12650>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12650
--# expr-start 6699 '<And at ast.py:12650>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12650
--# expr-start 6697 '<And at ast.py:12650>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12650
--# expr-start 6693 '<And at ast.py:12650>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12650
--# expr-start 6689 '<Bind at ast.py:12650>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:12650
--# expr-start 6687 '<FieldAccess for expected_type_var at ast.py:12650>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12650
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6687
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
--# expr-start 6688 '<FieldAccess for type_var at ast.py:12650>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12650
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6688
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
Bind_Result_3 := Solver.Create_Propagate (Fld_11, Fld_12, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12650") else null)); 
--# expr-done 6689
--# expr-start 6692 '<FieldAccess for comp_bind at ast.py:12652>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12652
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6690 '<FieldAccess for type_var at ast.py:12652>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12652
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6690
--# expr-start 6691 '<FieldAccess for expected_type_var at ast.py:12652>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:12652
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6691
--# property-call-start AdaNode.comp_bind
Fld_15 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_13, Right => Fld_14, Origin => Origin);
--# end
--# expr-done 6692
And_Pred_2 := Create_And (Bind_Result_3, Fld_15, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12650") else null)); 
--# expr-done 6693
--# expr-start 6696 '<FieldAccess for comp_bind at ast.py:12653>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12653
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6694 '<FieldAccess for type_var at ast.py:12653>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12653
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6694
--# expr-start 6695 '<FieldAccess for expected_type_var at ast.py:12653>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12653
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6695
--# property-call-start AdaNode.comp_bind
Fld_18 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_16, Right => Fld_17, Origin => Origin);
--# end
--# expr-done 6696
And_Pred_3 := Create_And (And_Pred_2, Fld_18, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12650") else null)); 
--# expr-done 6697
--# expr-start 6698 '<FieldAccess for matches_expected_formal_type at ast.py:12654>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:12654
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_19 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Left.Node, Origin => Origin);
--# end
--# expr-done 6698
And_Pred_4 := Create_And (And_Pred_3, Fld_19, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12650") else null)); 
--# expr-done 6699
--# expr-start 6700 '<FieldAccess for matches_expected_formal_type at ast.py:12655>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:12655
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_20 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Right.Node, Origin => Origin);
--# end
--# expr-done 6700
And_Pred_5 := Create_And (And_Pred_4, Fld_20, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12650") else null)); 
--# expr-done 6701
Or_Pred := Create_Or (And_Pred_1, And_Pred_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12629") else null)); 
--# expr-done 6702
   If_Result_3 := Or_Pred;
else
if Block_Var then
   --# expr-start 6729 '<And at ast.py:12659>' And_Pred_10 /tmp/lal-23.0.0/ada/ast.py:12659
--# expr-start 6727 '<And at ast.py:12659>' And_Pred_9 /tmp/lal-23.0.0/ada/ast.py:12659
--# expr-start 6719 '<Or at ast.py:12659>' Or_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12659
--# expr-start 6709 '<And at ast.py:12663>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:12663
--# expr-start 6705 '<Bind at ast.py:12663>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:12663
--# expr-start 6703 '<FieldAccess for type_var at ast.py:12663>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:12663
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Left.Node);
--# expr-done 6703
Fld_21.Value := No_Entity;
Entity_Vars.Reset (Fld_21);
--# expr-start 6704 '<FieldAccess for type_var at ast.py:12663>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:12663
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6704
Fld_22.Value := No_Entity;
Entity_Vars.Reset (Fld_22);
Bind_Result_4 := Solver.Create_Propagate (Fld_21, Fld_22, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12663") else null)); 
--# expr-done 6705
--# expr-start 6708 '<Bind at ast.py:12665>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:12665
--# expr-start 6706 '<FieldAccess for type_var at ast.py:12665>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:12665
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6706
Fld_23.Value := No_Entity;
Entity_Vars.Reset (Fld_23);
--# expr-start 6707 '<FieldAccess for expected_type_var at ast.py:12665>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:12665
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6707
Fld_24.Value := No_Entity;
Entity_Vars.Reset (Fld_24);
Bind_Result_5 := Solver.Create_Unify (Fld_23, Fld_24, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12665") else null)); 
--# expr-done 6708
And_Pred_6 := Create_And (Bind_Result_4, Bind_Result_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12663") else null)); 
--# expr-done 6709
--# expr-start 6718 '<And at ast.py:12671>' And_Pred_8 /tmp/lal-23.0.0/ada/ast.py:12671
--# expr-start 6716 '<And at ast.py:12671>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:12671
--# expr-start 6712 '<Bind at ast.py:12671>' Bind_Result_6 /tmp/lal-23.0.0/ada/ast.py:12671
--# expr-start 6710 '<FieldAccess for expected_type_var at ast.py:12671>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:12671
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6710
Fld_25.Value := No_Entity;
Entity_Vars.Reset (Fld_25);
--# expr-start 6711 '<FieldAccess for type_var at ast.py:12671>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:12671
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6711
Fld_26.Value := No_Entity;
Entity_Vars.Reset (Fld_26);
Bind_Result_6 := Solver.Create_Propagate (Fld_25, Fld_26, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12671") else null)); 
--# expr-done 6712
--# expr-start 6715 '<FieldAccess for comp_bind at ast.py:12673>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:12673
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6713 '<FieldAccess for type_var at ast.py:12673>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:12673
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6713
--# expr-start 6714 '<FieldAccess for expected_type_var at ast.py:12673>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:12673
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6714
--# property-call-start AdaNode.comp_bind
Fld_29 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_27, Right => Fld_28, Origin => Origin);
--# end
--# expr-done 6715
And_Pred_7 := Create_And (Bind_Result_6, Fld_29, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12671") else null)); 
--# expr-done 6716
--# expr-start 6717 '<FieldAccess for matches_expected_formal_type at ast.py:12674>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:12674
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_30 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Left.Node, Origin => Origin);
--# end
--# expr-done 6717
And_Pred_8 := Create_And (And_Pred_7, Fld_30, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12671") else null)); 
--# expr-done 6718
Or_Pred_1 := Create_Or (And_Pred_6, And_Pred_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12659") else null)); 
--# expr-done 6719
--# expr-start 6726 '<Or at ast.py:12678>' Or_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12678
--# expr-start 6722 '<Bind at ast.py:12679>' Bind_Result_7 /tmp/lal-23.0.0/ada/ast.py:12679
--# expr-start 6720 '<FieldAccess for type_var at ast.py:12679>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:12679
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6720
Fld_31.Value := No_Entity;
Entity_Vars.Reset (Fld_31);
--# expr-start 6721 '<FieldAccess for expected_type_var at ast.py:12679>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:12679
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_32 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6721
Fld_32.Value := No_Entity;
Entity_Vars.Reset (Fld_32);
Bind_Result_7 := Solver.Create_Unify (Fld_31, Fld_32, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12679") else null)); 
--# expr-done 6722
--# expr-start 6725 '<FieldAccess for comp_bind at ast.py:12680>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:12680
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6723 '<FieldAccess for type_var at ast.py:12680>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:12680
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_33 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6723
--# expr-start 6724 '<FieldAccess for expected_type_var at ast.py:12680>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:12680
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_34 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6724
--# property-call-start AdaNode.comp_bind
Fld_35 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_33, Right => Fld_34, Origin => Origin);
--# end
--# expr-done 6725
Or_Pred_2 := Create_Or (Bind_Result_7, Fld_35, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12678") else null)); 
--# expr-done 6726
And_Pred_9 := Create_And (Or_Pred_1, Or_Pred_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12659") else null)); 
--# expr-done 6727
--# expr-start 6728 '<FieldAccess for matches_expected_formal_type at ast.py:12682>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:12682
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_36 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Right.Node, Origin => Origin);
--# end
--# expr-done 6728
And_Pred_10 := Create_And (And_Pred_9, Fld_36, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12659") else null)); 
--# expr-done 6729
   If_Result_2 := And_Pred_10;
else
if Block_Var_1 then
   --# expr-start 6756 '<And at ast.py:12685>' And_Pred_15 /tmp/lal-23.0.0/ada/ast.py:12685
--# expr-start 6754 '<And at ast.py:12685>' And_Pred_14 /tmp/lal-23.0.0/ada/ast.py:12685
--# expr-start 6746 '<Or at ast.py:12685>' Or_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12685
--# expr-start 6736 '<And at ast.py:12689>' And_Pred_11 /tmp/lal-23.0.0/ada/ast.py:12689
--# expr-start 6732 '<Bind at ast.py:12689>' Bind_Result_8 /tmp/lal-23.0.0/ada/ast.py:12689
--# expr-start 6730 '<FieldAccess for type_var at ast.py:12689>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:12689
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_37 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Right.Node);
--# expr-done 6730
Fld_37.Value := No_Entity;
Entity_Vars.Reset (Fld_37);
--# expr-start 6731 '<FieldAccess for type_var at ast.py:12689>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:12689
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_38 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6731
Fld_38.Value := No_Entity;
Entity_Vars.Reset (Fld_38);
Bind_Result_8 := Solver.Create_Propagate (Fld_37, Fld_38, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12689") else null)); 
--# expr-done 6732
--# expr-start 6735 '<Bind at ast.py:12691>' Bind_Result_9 /tmp/lal-23.0.0/ada/ast.py:12691
--# expr-start 6733 '<FieldAccess for type_var at ast.py:12691>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:12691
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_39 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6733
Fld_39.Value := No_Entity;
Entity_Vars.Reset (Fld_39);
--# expr-start 6734 '<FieldAccess for expected_type_var at ast.py:12691>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:12691
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_40 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6734
Fld_40.Value := No_Entity;
Entity_Vars.Reset (Fld_40);
Bind_Result_9 := Solver.Create_Unify (Fld_39, Fld_40, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12691") else null)); 
--# expr-done 6735
And_Pred_11 := Create_And (Bind_Result_8, Bind_Result_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12689") else null)); 
--# expr-done 6736
--# expr-start 6745 '<And at ast.py:12697>' And_Pred_13 /tmp/lal-23.0.0/ada/ast.py:12697
--# expr-start 6743 '<And at ast.py:12697>' And_Pred_12 /tmp/lal-23.0.0/ada/ast.py:12697
--# expr-start 6739 '<Bind at ast.py:12697>' Bind_Result_10 /tmp/lal-23.0.0/ada/ast.py:12697
--# expr-start 6737 '<FieldAccess for expected_type_var at ast.py:12697>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:12697
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_41 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6737
Fld_41.Value := No_Entity;
Entity_Vars.Reset (Fld_41);
--# expr-start 6738 '<FieldAccess for type_var at ast.py:12697>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:12697
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_42 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6738
Fld_42.Value := No_Entity;
Entity_Vars.Reset (Fld_42);
Bind_Result_10 := Solver.Create_Propagate (Fld_41, Fld_42, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12697") else null)); 
--# expr-done 6739
--# expr-start 6742 '<FieldAccess for comp_bind at ast.py:12699>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:12699
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6740 '<FieldAccess for type_var at ast.py:12699>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:12699
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_43 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6740
--# expr-start 6741 '<FieldAccess for expected_type_var at ast.py:12699>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:12699
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_44 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6741
--# property-call-start AdaNode.comp_bind
Fld_45 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_43, Right => Fld_44, Origin => Origin);
--# end
--# expr-done 6742
And_Pred_12 := Create_And (Bind_Result_10, Fld_45, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12697") else null)); 
--# expr-done 6743
--# expr-start 6744 '<FieldAccess for matches_expected_formal_type at ast.py:12700>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:12700
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_46 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Right.Node, Origin => Origin);
--# end
--# expr-done 6744
And_Pred_13 := Create_And (And_Pred_12, Fld_46, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12697") else null)); 
--# expr-done 6745
Or_Pred_3 := Create_Or (And_Pred_11, And_Pred_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12685") else null)); 
--# expr-done 6746
--# expr-start 6753 '<Or at ast.py:12704>' Or_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12704
--# expr-start 6749 '<Bind at ast.py:12705>' Bind_Result_11 /tmp/lal-23.0.0/ada/ast.py:12705
--# expr-start 6747 '<FieldAccess for type_var at ast.py:12705>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:12705
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_47 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6747
Fld_47.Value := No_Entity;
Entity_Vars.Reset (Fld_47);
--# expr-start 6748 '<FieldAccess for expected_type_var at ast.py:12705>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:12705
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_48 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6748
Fld_48.Value := No_Entity;
Entity_Vars.Reset (Fld_48);
Bind_Result_11 := Solver.Create_Unify (Fld_47, Fld_48, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12705") else null)); 
--# expr-done 6749
--# expr-start 6752 '<FieldAccess for comp_bind at ast.py:12706>' Fld_51 /tmp/lal-23.0.0/ada/ast.py:12706
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6750 '<FieldAccess for type_var at ast.py:12706>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:12706
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_49 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6750
--# expr-start 6751 '<FieldAccess for expected_type_var at ast.py:12706>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:12706
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_50 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6751
--# property-call-start AdaNode.comp_bind
Fld_51 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_49, Right => Fld_50, Origin => Origin);
--# end
--# expr-done 6752
Or_Pred_4 := Create_Or (Bind_Result_11, Fld_51, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12704") else null)); 
--# expr-done 6753
And_Pred_14 := Create_And (Or_Pred_3, Or_Pred_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12685") else null)); 
--# expr-done 6754
--# expr-start 6755 '<FieldAccess for matches_expected_formal_type at ast.py:12708>' Fld_52 /tmp/lal-23.0.0/ada/ast.py:12708
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_52 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Left.Node, Origin => Origin);
--# end
--# expr-done 6755
And_Pred_15 := Create_And (And_Pred_14, Fld_52, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12685") else null)); 
--# expr-done 6756
   If_Result_1 := And_Pred_15;
else
   --# expr-start 6779 '<And at ast.py:12713>' And_Pred_19 /tmp/lal-23.0.0/ada/ast.py:12713
--# expr-start 6777 '<And at ast.py:12713>' And_Pred_18 /tmp/lal-23.0.0/ada/ast.py:12713
--# expr-start 6775 '<And at ast.py:12713>' And_Pred_17 /tmp/lal-23.0.0/ada/ast.py:12713
--# expr-start 6767 '<And at ast.py:12713>' And_Pred_16 /tmp/lal-23.0.0/ada/ast.py:12713
--# expr-start 6759 '<Bind at ast.py:12713>' Bind_Result_12 /tmp/lal-23.0.0/ada/ast.py:12713
--# expr-start 6757 '<FieldAccess for expected_type_var at ast.py:12713>' Fld_53 /tmp/lal-23.0.0/ada/ast.py:12713
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_53 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Op.Node);
--# expr-done 6757
Fld_53.Value := No_Entity;
Entity_Vars.Reset (Fld_53);
--# expr-start 6758 '<FieldAccess for type_var at ast.py:12713>' Fld_54 /tmp/lal-23.0.0/ada/ast.py:12713
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_54 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6758
Fld_54.Value := No_Entity;
Entity_Vars.Reset (Fld_54);
Bind_Result_12 := Solver.Create_Propagate (Fld_53, Fld_54, Logic_Functor_630'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12713") else null)); 
--# expr-done 6759
--# expr-start 6766 '<Or at ast.py:12715>' Or_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12715
--# expr-start 6762 '<Bind at ast.py:12716>' Bind_Result_13 /tmp/lal-23.0.0/ada/ast.py:12716
--# expr-start 6760 '<FieldAccess for type_var at ast.py:12716>' Fld_55 /tmp/lal-23.0.0/ada/ast.py:12716
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_55 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6760
Fld_55.Value := No_Entity;
Entity_Vars.Reset (Fld_55);
--# expr-start 6761 '<FieldAccess for expected_type_var at ast.py:12716>' Fld_56 /tmp/lal-23.0.0/ada/ast.py:12716
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_56 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6761
Fld_56.Value := No_Entity;
Entity_Vars.Reset (Fld_56);
Bind_Result_13 := Solver.Create_Unify (Fld_55, Fld_56, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12716") else null)); 
--# expr-done 6762
--# expr-start 6765 '<FieldAccess for comp_bind at ast.py:12717>' Fld_59 /tmp/lal-23.0.0/ada/ast.py:12717
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6763 '<FieldAccess for type_var at ast.py:12717>' Fld_57 /tmp/lal-23.0.0/ada/ast.py:12717
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_57 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6763
--# expr-start 6764 '<FieldAccess for expected_type_var at ast.py:12717>' Fld_58 /tmp/lal-23.0.0/ada/ast.py:12717
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_58 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Left.Node);
--# expr-done 6764
--# property-call-start AdaNode.comp_bind
Fld_59 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_57, Right => Fld_58, Origin => Origin);
--# end
--# expr-done 6765
Or_Pred_5 := Create_Or (Bind_Result_13, Fld_59, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12715") else null)); 
--# expr-done 6766
And_Pred_16 := Create_And (Bind_Result_12, Or_Pred_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12713") else null)); 
--# expr-done 6767
--# expr-start 6774 '<Or at ast.py:12719>' Or_Pred_6 /tmp/lal-23.0.0/ada/ast.py:12719
--# expr-start 6770 '<Bind at ast.py:12720>' Bind_Result_14 /tmp/lal-23.0.0/ada/ast.py:12720
--# expr-start 6768 '<FieldAccess for type_var at ast.py:12720>' Fld_60 /tmp/lal-23.0.0/ada/ast.py:12720
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_60 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6768
Fld_60.Value := No_Entity;
Entity_Vars.Reset (Fld_60);
--# expr-start 6769 '<FieldAccess for expected_type_var at ast.py:12720>' Fld_61 /tmp/lal-23.0.0/ada/ast.py:12720
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_61 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6769
Fld_61.Value := No_Entity;
Entity_Vars.Reset (Fld_61);
Bind_Result_14 := Solver.Create_Unify (Fld_60, Fld_61, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12720") else null)); 
--# expr-done 6770
--# expr-start 6773 '<FieldAccess for comp_bind at ast.py:12721>' Fld_64 /tmp/lal-23.0.0/ada/ast.py:12721
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6771 '<FieldAccess for type_var at ast.py:12721>' Fld_62 /tmp/lal-23.0.0/ada/ast.py:12721
      if Op.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_62 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Op.Node);
--# expr-done 6771
--# expr-start 6772 '<FieldAccess for expected_type_var at ast.py:12721>' Fld_63 /tmp/lal-23.0.0/ada/ast.py:12721
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_63 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Right.Node);
--# expr-done 6772
--# property-call-start AdaNode.comp_bind
Fld_64 := Libadalang.Implementation.Ada_Node_P_Comp_Bind (Node => Self, Left => Fld_62, Right => Fld_63, Origin => Origin);
--# end
--# expr-done 6773
Or_Pred_6 := Create_Or (Bind_Result_14, Fld_64, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12719") else null)); 
--# expr-done 6774
And_Pred_17 := Create_And (And_Pred_16, Or_Pred_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12713") else null)); 
--# expr-done 6775
--# expr-start 6776 '<FieldAccess for matches_expected_formal_type at ast.py:12723>' Fld_65 /tmp/lal-23.0.0/ada/ast.py:12723
      if Left.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_65 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Left.Node, Origin => Origin);
--# end
--# expr-done 6776
And_Pred_18 := Create_And (And_Pred_17, Fld_65, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12713") else null)); 
--# expr-done 6777
--# expr-start 6778 '<FieldAccess for matches_expected_formal_type at ast.py:12724>' Fld_66 /tmp/lal-23.0.0/ada/ast.py:12724
      if Right.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_66 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Right.Node, Origin => Origin);
--# end
--# expr-done 6778
And_Pred_19 := Create_And (And_Pred_18, Fld_66, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12713") else null)); 
--# expr-done 6779
   If_Result_1 := And_Pred_19;
end if;
      Inc_Ref (If_Result_1);
   If_Result_2 := If_Result_1;
end if;
      Inc_Ref (If_Result_2);
   If_Result_3 := If_Result_2;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 6780
Let_Result := If_Result_3; Inc_Ref (Let_Result);
--# end
--# expr-done 6781
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_972;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_972;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Op_P_Array_Concat_Expected_Type_Equation;
--# end
   --
   --  Primitives for Bare_Concat_Operand
   --
      procedure Initialize_Fields_For_Concat_Operand
        (Self : Bare_Concat_Operand
         ; Concat_Operand_F_Operator : Bare_Op_Concat
         ; Concat_Operand_F_Operand : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Concat_Operand_F_Operator := Concat_Operand_F_Operator;
            Self.Concat_Operand_F_Operand := Concat_Operand_F_Operand;
      end Initialize_Fields_For_Concat_Operand;
   function Concat_Operand_F_Operator
     (Node : Bare_Concat_Operand) return Bare_Op_Concat
   is
   begin
         return Node.Concat_Operand_F_Operator;
   end;
   function Concat_Operand_F_Operand
     (Node : Bare_Concat_Operand) return Bare_Expr
   is
   begin
         return Node.Concat_Operand_F_Operand;
   end;
--# property-start ConcatOperand.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12739
pragma Warnings (Off, "is not referenced");
 function Concat_Operand_P_Has_Context_Free_Type
  (Node : Bare_Concat_Operand
  )
   return Boolean
is
   Self : Bare_Concat_Operand := Bare_Concat_Operand (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6782 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 6782
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Concat_Operand_P_Has_Context_Free_Type;
--# end
   --
   --  Primitives for Bare_Cond_Expr
   --
      procedure Initialize_Fields_For_Cond_Expr
        (Self : Bare_Cond_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
      end Initialize_Fields_For_Cond_Expr;
--# property-start '[dispatcher]CondExpr.dependent_exprs' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Cond_Expr_P_Dependent_Exprs
  (Node : Bare_Cond_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr_Array_Access
is
   Self : Bare_Cond_Expr := Bare_Cond_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Expr_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Cond_Expr (Self.Kind) is
               when Ada_Case_Expr =>
                  --# property-call-start CaseExpr.dependent_exprs
                  Property_Result := Case_Expr_P_Dependent_Exprs
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_If_Expr =>
                  --# property-call-start IfExpr.dependent_exprs
                  Property_Result := If_Expr_P_Dependent_Exprs
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Cond_Expr_P_Dependent_Exprs;
--# end
   --
   --  Primitives for Bare_Case_Expr
   --
      procedure Initialize_Fields_For_Case_Expr
        (Self : Bare_Case_Expr
         ; Case_Expr_F_Expr : Bare_Expr
         ; Case_Expr_F_Cases : Bare_Case_Expr_Alternative_List
        ) is
      begin
            Initialize_Fields_For_Cond_Expr
              (Self);
            Self.Case_Expr_F_Expr := Case_Expr_F_Expr;
            Self.Case_Expr_F_Cases := Case_Expr_F_Cases;
      end Initialize_Fields_For_Case_Expr;
   function Case_Expr_F_Expr
     (Node : Bare_Case_Expr) return Bare_Expr
   is
   begin
         return Node.Case_Expr_F_Expr;
   end;
   function Case_Expr_F_Cases
     (Node : Bare_Case_Expr) return Bare_Case_Expr_Alternative_List
   is
   begin
         return Node.Case_Expr_F_Cases;
   end;
--# property-start CaseExpr.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:15498
pragma Warnings (Off, "is not referenced");
 function Case_Expr_P_Has_Context_Free_Type
  (Node : Bare_Case_Expr
  )
   return Boolean
is
   Self : Bare_Case_Expr := Bare_Case_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Case_Expr_P_Has_Context_Free_Type;
--# end
--# property-start CaseExpr.dependent_exprs /tmp/lal-23.0.0/ada/ast.py:15501
pragma Warnings (Off, "is not referenced");
 function Case_Expr_P_Dependent_Exprs
  (Node : Bare_Case_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr_Array_Access
is
   Self : Bare_Case_Expr := Bare_Case_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Case_Expr :=
     Internal_Entity_Case_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr_Array_Access;
            procedure Finalizer_Scope_1116 with Inline_Always;
      Fld : Internal_Entity_Case_Expr_Alternative_List;
Fld_1 : Bare_Case_Expr_Alternative_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Case_Expr_Alternative;
Is_Null : Boolean;
If_Result : Internal_Entity_Case_Expr_Alternative;
Fld_3 : Internal_Entity_Expr;
Item_229 : Internal_Entity_Case_Expr_Alternative;
Bare_Item_229 : Bare_Case_Expr_Alternative;
Map_Result : Internal_Entity_Expr_Array_Access;
Let_Result : Internal_Entity_Expr_Array_Access;
            procedure Finalizer_Scope_1116 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1116;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6786 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6785 '<Map at ast.py:15502>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15502
   --# expr-start 6783 '<FieldAccess for cases at ast.py:15502>' Fld /tmp/lal-23.0.0/ada/ast.py:15502
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Case_Expr_Alternative_List (Node => Ent.Node.Case_Expr_F_Cases, Info => Ent.Info);
--# expr-done 6783
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Expr_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Expr_Array (0);
      else
      declare
         Collection : constant Bare_Case_Expr_Alternative_List := Fld_1;
      begin
         for Untyped_Item_229 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_229 := Untyped_Item_229; 
Is_Null := Bare_Item_229 = null; 
if Is_Null then
   If_Result := No_Entity_Case_Expr_Alternative;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_229); 
   If_Result := As_Entity;
end if;
                  Item_229 := If_Result; 
   --# scope-start
               --# bind c Item_229
      --# expr-start 6784 '<FieldAccess for expr at ast.py:15502>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15502
      if Item_229.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Item_229.Node.Case_Expr_Alternative_F_Expr, Info => Item_229.Info);
--# expr-done 6784
         declare
            Item_To_Append : constant Internal_Entity_Expr := Fld_3;
         begin
            Internal_Entity_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Expr_Array
           (Items_Count => Natural (Internal_Entity_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6785
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 6786
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1116;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1116;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Case_Expr_P_Dependent_Exprs;
--# end
--# property-start CaseExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:15505
pragma Warnings (Off, "is not referenced");
 function Case_Expr_P_Xref_Equation
  (Node : Bare_Case_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Case_Expr := Bare_Case_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Case_Expr :=
     Internal_Entity_Case_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1117 with Inline_Always;
            procedure Finalizer_Scope_2714 with Inline_Always;
            procedure Finalizer_Scope_2715 with Inline_Always;
            procedure Finalizer_Scope_2716 with Inline_Always;
            procedure Finalizer_Scope_2718 with Inline_Always;
            procedure Finalizer_Scope_2719 with Inline_Always;
      Block_Var : Boolean;
Match_0 : Internal_Entity_Expr;
Match_1 : Internal_Entity_Subtype_Indication;
Match_2 : Internal_Entity_Others_Designator;
Match_3 : Internal_Entity;
Var_Expr : Internal_Entity_Name;
Fld : Internal_Entity_Expr;
Fld_1 : Bare_Expr;
Fld_2 : Logic_Var;
Pred : Logic_Equation;
Fld_3 : Boolean;
Fld_4 : Logic_Var;
Fld_5 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_6 : Internal_Entity_Case_Expr_Alternative_List;
Fld_7 : Bare_Case_Expr_Alternative_List;
Fld_8 : Internal_Entity_Info;
As_Entity : Internal_Entity_Case_Expr_Alternative;
Is_Null : Boolean;
If_Result : Internal_Entity_Case_Expr_Alternative;
Fld_9 : Internal_Entity_Alternatives_List;
Fld_10 : Bare_Alternatives_List;
Fld_11 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_12 : Logic_Equation;
Fld_13 : Logic_Var;
Fld_14 : Bare_Expr;
Fld_15 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_16 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_17 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Cast_Expr_1 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_18 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Is_Null_2 : Boolean;
Not_Val : Boolean;
If_Result_2 : Logic_Equation;
Fld_19 : Logic_Equation;
True_Rel : Logic_Equation;
Match_Prefix : Internal_Entity;
Cast_Result_2 : Internal_Entity_Expr;
Let_Result : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_3 : Internal_Entity_Subtype_Indication;
Let_Result_1 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_4 : Internal_Entity_Others_Designator;
Let_Result_2 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Cast_Result_5 : Internal_Entity;
Let_Result_3 : Logic_Equation;
Scope_Result_4 : Logic_Equation;
Match_Result : Logic_Equation;
Item_231 : Internal_Entity;
Bare_Item_231 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_20 : Logic_Var;
Fld_21 : Internal_Entity_Expr;
Fld_22 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_23 : Internal_Entity_Expr;
Fld_24 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_25 : Internal_Entity_Expr;
Fld_26 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Item_230 : Internal_Entity_Case_Expr_Alternative;
Bare_Item_230 : Bare_Case_Expr_Alternative;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Let_Result_4 : Logic_Equation;
            procedure Finalizer_Scope_1117 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1117;
            procedure Finalizer_Scope_2714 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_24);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_26);
                     Dec_Ref (And_Pred_4);
            end Finalizer_Scope_2714;
            procedure Finalizer_Scope_2715 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_2715;
            procedure Finalizer_Scope_2716 is
            begin
                     Dec_Ref (Fld_12);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_16);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_17);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result_2);
            end Finalizer_Scope_2716;
            procedure Finalizer_Scope_2718 is
            begin
                     Dec_Ref (Fld_19);
            end Finalizer_Scope_2718;
            procedure Finalizer_Scope_2719 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_2719;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6830 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 6791 '<FieldAccess for resolve_names_internal_with_eq at ast.py:15508>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15508
--# expr-start 6787 '<FieldAccess for expr at ast.py:15508>' Fld /tmp/lal-23.0.0/ada/ast.py:15508
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Case_Expr_F_Expr, Info => Ent.Info);
--# expr-done 6787
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 6790 '<Predicate on BaseTypeDecl.is_discrete_type at ast.py:15509>' Pred /tmp/lal-23.0.0/ada/ast.py:15509
--# expr-start 6789 '<FieldAccess for type_var at ast.py:15509>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15509
--# expr-start 6788 '<FieldAccess for expr at ast.py:15509>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15509
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Case_Expr_F_Expr;
--# expr-done 6788
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_1);
--# expr-done 6789
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Pred := Solver.Create_Predicate (Fld_2, Create_Base_Type_Decl_P_Is_Discrete_Type_0_Predicate (Origin)); 
--# expr-done 6790
--# property-call-start AdaNode.resolve_names_internal_with_eq
Fld_3 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal_With_Eq (Node => Fld.Node, Additional_Equation => Pred, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 6791
Block_Var := Fld_3; 
--# expr-start 6829 '<And at ast.py:15512>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:15512
--# expr-start 6794 '<Bind at ast.py:15513>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15513
--# expr-start 6792 '<FieldAccess for type_var at ast.py:15513>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15513
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6792
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 6793 '<FieldAccess for expected_type_var at ast.py:15513>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15513
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6793
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result := Solver.Create_Unify (Fld_4, Fld_5, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15513") else null)); 
--# expr-done 6794
--# expr-start 6828 '<LogicAll at ast.py:15514>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:15514
--# expr-start 6827 '<Map at ast.py:15514>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:15514
   --# expr-start 6795 '<FieldAccess for cases at ast.py:15514>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15514
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Case_Expr_Alternative_List (Node => Ent.Node.Case_Expr_F_Cases, Info => Ent.Info);
--# expr-done 6795
Fld_7 := Fld_6.Node;
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_7 = null then
      Map_Result_1 := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Case_Expr_Alternative_List := Fld_7;
      begin
         for Untyped_Item_230 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_230 := Untyped_Item_230; 
Is_Null := Bare_Item_230 = null; 
if Is_Null then
   If_Result := No_Entity_Case_Expr_Alternative;
else
Fld_8 := Fld_6.Info;
As_Entity := (Info => Fld_8, Node => Bare_Item_230); 
   If_Result := As_Entity;
end if;
                  Item_230 := If_Result; 
   --# scope-start
               --# bind alt Item_230
      --# expr-start 6826 '<And at ast.py:15517>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:15517
--# expr-start 6823 '<And at ast.py:15517>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:15517
--# expr-start 6820 '<And at ast.py:15517>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:15517
--# expr-start 6815 '<LogicAll at ast.py:15517>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:15517
--# expr-start 6814 '<Map at ast.py:15517>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15517
   --# expr-start 6796 '<FieldAccess for choices at ast.py:15517>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15517
      if Item_230.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Alternatives_List (Node => Item_230.Node.Case_Expr_Alternative_F_Choices, Info => Item_230.Info);
--# expr-done 6796
Fld_10 := Fld_9.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_10 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_10;
      begin
         for Untyped_Item_231 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_231 := Untyped_Item_231; 
Is_Null_1 := Bare_Item_231 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_11 := Fld_9.Info;
As_Entity_1 := (Info => Fld_11, Node => Bare_Item_231); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_231 := If_Result_1; 
   --# scope-start
               --# bind c Item_231
      --# expr-start 6813 '<Match at ast.py:15517>' Match_Result /tmp/lal-23.0.0/ada/ast.py:15517
      if Item_231.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_231; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Abstract_State_Decl_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind e Match_0
--# expr-start 6811 '<If at ast.py:15519>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:15519
--# expr-start 6800 '<Not at ast.py:15520>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15520
--# expr-start 6799 '<IsNull at ast.py:15520>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:15520
--# expr-start 6797 '<Cast to Name at ast.py:15520>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15520
Cast_Expr_1 := Match_0; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 6797
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Name then
   --# scope-start
--# expr-start 6798 '<FieldAccess for name_designated_type at ast.py:15520>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:15520
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_18 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 6798
Scope_Result := Fld_18;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Is_Null_2 := Result_Var.Node = null; 
--# expr-done 6799
Not_Val := not (Is_Null_2); 
--# expr-done 6800
if Not_Val then
   --# expr-start 6802 '<FieldAccess for xref_no_overloading at ast.py:15522>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15522
--# expr-start 6801 '<Cast to Name at ast.py:15522>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15522
Cast_Expr := Match_0; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 6801
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_12 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result.Node, Env => Env, Origin => Origin, E_Info => Cast_Result.Info);
--# end
--# expr-done 6802
   If_Result_2 := Fld_12;
else
   --# expr-start 6810 '<And at ast.py:15524>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15524
--# expr-start 6808 '<And at ast.py:15524>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15524
--# expr-start 6806 '<Bind at ast.py:15524>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15524
--# expr-start 6803 '<FieldAccess for expected_type_var at ast.py:15524>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15524
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Match_0.Node);
--# expr-done 6803
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
--# expr-start 6805 '<FieldAccess for type_val at ast.py:15524>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:15524
--# expr-start 6804 '<FieldAccess for expr at ast.py:15524>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:15524
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Self.Case_Expr_F_Expr;
--# expr-done 6804
      if Fld_14 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_15 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld_14);
--# end
--# expr-done 6805
Bind_Result_1 := Solver.Create_Assign (Fld_13, Fld_15, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15524") else null)); 
--# expr-done 6806
--# expr-start 6807 '<FieldAccess for sub_equation at ast.py:15525>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15525
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_16 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_0.Node, Env => Env, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 6807
And_Pred := Create_And (Bind_Result_1, Fld_16, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15524") else null)); 
--# expr-done 6808
--# expr-start 6809 '<FieldAccess for matches_expected_type at ast.py:15526>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15526
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_17 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Match_0.Node, Origin => Origin);
--# end
--# expr-done 6809
And_Pred_1 := Create_And (And_Pred, Fld_17, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15524") else null)); 
--# expr-done 6810
   If_Result_2 := And_Pred_1;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 6811
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
Scope_Result_1 := Let_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2716;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind t Match_1
--# expr-start 6812 '<FieldAccess for xref_equation at ast.py:15530>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:15530
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_19 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Match_1.Node, Env => Env, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 6812
Let_Result_1 := Fld_19; Inc_Ref (Let_Result_1);
--# end
Scope_Result_2 := Let_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2718;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Others_Designator =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Others_Designator
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15532") else null)); 
Let_Result_2 := True_Rel; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2719;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Null_Component_Decl | Ada_Overriding_Not_Overriding .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_5; 
--# bind _ Match_3
Let_Result_3 := raise Property_Error with "Should not happen"; Inc_Ref (Let_Result_3);
--# end
Scope_Result_4 := Let_Result_3;
   Inc_Ref (Scope_Result_4);
   --# end
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
end case;
--# expr-done 6813
         declare
            Item_To_Append : constant Logic_Equation := Match_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2715;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6814
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15517") else null)); 
--# expr-done 6815
--# expr-start 6819 '<Bind at ast.py:15538>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:15538
--# expr-start 6816 '<FieldAccess for expected_type_var at ast.py:15538>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:15538
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6816
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
--# expr-start 6818 '<FieldAccess for expected_type_var at ast.py:15538>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:15538
--# expr-start 6817 '<FieldAccess for expr at ast.py:15538>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:15538
      if Item_230.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Expr (Node => Item_230.Node.Case_Expr_Alternative_F_Expr, Info => Item_230.Info);
--# expr-done 6817
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_21.Node);
--# expr-done 6818
Fld_22.Value := No_Entity;
Entity_Vars.Reset (Fld_22);
Bind_Result_2 := Solver.Create_Unify (Fld_20, Fld_22, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15538") else null)); 
--# expr-done 6819
And_Pred_2 := Create_And (Logic_Boolean_Op, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15517") else null)); 
--# expr-done 6820
--# expr-start 6822 '<FieldAccess for sub_equation at ast.py:15539>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:15539
--# expr-start 6821 '<FieldAccess for expr at ast.py:15539>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:15539
      if Item_230.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Create_Internal_Entity_Expr (Node => Item_230.Node.Case_Expr_Alternative_F_Expr, Info => Item_230.Info);
--# expr-done 6821
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_24 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_23.Node, Env => Env, Origin => Origin, E_Info => Fld_23.Info);
--# end
--# expr-done 6822
And_Pred_3 := Create_And (And_Pred_2, Fld_24, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15517") else null)); 
--# expr-done 6823
--# expr-start 6825 '<FieldAccess for matches_expected_type at ast.py:15540>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:15540
--# expr-start 6824 '<FieldAccess for expr at ast.py:15540>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:15540
      if Item_230.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Expr (Node => Item_230.Node.Case_Expr_Alternative_F_Expr, Info => Item_230.Info);
--# expr-done 6824
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_26 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_25.Node, Origin => Origin);
--# end
--# expr-done 6825
And_Pred_4 := Create_And (And_Pred_3, Fld_26, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15517") else null)); 
--# expr-done 6826
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_4;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2714;
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 6827
Logic_Boolean_Op_1 := Solver.Create_All (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15514") else null)); 
--# expr-done 6828
And_Pred_5 := Create_And (Bind_Result, Logic_Boolean_Op_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15512") else null)); 
--# expr-done 6829
Let_Result_4 := And_Pred_5; Inc_Ref (Let_Result_4);
--# end
--# expr-done 6830
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1117;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1117;
               Finalizer_Scope_2714;
               Finalizer_Scope_2715;
               Finalizer_Scope_2716;
               Finalizer_Scope_2718;
               Finalizer_Scope_2719;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Case_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_If_Expr
   --
      procedure Initialize_Fields_For_If_Expr
        (Self : Bare_If_Expr
         ; If_Expr_F_Cond_Expr : Bare_Expr
         ; If_Expr_F_Then_Expr : Bare_Expr
         ; If_Expr_F_Alternatives : Bare_Elsif_Expr_Part_List
         ; If_Expr_F_Else_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Cond_Expr
              (Self);
            Self.If_Expr_F_Cond_Expr := If_Expr_F_Cond_Expr;
            Self.If_Expr_F_Then_Expr := If_Expr_F_Then_Expr;
            Self.If_Expr_F_Alternatives := If_Expr_F_Alternatives;
            Self.If_Expr_F_Else_Expr := If_Expr_F_Else_Expr;
      end Initialize_Fields_For_If_Expr;
   function If_Expr_F_Cond_Expr
     (Node : Bare_If_Expr) return Bare_Expr
   is
   begin
         return Node.If_Expr_F_Cond_Expr;
   end;
   function If_Expr_F_Then_Expr
     (Node : Bare_If_Expr) return Bare_Expr
   is
   begin
         return Node.If_Expr_F_Then_Expr;
   end;
   function If_Expr_F_Alternatives
     (Node : Bare_If_Expr) return Bare_Elsif_Expr_Part_List
   is
   begin
         return Node.If_Expr_F_Alternatives;
   end;
   function If_Expr_F_Else_Expr
     (Node : Bare_If_Expr) return Bare_Expr
   is
   begin
         return Node.If_Expr_F_Else_Expr;
   end;
--# property-start IfExpr.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:15391
pragma Warnings (Off, "is not referenced");
 function If_Expr_P_Has_Context_Free_Type
  (Node : Bare_If_Expr
  )
   return Boolean
is
   Self : Bare_If_Expr := Bare_If_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end If_Expr_P_Has_Context_Free_Type;
--# end
--# property-start IfExpr.dependent_exprs /tmp/lal-23.0.0/ada/ast.py:15394
pragma Warnings (Off, "is not referenced");
 function If_Expr_P_Dependent_Exprs
  (Node : Bare_If_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr_Array_Access
is
   Self : Bare_If_Expr := Bare_If_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_If_Expr :=
     Internal_Entity_If_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr_Array_Access;
            procedure Finalizer_Scope_1111 with Inline_Always;
      Fld : Internal_Entity_Expr;
Singleton : Internal_Entity_Expr_Array_Access;
Fld_1 : Internal_Entity_Elsif_Expr_Part_List;
Fld_2 : Bare_Elsif_Expr_Part_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Elsif_Expr_Part;
Is_Null : Boolean;
If_Result : Internal_Entity_Elsif_Expr_Part;
Fld_4 : Internal_Entity_Expr;
Item_232 : Internal_Entity_Elsif_Expr_Part;
Bare_Item_232 : Bare_Elsif_Expr_Part;
Map_Result : Internal_Entity_Expr_Array_Access;
Concat_Result : Internal_Entity_Expr_Array_Access;
Fld_5 : Internal_Entity_Expr;
Singleton_1 : Internal_Entity_Expr_Array_Access;
Concat_Result_1 : Internal_Entity_Expr_Array_Access;
Let_Result : Internal_Entity_Expr_Array_Access;
            procedure Finalizer_Scope_1111 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Singleton_1);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1111;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6838 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6837 '<Concat at ast.py:15397>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:15397
--# expr-start 6835 '<Concat at ast.py:15395>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15395
--# expr-start 6831 '<FieldAccess for then_expr at ast.py:15395>' Fld /tmp/lal-23.0.0/ada/ast.py:15395
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Then_Expr, Info => Ent.Info);
--# expr-done 6831
                Singleton := Create_Internal_Entity_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
--# expr-start 6834 '<Map at ast.py:15396>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15396
   --# expr-start 6832 '<FieldAccess for alternatives at ast.py:15396>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15396
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Elsif_Expr_Part_List (Node => Ent.Node.If_Expr_F_Alternatives, Info => Ent.Info);
--# expr-done 6832
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Internal_Entity_Expr_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Internal_Entity_Expr_Array (0);
      else
      declare
         Collection : constant Bare_Elsif_Expr_Part_List := Fld_2;
      begin
         for Untyped_Item_232 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_232 := Untyped_Item_232; 
Is_Null := Bare_Item_232 = null; 
if Is_Null then
   If_Result := No_Entity_Elsif_Expr_Part;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_232); 
   If_Result := As_Entity;
end if;
                  Item_232 := If_Result; 
   --# scope-start
               --# bind a Item_232
      --# expr-start 6833 '<FieldAccess for then_expr at ast.py:15396>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15396
      if Item_232.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Item_232.Node.Elsif_Expr_Part_F_Then_Expr, Info => Item_232.Info);
--# expr-done 6833
         declare
            Item_To_Append : constant Internal_Entity_Expr := Fld_4;
         begin
            Internal_Entity_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Expr_Array
           (Items_Count => Natural (Internal_Entity_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6834
Concat_Result := Concat (Singleton, Map_Result); 
--# expr-done 6835
--# expr-start 6836 '<FieldAccess for else_expr at ast.py:15397>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15397
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Else_Expr, Info => Ent.Info);
--# expr-done 6836
                Singleton_1 := Create_Internal_Entity_Expr_Array (Items_Count => 1);
                Singleton_1.Items (1) := Fld_5;
Concat_Result_1 := Concat (Concat_Result, Singleton_1); 
--# expr-done 6837
Let_Result := Concat_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6838
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1111;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1111;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end If_Expr_P_Dependent_Exprs;
--# end
--# property-start IfExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:15400
pragma Warnings (Off, "is not referenced");
 function If_Expr_P_Xref_Equation
  (Node : Bare_If_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_If_Expr := Bare_If_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_If_Expr :=
     Internal_Entity_If_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1112 with Inline_Always;
            procedure Finalizer_Scope_2722 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_7 : Internal_Entity_Expr;
Fld_8 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_9 : Internal_Entity_Elsif_Expr_Part_List;
Fld_10 : Bare_Elsif_Expr_Part_List;
Fld_11 : Internal_Entity_Info;
As_Entity : Internal_Entity_Elsif_Expr_Part;
Is_Null : Boolean;
If_Result : Internal_Entity_Elsif_Expr_Part;
Fld_12 : Internal_Entity_Expr;
Fld_13 : Logic_Var;
Fld_14 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_15 : Internal_Entity_Expr;
Fld_16 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_17 : Internal_Entity_Expr;
Fld_18 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_19 : Internal_Entity_Expr;
Fld_20 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Item_233 : Internal_Entity_Elsif_Expr_Part;
Bare_Item_233 : Bare_Elsif_Expr_Part;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_6 : Logic_Equation;
Fld_21 : Internal_Entity_Expr;
Fld_22 : Logic_Equation;
Fld_23 : Bare_Expr;
Fld_24 : Logic_Var;
Fld_25 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Fld_26 : Internal_Entity_Expr;
Fld_27 : Logic_Equation;
And_Pred_7 : Logic_Equation;
Fld_28 : Bare_Expr;
Is_Null_1 : Boolean;
Not_Val : Boolean;
If_Result_1 : Logic_Equation;
And_Pred_8 : Logic_Equation;
Fld_29 : Logic_Var;
Pred : Logic_Equation;
Fld_30 : Logic_Equation;
And_Pred_9 : Logic_Equation;
Fld_31 : Logic_Var;
Node_For_Entity : Bare_Base_Type_Decl;
As_Entity_1 : Internal_Entity_Base_Type_Decl;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_3 : Logic_Equation;
Fld_32 : Logic_Equation;
And_Pred_10 : Logic_Equation;
Or_Pred : Logic_Equation;
And_Pred_11 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1112 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_8);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Fld_22);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Fld_27);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_8);
                     Dec_Ref (Pred);
                     Dec_Ref (Fld_30);
                     Dec_Ref (And_Pred_9);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Fld_32);
                     Dec_Ref (And_Pred_10);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (And_Pred_11);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1112;
            procedure Finalizer_Scope_2722 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_16);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_18);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_20);
                     Dec_Ref (And_Pred_5);
            end Finalizer_Scope_2722;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6894 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6893 '<And at ast.py:15403>' And_Pred_11 /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6882 '<And at ast.py:15403>' And_Pred_8 /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6868 '<And at ast.py:15403>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6851 '<And at ast.py:15403>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6848 '<And at ast.py:15403>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6845 '<And at ast.py:15403>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6842 '<Bind at ast.py:15403>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6840 '<FieldAccess for expected_type_var at ast.py:15403>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15403
--# expr-start 6839 '<FieldAccess for cond_expr at ast.py:15403>' Fld /tmp/lal-23.0.0/ada/ast.py:15403
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.If_Expr_F_Cond_Expr;
--# expr-done 6839
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 6840
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 6841 '<FieldAccess for bool_type at ast.py:15403>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15403
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6841
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6842
--# expr-start 6844 '<FieldAccess for sub_equation at ast.py:15404>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15404
--# expr-start 6843 '<FieldAccess for cond_expr at ast.py:15404>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15404
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Cond_Expr, Info => Ent.Info);
--# expr-done 6843
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 6844
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6845
--# expr-start 6847 '<FieldAccess for matches_expected_formal_prim_type at ast.py:15405>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15405
--# expr-start 6846 '<FieldAccess for cond_expr at ast.py:15405>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15405
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Cond_Expr, Info => Ent.Info);
--# expr-done 6846
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 6847
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6848
--# expr-start 6850 '<FieldAccess for sub_equation at ast.py:15408>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15408
--# expr-start 6849 '<FieldAccess for then_expr at ast.py:15408>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15408
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Then_Expr, Info => Ent.Info);
--# expr-done 6849
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_8 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_7.Node, Env => Env, Origin => Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 6850
And_Pred_2 := Create_And (And_Pred_1, Fld_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6851
--# expr-start 6867 '<LogicAll at ast.py:15410>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:15410
--# expr-start 6866 '<Map at ast.py:15410>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15410
   --# expr-start 6852 '<FieldAccess for alternatives at ast.py:15410>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15410
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Elsif_Expr_Part_List (Node => Ent.Node.If_Expr_F_Alternatives, Info => Ent.Info);
--# expr-done 6852
Fld_10 := Fld_9.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_10 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Elsif_Expr_Part_List := Fld_10;
      begin
         for Untyped_Item_233 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_233 := Untyped_Item_233; 
Is_Null := Bare_Item_233 = null; 
if Is_Null then
   If_Result := No_Entity_Elsif_Expr_Part;
else
Fld_11 := Fld_9.Info;
As_Entity := (Info => Fld_11, Node => Bare_Item_233); 
   If_Result := As_Entity;
end if;
                  Item_233 := If_Result; 
   --# scope-start
               --# bind elsif Item_233
      --# expr-start 6865 '<And at ast.py:15413>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:15413
--# expr-start 6862 '<And at ast.py:15413>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:15413
--# expr-start 6859 '<And at ast.py:15413>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:15413
--# expr-start 6856 '<Bind at ast.py:15413>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15413
--# expr-start 6854 '<FieldAccess for expected_type_var at ast.py:15413>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15413
--# expr-start 6853 '<FieldAccess for cond_expr at ast.py:15413>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15413
      if Item_233.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Expr (Node => Item_233.Node.Elsif_Expr_Part_F_Cond_Expr, Info => Item_233.Info);
--# expr-done 6853
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_12.Node);
--# expr-done 6854
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
--# expr-start 6855 '<FieldAccess for bool_type at ast.py:15413>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:15413
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_14 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6855
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_14.Node,
         Info => Fld_14.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_13, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15413") else null)); 
--# expr-done 6856
--# expr-start 6858 '<FieldAccess for sub_equation at ast.py:15414>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15414
--# expr-start 6857 '<FieldAccess for cond_expr at ast.py:15414>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:15414
      if Item_233.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Expr (Node => Item_233.Node.Elsif_Expr_Part_F_Cond_Expr, Info => Item_233.Info);
--# expr-done 6857
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_16 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_15.Node, Env => Env, Origin => Origin, E_Info => Fld_15.Info);
--# end
--# expr-done 6858
And_Pred_3 := Create_And (Bind_Result_1, Fld_16, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15413") else null)); 
--# expr-done 6859
--# expr-start 6861 '<FieldAccess for matches_expected_formal_prim_type at ast.py:15415>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:15415
--# expr-start 6860 '<FieldAccess for cond_expr at ast.py:15415>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15415
      if Item_233.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Create_Internal_Entity_Expr (Node => Item_233.Node.Elsif_Expr_Part_F_Cond_Expr, Info => Item_233.Info);
--# expr-done 6860
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_18 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_17.Node, Origin => Origin);
--# end
--# expr-done 6861
And_Pred_4 := Create_And (And_Pred_3, Fld_18, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15413") else null)); 
--# expr-done 6862
--# expr-start 6864 '<FieldAccess for sub_equation at ast.py:15416>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:15416
--# expr-start 6863 '<FieldAccess for then_expr at ast.py:15416>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:15416
      if Item_233.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Expr (Node => Item_233.Node.Elsif_Expr_Part_F_Then_Expr, Info => Item_233.Info);
--# expr-done 6863
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_20 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_19.Node, Env => Env, Origin => Origin, E_Info => Fld_19.Info);
--# end
--# expr-done 6864
And_Pred_5 := Create_And (And_Pred_4, Fld_20, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15413") else null)); 
--# expr-done 6865
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_5;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2722;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6866
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15410") else null)); 
--# expr-done 6867
And_Pred_6 := Create_And (And_Pred_2, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6868
--# expr-start 6881 '<If at ast.py:15419>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15419
--# expr-start 6871 '<Not at ast.py:15420>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15420
--# expr-start 6870 '<IsNull at ast.py:15420>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:15420
--# expr-start 6869 '<FieldAccess for else_expr at ast.py:15420>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:15420
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Self.If_Expr_F_Else_Expr;
--# expr-done 6869
Is_Null_1 := Fld_28 = null; 
--# expr-done 6870
Not_Val := not (Is_Null_1); 
--# expr-done 6871
if Not_Val then
   --# expr-start 6873 '<FieldAccess for sub_equation at ast.py:15423>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:15423
--# expr-start 6872 '<FieldAccess for else_expr at ast.py:15423>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:15423
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Else_Expr, Info => Ent.Info);
--# expr-done 6872
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_22 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_21.Node, Env => Env, Origin => Origin, E_Info => Fld_21.Info);
--# end
--# expr-done 6873
   If_Result_1 := Fld_22;
else
   --# expr-start 6880 '<And at ast.py:15426>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:15426
--# expr-start 6877 '<Bind at ast.py:15426>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:15426
--# expr-start 6875 '<FieldAccess for expected_type_var at ast.py:15426>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:15426
--# expr-start 6874 '<FieldAccess for then_expr at ast.py:15426>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:15426
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Self.If_Expr_F_Then_Expr;
--# expr-done 6874
      if Fld_23 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_23);
--# expr-done 6875
Fld_24.Value := No_Entity;
Entity_Vars.Reset (Fld_24);
--# expr-start 6876 '<FieldAccess for bool_type at ast.py:15426>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:15426
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_25 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6876
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_25.Node,
         Info => Fld_25.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_24, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15426") else null)); 
--# expr-done 6877
--# expr-start 6879 '<FieldAccess for matches_expected_formal_prim_type at ast.py:15427>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:15427
--# expr-start 6878 '<FieldAccess for then_expr at ast.py:15427>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:15427
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Then_Expr, Info => Ent.Info);
--# expr-done 6878
      if Fld_26.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_27 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_26.Node, Origin => Origin);
--# end
--# expr-done 6879
And_Pred_7 := Create_And (Bind_Result_2, Fld_27, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15426") else null)); 
--# expr-done 6880
   If_Result_1 := And_Pred_7;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 6881
And_Pred_8 := Create_And (And_Pred_6, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6882
--# expr-start 6892 '<Or at ast.py:15430>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:15430
--# expr-start 6886 '<And at ast.py:15431>' And_Pred_9 /tmp/lal-23.0.0/ada/ast.py:15431
--# expr-start 6884 '<Predicate on AdaNode.is_not_null at ast.py:15431>' Pred /tmp/lal-23.0.0/ada/ast.py:15431
--# expr-start 6883 '<FieldAccess for expected_type_var at ast.py:15431>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:15431
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6883
Fld_29.Value := No_Entity;
Entity_Vars.Reset (Fld_29);
Pred := Solver.Create_Predicate (Fld_29, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 6884
--# expr-start 6885 '<FieldAccess for expected_type_equation at ast.py:15432>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:15432
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start IfExpr.expected_type_equation
Fld_30 := Libadalang.Implementation.If_Expr_P_Expected_Type_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 6885
And_Pred_9 := Create_And (Pred, Fld_30, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15431") else null)); 
--# expr-done 6886
--# expr-start 6891 '<And at ast.py:15434>' And_Pred_10 /tmp/lal-23.0.0/ada/ast.py:15434
--# expr-start 6889 '<Bind at ast.py:15434>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:15434
--# expr-start 6887 '<FieldAccess for expected_type_var at ast.py:15434>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:15434
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6887
Fld_31.Value := No_Entity;
Entity_Vars.Reset (Fld_31);
--# expr-start 6888 '<No BaseTypeDecl at ast.py:15434>' Node_For_Entity /tmp/lal-23.0.0/ada/ast.py:15434
Node_For_Entity := No_Bare_Ada_Node;
--# expr-done 6888
Is_Null_2 := Node_For_Entity = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity_Base_Type_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Node_For_Entity); 
   If_Result_2 := As_Entity_1;
end if;
      Cast_Result_3 := Create_Internal_Entity
        (Node => If_Result_2.Node,
         Info => If_Result_2.Info);
Bind_Result_3 := Solver.Create_Assign (Fld_31, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15434") else null)); 
--# expr-done 6889
--# expr-start 6890 '<FieldAccess for no_expected_type_equation at ast.py:15435>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:15435
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start IfExpr.no_expected_type_equation
Fld_32 := Libadalang.Implementation.If_Expr_P_No_Expected_Type_Equation (Node => Ent.Node, Env => Env, Origin => Origin);
--# end
--# expr-done 6890
And_Pred_10 := Create_And (Bind_Result_3, Fld_32, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15434") else null)); 
--# expr-done 6891
Or_Pred := Create_Or (And_Pred_9, And_Pred_10, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15430") else null)); 
--# expr-done 6892
And_Pred_11 := Create_And (And_Pred_8, Or_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15403") else null)); 
--# expr-done 6893
Let_Result := And_Pred_11; Inc_Ref (Let_Result);
--# end
--# expr-done 6894
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1112;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1112;
               Finalizer_Scope_2722;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end If_Expr_P_Xref_Equation;
--# end
--# property-start IfExpr.expected_type_equation /tmp/lal-23.0.0/ada/ast.py:15440
pragma Warnings (Off, "is not referenced");
 function If_Expr_P_Expected_Type_Equation
  (Node : Bare_If_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_If_Expr := Bare_If_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_If_Expr :=
     Internal_Entity_If_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1113 with Inline_Always;
            procedure Finalizer_Scope_2723 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Fld_4 : Logic_Var;
Bind_Result_1 : Logic_Equation;
Fld_5 : Bare_Expr;
Fld_6 : Logic_Var;
Fld_7 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_8 : Internal_Entity_Expr;
Fld_9 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_10 : Internal_Entity_Expr;
Fld_11 : Logic_Equation;
And_Pred_2 : Logic_Equation;
True_Rel : Logic_Equation;
Fld_12 : Bare_Expr;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_13 : Internal_Entity_Elsif_Expr_Part_List;
Fld_14 : Bare_Elsif_Expr_Part_List;
Fld_15 : Internal_Entity_Info;
As_Entity : Internal_Entity_Elsif_Expr_Part;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Elsif_Expr_Part;
Fld_16 : Internal_Entity_Expr;
Fld_17 : Logic_Var;
Fld_18 : Logic_Var;
Bind_Result_3 : Logic_Equation;
Fld_19 : Internal_Entity_Expr;
Fld_20 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Item_234 : Internal_Entity_Elsif_Expr_Part;
Bare_Item_234 : Bare_Elsif_Expr_Part;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_5 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1113 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_11);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1113;
            procedure Finalizer_Scope_2723 is
            begin
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Fld_20);
                     Dec_Ref (And_Pred_4);
            end Finalizer_Scope_2723;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6929 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6928 '<And at ast.py:15446>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:15446
--# expr-start 6917 '<And at ast.py:15446>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:15446
--# expr-start 6897 '<Bind at ast.py:15446>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15446
--# expr-start 6895 '<FieldAccess for type_var at ast.py:15446>' Fld /tmp/lal-23.0.0/ada/ast.py:15446
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6895
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 6896 '<FieldAccess for expected_type_var at ast.py:15446>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15446
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6896
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Bind_Result := Solver.Create_Unify (Fld, Fld_1, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15446") else null)); 
--# expr-done 6897
--# expr-start 6916 '<If at ast.py:15446>' If_Result /tmp/lal-23.0.0/ada/ast.py:15446
--# expr-start 6900 '<Not at ast.py:15447>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15447
--# expr-start 6899 '<IsNull at ast.py:15447>' Is_Null /tmp/lal-23.0.0/ada/ast.py:15447
--# expr-start 6898 '<FieldAccess for else_expr at ast.py:15447>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15447
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.If_Expr_F_Else_Expr;
--# expr-done 6898
Is_Null := Fld_12 = null; 
--# expr-done 6899
Not_Val := not (Is_Null); 
--# expr-done 6900
if Not_Val then
   --# expr-start 6915 '<And at ast.py:15449>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:15449
--# expr-start 6912 '<And at ast.py:15449>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15449
--# expr-start 6909 '<And at ast.py:15449>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15449
--# expr-start 6904 '<Bind at ast.py:15449>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15449
--# expr-start 6902 '<FieldAccess for expected_type_var at ast.py:15449>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15449
--# expr-start 6901 '<FieldAccess for else_expr at ast.py:15449>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15449
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.If_Expr_F_Else_Expr;
--# expr-done 6901
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2);
--# expr-done 6902
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 6903 '<FieldAccess for expected_type_var at ast.py:15449>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15449
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6903
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Bind_Result_1 := Solver.Create_Unify (Fld_3, Fld_4, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15449") else null)); 
--# expr-done 6904
--# expr-start 6908 '<Bind at ast.py:15450>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:15450
--# expr-start 6906 '<FieldAccess for expected_type_var at ast.py:15450>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15450
--# expr-start 6905 '<FieldAccess for then_expr at ast.py:15450>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15450
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.If_Expr_F_Then_Expr;
--# expr-done 6905
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_5);
--# expr-done 6906
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 6907 '<FieldAccess for expected_type_var at ast.py:15450>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15450
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6907
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result_2 := Solver.Create_Unify (Fld_6, Fld_7, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15450") else null)); 
--# expr-done 6908
And_Pred := Create_And (Bind_Result_1, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15449") else null)); 
--# expr-done 6909
--# expr-start 6911 '<FieldAccess for matches_expected_formal_type at ast.py:15451>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15451
--# expr-start 6910 '<FieldAccess for else_expr at ast.py:15451>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15451
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Else_Expr, Info => Ent.Info);
--# expr-done 6910
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_9 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_8.Node, Origin => Origin);
--# end
--# expr-done 6911
And_Pred_1 := Create_And (And_Pred, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15449") else null)); 
--# expr-done 6912
--# expr-start 6914 '<FieldAccess for matches_expected_formal_type at ast.py:15452>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15452
--# expr-start 6913 '<FieldAccess for then_expr at ast.py:15452>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15452
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Expr_F_Then_Expr, Info => Ent.Info);
--# expr-done 6913
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_11 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_10.Node, Origin => Origin);
--# end
--# expr-done 6914
And_Pred_2 := Create_And (And_Pred_1, Fld_11, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15449") else null)); 
--# expr-done 6915
   If_Result := And_Pred_2;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15454") else null)); 
   If_Result := True_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 6916
And_Pred_3 := Create_And (Bind_Result, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15446") else null)); 
--# expr-done 6917
--# expr-start 6927 '<LogicAll at ast.py:15455>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:15455
--# expr-start 6926 '<Map at ast.py:15455>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15455
   --# expr-start 6918 '<FieldAccess for alternatives at ast.py:15455>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15455
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Elsif_Expr_Part_List (Node => Ent.Node.If_Expr_F_Alternatives, Info => Ent.Info);
--# expr-done 6918
Fld_14 := Fld_13.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_14 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Elsif_Expr_Part_List := Fld_14;
      begin
         for Untyped_Item_234 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_234 := Untyped_Item_234; 
Is_Null_1 := Bare_Item_234 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Elsif_Expr_Part;
else
Fld_15 := Fld_13.Info;
As_Entity := (Info => Fld_15, Node => Bare_Item_234); 
   If_Result_1 := As_Entity;
end if;
                  Item_234 := If_Result_1; 
   --# scope-start
               --# bind elsif Item_234
      --# expr-start 6925 '<And at ast.py:15457>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:15457
--# expr-start 6922 '<Bind at ast.py:15457>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:15457
--# expr-start 6920 '<FieldAccess for expected_type_var at ast.py:15457>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15457
--# expr-start 6919 '<FieldAccess for then_expr at ast.py:15457>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15457
      if Item_234.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Expr (Node => Item_234.Node.Elsif_Expr_Part_F_Then_Expr, Info => Item_234.Info);
--# expr-done 6919
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_16.Node);
--# expr-done 6920
Fld_17.Value := No_Entity;
Entity_Vars.Reset (Fld_17);
--# expr-start 6921 '<FieldAccess for expected_type_var at ast.py:15457>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:15457
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6921
Fld_18.Value := No_Entity;
Entity_Vars.Reset (Fld_18);
Bind_Result_3 := Solver.Create_Unify (Fld_17, Fld_18, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15457") else null)); 
--# expr-done 6922
--# expr-start 6924 '<FieldAccess for matches_expected_formal_type at ast.py:15458>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:15458
--# expr-start 6923 '<FieldAccess for then_expr at ast.py:15458>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:15458
      if Item_234.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Expr (Node => Item_234.Node.Elsif_Expr_Part_F_Then_Expr, Info => Item_234.Info);
--# expr-done 6923
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_20 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_19.Node, Origin => Origin);
--# end
--# expr-done 6924
And_Pred_4 := Create_And (Bind_Result_3, Fld_20, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15457") else null)); 
--# expr-done 6925
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_4;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2723;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6926
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15455") else null)); 
--# expr-done 6927
And_Pred_5 := Create_And (And_Pred_3, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15446") else null)); 
--# expr-done 6928
Let_Result := And_Pred_5; Inc_Ref (Let_Result);
--# end
--# expr-done 6929
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1113;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1113;
               Finalizer_Scope_2723;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end If_Expr_P_Expected_Type_Equation;
--# end
--# property-start IfExpr.no_expected_type_equation /tmp/lal-23.0.0/ada/ast.py:15462
pragma Warnings (Off, "is not referenced");
 function If_Expr_P_No_Expected_Type_Equation
  (Node : Bare_If_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
  )
   return Logic_Equation
is
   Self : Bare_If_Expr := Bare_If_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1114 with Inline_Always;
            procedure Finalizer_Scope_2726 with Inline_Always;
            procedure Finalizer_Scope_2728 with Inline_Always;
      Var_Expr : Bare_Expr;
Fld : Bare_Expr;
Singleton : Bare_Expr_Array_Access;
Fld_1 : Bare_Elsif_Expr_Part_List;
Fld_2 : Bare_Expr;
Item_237 : Bare_Elsif_Expr_Part;
Map_Result : Bare_Expr_Array_Access;
Concat_Result : Bare_Expr_Array_Access;
Fld_3 : Bare_Expr;
Singleton_1 : Bare_Expr_Array_Access;
Scope_Result : Bare_Expr_Array_Access;
Result_Var : Bare_Expr_Array_Access;
Concat_Result_1 : Bare_Expr_Array_Access;
Fld_4 : Boolean;
Map_Result_1 : Bare_Expr_Array_Access;
Fld_5 : Logic_Var;
Pred : Logic_Equation;
Fld_6 : Logic_Var;
Fld_7 : Logic_Var;
Bind_Result : Logic_Equation;
Or_Pred : Logic_Equation;
Map_Result_2 : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1114 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1114;
            procedure Finalizer_Scope_2726 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_2726;
            procedure Finalizer_Scope_2728 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Or_Pred);
            end Finalizer_Scope_2728;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6947 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6946 '<LogicAll at ast.py:15475>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:15475
--# expr-start 6945 '<Map at ast.py:15475>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:15475
   --# expr-start 6938 '<Filter at ast.py:15473>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:15473
   --# expr-start 6936 '<Concat at ast.py:15471>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:15471
--# expr-start 6934 '<Concat at ast.py:15469>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15469
--# expr-start 6930 '<FieldAccess for then_expr at ast.py:15469>' Fld /tmp/lal-23.0.0/ada/ast.py:15469
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.If_Expr_F_Then_Expr;
--# expr-done 6930
                Singleton := Create_Bare_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
--# expr-start 6933 '<Map at ast.py:15470>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15470
   --# expr-start 6931 '<FieldAccess for alternatives at ast.py:15470>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15470
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.If_Expr_F_Alternatives;
--# expr-done 6931
      declare
         Map_Result_Vec : Bare_Expr_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Bare_Expr_Array (0);
      else
      declare
         Collection : constant Bare_Elsif_Expr_Part_List := Fld_1;
      begin
         for Untyped_Item_237 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_237 := Untyped_Item_237; 
   --# scope-start
               --# bind a Item_237
      --# expr-start 6932 '<FieldAccess for then_expr at ast.py:15470>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15470
      if Item_237 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Item_237.Elsif_Expr_Part_F_Then_Expr;
--# expr-done 6932
         declare
            Item_To_Append : constant Bare_Expr := Fld_2;
         begin
            Bare_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Expr_Array
           (Items_Count => Natural (Bare_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 6933
Concat_Result := Concat (Singleton, Map_Result); 
--# expr-done 6934
--# expr-start 6935 '<FieldAccess for else_expr at ast.py:15472>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15472
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.If_Expr_F_Else_Expr;
--# expr-done 6935
Var_Expr := Fld_3;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
                Singleton_1 := Create_Bare_Expr_Array (Items_Count => 1);
                Singleton_1.Items (1) := Var_Expr;
Scope_Result := Singleton_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2726;
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Expr_Array_Type;
end if;
      Inc_Ref (Result_Var);
Concat_Result_1 := Concat (Concat_Result, Result_Var); 
--# expr-done 6936
      declare
         Map_Result_1_Vec : Bare_Expr_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Expr_Array_Access := Concat_Result_1;
      begin
         for Item_236 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_236
         --# expr-start 6937 '<FieldAccess for has_context_free_type at ast.py:15474>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15474
      if Item_236 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Item_236);
--# end
--# expr-done 6937
         if Fld_4 then
         declare
            Item_To_Append : constant Bare_Expr := Item_236;
         begin
            Bare_Expr_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Bare_Expr_Array
           (Items_Count => Natural (Bare_Expr_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Bare_Expr_Vectors.Get
              (Map_Result_1_Vec,
               I + Bare_Expr_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Bare_Expr_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 6938
      declare
         Map_Result_2_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Expr_Array_Access := Map_Result_1;
      begin
         for Item_235 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_235
      --# expr-start 6944 '<Or at ast.py:15477>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:15477
--# expr-start 6940 '<Predicate on BaseTypeDecl.is_universal_type at ast.py:15477>' Pred /tmp/lal-23.0.0/ada/ast.py:15477
--# expr-start 6939 '<FieldAccess for type_var at ast.py:15477>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15477
      if Item_235 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Item_235);
--# expr-done 6939
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Pred := Solver.Create_Predicate (Fld_5, Create_Base_Type_Decl_P_Is_Universal_Type_0_Predicate); 
--# expr-done 6940
--# expr-start 6943 '<Bind at ast.py:15478>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15478
--# expr-start 6941 '<FieldAccess for type_var at ast.py:15478>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15478
      if Item_235 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Item_235);
--# expr-done 6941
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 6942 '<FieldAccess for type_var at ast.py:15478>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15478
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6942
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result := Solver.Create_Propagate (Fld_6, Fld_7, Logic_Functor_602'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15478") else null)); 
--# expr-done 6943
Or_Pred := Create_Or (Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15477") else null)); 
--# expr-done 6944
         declare
            Item_To_Append : constant Logic_Equation := Or_Pred;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2728;
         end loop;
      end;
         Map_Result_2 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_2_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 6945
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result_2.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15475") else null)); 
--# expr-done 6946
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 6947
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1114;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1114;
               Finalizer_Scope_2726;
               Finalizer_Scope_2728;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end If_Expr_P_No_Expected_Type_Equation;
--# end
   --
   --  Primitives for Bare_Contract_Cases
   --
      procedure Initialize_Fields_For_Contract_Cases
        (Self : Bare_Contract_Cases
         ; Contract_Cases_F_Contract_Cases : Bare_Contract_Case_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Contract_Cases_F_Contract_Cases := Contract_Cases_F_Contract_Cases;
      end Initialize_Fields_For_Contract_Cases;
   function Contract_Cases_F_Contract_Cases
     (Node : Bare_Contract_Cases) return Bare_Contract_Case_Assoc_List
   is
   begin
         return Node.Contract_Cases_F_Contract_Cases;
   end;
   --
   --  Primitives for Bare_Decl_Expr
   --
      procedure Decl_Expr_Pre_Env_Actions
        (Self            : Bare_Decl_Expr;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_128 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Decl_Expr
        (Self : Bare_Decl_Expr
         ; Decl_Expr_F_Decls : Bare_Basic_Decl_List
         ; Decl_Expr_F_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Decl_Expr_F_Decls := Decl_Expr_F_Decls;
            Self.Decl_Expr_F_Expr := Decl_Expr_F_Expr;
      end Initialize_Fields_For_Decl_Expr;
   function Decl_Expr_F_Decls
     (Node : Bare_Decl_Expr) return Bare_Basic_Decl_List
   is
   begin
         return Node.Decl_Expr_F_Decls;
   end;
   function Decl_Expr_F_Expr
     (Node : Bare_Decl_Expr) return Bare_Expr
   is
   begin
         return Node.Decl_Expr_F_Expr;
   end;
--# property-start DeclExpr.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12117
pragma Warnings (Off, "is not referenced");
 function Decl_Expr_P_Has_Context_Free_Type
  (Node : Bare_Decl_Expr
  )
   return Boolean
is
   Self : Bare_Decl_Expr := Bare_Decl_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Expr;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 6949 '<FieldAccess for has_context_free_type at ast.py:12117>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12117
--# expr-start 6948 '<FieldAccess for expr at ast.py:12117>' Fld /tmp/lal-23.0.0/ada/ast.py:12117
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Decl_Expr_F_Expr;
--# expr-done 6948
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Fld);
--# end
--# expr-done 6949
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Decl_Expr_P_Has_Context_Free_Type;
--# end
--# property-start DeclExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:12120
pragma Warnings (Off, "is not referenced");
 function Decl_Expr_P_Xref_Equation
  (Node : Bare_Decl_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Decl_Expr := Bare_Decl_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Decl_Expr :=
     Internal_Entity_Decl_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_947 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Expr;
Fld_2 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
Fld_3 : Bare_Expr;
Fld_4 : Logic_Var;
Fld_5 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_Expr;
Fld_7 : Logic_Var;
Fld_8 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_947 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_947;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 6964 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 6963 '<And at ast.py:12121>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12121
--# expr-start 6958 '<And at ast.py:12121>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12121
--# expr-start 6953 '<bind at ast.py:12122>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:12122
--# expr-start 6950 '<FieldAccess for children_env at ast.py:12122>' Fld /tmp/lal-23.0.0/ada/ast.py:12122
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 6950
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 6952 '<FieldAccess for sub_equation at ast.py:12122>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12122
--# expr-start 6951 '<FieldAccess for expr at ast.py:12122>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12122
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Expr (Node => Ent.Node.Decl_Expr_F_Expr, Info => Ent.Info);
--# expr-done 6951
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_2 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_1.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 6952
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 6953
--# expr-start 6957 '<Bind at ast.py:12123>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12123
--# expr-start 6955 '<FieldAccess for expected_type_var at ast.py:12123>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12123
--# expr-start 6954 '<FieldAccess for expr at ast.py:12123>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12123
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Decl_Expr_F_Expr;
--# expr-done 6954
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_3);
--# expr-done 6955
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 6956 '<FieldAccess for expected_type_var at ast.py:12123>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12123
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 6956
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result := Solver.Create_Unify (Fld_4, Fld_5, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12123") else null)); 
--# expr-done 6957
And_Pred := Create_And (Dyn_Var_Bind_Result, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12121") else null)); 
--# expr-done 6958
--# expr-start 6962 '<Bind at ast.py:12124>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12124
--# expr-start 6960 '<FieldAccess for type_var at ast.py:12124>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12124
--# expr-start 6959 '<FieldAccess for expr at ast.py:12124>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12124
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Decl_Expr_F_Expr;
--# expr-done 6959
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_6);
--# expr-done 6960
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
--# expr-start 6961 '<FieldAccess for type_var at ast.py:12124>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12124
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6961
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Bind_Result_1 := Solver.Create_Unify (Fld_7, Fld_8, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12124") else null)); 
--# expr-done 6962
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12121") else null)); 
--# expr-done 6963
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 6964
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_947;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_947;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Decl_Expr_P_Xref_Equation;
--# end
--# property-start DeclExpr._env_trans_parent_128 /tmp/lal-23.0.0/ada/ast.py:12113
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_128
  (Node : Bare_Decl_Expr
  )
   return Boolean
is
   Self : Bare_Decl_Expr := Bare_Decl_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_128;
--# end
   --
   --  Primitives for Bare_Membership_Expr
   --
      procedure Initialize_Fields_For_Membership_Expr
        (Self : Bare_Membership_Expr
         ; Membership_Expr_F_Expr : Bare_Expr
         ; Membership_Expr_F_Op : Bare_Op
         ; Membership_Expr_F_Membership_Exprs : Bare_Expr_Alternatives_List
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Membership_Expr_F_Expr := Membership_Expr_F_Expr;
            Self.Membership_Expr_F_Op := Membership_Expr_F_Op;
            Self.Membership_Expr_F_Membership_Exprs := Membership_Expr_F_Membership_Exprs;
      end Initialize_Fields_For_Membership_Expr;
   function Membership_Expr_F_Expr
     (Node : Bare_Membership_Expr) return Bare_Expr
   is
   begin
         return Node.Membership_Expr_F_Expr;
   end;
   function Membership_Expr_F_Op
     (Node : Bare_Membership_Expr) return Bare_Op
   is
   begin
         return Node.Membership_Expr_F_Op;
   end;
   function Membership_Expr_F_Membership_Exprs
     (Node : Bare_Membership_Expr) return Bare_Expr_Alternatives_List
   is
   begin
         return Node.Membership_Expr_F_Membership_Exprs;
   end;
--# property-start MembershipExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:12770
pragma Warnings (Off, "is not referenced");
 function Membership_Expr_P_Xref_Equation
  (Node : Bare_Membership_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Membership_Expr := Bare_Membership_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Membership_Expr :=
     Internal_Entity_Membership_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_976 with Inline_Always;
            procedure Finalizer_Scope_2729 with Inline_Always;
            procedure Finalizer_Scope_2731 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Name;
Fld : Logic_Var;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Internal_Entity_Expr_Alternatives_List;
Fld_5 : Bare_Expr_Alternatives_List;
Fld_6 : Internal_Entity_Info;
As_Entity : Internal_Entity_Expr;
Is_Null : Boolean;
If_Result : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_7 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Cast_Expr_1 : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity_Name;
Fld_8 : Logic_Equation;
Fld_9 : Boolean;
Fld_10 : Bare_Expr;
Fld_11 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_12 : Bare_Expr;
Fld_13 : Logic_Var;
Pred : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_14 : Bare_Expr;
Fld_15 : Logic_Var;
Fld_16 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Fld_17 : Bare_Expr;
Fld_18 : Logic_Equation;
And_Pred_2 : Logic_Equation;
If_Result_1 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Fld_19 : Logic_Var;
Fld_20 : Bare_Expr;
Fld_21 : Logic_Var;
Bind_Result_3 : Logic_Equation;
Fld_22 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_23 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Result_Var_1 : Logic_Equation;
Item_238 : Internal_Entity_Expr;
Bare_Item_238 : Bare_Expr;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_6 : Logic_Equation;
            procedure Finalizer_Scope_976 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_6);
            end Finalizer_Scope_976;
            procedure Finalizer_Scope_2729 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Fld_22);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_23);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_2729;
            procedure Finalizer_Scope_2731 is
            begin
                     Dec_Ref (Fld_8);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Fld_18);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_2731;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7003 '<And at ast.py:12771>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:12771
--# expr-start 6970 '<And at ast.py:12771>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12771
--# expr-start 6967 '<Bind at ast.py:12771>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12771
--# expr-start 6965 '<FieldAccess for type_var at ast.py:12771>' Fld /tmp/lal-23.0.0/ada/ast.py:12771
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 6965
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 6966 '<FieldAccess for bool_type at ast.py:12771>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12771
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 6966
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12771") else null)); 
--# expr-done 6967
--# expr-start 6969 '<FieldAccess for sub_equation at ast.py:12772>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12772
--# expr-start 6968 '<FieldAccess for expr at ast.py:12772>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12772
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Membership_Expr_F_Expr, Info => Ent.Info);
--# expr-done 6968
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 6969
And_Pred := Create_And (Bind_Result, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12771") else null)); 
--# expr-done 6970
--# expr-start 7002 '<LogicAll at ast.py:12773>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:12773
--# expr-start 7001 '<Map at ast.py:12773>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12773
   --# expr-start 6971 '<FieldAccess for membership_exprs at ast.py:12773>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12773
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr_Alternatives_List (Node => Ent.Node.Membership_Expr_F_Membership_Exprs, Info => Ent.Info);
--# expr-done 6971
Fld_5 := Fld_4.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_5 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Expr_Alternatives_List := Fld_5;
      begin
         for Untyped_Item_238 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_238 := Untyped_Item_238; 
Is_Null := Bare_Item_238 = null; 
if Is_Null then
   If_Result := No_Entity_Expr;
else
Fld_6 := Fld_4.Info;
As_Entity := (Info => Fld_6, Node => Bare_Item_238); 
   If_Result := As_Entity;
end if;
                  Item_238 := If_Result; 
   --# scope-start
               --# bind m Item_238
--# expr-start 6972 '<Cast to Name at ast.py:12774>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:12774
Cast_Expr := Item_238; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 6972
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Name then
   --# scope-start
--# expr-start 6973 '<FieldAccess for name_designated_type at ast.py:12774>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12774
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_7 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 6973
Scope_Result := Fld_7;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr
--# expr-start 6992 '<And at ast.py:12777>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:12777
--# expr-start 6975 '<FieldAccess for xref_no_overloading at ast.py:12777>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12777
--# expr-start 6974 '<Cast to Name at ast.py:12777>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:12777
Cast_Expr_1 := Item_238; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Name
   then
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Name;
   end if;
--# expr-done 6974
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_8 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_2.Node, Env => Env, Origin => Origin, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 6975
--# expr-start 6991 '<Cond at ast.py:12778>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:12778
--# expr-start 6976 '<FieldAccess for is_tagged_type at ast.py:12786>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12786
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_tagged_type'
Fld_9 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Tagged_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 6976
if Fld_9 then
   --# expr-start 6983 '<And at ast.py:12787>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12787
--# expr-start 6979 '<Bind at ast.py:12787>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12787
--# expr-start 6978 '<FieldAccess for expected_type_var at ast.py:12787>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:12787
--# expr-start 6977 '<FieldAccess for expr at ast.py:12787>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12787
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Membership_Expr_F_Expr;
--# expr-done 6977
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_10);
--# expr-done 6978
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
Cast_Expr_2 := No_Entity_Base_Type_Decl; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_11, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12787") else null)); 
--# expr-done 6979
--# expr-start 6982 '<Predicate on BaseTypeDecl.is_tagged_type_with_deref at ast.py:12788>' Pred /tmp/lal-23.0.0/ada/ast.py:12788
--# expr-start 6981 '<FieldAccess for type_var at ast.py:12789>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:12789
--# expr-start 6980 '<FieldAccess for expr at ast.py:12789>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:12789
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.Membership_Expr_F_Expr;
--# expr-done 6980
      if Fld_12 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_12);
--# expr-done 6981
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
Pred := Solver.Create_Predicate (Fld_13, Create_Base_Type_Decl_P_Is_Tagged_Type_With_Deref_0_Predicate (Origin)); 
--# expr-done 6982
And_Pred_1 := Create_And (Bind_Result_1, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12787") else null)); 
--# expr-done 6983
   If_Result_1 := And_Pred_1;
else
   --# expr-start 6990 '<And at ast.py:12793>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12793
--# expr-start 6987 '<Bind at ast.py:12793>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12793
--# expr-start 6985 '<FieldAccess for expected_type_var at ast.py:12793>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:12793
--# expr-start 6984 '<FieldAccess for expr at ast.py:12793>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:12793
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Self.Membership_Expr_F_Expr;
--# expr-done 6984
      if Fld_14 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_14);
--# expr-done 6985
Fld_15.Value := No_Entity;
Entity_Vars.Reset (Fld_15);
--# expr-start 6986 '<FieldAccess for base_subtype at ast.py:12794>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:12794
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.base_subtype
Fld_16 := Libadalang.Implementation.Base_Type_Decl_P_Base_Subtype (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 6986
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_16.Node,
         Info => Fld_16.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_15, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12793") else null)); 
--# expr-done 6987
--# expr-start 6989 '<FieldAccess for matches_expected_formal_type at ast.py:12795>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:12795
--# expr-start 6988 '<FieldAccess for expr at ast.py:12795>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:12795
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Self.Membership_Expr_F_Expr;
--# expr-done 6988
      if Fld_17 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_18 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_17, Origin => Origin);
--# end
--# expr-done 6989
And_Pred_2 := Create_And (Bind_Result_2, Fld_18, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12793") else null)); 
--# expr-done 6990
   If_Result_1 := And_Pred_2;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 6991
And_Pred_3 := Create_And (Fld_8, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12777") else null)); 
--# expr-done 6992
Scope_Result_1 := And_Pred_3;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2731;
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 7000 '<And at ast.py:12799>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:12799
--# expr-start 6998 '<And at ast.py:12799>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:12799
--# expr-start 6996 '<Bind at ast.py:12800>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:12800
--# expr-start 6993 '<FieldAccess for expected_type_var at ast.py:12800>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:12800
      if Item_238.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Item_238.Node);
--# expr-done 6993
Fld_19.Value := No_Entity;
Entity_Vars.Reset (Fld_19);
--# expr-start 6995 '<FieldAccess for type_var at ast.py:12800>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:12800
--# expr-start 6994 '<FieldAccess for expr at ast.py:12800>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:12800
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Self.Membership_Expr_F_Expr;
--# expr-done 6994
      if Fld_20 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_20);
--# expr-done 6995
Fld_21.Value := No_Entity;
Entity_Vars.Reset (Fld_21);
Bind_Result_3 := Solver.Create_Unify (Fld_19, Fld_21, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12800") else null)); 
--# expr-done 6996
--# expr-start 6997 '<FieldAccess for sub_equation at ast.py:12801>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:12801
      if Item_238.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_22 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_238.Node, Env => Env, Origin => Origin, E_Info => Item_238.Info);
--# end
--# expr-done 6997
And_Pred_4 := Create_And (Bind_Result_3, Fld_22, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12799") else null)); 
--# expr-done 6998
--# expr-start 6999 '<FieldAccess for matches_expected_type at ast.py:12802>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:12802
      if Item_238.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_23 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Item_238.Node, Origin => Origin);
--# end
--# expr-done 6999
And_Pred_5 := Create_And (And_Pred_4, Fld_23, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12799") else null)); 
--# expr-done 7000
   Result_Var_1 := And_Pred_5;
end if;
      Inc_Ref (Result_Var_1);
         declare
            Item_To_Append : constant Logic_Equation := Result_Var_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2729;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 7001
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12773") else null)); 
--# expr-done 7002
And_Pred_6 := Create_And (And_Pred, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12771") else null)); 
--# expr-done 7003
      Property_Result := And_Pred_6;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_976;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_976;
               Finalizer_Scope_2729;
               Finalizer_Scope_2731;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Membership_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Name
   --
      procedure Initialize_Fields_For_Name
        (Self : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
      end Initialize_Fields_For_Name;
--# property-start Name.enclosing_defining_name /tmp/lal-23.0.0/ada/ast.py:13119
pragma Warnings (Off, "is not referenced");
 function Name_P_Enclosing_Defining_Name
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_989 with Inline_Always;
      Fld : Internal_Entity_Array_Access;
Is_A : Boolean;
Find_Result : Internal_Entity;
Cast_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_989 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_989;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7007 '<Cast to DefiningName at ast.py:13121>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13121
--# expr-start 7006 '<Find at ast.py:13120>' Find_Result /tmp/lal-23.0.0/ada/ast.py:13120
   --# expr-start 7004 '<FieldAccess for parents at ast.py:13120>' Fld /tmp/lal-23.0.0/ada/ast.py:13120
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parents (Node => Ent.Node, With_Self => True, E_Info => Ent.Info);
--# expr-done 7004
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_239 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_239
      --# expr-start 7005 '<IsA DefiningName at ast.py:13120>' Is_A /tmp/lal-23.0.0/ada/ast.py:13120
Is_A := Item_239.Node /= null 
and then Item_239.Node.Kind in Ada_Defining_Name_Range; 
--# expr-done 7005
      if Is_A then
         Find_Result := Item_239;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 7006
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Defining_Name_Range
   then
      Cast_Result := Create_Internal_Entity_Defining_Name
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result := No_Entity_Defining_Name;
   end if;
--# expr-done 7007
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_989;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_989;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Enclosing_Defining_Name;
--# end
--# property-start Name.is_defining /tmp/lal-23.0.0/ada/ast.py:13129
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Defining
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Dotted_Name;
Is_A : Boolean;
Fld : Bare_Ada_Node;
Is_A_1 : Boolean;
If_Result : Boolean;
Fld_1 : Bare_Ada_Node;
Fld_2 : Bare_Ada_Node;
Is_A_2 : Boolean;
Fld_3 : Bare_Ada_Node;
Cast_Result : Bare_Dotted_Name;
Fld_4 : Bare_Base_Id;
Scope_Result : Bare_Base_Id;
Result_Var : Bare_Base_Id;
Cast_Result_1 : Bare_Name;
Is_Equal : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7018 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7008 '<IsA DefiningName at ast.py:13135>' Is_A /tmp/lal-23.0.0/ada/ast.py:13135
Is_A := Self /= null 
and then Self.Kind in Ada_Defining_Name_Range; 
--# expr-done 7008
if Is_A then
   If_Result := True;
else
   --# expr-start 7010 '<IsA DefiningName at ast.py:13139>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13139
--# expr-start 7009 '<parent at ast.py:13139>' Fld /tmp/lal-23.0.0/ada/ast.py:13139
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 7009
Is_A_1 := Fld /= null 
and then Fld.Kind in Ada_Defining_Name_Range; 
--# expr-done 7010
   If_Result := Is_A_1;
end if;
if If_Result then
   If_Result_2 := True;
else
--# expr-start 7013 '<IsA DefiningName at ast.py:13143>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:13143
--# expr-start 7012 '<parent at ast.py:13143>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13143
--# expr-start 7011 '<parent at ast.py:13143>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13143
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Parent; 
--# expr-done 7011
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Fld_1.Parent; 
--# expr-done 7012
Is_A_2 := Fld_2 /= null 
and then Fld_2.Kind in Ada_Defining_Name_Range; 
--# expr-done 7013
if Is_A_2 then
   --# expr-start 7017 '<Eq at ast.py:13144>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13144
--# expr-start 7015 '<Cast to DottedName at ast.py:13144>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13144
--# expr-start 7014 '<parent at ast.py:13144>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13144
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Parent; 
--# expr-done 7014
   if Fld_3 = null
      or else Fld_3.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Fld_3;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 7015
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 7016 '<FieldAccess for suffix at ast.py:13144>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13144
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Var_Expr.Dotted_Name_F_Suffix;
--# expr-done 7016
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
      Cast_Result_1 := Result_Var;
Is_Equal := Cast_Result_1 = Self; 
--# expr-done 7017
   If_Result_1 := Is_Equal;
else
   If_Result_1 := False;
end if;
   If_Result_2 := If_Result_1;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 7018
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Defining;
--# end
--# property-start '[dispatcher]Name.parent_scope' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Parent_Scope
  (Node : Bare_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref .. Ada_Call_Expr | Ada_Discrete_Subtype_Name | Ada_Explicit_Deref .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.parent_scope
                  Property_Result := Name_P_Parent_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.parent_scope
                  Property_Result := Defining_Name_P_Parent_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.parent_scope
                  Property_Result := Dotted_Name_P_Parent_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.parent_scope
                  Property_Result := End_Name_P_Parent_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.parent_scope
                  Property_Result := Base_Id_P_Parent_Scope
                    (Self
                        , Env
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Parent_Scope;
--# end
--# property-start Name.name_is /tmp/lal-23.0.0/ada/ast.py:13157
pragma Warnings (Off, "is not referenced");
 function Name_P_Name_Is
  (Node : Bare_Name
      ; Sym : Symbol_Type
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   Property_Result : Boolean;
      Var_Expr : Symbol_Type;
Fld : Symbol_Type;
Is_Equal : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7021 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7019 '<FieldAccess for name_symbol at ast.py:13161>' Fld /tmp/lal-23.0.0/ada/ast.py:13161
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Self);
--# end
--# expr-done 7019
Var_Expr := Fld;
if Var_Expr /= null then
   --# scope-start
   --# bind ns Var_Expr
--# expr-start 7020 '<Eq at ast.py:13161>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13161
Is_Equal := Var_Expr = Sym; 
--# expr-done 7020
Scope_Result := Is_Equal;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 7021
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Name_Is;
--# end
--# property-start Name.is_direct_call /tmp/lal-23.0.0/ada/ast.py:13164
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Direct_Call
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_2 : Internal_Entity;
Is_A : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7027 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7022 '<FieldAccess for is_call at ast.py:13170>' Fld /tmp/lal-23.0.0/ada/ast.py:13170
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_call
Fld := Libadalang.Implementation.Name_P_Is_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7022
if Fld then
   --# expr-start 7026 '<Not at ast.py:13171>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13171
--# expr-start 7025 '<IsA AccessToSubpDef at ast.py:13171>' Is_A /tmp/lal-23.0.0/ada/ast.py:13171
--# expr-start 7024 '<parent at ast.py:13171>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13171
--# expr-start 7023 '<FieldAccess for called_subp_spec at ast.py:13171>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13171
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_1 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7023
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 7024
Is_A := Fld_2.Node /= null 
and then Fld_2.Node.Kind in Ada_Access_To_Subp_Def_Range; 
--# expr-done 7025
Not_Val := not (Is_A); 
--# expr-done 7026
   If_Result := Not_Val;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 7027
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Direct_Call;
--# end
--# property-start Name.is_access_call /tmp/lal-23.0.0/ada/ast.py:13175
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Access_Call
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_2 : Internal_Entity;
Is_A : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7032 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7028 '<FieldAccess for is_call at ast.py:13181>' Fld /tmp/lal-23.0.0/ada/ast.py:13181
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_call
Fld := Libadalang.Implementation.Name_P_Is_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7028
if Fld then
   --# expr-start 7031 '<IsA AccessToSubpDef at ast.py:13182>' Is_A /tmp/lal-23.0.0/ada/ast.py:13182
--# expr-start 7030 '<parent at ast.py:13182>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13182
--# expr-start 7029 '<FieldAccess for called_subp_spec at ast.py:13182>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13182
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_1 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7029
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# expr-done 7030
Is_A := Fld_2.Node /= null 
and then Fld_2.Node.Kind in Ada_Access_To_Subp_Def_Range; 
--# expr-done 7031
   If_Result := Is_A;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 7032
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Access_Call;
--# end
--# property-start Name.is_call /tmp/lal-23.0.0/ada/ast.py:13186
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Call
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity_Base_Formal_Param_Holder;
Is_Null : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7038 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7034 '<Not at ast.py:13191>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13191
--# expr-start 7033 '<FieldAccess for is_defining at ast.py:13191>' Fld /tmp/lal-23.0.0/ada/ast.py:13191
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_defining
Fld := Libadalang.Implementation.Name_P_Is_Defining (Node => Ent.Node);
--# end
--# expr-done 7033
Not_Val := not (Fld); 
--# expr-done 7034
if Not_Val then
   --# expr-start 7037 '<Not at ast.py:13192>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:13192
--# expr-start 7036 '<IsNull at ast.py:13192>' Is_Null /tmp/lal-23.0.0/ada/ast.py:13192
--# expr-start 7035 '<FieldAccess for called_subp_spec at ast.py:13192>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13192
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_1 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7035
Is_Null := Fld_1.Node = null; 
--# expr-done 7036
Not_Val_1 := not (Is_Null); 
--# expr-done 7037
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 7038
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Call;
--# end
--# property-start Name.is_dot_call /tmp/lal-23.0.0/ada/ast.py:13197
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Dot_Call
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Info;
Fld_3 : Internal_Metadata;
Fld_4 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7045 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7040 '<Not at ast.py:13202>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13202
--# expr-start 7039 '<FieldAccess for is_defining at ast.py:13202>' Fld /tmp/lal-23.0.0/ada/ast.py:13202
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_defining
Fld := Libadalang.Implementation.Name_P_Is_Defining (Node => Ent.Node);
--# end
--# expr-done 7039
Not_Val := not (Fld); 
--# expr-done 7040
if Not_Val then
   --# expr-start 7044 '<FieldAccess for dottable_subp at ast.py:13203>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13203
--# expr-start 7043 '<FieldAccess for md at ast.py:13203>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13203
--# expr-start 7042 '<FieldAccess for info at ast.py:13203>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13203
--# expr-start 7041 '<FieldAccess for referenced_decl at ast.py:13203>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13203
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_1 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7041
Fld_2 := Fld_1.Info;
--# expr-done 7042
Fld_3 := Fld_2.Md;
--# expr-done 7043
Fld_4 := Fld_3.Dottable_Subp;
--# expr-done 7044
   If_Result := Fld_4;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 7045
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Dot_Call;
--# end
--# property-start Name.failsafe_referenced_def_name /tmp/lal-23.0.0/ada/ast.py:13208
pragma Warnings (Off, "is not referenced");
 function Name_P_Failsafe_Referenced_Def_Name
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Refd_Def
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Refd_Def;
            procedure Finalizer_Scope_2735 with Inline_Always;
      Block_Var : Internal_Refd_Decl;
Block_Var_1 : Internal_Entity_Defining_Name;
Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Defining_Name;
Var_Expr_2 : Symbol_Type;
Fld : Internal_Refd_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Symbol_Type;
Fld_3 : Internal_Entity_Defining_Name_Array_Access;
Fld_4 : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Scope_Result : Internal_Entity_Defining_Name;
Result_Var : Internal_Entity_Defining_Name;
Scope_Result_1 : Internal_Entity_Defining_Name;
Fld_5 : Internal_Entity_Defining_Name;
Result_Var_1 : Internal_Entity_Defining_Name;
Scope_Result_2 : Internal_Entity_Defining_Name;
Result_Var_2 : Internal_Entity_Defining_Name;
Fld_6 : Ref_Result_Kind;
New_Struct : Internal_Refd_Def;
Let_Result : Internal_Refd_Def;
            procedure Finalizer_Scope_2735 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2735;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7055 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7046 '<FieldAccess for failsafe_referenced_decl at ast.py:13213>' Fld /tmp/lal-23.0.0/ada/ast.py:13213
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.failsafe_referenced_decl
Fld := Libadalang.Implementation.Name_P_Failsafe_Referenced_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7046
Block_Var := Fld; 
--# bind ref_decl Block_Var
--# expr-start 7047 '<FieldAccess for decl at ast.py:13215>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13215
Fld_1 := Block_Var.Decl;
--# expr-done 7047
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind ref_decl Var_Expr
--# expr-start 7048 '<FieldAccess for name_symbol at ast.py:13216>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13216
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7048
Var_Expr_2 := Fld_2;
if Var_Expr_2 /= null then
   --# scope-start
   --# bind rel_name Var_Expr_2
--# expr-start 7051 '<Find at ast.py:13217>' Find_Result /tmp/lal-23.0.0/ada/ast.py:13217
   --# expr-start 7049 '<FieldAccess for defining_names at ast.py:13217>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13217
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7049
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_3;
      begin
         for Item_240 of
               Collection.Items
         loop
   --# scope-start
               --# bind dn Item_240
      --# expr-start 7050 '<FieldAccess for name_is at ast.py:13218>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13218
      if Item_240.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_4 := Libadalang.Implementation.Name_P_Name_Is (Node => Item_240.Node, Sym => Var_Expr_2);
--# end
--# expr-done 7050
      if Fld_4 then
         Find_Result := Item_240;
      end if;
   --# end
               exit when Fld_4;
         end loop;
      end;
--# expr-done 7051
Scope_Result := Find_Result;
   --# end
      Finalizer_Scope_2735;
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Defining_Name;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result_1 := Var_Expr_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 7052 '<FieldAccess for defining_name at ast.py:13220>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13220
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7052
   Result_Var_1 := Fld_5;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Defining_Name;
end if;
Block_Var_1 := Result_Var_2; 
--# bind def_name Block_Var_1
--# expr-start 7054 '<New RefdDef at ast.py:13224>' New_Struct /tmp/lal-23.0.0/ada/ast.py:13224
--# expr-start 7053 '<FieldAccess for kind at ast.py:13224>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13224
Fld_6 := Block_Var.Kind;
--# expr-done 7053
New_Struct := (Def_Name => Block_Var_1, Kind => Fld_6); 
--# expr-done 7054
Let_Result := New_Struct; 
--# end
--# expr-done 7055
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2735;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Failsafe_Referenced_Def_Name;
--# end
--# property-start Name.referenced_defining_name /tmp/lal-23.0.0/ada/ast.py:13228
pragma Warnings (Off, "is not referenced");
 function Name_P_Referenced_Defining_Name
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_2739 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Defining_Name;
Var_Expr_2 : Symbol_Type;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Defining_Name_Array_Access;
Fld_3 : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Scope_Result : Internal_Entity_Defining_Name;
Result_Var : Internal_Entity_Defining_Name;
Scope_Result_1 : Internal_Entity_Defining_Name;
Fld_4 : Internal_Entity_Defining_Name;
Result_Var_1 : Internal_Entity_Defining_Name;
Scope_Result_2 : Internal_Entity_Defining_Name;
Result_Var_2 : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_2739 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2739;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7062 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7056 '<FieldAccess for referenced_decl at ast.py:13233>' Fld /tmp/lal-23.0.0/ada/ast.py:13233
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7056
Block_Var := Fld; 
--# bind ref_decl Block_Var
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind ref_decl Var_Expr
--# expr-start 7057 '<FieldAccess for name_symbol at ast.py:13234>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13234
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7057
Var_Expr_2 := Fld_1;
if Var_Expr_2 /= null then
   --# scope-start
   --# bind rel_name Var_Expr_2
--# expr-start 7060 '<Find at ast.py:13235>' Find_Result /tmp/lal-23.0.0/ada/ast.py:13235
   --# expr-start 7058 '<FieldAccess for defining_names at ast.py:13235>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13235
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7058
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_2;
      begin
         for Item_241 of
               Collection.Items
         loop
   --# scope-start
               --# bind dn Item_241
      --# expr-start 7059 '<FieldAccess for name_is at ast.py:13236>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13236
      if Item_241.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_3 := Libadalang.Implementation.Name_P_Name_Is (Node => Item_241.Node, Sym => Var_Expr_2);
--# end
--# expr-done 7059
      if Fld_3 then
         Find_Result := Item_241;
      end if;
   --# end
               exit when Fld_3;
         end loop;
      end;
--# expr-done 7060
Scope_Result := Find_Result;
   --# end
      Finalizer_Scope_2739;
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Defining_Name;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result_1 := Var_Expr_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 7061 '<FieldAccess for defining_name at ast.py:13238>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13238
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7061
   Result_Var_1 := Fld_4;
end if;
Scope_Result_2 := Result_Var_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Defining_Name;
end if;
Let_Result := Result_Var_2; 
--# end
--# expr-done 7062
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2739;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Referenced_Defining_Name;
--# end
--# property-start Name.gnat_xref_decl /tmp/lal-23.0.0/ada/ast.py:13242
pragma Warnings (Off, "is not referenced");
 function Name_P_Gnat_Xref_Decl
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
      Block_Var : Internal_Entity_Defining_Name;
Block_Var_1 : Internal_Entity_Basic_Decl;
Var_Expr : Boolean;
Var_Expr_1 : Internal_Entity_Defining_Name;
Var_Expr_2 : Internal_Entity_Basic_Decl;
Var_Expr_3 : Internal_Entity_Basic_Decl;
Var_Expr_4 : Internal_Entity_Basic_Decl;
Var_Expr_5 : Internal_Entity_Basic_Decl;
Var_Expr_6 : Internal_Entity_Base_Type_Decl;
Var_Expr_7 : Internal_Entity_Basic_Decl;
Var_Expr_8 : Internal_Entity_Basic_Decl;
Var_Expr_9 : Internal_Entity_Basic_Decl;
Var_Expr_10 : Internal_Entity_Defining_Name;
Var_Expr_11 : Internal_Entity_Body_Node;
Fld : Boolean;
Fld_1 : Internal_Entity_Defining_Name;
Scope_Result : Internal_Entity_Defining_Name;
Result_Var : Internal_Entity_Defining_Name;
Fld_2 : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
Is_A : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Param_Spec;
Fld_3 : Internal_Entity_Defining_Name;
Is_A_1 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Body_Node;
Fld_4 : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Defining_Name;
Scope_Result_4 : Internal_Entity_Defining_Name;
Result_Var_4 : Internal_Entity_Defining_Name;
Is_A_2 : Boolean;
Cast_Expr_2 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Fld_6 : Boolean;
If_Result : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
Cast_Expr_3 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Fld_7 : Internal_Entity_Base_Type_Decl;
Fld_8 : Internal_Entity_Defining_Name;
Scope_Result_6 : Internal_Entity_Defining_Name;
Result_Var_6 : Internal_Entity_Defining_Name;
Is_A_3 : Boolean;
Scope_Result_7 : Boolean;
Result_Var_7 : Boolean;
Is_A_4 : Boolean;
Scope_Result_8 : Boolean;
Result_Var_8 : Boolean;
Is_A_5 : Boolean;
Scope_Result_9 : Boolean;
Result_Var_9 : Boolean;
Fld_9 : Internal_Entity_Body_Node;
Fld_10 : Internal_Entity_Defining_Name;
Scope_Result_10 : Internal_Entity_Defining_Name;
Result_Var_10 : Internal_Entity_Defining_Name;
Scope_Result_11 : Internal_Entity_Defining_Name;
Fld_11 : Internal_Entity_Defining_Name;
Result_Var_11 : Internal_Entity_Defining_Name;
Fld_12 : Internal_Entity_Defining_Name;
If_Result_1 : Internal_Entity_Defining_Name;
If_Result_2 : Internal_Entity_Defining_Name;
If_Result_3 : Internal_Entity_Defining_Name;
If_Result_4 : Internal_Entity_Defining_Name;
If_Result_5 : Internal_Entity_Defining_Name;
If_Result_6 : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7087 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7063 '<FieldAccess for is_defining at ast.py:13247>' Fld /tmp/lal-23.0.0/ada/ast.py:13247
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_defining
Fld := Libadalang.Implementation.Name_P_Is_Defining (Node => Ent.Node);
--# end
--# expr-done 7063
Var_Expr := Fld;
if Var_Expr /= False then
   --# scope-start
   --# bind _ Var_Expr
--# expr-start 7064 '<FieldAccess for enclosing_defining_name at ast.py:13248>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13248
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.enclosing_defining_name
Fld_1 := Libadalang.Implementation.Name_P_Enclosing_Defining_Name (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7064
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Defining_Name;
end if;
Block_Var := Result_Var; 
--# bind dn Block_Var
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind dn Var_Expr_1
--# expr-start 7065 '<FieldAccess for basic_decl at ast.py:13250>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13250
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_2 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 7065
Scope_Result_1 := Fld_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Basic_Decl;
end if;
Block_Var_1 := Result_Var_1; 
--# bind bd Block_Var_1
--# expr-start 7086 '<Cond at ast.py:13252>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:13252
Var_Expr_2 := Block_Var_1;
if Var_Expr_2 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_2
--# expr-start 7066 '<IsA ParamSpec at ast.py:13253>' Is_A /tmp/lal-23.0.0/ada/ast.py:13253
Is_A := Var_Expr_2.Node /= null 
and then Var_Expr_2.Node.Kind in Ada_Param_Spec_Range; 
--# expr-done 7066
Scope_Result_2 := Is_A;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
if Result_Var_2 then
   --# expr-start 7068 '<FieldAccess for decl_param at ast.py:13254>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13254
--# expr-start 7067 '<Cast to ParamSpec at ast.py:13254>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13254
Cast_Expr := Block_Var_1; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Param_Spec_Range
   then
      Cast_Result := Create_Internal_Entity_Param_Spec
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Param_Spec;
   end if;
--# expr-done 7067
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.decl_param
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Decl_Param (Node => Cast_Result.Node, Param => Block_Var, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result.Info);
--# end
--# expr-done 7068
   If_Result_6 := Fld_3;
else
Var_Expr_3 := Block_Var_1;
if Var_Expr_3 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_3
--# expr-start 7069 '<IsA Body at ast.py:13256>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13256
Is_A_1 := Var_Expr_3.Node /= null 
and then Var_Expr_3.Node.Kind in Ada_Body_Node; 
--# expr-done 7069
Scope_Result_3 := Is_A_1;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
if Result_Var_3 then
--# expr-start 7071 '<FieldAccess for decl_part at ast.py:13257>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13257
--# expr-start 7070 '<Cast to Body at ast.py:13257>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:13257
Cast_Expr_1 := Block_Var_1; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Body_Node
   then
      Cast_Result_1 := Create_Internal_Entity_Body_Node
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Body_Node;
   end if;
--# expr-done 7070
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.decl_part
Fld_4 := Libadalang.Implementation.Body_Node_P_Decl_Part (Node => Cast_Result_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 7071
Var_Expr_4 := Fld_4;
if Var_Expr_4 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 7072 '<FieldAccess for defining_name at ast.py:13257>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13257
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_4.Node, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 7072
Scope_Result_4 := Fld_5;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Defining_Name;
end if;
   If_Result_5 := Result_Var_4;
else
Var_Expr_5 := Block_Var_1;
if Var_Expr_5 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_5
--# expr-start 7073 '<IsA BaseTypeDecl at ast.py:13259>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:13259
Is_A_2 := Var_Expr_5.Node /= null 
and then Var_Expr_5.Node.Kind in Ada_Base_Type_Decl; 
--# expr-done 7073
if Is_A_2 then
   --# expr-start 7075 '<FieldAccess for is_in_private_part at ast.py:13260>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13260
--# expr-start 7074 '<Cast to BaseTypeDecl at ast.py:13260>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:13260
Cast_Expr_2 := Var_Expr_5; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_2 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 7074
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_6 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Cast_Result_2.Node, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 7075
   If_Result := Fld_6;
else
   If_Result := False;
end if;
Scope_Result_5 := If_Result;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
if Result_Var_5 then
--# expr-start 7077 '<FieldAccess for previous_part at ast.py:13261>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13261
--# expr-start 7076 '<Cast to BaseTypeDecl at ast.py:13261>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:13261
Cast_Expr_3 := Block_Var_1; 
   if Cast_Expr_3.Node = null
      or else Cast_Expr_3.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
   else
         Cast_Result_3 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 7076
      if Cast_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Cast_Result_3.Node, Go_To_Incomplete => True, E_Info => Cast_Result_3.Info);
--# end
--# expr-done 7077
Var_Expr_6 := Fld_7;
if Var_Expr_6 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7078 '<FieldAccess for defining_name at ast.py:13261>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13261
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 7078
Scope_Result_6 := Fld_8;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Defining_Name;
end if;
   If_Result_4 := Result_Var_6;
else
Var_Expr_7 := Block_Var_1;
if Var_Expr_7 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_7
--# expr-start 7079 '<IsA ObjectDecl at ast.py:13263>' Is_A_3 /tmp/lal-23.0.0/ada/ast.py:13263
Is_A_3 := Var_Expr_7.Node /= null 
and then Var_Expr_7.Node.Kind in Ada_Object_Decl_Range; 
--# expr-done 7079
Scope_Result_7 := Is_A_3;
   --# end
   Result_Var_7 := Scope_Result_7;
else
   Result_Var_7 := False;
end if;
if Result_Var_7 then
   If_Result_3 := No_Entity_Defining_Name;
else
Var_Expr_8 := Block_Var_1;
if Var_Expr_8 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_8
--# expr-start 7080 '<IsA NumberDecl at ast.py:13268>' Is_A_4 /tmp/lal-23.0.0/ada/ast.py:13268
Is_A_4 := Var_Expr_8.Node /= null 
and then Var_Expr_8.Node.Kind in Ada_Number_Decl_Range; 
--# expr-done 7080
Scope_Result_8 := Is_A_4;
   --# end
   Result_Var_8 := Scope_Result_8;
else
   Result_Var_8 := False;
end if;
if Result_Var_8 then
   If_Result_2 := No_Entity_Defining_Name;
else
Var_Expr_9 := Block_Var_1;
if Var_Expr_9 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_9
--# expr-start 7081 '<IsA BasicDecl at ast.py:13272>' Is_A_5 /tmp/lal-23.0.0/ada/ast.py:13272
Is_A_5 := Var_Expr_9.Node /= null 
and then Var_Expr_9.Node.Kind in Ada_Basic_Decl; 
--# expr-done 7081
Scope_Result_9 := Is_A_5;
   --# end
   Result_Var_9 := Scope_Result_9;
else
   Result_Var_9 := False;
end if;
if Result_Var_9 then
--# expr-start 7082 '<FieldAccess for body_part_for_decl at ast.py:13273>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13273
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.body_part_for_decl
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Body_Part_For_Decl (Node => Block_Var_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var_1.Info);
--# end
--# expr-done 7082
Var_Expr_11 := Fld_9;
if Var_Expr_11 /= No_Entity_Body_Node then
   --# scope-start
   --# bind bpe Var_Expr_11
--# expr-start 7083 '<FieldAccess for defining_name at ast.py:13273>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13273
      if Var_Expr_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_11.Node, E_Info => Var_Expr_11.Info);
--# end
--# expr-done 7083
Scope_Result_10 := Fld_10;
   --# end
   Result_Var_10 := Scope_Result_10;
else
   Result_Var_10 := No_Entity_Defining_Name;
end if;
Var_Expr_10 := Result_Var_10;
if Var_Expr_10 /= No_Entity_Defining_Name then
   --# scope-start
   --# bind e Var_Expr_10
Scope_Result_11 := Var_Expr_10;
   --# end
   Result_Var_11 := Scope_Result_11;
else
   --# expr-start 7084 '<FieldAccess for defining_name at ast.py:13274>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13274
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 7084
   Result_Var_11 := Fld_11;
end if;
   If_Result_1 := Result_Var_11;
else
   --# expr-start 7085 '<FieldAccess for referenced_defining_name at ast.py:13276>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13276
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_defining_name
Fld_12 := Libadalang.Implementation.Name_P_Referenced_Defining_Name (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7085
   If_Result_1 := Fld_12;
end if;
   If_Result_2 := If_Result_1;
end if;
   If_Result_3 := If_Result_2;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
   If_Result_6 := If_Result_5;
end if;
--# expr-done 7086
Let_Result := If_Result_6; 
--# end
--# expr-done 7087
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Gnat_Xref_Decl;
--# end
--# property-start '[dispatcher]Name.all_env_els_impl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_All_Env_Els_Impl
  (Node : Bare_Name
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind seq Seq
   --# bind seq_from Seq_From
   --# bind categories Categories
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref .. Ada_Call_Expr | Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.all_env_els_impl
                  Property_Result := Name_P_All_Env_Els_Impl
                    (Self
                        , Seq
                        , Seq_From
                        , Categories
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.all_env_els_impl
                  Property_Result := Defining_Name_P_All_Env_Els_Impl
                    (Self
                        , Seq
                        , Seq_From
                        , Categories
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.all_env_els_impl
                  Property_Result := Dotted_Name_P_All_Env_Els_Impl
                    (Self
                        , Seq
                        , Seq_From
                        , Categories
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.all_env_els_impl
                  Property_Result := Base_Id_P_All_Env_Els_Impl
                    (Self
                        , Seq
                        , Seq_From
                        , Categories
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_All_Env_Els_Impl;
--# end
--# property-start Name.all_env_elements_internal /tmp/lal-23.0.0/ada/ast.py:13290
pragma Warnings (Off, "is not referenced");
 function Name_P_All_Env_Elements_Internal
  (Node : Bare_Name
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind seq Seq
   --# bind seq_from Seq_From
   --# bind categories Categories
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1001 with Inline_Always;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result_1 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1001 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1001;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7093 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7092 '<bind at ast.py:13299>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:13299
--# expr-start 7088 '<FieldAccess for origin_node at ast.py:13300>' Fld /tmp/lal-23.0.0/ada/ast.py:13300
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 7088
Bound_Origin := Fld; 
--# expr-start 7091 '<bind at ast.py:13301>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:13301
--# expr-start 7089 '<FieldAccess for node_env at ast.py:13302>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13302
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 7089
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 7090 '<FieldAccess for all_env_els_impl at ast.py:13303>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13303
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.all_env_els_impl'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_All_Env_Els_Impl (Node => Ent.Node, Seq => Seq, Seq_From => Seq_From, Categories => Categories, Env => Bound_Env, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 7090
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 7091
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 7092
Let_Result := Dyn_Var_Bind_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 7093
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1001;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1001;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_All_Env_Elements_Internal;
--# end
--# property-start Name.all_env_elements /tmp/lal-23.0.0/ada/ast.py:13312
pragma Warnings (Off, "is not referenced");
 function Name_P_All_Env_Elements
  (Node : Bare_Name
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind seq Seq
   --# bind seq_from Seq_From
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1002 with Inline_Always;
      Fld : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1002 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1002;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7095 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7094 '<FieldAccess for all_env_elements_internal at ast.py:13319>' Fld /tmp/lal-23.0.0/ada/ast.py:13319
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_env_elements_internal
Fld := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Ent.Node, Seq => Seq, Seq_From => Seq_From, E_Info => Ent.Info);
--# end
--# expr-done 7094
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 7095
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1002;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1002;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_All_Env_Elements;
--# end
--# property-start Name.first_corresponding_decl /tmp/lal-23.0.0/ada/ast.py:13322
pragma Warnings (Off, "is not referenced");
 function Name_P_First_Corresponding_Decl
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_1003 with Inline_Always;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Dotted_Name;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_3 : Bare_Ada_Node;
Is_A : Boolean;
Fld_4 : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_1003 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_1003;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7106 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7105 '<If at ast.py:13323>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:13323
--# expr-start 7097 '<IsA DottedName at ast.py:13324>' Is_A /tmp/lal-23.0.0/ada/ast.py:13324
--# expr-start 7096 '<parent at ast.py:13324>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13324
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Parent; 
--# expr-done 7096
Is_A := Fld_3 /= null 
and then Fld_3.Kind in Ada_Dotted_Name_Range; 
--# expr-done 7097
if Is_A then
   --# expr-start 7098 '<FieldAccess for is_suffix at ast.py:13324>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13324
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_suffix
Fld_4 := Libadalang.Implementation.Name_P_Is_Suffix (Node => Self);
--# end
--# expr-done 7098
   If_Result := Fld_4;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 7101 '<FieldAccess for first_corresponding_decl at ast.py:13325>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13325
--# expr-start 7100 '<Cast to DottedName at ast.py:13325>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13325
--# expr-start 7099 '<parent at ast.py:13325>' Fld /tmp/lal-23.0.0/ada/ast.py:13325
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 7099
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Create_Internal_Entity_Dotted_Name
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Dotted_Name;
   end if;
--# expr-done 7100
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.first_corresponding_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_First_Corresponding_Decl (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 7101
   If_Result_1 := Fld_1;
else
   --# expr-start 7104 '<Cast to BasicDecl at ast.py:13326>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:13326
--# expr-start 7103 '<at at ast.py:13326>' Get_Result /tmp/lal-23.0.0/ada/ast.py:13326
--# expr-start 7102 '<FieldAccess for all_env_elements_internal at ast.py:13326>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13326
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_env_elements_internal
Fld_2 := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7102
Get_Result := Get (Self, Fld_2, 0, True); 
--# expr-done 7103
   if Get_Result.Node = null
      or else Get_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Get_Result.Node,
         Info => Get_Result.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 7104
   If_Result_1 := Cast_Result_1;
end if;
--# expr-done 7105
Let_Result := If_Result_1; 
--# end
--# expr-done 7106
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1003;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1003;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_First_Corresponding_Decl;
--# end
--# property-start Name.all_args_xref_equation /tmp/lal-23.0.0/ada/ast.py:13330
pragma Warnings (Off, "is not referenced");
 function Name_P_All_Args_Xref_Equation
  (Node : Bare_Name
      ; Root : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1004 with Inline_Always;
            procedure Finalizer_Scope_2754 with Inline_Always;
            procedure Finalizer_Scope_2755 with Inline_Always;
            procedure Finalizer_Scope_2756 with Inline_Always;
            procedure Finalizer_Scope_2757 with Inline_Always;
      Var_Expr : Internal_Entity_Call_Expr;
Var_Expr_1 : Internal_Entity_Assoc_List;
Var_Expr_2 : Internal_Entity_Name;
Cast_Expr : Internal_Entity_Name;
Cast_Result : Internal_Entity_Call_Expr;
Fld : Internal_Entity_Assoc_List;
Saved : Internal_Entity_Assoc_List;
Fld_1 : Bare_Assoc_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
Item_242 : Internal_Entity_Basic_Assoc;
Bare_Item_242 : Bare_Basic_Assoc;
Map_Result : Logic_Equation_Array_Access;
Scope_Result : Logic_Equation_Array_Access;
Result_Var : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var_1 : Logic_Equation;
Fld_5 : Internal_Entity_Name;
Fld_6 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_2 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1004 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1004;
            procedure Finalizer_Scope_2754 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_2754;
            procedure Finalizer_Scope_2755 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2755;
            procedure Finalizer_Scope_2756 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2756;
            procedure Finalizer_Scope_2757 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2757;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7116 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7115 '<And at ast.py:13339>' And_Pred /tmp/lal-23.0.0/ada/ast.py:13339
--# expr-start 7107 '<Cast to CallExpr at ast.py:13339>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13339
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result := Create_Internal_Entity_Call_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Call_Expr;
   end if;
--# expr-done 7107
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Call_Expr then
   --# scope-start
   --# bind ce Var_Expr
--# expr-start 7112 '<LogicAll at ast.py:13340>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:13340
--# expr-start 7108 '<FieldAccess for params at ast.py:13340>' Fld /tmp/lal-23.0.0/ada/ast.py:13340
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld := Libadalang.Implementation.Call_Expr_P_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7108
Var_Expr_1 := Fld;
if Var_Expr_1 /= No_Entity_Assoc_List then
   --# scope-start
--# expr-start 7111 '<Map at ast.py:13340>' Map_Result /tmp/lal-23.0.0/ada/ast.py:13340
Saved := Var_Expr_1; 
Fld_1 := Saved.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_1;
      begin
         for Untyped_Item_242 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_242 := Untyped_Item_242; 
Is_Null := Bare_Item_242 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_2 := Saved.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_242); 
   If_Result := As_Entity;
end if;
                  Item_242 := If_Result; 
   --# scope-start
               --# bind pa Item_242
      --# expr-start 7110 '<FieldAccess for sub_equation at ast.py:13341>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13341
--# expr-start 7109 '<FieldAccess for expr at ast.py:13341>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13341
      if Item_242.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_242.Node, E_Info => Item_242.Info);
--# end
--# expr-done 7109
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 7110
         declare
            Item_To_Append : constant Logic_Equation := Fld_4;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2756;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 7111
Scope_Result := Map_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2755;
   Result_Var := Scope_Result;
else
   Result_Var := No_Logic_Equation_Array_Type;
end if;
      Inc_Ref (Result_Var);
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Result_Var.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13340") else null)); 
--# expr-done 7112
Scope_Result_1 := Logic_Boolean_Op;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2754;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13343") else null)); 
   Result_Var_1 := True_Rel;
end if;
      Inc_Ref (Result_Var_1);
--# expr-start 7113 '<FieldAccess for parent_name at ast.py:13344>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13344
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_5 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 7113
Var_Expr_2 := Fld_5;
if Var_Expr_2 /= No_Entity_Name then
   --# scope-start
   --# bind name Var_Expr_2
--# expr-start 7114 '<FieldAccess for all_args_xref_equation at ast.py:13345>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13345
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_args_xref_equation
Fld_6 := Libadalang.Implementation.Name_P_All_Args_Xref_Equation (Node => Var_Expr_2.Node, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 7114
Scope_Result_2 := Fld_6;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2757;
   Result_Var_2 := Scope_Result_2;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13346") else null)); 
   Result_Var_2 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_2);
And_Pred := Create_And (Result_Var_1, Result_Var_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13339") else null)); 
--# expr-done 7115
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 7116
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1004;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1004;
               Finalizer_Scope_2754;
               Finalizer_Scope_2755;
               Finalizer_Scope_2756;
               Finalizer_Scope_2757;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_All_Args_Xref_Equation;
--# end
--# property-start Name.bottom_up_name_equation /tmp/lal-23.0.0/ada/ast.py:13350
pragma Warnings (Off, "is not referenced");
 function Name_P_Bottom_Up_Name_Equation
  (Node : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1005 with Inline_Always;
            procedure Finalizer_Scope_2758 with Inline_Always;
            procedure Finalizer_Scope_2759 with Inline_Always;
            procedure Finalizer_Scope_2760 with Inline_Always;
            procedure Finalizer_Scope_2761 with Inline_Always;
      Match_0 : Internal_Entity_Call_Expr;
Match_1 : Internal_Entity_Explicit_Deref;
Match_2 : Internal_Entity_Qual_Expr;
Match_3 : Internal_Entity_Name;
Fld : Bare_Name;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Equation;
Fld_3 : Logic_Equation;
False_Rel : Logic_Equation;
Match_Prefix : Internal_Entity_Name;
Cast_Result : Internal_Entity_Call_Expr;
Let_Result : Logic_Equation;
Scope_Result : Logic_Equation;
Cast_Result_1 : Internal_Entity_Explicit_Deref;
Let_Result_1 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_2 : Internal_Entity_Qual_Expr;
Let_Result_2 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_3 : Internal_Entity_Name;
Let_Result_3 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Match_Result : Logic_Equation;
Let_Result_4 : Logic_Equation;
            procedure Finalizer_Scope_1005 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1005;
            procedure Finalizer_Scope_2758 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2758;
            procedure Finalizer_Scope_2759 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2759;
            procedure Finalizer_Scope_2760 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2760;
            procedure Finalizer_Scope_2761 is
            begin
                     Dec_Ref (False_Rel);
            end Finalizer_Scope_2761;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7123 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 7122 '<Match at ast.py:13351>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13351
--# expr-start 7118 '<as_entity at ast.py:13351>' If_Result /tmp/lal-23.0.0/ada/ast.py:13351
--# expr-start 7117 '<FieldAccess for innermost_name at ast.py:13351>' Fld /tmp/lal-23.0.0/ada/ast.py:13351
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.innermost_name
Fld := Libadalang.Implementation.Name_P_Innermost_Name (Node => Self);
--# end
--# expr-done 7117
Is_Null := Fld = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
As_Entity := (Info => E_Info, Node => Fld); 
   If_Result := As_Entity;
end if;
--# expr-done 7118
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := If_Result; 
case Ada_Name (Match_Prefix.Node.Kind) is
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind ce Match_0
--# expr-start 7119 '<FieldAccess for general_xref_equation at ast.py:13352>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13352
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.general_xref_equation
Fld_1 := Libadalang.Implementation.Call_Expr_P_General_Xref_Equation (Node => Match_0.Node, Root => Self, Env => Env, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 7119
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2758;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Explicit_Deref =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Explicit_Deref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind ed Match_1
--# expr-start 7120 '<FieldAccess for general_xref_equation at ast.py:13353>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13353
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ExplicitDeref.general_xref_equation
Fld_2 := Libadalang.Implementation.Explicit_Deref_P_General_Xref_Equation (Node => Match_1.Node, Root => Self, Env => Env, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 7120
Let_Result_1 := Fld_2; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2759;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Qual_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Qual_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind qe Match_2
--# expr-start 7121 '<FieldAccess for general_xref_equation at ast.py:13354>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13354
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start QualExpr.general_xref_equation
Fld_3 := Libadalang.Implementation.Qual_Expr_P_General_Xref_Equation (Node => Match_2.Node, Root => Self, Env => Env, Origin => Origin, E_Info => Match_2.Info);
--# end
--# expr-done 7121
Let_Result_2 := Fld_3; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2760;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref | Ada_Defining_Name .. Ada_End_Name | Ada_Reduce_Attribute_Ref .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_3; 
--# bind _ Match_3
False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13355") else null)); 
Let_Result_3 := False_Rel; Inc_Ref (Let_Result_3);
--# end
Scope_Result_3 := Let_Result_3;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2761;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
end case;
--# expr-done 7122
Let_Result_4 := Match_Result; Inc_Ref (Let_Result_4);
--# end
--# expr-done 7123
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1005;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1005;
               Finalizer_Scope_2758;
               Finalizer_Scope_2759;
               Finalizer_Scope_2760;
               Finalizer_Scope_2761;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Bottom_Up_Name_Equation;
--# end
--# property-start Name.innermost_name /tmp/lal-23.0.0/ada/ast.py:13359
pragma Warnings (Off, "is not referenced");
 function Name_P_Innermost_Name
  (Node : Bare_Name
  )
   return Bare_Name
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Name;
      Block_Var : Bare_Name;
Match_0 : Bare_Call_Expr;
Match_1 : Bare_Explicit_Deref;
Match_2 : Bare_Name;
Fld : Bare_Name;
Fld_1 : Bare_Name;
Match_Prefix : Bare_Name;
Cast_Result : Bare_Call_Expr;
Let_Result : Bare_Name;
Scope_Result : Bare_Name;
Cast_Result_1 : Bare_Explicit_Deref;
Let_Result_1 : Bare_Name;
Scope_Result_1 : Bare_Name;
Cast_Result_2 : Bare_Name;
Let_Result_2 : Bare_Name;
Scope_Result_2 : Bare_Name;
Match_Result : Bare_Name;
Is_A : Boolean;
Fld_2 : Bare_Name;
Is_A_1 : Boolean;
If_Result : Bare_Name;
If_Result_1 : Bare_Name;
Let_Result_3 : Bare_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7131 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 7126 '<Match at ast.py:13372>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13372
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Name (Match_Prefix.Kind) is
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind ce Match_0
--# expr-start 7124 '<FieldAccess for name at ast.py:13373>' Fld /tmp/lal-23.0.0/ada/ast.py:13373
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Match_0.Call_Expr_F_Name;
--# expr-done 7124
Let_Result := Fld; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Explicit_Deref =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind ed Match_1
--# expr-start 7125 '<FieldAccess for prefix at ast.py:13374>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13374
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Match_1.Explicit_Deref_F_Prefix;
--# expr-done 7125
Let_Result_1 := Fld_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Attribute_Ref | Ada_Defining_Name .. Ada_End_Name | Ada_Qual_Expr .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Bare_Ada_Node; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 7126
Block_Var := Match_Result; 
--# bind name Block_Var
--# expr-start 7130 '<Cond at ast.py:13379>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:13379
--# expr-start 7127 '<IsA CallExpr, ExplicitDeref at ast.py:13380>' Is_A /tmp/lal-23.0.0/ada/ast.py:13380
Is_A := Block_Var /= null 
and then Block_Var.Kind in Ada_Call_Expr_Range | Ada_Explicit_Deref_Range; 
--# expr-done 7127
if Is_A then
   --# expr-start 7128 '<FieldAccess for innermost_name at ast.py:13380>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13380
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.innermost_name
Fld_2 := Libadalang.Implementation.Name_P_Innermost_Name (Node => Block_Var);
--# end
--# expr-done 7128
   If_Result_1 := Fld_2;
else
--# expr-start 7129 '<IsA QualExpr at ast.py:13381>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13381
Is_A_1 := Block_Var /= null 
and then Block_Var.Kind in Ada_Qual_Expr_Range; 
--# expr-done 7129
if Is_A_1 then
   If_Result := Block_Var;
else
   If_Result := Self;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 7130
Let_Result_3 := If_Result_1; 
--# end
--# expr-done 7131
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Innermost_Name;
--# end
--# property-start Name.parent_name_equation /tmp/lal-23.0.0/ada/ast.py:13386
pragma Warnings (Off, "is not referenced");
 function Name_P_Parent_Name_Equation
  (Node : Bare_Name
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Root : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1007 with Inline_Always;
            procedure Finalizer_Scope_2771 with Inline_Always;
            procedure Finalizer_Scope_2772 with Inline_Always;
            procedure Finalizer_Scope_2774 with Inline_Always;
            procedure Finalizer_Scope_2775 with Inline_Always;
      Block_Var : Internal_Entity_Access_To_Subp_Def;
Block_Var_1 : Boolean;
Block_Var_2 : Boolean;
Block_Var_3 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Access_To_Subp_Def;
Var_Expr_2 : Internal_Entity_Access_To_Subp_Def;
Var_Expr_3 : Internal_Entity_Base_Type_Decl;
Var_Expr_4 : Internal_Entity_Base_Type_Decl;
Var_Expr_5 : Internal_Entity_Base_Type_Decl;
Match_0 : Bare_Call_Expr;
Match_1 : Bare_Explicit_Deref;
Match_2 : Bare_Name;
Var_Expr_6 : Internal_Entity_Access_To_Subp_Def;
Var_Expr_7 : Internal_Entity_Name;
Var_Expr_8 : Internal_Entity_Call_Expr;
Fld : Internal_Entity_Access_Def;
Scope_Result : Internal_Entity_Access_Def;
Result_Var : Internal_Entity_Access_Def;
Cast_Result : Internal_Entity_Access_To_Subp_Def;
Fld_1 : Internal_Entity_Subp_Spec;
Fld_2 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Fld_3 : Internal_Entity_Subp_Spec;
Fld_4 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Fld_5 : Internal_Entity_Base_Type_Decl;
Scope_Result_3 : Internal_Entity_Base_Type_Decl;
Result_Var_3 : Internal_Entity_Base_Type_Decl;
Is_A : Boolean;
Not_Val : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_4 : Internal_Entity_Base_Type_Decl;
Fld_7 : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
False_Rel : Logic_Equation;
As_Entity : Internal_Entity_Call_Expr;
Is_Null : Boolean;
If_Result_1 : Internal_Entity_Call_Expr;
Fld_8 : Logic_Equation;
As_Entity_1 : Internal_Entity_Explicit_Deref;
Is_Null_1 : Boolean;
If_Result_2 : Internal_Entity_Explicit_Deref;
Fld_9 : Logic_Equation;
Fld_10 : Logic_Var;
Fld_11 : Internal_Entity_Subp_Spec;
Scope_Result_6 : Internal_Entity_Subp_Spec;
Result_Var_6 : Internal_Entity_Subp_Spec;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_12 : Logic_Var;
Fld_13 : Bare_Ada_Node;
As_Entity_2 : Internal_Entity;
Is_Null_2 : Boolean;
If_Result_3 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Match_Prefix : Bare_Name;
Cast_Result_2 : Bare_Call_Expr;
Let_Result : Logic_Equation;
Scope_Result_7 : Logic_Equation;
Cast_Result_3 : Bare_Explicit_Deref;
Let_Result_1 : Logic_Equation;
Scope_Result_8 : Logic_Equation;
Cast_Result_4 : Bare_Name;
Let_Result_2 : Logic_Equation;
Scope_Result_9 : Logic_Equation;
Match_Result : Logic_Equation;
Fld_14 : Internal_Entity_Name;
Is_A_1 : Boolean;
Is_Null_3 : Boolean;
Not_Val_1 : Boolean;
If_Result_4 : Boolean;
Fld_15 : Logic_Equation;
Fld_16 : Logic_Equation;
Fld_17 : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_18 : Logic_Equation;
If_Result_5 : Logic_Equation;
If_Result_6 : Logic_Equation;
Cast_Expr : Internal_Entity_Name;
Cast_Result_5 : Internal_Entity_Call_Expr;
Fld_19 : Boolean;
Scope_Result_10 : Boolean;
Result_Var_7 : Boolean;
Fld_20 : Logic_Equation;
Fld_21 : Logic_Equation;
If_Result_7 : Logic_Equation;
If_Result_8 : Logic_Equation;
Scope_Result_11 : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var_8 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Is_Null_4 : Boolean;
If_Result_9 : Logic_Equation;
Let_Result_3 : Logic_Equation;
            procedure Finalizer_Scope_1007 is
            begin
                     Dec_Ref (False_Rel);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_8);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_9);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Scope_Result_11);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var_8);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_1007;
            procedure Finalizer_Scope_2771 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_2771;
            procedure Finalizer_Scope_2772 is
            begin
                     Dec_Ref (Fld_9);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_2772;
            procedure Finalizer_Scope_2774 is
            begin
                     Dec_Ref (Bind_Result_1);
            end Finalizer_Scope_2774;
            procedure Finalizer_Scope_2775 is
            begin
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Fld_18);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Fld_21);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (If_Result_8);
            end Finalizer_Scope_2775;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7174 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 7133 '<Cast to AccessToSubpDef at ast.py:13390>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13390
Var_Expr := Typ;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7132 '<FieldAccess for access_def at ast.py:13390>' Fld /tmp/lal-23.0.0/ada/ast.py:13390
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 7132
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Access_Def;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Access_To_Subp_Def_Range
   then
      Cast_Result := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result := No_Entity_Access_To_Subp_Def;
   end if;
--# expr-done 7133
Block_Var := Cast_Result; 
--# bind as_subp_access Block_Var
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Access_To_Subp_Def then
   --# scope-start
--# expr-start 7135 '<FieldAccess for paramless at ast.py:13391>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13391
--# expr-start 7134 '<FieldAccess for subp_spec at ast.py:13391>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13391
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr_1.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Var_Expr_1.Info);
--# expr-done 7134
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.paramless
Fld_2 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Paramless (Node => Fld_1.Node, Dottable_Subp => False, Can_Be => False);
--# end
--# expr-done 7135
Scope_Result_1 := Fld_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Block_Var_1 := Result_Var_1; 
--# bind is_paramless Block_Var_1
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Entity_Access_To_Subp_Def then
   --# scope-start
--# expr-start 7137 '<FieldAccess for paramless at ast.py:13395>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13395
--# expr-start 7136 '<FieldAccess for subp_spec at ast.py:13395>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13395
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr_2.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Var_Expr_2.Info);
--# expr-done 7136
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.paramless
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Paramless (Node => Fld_3.Node, Dottable_Subp => False, Can_Be => True);
--# end
--# expr-done 7137
Scope_Result_2 := Fld_4;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
Block_Var_2 := Result_Var_2; 
--# bind can_be_paramless Block_Var_2
--# expr-start 7143 '<If at ast.py:13399>' If_Result /tmp/lal-23.0.0/ada/ast.py:13399
Var_Expr_3 := Typ;
if Var_Expr_3 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7138 '<FieldAccess for is_iterable_type at ast.py:13403>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13403
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => Var_Expr_3.Node, Origin => Origin, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 7138
Scope_Result_5 := Fld_7;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
if Result_Var_5 then
Var_Expr_4 := Typ;
if Var_Expr_4 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7139 '<FieldAccess for iterable_comp_type at ast.py:13404>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13404
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => Var_Expr_4.Node, Origin => Origin, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 7139
Scope_Result_3 := Fld_5;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Entity_Base_Type_Decl;
end if;
   If_Result := Result_Var_3;
else
Var_Expr_5 := Typ;
if Var_Expr_5 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7142 '<FieldAccess for comp_type at ast.py:13405>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13405
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7141 '<Not at ast.py:13405>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13405
--# expr-start 7140 '<IsA ExplicitDeref at ast.py:13405>' Is_A /tmp/lal-23.0.0/ada/ast.py:13405
Is_A := Self /= null 
and then Self.Kind in Ada_Explicit_Deref_Range; 
--# expr-done 7140
Not_Val := not (Is_A); 
--# expr-done 7141
--# property-call-start BaseTypeDecl.comp_type
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Var_Expr_5.Node, Is_Subscript => Not_Val, Origin => Origin, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 7142
Scope_Result_4 := Fld_6;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Base_Type_Decl;
end if;
   If_Result := Result_Var_4;
end if;
--# expr-done 7143
Block_Var_3 := If_Result; 
--# bind comp_type Block_Var_3
--# expr-start 7173 '<If at ast.py:13407>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:13407
--# expr-start 7144 '<IsNull at ast.py:13408>' Is_Null_4 /tmp/lal-23.0.0/ada/ast.py:13408
Is_Null_4 := Typ.Node = null; 
--# expr-done 7144
if Is_Null_4 then
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13409") else null)); 
   If_Result_9 := False_Rel;
else
   --# expr-start 7172 '<And at ast.py:13411>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:13411
--# expr-start 7156 '<Match at ast.py:13411>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13411
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Name (Match_Prefix.Kind) is
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_0 := Cast_Result_2; 
--# bind ce Match_0
--# expr-start 7146 '<FieldAccess for subscriptable_type_equation at ast.py:13413>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13413
--# expr-start 7145 '<as_entity at ast.py:13413>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:13413
Is_Null := Match_0 = null; 
if Is_Null then
   If_Result_1 := No_Entity_Call_Expr;
else
As_Entity := (Info => E_Info, Node => Match_0); 
   If_Result_1 := As_Entity;
end if;
--# expr-done 7145
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.subscriptable_type_equation
Fld_8 := Libadalang.Implementation.Call_Expr_P_Subscriptable_Type_Equation (Node => If_Result_1.Node, Typ => Typ, Env => Env, Origin => Origin, E_Info => If_Result_1.Info);
--# end
--# expr-done 7146
Let_Result := Fld_8; Inc_Ref (Let_Result);
--# end
Scope_Result_7 := Let_Result;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_2771;
            Match_Result := Scope_Result_7; Inc_Ref (Match_Result);
         when Ada_Explicit_Deref =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_1 := Cast_Result_3; 
--# bind ed Match_1
--# expr-start 7152 '<And at ast.py:13416>' And_Pred /tmp/lal-23.0.0/ada/ast.py:13416
--# expr-start 7148 '<FieldAccess for eq_for_type at ast.py:13416>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13416
--# expr-start 7147 '<as_entity at ast.py:13416>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:13416
Is_Null_1 := Match_1 = null; 
if Is_Null_1 then
   If_Result_2 := No_Entity_Explicit_Deref;
else
As_Entity_1 := (Info => E_Info, Node => Match_1); 
   If_Result_2 := As_Entity_1;
end if;
--# expr-done 7147
      if If_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ExplicitDeref.eq_for_type
Fld_9 := Libadalang.Implementation.Explicit_Deref_P_Eq_For_Type (Node => If_Result_2.Node, Typ => Typ, Env => Env, Origin => Origin, E_Info => If_Result_2.Info);
--# end
--# expr-done 7148
--# expr-start 7151 '<Bind at ast.py:13421>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:13421
--# expr-start 7149 '<FieldAccess for subp_spec_var at ast.py:13421>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13421
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_10 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Self);
--# end
--# expr-done 7149
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Var_Expr_6 := Block_Var;
if Var_Expr_6 /= No_Entity_Access_To_Subp_Def then
   --# scope-start
--# expr-start 7150 '<FieldAccess for subp_spec at ast.py:13421>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13421
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr_6.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Var_Expr_6.Info);
--# expr-done 7150
Scope_Result_6 := Fld_11;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Subp_Spec;
end if;
      Cast_Result_1 := Create_Internal_Entity
        (Node => Result_Var_6.Node,
         Info => Result_Var_6.Info);
Bind_Result := Solver.Create_Assign (Fld_10, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13421") else null)); 
--# expr-done 7151
And_Pred := Create_And (Fld_9, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13416") else null)); 
--# expr-done 7152
Let_Result_1 := And_Pred; Inc_Ref (Let_Result_1);
--# end
Scope_Result_8 := Let_Result_1;
   Inc_Ref (Scope_Result_8);
   --# end
      Finalizer_Scope_2772;
            Match_Result := Scope_Result_8; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref | Ada_Defining_Name .. Ada_End_Name | Ada_Qual_Expr .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix;
Match_2 := Cast_Result_4; 
--# bind _ Match_2
--# expr-start 7155 '<Bind at ast.py:13423>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:13423
--# expr-start 7153 '<FieldAccess for type_var at ast.py:13423>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13423
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 7153
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
--# expr-start 7154 '<FieldAccess for node at ast.py:13423>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:13423
Fld_13 := No_Entity.Node;
--# expr-done 7154
Is_Null_2 := Fld_13 = null; 
if Is_Null_2 then
   If_Result_3 := No_Entity;
else
As_Entity_2 := (Info => E_Info, Node => Fld_13); 
   If_Result_3 := As_Entity_2;
end if;
Bind_Result_1 := Solver.Create_Assign (Fld_12, If_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13423") else null)); 
--# expr-done 7155
Let_Result_2 := Bind_Result_1; Inc_Ref (Let_Result_2);
--# end
Scope_Result_9 := Let_Result_2;
   Inc_Ref (Scope_Result_9);
   --# end
      Finalizer_Scope_2774;
            Match_Result := Scope_Result_9; Inc_Ref (Match_Result);
end case;
--# expr-done 7156
--# expr-start 7157 '<FieldAccess for parent_name at ast.py:13424>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:13424
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_14 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 7157
Var_Expr_7 := Fld_14;
if Var_Expr_7 /= No_Entity_Name then
   --# scope-start
   --# bind pn Var_Expr_7
--# expr-start 7171 '<Cond at ast.py:13425>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:13425
--# expr-start 7158 '<IsA ExplicitDeref at ast.py:13426>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13426
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Explicit_Deref_Range; 
--# expr-done 7158
if Is_A_1 then
   --# expr-start 7160 '<Not at ast.py:13426>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:13426
--# expr-start 7159 '<IsNull at ast.py:13426>' Is_Null_3 /tmp/lal-23.0.0/ada/ast.py:13426
Is_Null_3 := Block_Var.Node = null; 
--# expr-done 7159
Not_Val_1 := not (Is_Null_3); 
--# expr-done 7160
   If_Result_4 := Not_Val_1;
else
   If_Result_4 := False;
end if;
if If_Result_4 then
   --# expr-start 7166 '<Cond at ast.py:13430>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:13430
if Block_Var_1 then
   --# expr-start 7161 '<FieldAccess for parent_name_equation at ast.py:13436>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:13436
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_15 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_7.Node, Typ => Block_Var_3, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 7161
   If_Result_6 := Fld_15;
else
if Block_Var_2 then
   --# expr-start 7164 '<Or at ast.py:13443>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:13443
--# expr-start 7162 '<FieldAccess for parent_name_equation at ast.py:13444>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:13444
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_16 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_7.Node, Typ => Block_Var_3, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 7162
--# expr-start 7163 '<FieldAccess for parent_name_equation at ast.py:13445>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:13445
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_17 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_7.Node, Typ => Typ, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 7163
Or_Pred := Create_Or (Fld_16, Fld_17, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13443") else null)); 
--# expr-done 7164
   If_Result_5 := Or_Pred;
else
   --# expr-start 7165 '<FieldAccess for parent_name_equation at ast.py:13451>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:13451
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_18 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_7.Node, Typ => Typ, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 7165
   If_Result_5 := Fld_18;
end if;
      Inc_Ref (If_Result_5);
   If_Result_6 := If_Result_5;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 7166
   If_Result_8 := If_Result_6;
else
--# expr-start 7167 '<Cast to CallExpr at ast.py:13455>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:13455
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Call_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_5 := No_Entity_Call_Expr;
   end if;
--# expr-done 7167
Var_Expr_8 := Cast_Result_5;
if Var_Expr_8 /= No_Entity_Call_Expr then
   --# scope-start
--# expr-start 7168 '<FieldAccess for check_array_slice at ast.py:13455>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:13455
      if Var_Expr_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.check_array_slice
Fld_19 := Libadalang.Implementation.Call_Expr_P_Check_Array_Slice (Node => Var_Expr_8.Node, Typ => Typ, Origin => Origin, E_Info => Var_Expr_8.Info);
--# end
--# expr-done 7168
Scope_Result_10 := Fld_19;
   --# end
   Result_Var_7 := Scope_Result_10;
else
   Result_Var_7 := False;
end if;
if Result_Var_7 then
   --# expr-start 7169 '<FieldAccess for parent_name_equation at ast.py:13456>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:13456
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_20 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_7.Node, Typ => Typ, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 7169
   If_Result_7 := Fld_20;
else
   --# expr-start 7170 '<FieldAccess for parent_name_equation at ast.py:13460>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:13460
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_21 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_7.Node, Typ => Block_Var_3, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 7170
   If_Result_7 := Fld_21;
end if;
      Inc_Ref (If_Result_7);
   If_Result_8 := If_Result_7;
end if;
      Inc_Ref (If_Result_8);
--# expr-done 7171
Scope_Result_11 := If_Result_8;
   Inc_Ref (Scope_Result_11);
   --# end
      Finalizer_Scope_2775;
   Result_Var_8 := Scope_Result_11;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13462") else null)); 
   Result_Var_8 := True_Rel;
end if;
      Inc_Ref (Result_Var_8);
And_Pred_1 := Create_And (Match_Result, Result_Var_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13411") else null)); 
--# expr-done 7172
   If_Result_9 := And_Pred_1;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 7173
Let_Result_3 := If_Result_9; Inc_Ref (Let_Result_3);
--# end
--# expr-done 7174
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1007;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1007;
               Finalizer_Scope_2771;
               Finalizer_Scope_2772;
               Finalizer_Scope_2774;
               Finalizer_Scope_2775;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Parent_Name_Equation;
--# end
--# property-start Name.subtype_indication_equation /tmp/lal-23.0.0/ada/ast.py:13467
pragma Warnings (Off, "is not referenced");
 function Name_P_Subtype_Indication_Equation
  (Node : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1008 with Inline_Always;
      Fld : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1008 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1008;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7176 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7175 '<FieldAccess for xref_no_overloading at ast.py:13468>' Fld /tmp/lal-23.0.0/ada/ast.py:13468
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7175
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 7176
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1008;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1008;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Subtype_Indication_Equation;
--# end
--# property-start Name.can_designate_primitive /tmp/lal-23.0.0/ada/ast.py:13471
pragma Warnings (Off, "is not referenced");
 function Name_P_Can_Designate_Primitive
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Match_0 : Bare_Name;
Match_1 : Bare_Renaming_Clause;
Match_2 : Bare_Ada_Node;
Fld : Bare_Ada_Node;
Fld_1 : Boolean;
Fld_2 : Bare_Ada_Node;
Is_A : Boolean;
Not_Val : Boolean;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Name;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Bare_Renaming_Clause;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_2 : Bare_Ada_Node;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
Let_Result_3 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7183 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 7182 '<Match at ast.py:13480>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13480
--# expr-start 7177 '<parent at ast.py:13480>' Fld /tmp/lal-23.0.0/ada/ast.py:13480
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 7177
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Attribute_Ref .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind n Match_0
--# expr-start 7178 '<FieldAccess for can_designate_primitive at ast.py:13481>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13481
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.can_designate_primitive
Fld_1 := Libadalang.Implementation.Name_P_Can_Designate_Primitive (Node => Match_0);
--# end
--# expr-done 7178
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Renaming_Clause .. Ada_Synthetic_Renaming_Clause =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind r Match_1
--# expr-start 7181 '<Not at ast.py:13482>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13482
--# expr-start 7180 '<IsA PackageRenamingDecl at ast.py:13482>' Is_A /tmp/lal-23.0.0/ada/ast.py:13482
--# expr-start 7179 '<parent at ast.py:13482>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13482
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Match_1.Parent; 
--# expr-done 7179
Is_A := Fld_2 /= null 
and then Fld_2.Kind in Ada_Package_Renaming_Decl_Range; 
--# expr-done 7180
Not_Val := not (Is_A); 
--# expr-done 7181
Let_Result_1 := Not_Val; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Range_Spec | Ada_Reverse_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := True; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 7182
Let_Result_3 := Match_Result; 
--# end
--# expr-done 7183
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Can_Designate_Primitive;
--# end
--# property-start Name.parent_name /tmp/lal-23.0.0/ada/ast.py:13487
pragma Warnings (Off, "is not referenced");
 function Name_P_Parent_Name
  (Node : Bare_Name
      ; Stop_At : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind stop_at Stop_At
   Property_Result : Internal_Entity_Name;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Name;
Is_Null : Boolean;
Cast_Expr : Bare_Name;
Cast_Result_1 : Bare_Name;
Is_Equal : Boolean;
If_Result : Boolean;
If_Result_1 : Internal_Entity_Name;
Let_Result : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7189 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7188 '<If at ast.py:13491>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:13491
--# expr-start 7184 '<IsNull at ast.py:13491>' Is_Null /tmp/lal-23.0.0/ada/ast.py:13491
Is_Null := Stop_At = null; 
--# expr-done 7184
if Is_Null then
   If_Result := True;
else
   --# expr-start 7185 '<Eq at ast.py:13491>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13491
Cast_Expr := Self; 
      Cast_Result_1 := Cast_Expr;
Is_Equal := Cast_Result_1 = Stop_At; 
--# expr-done 7185
   If_Result := Is_Equal;
end if;
if If_Result then
   If_Result_1 := No_Entity_Name;
else
   --# expr-start 7187 '<Cast to Name at ast.py:13493>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13493
--# expr-start 7186 '<parent at ast.py:13493>' Fld /tmp/lal-23.0.0/ada/ast.py:13493
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 7186
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 7187
   If_Result_1 := Cast_Result;
end if;
--# expr-done 7188
Let_Result := If_Result_1; 
--# end
--# expr-done 7189
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Parent_Name;
--# end
--# property-start Name.parent_callexpr /tmp/lal-23.0.0/ada/ast.py:13496
pragma Warnings (Off, "is not referenced");
 function Name_P_Parent_Callexpr
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Call_Expr
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Call_Expr;
            procedure Finalizer_Scope_1011 with Inline_Always;
      Match_0 : Internal_Entity_Dotted_Name;
Match_1 : Internal_Entity_Call_Expr;
Match_2 : Internal_Entity;
Fld : Internal_Entity_Array_Access;
Is_A : Boolean;
Is_A_1 : Boolean;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity_Base_Id;
Cast_Result : Internal_Entity;
Is_Equiv : Boolean;
Fld_3 : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity;
Is_Equiv_1 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result_2 : Internal_Entity_Dotted_Name;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_3 : Internal_Entity_Call_Expr;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_4 : Internal_Entity;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Map_Result : Internal_Entity_Array_Access;
Is_A_2 : Boolean;
Find_Result : Internal_Entity;
Cast_Result_5 : Internal_Entity_Call_Expr;
Let_Result_3 : Internal_Entity_Call_Expr;
            procedure Finalizer_Scope_1011 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1011;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7203 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 7202 '<Cast to CallExpr at ast.py:13520>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:13520
--# expr-start 7201 '<Find at ast.py:13520>' Find_Result /tmp/lal-23.0.0/ada/ast.py:13520
   --# expr-start 7199 '<TakeWhile at ast.py:13513>' Map_Result /tmp/lal-23.0.0/ada/ast.py:13513
   --# expr-start 7190 '<FieldAccess for parents at ast.py:13513>' Fld /tmp/lal-23.0.0/ada/ast.py:13513
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parents (Node => Ent.Node, With_Self => True, E_Info => Ent.Info);
--# expr-done 7190
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
            Take_While_Ok : Boolean := False;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_244 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_244
--# expr-start 7191 '<IsA CallExpr at ast.py:13514>' Is_A /tmp/lal-23.0.0/ada/ast.py:13514
Is_A := Item_244.Node /= null 
and then Item_244.Node.Kind in Ada_Call_Expr_Range; 
--# expr-done 7191
if Is_A then
   If_Result_1 := True;
else
--# expr-start 7192 '<IsA DottedName, BaseId at ast.py:13515>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13515
Is_A_1 := Item_244.Node /= null 
and then Item_244.Node.Kind in Ada_Dotted_Name_Range | Ada_Base_Id; 
--# expr-done 7192
if Is_A_1 then
   --# expr-start 7198 '<Match at ast.py:13515>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13515
--# expr-start 7193 '<parent at ast.py:13515>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13515
      if Item_244.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Item_244.Node, E_Info => Item_244.Info);
--# expr-done 7193
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_1; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Dotted_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind pfx Match_0
--# expr-start 7195 '<Eq at ast.py:13516>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:13516
--# expr-start 7194 '<FieldAccess for suffix at ast.py:13516>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13516
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Id (Node => Match_0.Node.Dotted_Name_F_Suffix, Info => Match_0.Info);
--# expr-done 7194
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Is_Equiv := Equivalent (Cast_Result, Item_244); 
--# expr-done 7195
Let_Result := Is_Equiv; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind ce Match_1
--# expr-start 7197 '<Eq at ast.py:13517>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:13517
--# expr-start 7196 '<FieldAccess for name at ast.py:13517>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13517
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Match_1.Node.Call_Expr_F_Name, Info => Match_1.Info);
--# expr-done 7196
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Is_Equiv_1 := Equivalent (Cast_Result_1, Item_244); 
--# expr-done 7197
Let_Result_1 := Is_Equiv_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Attribute_Ref | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
Let_Result_2 := False; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 7198
   If_Result := Match_Result;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
end if;
         Take_While_Ok := If_Result_1;
         if Take_While_Ok then
         declare
            Item_To_Append : constant Internal_Entity := Item_244;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
               exit when not Take_While_Ok;
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 7199
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result;
      begin
         for Item_243 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_243
      --# expr-start 7200 '<IsA CallExpr at ast.py:13520>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:13520
Is_A_2 := Item_243.Node /= null 
and then Item_243.Node.Kind in Ada_Call_Expr_Range; 
--# expr-done 7200
      if Is_A_2 then
         Find_Result := Item_243;
      end if;
   --# end
               exit when Is_A_2;
         end loop;
      end;
--# expr-done 7201
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Call_Expr
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_5 := No_Entity_Call_Expr;
   end if;
--# expr-done 7202
Let_Result_3 := Cast_Result_5; 
--# end
--# expr-done 7203
      Property_Result := Let_Result_3;
   --# end
      Finalizer_Scope_1011;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1011;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Parent_Callexpr;
--# end
--# property-start Name.is_range_attribute /tmp/lal-23.0.0/ada/ast.py:13523
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Range_Attribute
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Var_Expr : Bare_Attribute_Ref;
Cast_Expr : Bare_Name;
Cast_Result : Bare_Attribute_Ref;
As_Entity : Internal_Entity_Attribute_Ref;
Is_Null : Boolean;
If_Result : Internal_Entity_Attribute_Ref;
Fld : Internal_Entity_Identifier;
Sym : Symbol_Type;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7209 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7204 '<Cast to AttributeRef at ast.py:13527>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13527
Cast_Expr := Self; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 7204
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind attr_ref Var_Expr
--# expr-start 7208 '<FieldAccess for name_is at ast.py:13529>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13529
--# expr-start 7206 '<FieldAccess for attribute at ast.py:13529>' Fld /tmp/lal-23.0.0/ada/ast.py:13529
--# expr-start 7205 '<as_bare_entity at ast.py:13529>' If_Result /tmp/lal-23.0.0/ada/ast.py:13529
Is_Null := Var_Expr = null; 
if Is_Null then
   If_Result := No_Entity_Attribute_Ref;
else
As_Entity := (Info => No_Entity_Info, Node => Var_Expr); 
   If_Result := As_Entity;
end if;
--# expr-done 7205
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => If_Result.Node.Attribute_Ref_F_Attribute, Info => If_Result.Info);
--# expr-done 7206
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7207 '<Symbol Range at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range); 
--# expr-done 7207
--# property-call-start Name.name_is
Fld_1 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld.Node, Sym => Sym);
--# end
--# expr-done 7208
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 7209
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Range_Attribute;
--# end
--# property-start '[dispatcher]Name.scope' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Scope
  (Node : Bare_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref .. Ada_Call_Expr | Ada_Discrete_Subtype_Name | Ada_Explicit_Deref .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.scope
                  Property_Result := Name_P_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.scope
                  Property_Result := Defining_Name_P_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.scope
                  Property_Result := Dotted_Name_P_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.scope
                  Property_Result := End_Name_P_Scope
                    (Self
                        , Env
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.scope
                  Property_Result := Base_Id_P_Scope
                    (Self
                        , Env
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Scope;
--# end
--# property-start '[dispatcher]Name.ref_var' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Ref_Var
  (Node : Bare_Name
  )
   return Logic_Var
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Discrete_Subtype_Name | Ada_Synthetic_Identifier =>
                  --# property-call-start Name.ref_var
                  Property_Result := Name_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.ref_var
                  Property_Result := Attribute_Ref_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.ref_var
                  Property_Result := Call_Expr_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.ref_var
                  Property_Result := Defining_Name_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.ref_var
                  Property_Result := Dotted_Name_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.ref_var
                  Property_Result := End_Name_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.ref_var
                  Property_Result := Explicit_Deref_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Qual_Expr =>
                  --# property-call-start QualExpr.ref_var
                  Property_Result := Qual_Expr_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Reduce_Attribute_Ref =>
                  --# property-call-start ReduceAttributeRef.ref_var
                  Property_Result := Reduce_Attribute_Ref_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Char_Literal .. Ada_Real_Literal =>
                  --# property-call-start SingleTokNode.ref_var
                  Property_Result := Single_Tok_Node_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Target_Name =>
                  --# property-call-start TargetName.ref_var
                  Property_Result := Target_Name_P_Ref_Var
                    (Self
                    );
                  --# end
               when Ada_Update_Attribute_Ref =>
                  --# property-call-start UpdateAttributeRef.ref_var
                  Property_Result := Update_Attribute_Ref_P_Ref_Var
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Ref_Var;
--# end
--# property-start '[dispatcher]Name.subp_spec_var' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Subp_Spec_Var
  (Node : Bare_Name
  )
   return Logic_Var
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name | Ada_Qual_Expr .. Ada_Reduce_Attribute_Ref | Ada_Synthetic_Identifier .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.subp_spec_var
                  Property_Result := Name_P_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.subp_spec_var
                  Property_Result := Call_Expr_P_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.subp_spec_var
                  Property_Result := Dotted_Name_P_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.subp_spec_var
                  Property_Result := Explicit_Deref_P_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Char_Literal .. Ada_Real_Literal =>
                  --# property-call-start SingleTokNode.subp_spec_var
                  Property_Result := Single_Tok_Node_P_Subp_Spec_Var
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Subp_Spec_Var;
--# end
--# property-start '[dispatcher]Name.defines_subp_spec_var' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Defines_Subp_Spec_Var
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name | Ada_Qual_Expr .. Ada_Reduce_Attribute_Ref | Ada_Synthetic_Identifier .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.defines_subp_spec_var
                  Property_Result := Name_P_Defines_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.defines_subp_spec_var
                  Property_Result := Call_Expr_P_Defines_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.defines_subp_spec_var
                  Property_Result := Dotted_Name_P_Defines_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.defines_subp_spec_var
                  Property_Result := Explicit_Deref_P_Defines_Subp_Spec_Var
                    (Self
                    );
                  --# end
               when Ada_Char_Literal .. Ada_Real_Literal =>
                  --# property-call-start SingleTokNode.defines_subp_spec_var
                  Property_Result := Single_Tok_Node_P_Defines_Subp_Spec_Var
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Defines_Subp_Spec_Var;
--# end
--# property-start Name.called_subp_spec /tmp/lal-23.0.0/ada/ast.py:13575
pragma Warnings (Off, "is not referenced");
 function Name_P_Called_Subp_Spec
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Holder
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Holder;
      Cast_Expr : Internal_Entity_Name;
Cast_Result : Internal_Entity;
Fld : Logic_Var;
Fld_1 : Internal_Logic_Val_Result;
Fld_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_3 : Boolean;
If_Result : Internal_Entity_Base_Formal_Param_Holder;
Let_Result : Internal_Entity_Base_Formal_Param_Holder;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7216 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7215 '<If at ast.py:13580>' If_Result /tmp/lal-23.0.0/ada/ast.py:13580
--# expr-start 7210 '<FieldAccess for defines_subp_spec_var at ast.py:13581>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13581
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.defines_subp_spec_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Defines_Subp_Spec_Var (Node => Self);
--# end
--# expr-done 7210
if Fld_3 then
   --# expr-start 7214 '<Cast to BaseFormalParamHolder at ast.py:13585>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:13585
--# expr-start 7213 '<FieldAccess for value at ast.py:13585>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13585
--# expr-start 7212 '<FieldAccess for logic_val at ast.py:13582>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13582
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 7211 '<FieldAccess for subp_spec_var at ast.py:13584>' Fld /tmp/lal-23.0.0/ada/ast.py:13584
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Self);
--# end
--# expr-done 7211
--# property-call-start AdaNode.logic_val
Fld_1 := Libadalang.Implementation.Ada_Node_P_Logic_Val (Node => Self, From_Node => Cast_Result, Lvar => Fld);
--# end
--# expr-done 7212
Fld_2 := Fld_1.Value;
--# expr-done 7213
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Base_Formal_Param_Holder
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result_1 := No_Entity_Base_Formal_Param_Holder;
   end if;
--# expr-done 7214
   If_Result := Cast_Result_1;
else
   If_Result := No_Entity_Base_Formal_Param_Holder;
end if;
--# expr-done 7215
Let_Result := If_Result; 
--# end
--# expr-done 7216
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Called_Subp_Spec;
--# end
--# property-start Name.referenced_decl /tmp/lal-23.0.0/ada/ast.py:13591
pragma Warnings (Off, "is not referenced");
 function Name_P_Referenced_Decl
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Refd_Decl;
Fld_1 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7219 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7218 '<FieldAccess for decl at ast.py:13598>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13598
--# expr-start 7217 '<FieldAccess for referenced_decl_internal at ast.py:13598>' Fld /tmp/lal-23.0.0/ada/ast.py:13598
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl_internal
Fld := Libadalang.Implementation.Name_P_Referenced_Decl_Internal (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7217
Fld_1 := Fld.Decl;
--# expr-done 7218
Let_Result := Fld_1; 
--# end
--# expr-done 7219
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Referenced_Decl;
--# end
--# property-start Name.failsafe_referenced_decl /tmp/lal-23.0.0/ada/ast.py:13602
pragma Warnings (Off, "is not referenced");
 function Name_P_Failsafe_Referenced_Decl
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Refd_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Refd_Decl;
      Fld : Internal_Refd_Decl;
New_Struct : Internal_Refd_Decl;
Try_Result : Internal_Refd_Decl;
Let_Result : Internal_Refd_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7223 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7222 '<Try at ast.py:13607>' Try_Result /tmp/lal-23.0.0/ada/ast.py:13607
begin
   --# expr-start 7220 '<FieldAccess for referenced_decl_internal at ast.py:13608>' Fld /tmp/lal-23.0.0/ada/ast.py:13608
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl_internal
Fld := Libadalang.Implementation.Name_P_Referenced_Decl_Internal (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7220
   Try_Result := Fld;
exception
   when Property_Error =>
      --# expr-start 7221 '<New RefdDecl at ast.py:13609>' New_Struct /tmp/lal-23.0.0/ada/ast.py:13609
New_Struct := (Decl => No_Entity_Basic_Decl, Kind => Error); 
--# expr-done 7221
      Try_Result := New_Struct;
end;
--# expr-done 7222
Let_Result := Try_Result; 
--# end
--# expr-done 7223
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Failsafe_Referenced_Decl;
--# end
--# property-start Name.referenced_decl_internal /tmp/lal-23.0.0/ada/ast.py:13614
pragma Warnings (Off, "is not referenced");
 function Name_P_Referenced_Decl_Internal
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Refd_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Refd_Decl;
      Var_Expr : Internal_Refd_Decl;
V : Internal_Logic_Val_Result;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Var_Expr_2 : Internal_Entity_Name;
V_1 : Internal_Logic_Val_Result;
Var_Expr_3 : Internal_Refd_Decl;
Var_Expr_4 : Internal_Entity_Basic_Decl;
Cast_Expr : Internal_Entity_Name;
Cast_Result : Internal_Entity;
Fld : Logic_Var;
Fld_1 : Internal_Logic_Val_Result;
New_Struct : Internal_Logic_Val_Result;
Try_Result : Internal_Logic_Val_Result;
Fld_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
New_Struct_1 : Internal_Refd_Decl;
Fld_3 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
New_Struct_2 : Internal_Refd_Decl;
Scope_Result_1 : Internal_Refd_Decl;
New_Struct_3 : Internal_Refd_Decl;
Result_Var_1 : Internal_Refd_Decl;
Fld_4 : Boolean;
If_Result : Internal_Refd_Decl;
Let_Result : Internal_Refd_Decl;
Cast_Expr_1 : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity;
Fld_5 : Logic_Var;
Fld_6 : Internal_Logic_Val_Result;
Fld_7 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Basic_Decl;
New_Struct_4 : Internal_Refd_Decl;
New_Struct_5 : Internal_Refd_Decl;
Fld_8 : Boolean;
If_Result_1 : Internal_Refd_Decl;
Let_Result_1 : Internal_Refd_Decl;
If_Result_2 : Internal_Refd_Decl;
Fld_9 : Internal_Entity_Basic_Decl;
Fld_10 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Result_Var_2 : Internal_Entity_Basic_Decl;
Fld_11 : Ref_Result_Kind;
New_Struct_6 : Internal_Refd_Decl;
Fld_12 : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
Fld_13 : Ref_Result_Kind;
Is_Equal : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Internal_Refd_Decl;
Scope_Result_3 : Internal_Refd_Decl;
Result_Var_3 : Internal_Refd_Decl;
Scope_Result_4 : Internal_Refd_Decl;
Result_Var_4 : Internal_Refd_Decl;
Fld_14 : Boolean;
If_Result_5 : Internal_Refd_Decl;
Let_Result_2 : Internal_Refd_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7258 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 7257 '<If at ast.py:13621>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:13621
--# expr-start 7224 '<FieldAccess for is_defining at ast.py:13624>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:13624
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_defining
Fld_14 := Libadalang.Implementation.Name_P_Is_Defining (Node => Ent.Node);
--# end
--# expr-done 7224
if Fld_14 then
   If_Result_5 := No_Refd_Decl;
else
--# expr-start 7247 '<If at ast.py:13627>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:13627
if Imprecise_Fallback then
   --# expr-start 7237 '<Let at ast.py:13631>' Let_Result /tmp/lal-23.0.0/ada/ast.py:13631
--# scope-start
--# expr-start 7228 '<Try at ast.py:13631>' Try_Result /tmp/lal-23.0.0/ada/ast.py:13631
begin
   --# expr-start 7226 '<FieldAccess for logic_val at ast.py:13632>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13632
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 7225 '<FieldAccess for ref_var at ast.py:13632>' Fld /tmp/lal-23.0.0/ada/ast.py:13632
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 7225
--# property-call-start AdaNode.logic_val
Fld_1 := Libadalang.Implementation.Ada_Node_P_Logic_Val (Node => Self, From_Node => Cast_Result, Lvar => Fld);
--# end
--# expr-done 7226
   Try_Result := Fld_1;
exception
   when Property_Error =>
      --# expr-start 7227 '<New LogicValResult at ast.py:13633>' New_Struct /tmp/lal-23.0.0/ada/ast.py:13633
New_Struct := (Success => False, Value => No_Entity); 
--# expr-done 7227
      Try_Result := New_Struct;
end;
--# expr-done 7228
V := Try_Result; 
--# bind v V
--# expr-start 7236 '<If at ast.py:13634>' If_Result /tmp/lal-23.0.0/ada/ast.py:13634
--# expr-start 7229 '<FieldAccess for success at ast.py:13635>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13635
Fld_4 := V.Success;
--# expr-done 7229
if Fld_4 then
   --# expr-start 7232 '<New RefdDecl at ast.py:13638>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:13638
--# expr-start 7231 '<Cast to BasicDecl.entity at ast.py:13639>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:13639
--# expr-start 7230 '<FieldAccess for value at ast.py:13639>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13639
Fld_2 := V.Value;
--# expr-done 7230
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 7231
New_Struct_1 := (Decl => Cast_Result_1, Kind => Precise); 
--# expr-done 7232
   If_Result := New_Struct_1;
else
Var_Expr_2 := Ent;
if Var_Expr_2 /= No_Entity_Name then
   --# scope-start
--# expr-start 7233 '<FieldAccess for first_corresponding_decl at ast.py:13645>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13645
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.first_corresponding_decl'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_First_Corresponding_Decl (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 7233
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind fcd Var_Expr_1
--# expr-start 7234 '<New RefdDecl at ast.py:13647>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:13647
New_Struct_2 := (Decl => Var_Expr_1, Kind => Imprecise); 
--# expr-done 7234
Scope_Result_1 := New_Struct_2;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 7235 '<New RefdDecl at ast.py:13648>' New_Struct_3 /tmp/lal-23.0.0/ada/ast.py:13648
New_Struct_3 := (Decl => No_Entity_Basic_Decl, Kind => Error); 
--# expr-done 7235
   Result_Var_1 := New_Struct_3;
end if;
   If_Result := Result_Var_1;
end if;
--# expr-done 7236
Let_Result := If_Result; 
--# end
--# expr-done 7237
   If_Result_2 := Let_Result;
else
   --# expr-start 7246 '<Let at ast.py:13653>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:13653
--# scope-start
--# expr-start 7239 '<FieldAccess for logic_val at ast.py:13653>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13653
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_1 := Ent; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
--# expr-start 7238 '<FieldAccess for ref_var at ast.py:13653>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13653
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 7238
--# property-call-start AdaNode.logic_val
Fld_6 := Libadalang.Implementation.Ada_Node_P_Logic_Val (Node => Self, From_Node => Cast_Result_2, Lvar => Fld_5);
--# end
--# expr-done 7239
V_1 := Fld_6; 
--# bind v V_1
--# expr-start 7245 '<If at ast.py:13653>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:13653
--# expr-start 7240 '<FieldAccess for success at ast.py:13654>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13654
Fld_8 := V_1.Success;
--# expr-done 7240
if Fld_8 then
   --# expr-start 7243 '<New RefdDecl at ast.py:13655>' New_Struct_4 /tmp/lal-23.0.0/ada/ast.py:13655
--# expr-start 7242 '<Cast to BasicDecl.entity at ast.py:13656>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:13656
--# expr-start 7241 '<FieldAccess for value at ast.py:13656>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13656
Fld_7 := V_1.Value;
--# expr-done 7241
   if Fld_7.Node = null
      or else Fld_7.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 7242
New_Struct_4 := (Decl => Cast_Result_3, Kind => Precise); 
--# expr-done 7243
   If_Result_1 := New_Struct_4;
else
   --# expr-start 7244 '<New RefdDecl at ast.py:13659>' New_Struct_5 /tmp/lal-23.0.0/ada/ast.py:13659
New_Struct_5 := (Decl => No_Entity_Basic_Decl, Kind => Error); 
--# expr-done 7244
   If_Result_1 := New_Struct_5;
end if;
--# expr-done 7245
Let_Result_1 := If_Result_1; 
--# end
--# expr-done 7246
   If_Result_2 := Let_Result_1;
end if;
--# expr-done 7247
Var_Expr := If_Result_2;
if Var_Expr /= No_Refd_Decl then
   --# scope-start
   --# bind res Var_Expr
--# expr-start 7251 '<New RefdDecl at ast.py:13664>' New_Struct_6 /tmp/lal-23.0.0/ada/ast.py:13664
--# expr-start 7248 '<FieldAccess for decl at ast.py:13665>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13665
Fld_9 := Var_Expr.Decl;
--# expr-done 7248
Var_Expr_4 := Fld_9;
if Var_Expr_4 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 7249 '<FieldAccess for wrap_public_reference at ast.py:13665>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13665
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.wrap_public_reference
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Wrap_Public_Reference (Node => Var_Expr_4.Node, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 7249
Scope_Result_2 := Fld_10;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Basic_Decl;
end if;
--# expr-start 7250 '<FieldAccess for kind at ast.py:13666>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13666
Fld_11 := Var_Expr.Kind;
--# expr-done 7250
New_Struct_6 := (Decl => Result_Var_2, Kind => Fld_11); 
--# expr-done 7251
Var_Expr_3 := New_Struct_6;
if Var_Expr_3 /= No_Refd_Decl then
   --# scope-start
   --# bind res Var_Expr_3
--# expr-start 7256 '<If at ast.py:13667>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:13667
--# expr-start 7253 '<IsNull at ast.py:13670>' Is_Null /tmp/lal-23.0.0/ada/ast.py:13670
--# expr-start 7252 '<FieldAccess for decl at ast.py:13670>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13670
Fld_12 := Var_Expr_3.Decl;
--# expr-done 7252
Is_Null := Fld_12.Node = null; 
--# expr-done 7253
if Is_Null then
   --# expr-start 7255 '<Eq at ast.py:13670>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13670
--# expr-start 7254 '<FieldAccess for kind at ast.py:13670>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:13670
Fld_13 := Var_Expr_3.Kind;
--# expr-done 7254
Is_Equal := Fld_13 = Precise; 
--# expr-done 7255
   If_Result_3 := Is_Equal;
else
   If_Result_3 := False;
end if;
if If_Result_3 then
   If_Result_4 := No_Refd_Decl;
else
   If_Result_4 := Var_Expr_3;
end if;
--# expr-done 7256
Scope_Result_3 := If_Result_4;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Refd_Decl;
end if;
Scope_Result_4 := Result_Var_3;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Refd_Decl;
end if;
   If_Result_5 := Result_Var_4;
end if;
--# expr-done 7257
Let_Result_2 := If_Result_5; 
--# end
--# expr-done 7258
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Referenced_Decl_Internal;
--# end
--# property-start '[dispatcher]Name.designated_type_impl' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Designated_Type_Impl
  (Node : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.designated_type_impl
                  Property_Result := Name_P_Designated_Type_Impl
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.designated_type_impl
                  Property_Result := Attribute_Ref_P_Designated_Type_Impl
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.designated_type_impl
                  Property_Result := Call_Expr_P_Designated_Type_Impl
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.designated_type_impl
                  Property_Result := Dotted_Name_P_Designated_Type_Impl
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal .. Ada_String_Literal =>
                  --# property-call-start BaseId.designated_type_impl
                  Property_Result := Base_Id_P_Designated_Type_Impl
                    (Self
                        , Env
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Designated_Type_Impl;
--# end
--# property-start Name.name_designated_type /tmp/lal-23.0.0/ada/ast.py:13687
pragma Warnings (Off, "is not referenced");
 function Name_P_Name_Designated_Type
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1022 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1022 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_1022;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7263 '<bind at ast.py:13688>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:13688
--# expr-start 7259 '<FieldAccess for node_env at ast.py:13688>' Fld /tmp/lal-23.0.0/ada/ast.py:13688
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 7259
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 7262 '<bind at ast.py:13689>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:13689
--# expr-start 7260 '<FieldAccess for origin_node at ast.py:13689>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13689
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 7260
Bound_Origin := Fld_1; 
--# expr-start 7261 '<FieldAccess for designated_type_impl at ast.py:13689>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13689
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Ent.Node, Env => Bound_Env, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 7261
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 7262
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; 
--# expr-done 7263
      Property_Result := Dyn_Var_Bind_Result_1;
   --# end
      Finalizer_Scope_1022;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1022;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Name_Designated_Type;
--# end
--# property-start Name.is_static_subtype /tmp/lal-23.0.0/ada/ast.py:13701
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Static_Subtype
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7266 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7265 '<FieldAccess for is_static_decl at ast.py:13705>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13705
--# expr-start 7264 '<FieldAccess for name_designated_type at ast.py:13705>' Fld /tmp/lal-23.0.0/ada/ast.py:13705
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7264
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 7265
Let_Result := Fld_1; 
--# end
--# expr-done 7266
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Static_Subtype;
--# end
--# property-start Name.name_designated_type_env /tmp/lal-23.0.0/ada/ast.py:13708
pragma Warnings (Off, "is not referenced");
 function Name_P_Name_Designated_Type_Env
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1024 with Inline_Always;
            procedure Finalizer_Scope_2791 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1024 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1024;
            procedure Finalizer_Scope_2791 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2791;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Name_Name_P_Name_Designated_Type_Env,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Name,
                                As_Bare_Name => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Lexical_Env;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 7269 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7267 '<FieldAccess for name_designated_type at ast.py:13709>' Fld /tmp/lal-23.0.0/ada/ast.py:13709
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7267
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7268 '<FieldAccess for primitives_env at ast.py:13709>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13709
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.primitives_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Primitives_Env (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7268
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2791;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 7269
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1024;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Lexical_Env,
                        As_Lexical_Env => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1024;
               Finalizer_Scope_2791;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Name_Designated_Type_Env;
--# end
--# property-start Name.referenced_unit /tmp/lal-23.0.0/ada/ast.py:13712
pragma Warnings (Off, "is not referenced");
 function Name_P_Referenced_Unit
  (Node : Bare_Name
      ; Kind : Analysis_Unit_Kind
      ; Not_Found_Is_Error : Boolean
         := True
  )
   return Internal_Unit
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind kind Kind
   --# bind not_found_is_error Not_Found_Is_Error
   Property_Result : Internal_Unit;
            procedure Finalizer_Scope_1025 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
Fld_1 : Internal_Unit;
Let_Result : Internal_Unit;
            procedure Finalizer_Scope_1025 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1025;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7272 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7271 '<FieldAccess for get_unit at ast.py:13718>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13718
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7270 '<FieldAccess for as_symbol_array at ast.py:13719>' Fld /tmp/lal-23.0.0/ada/ast.py:13719
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Self);
--# end
--# expr-done 7270
Fld_1 := Libadalang.Implementation.Extensions.Ada_Node_P_Get_Unit (Node => Self, Name => Fld, Kind => Kind, Load_If_Needed => True, Not_Found_Is_Error => Not_Found_Is_Error);
--# expr-done 7271
Let_Result := Fld_1; 
--# end
--# expr-done 7272
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1025;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1025;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Referenced_Unit;
--# end
--# property-start Name.matches /tmp/lal-23.0.0/ada/ast.py:13723
pragma Warnings (Off, "is not referenced");
 function Name_P_Matches
  (Node : Bare_Name
      ; N : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind n N
   Property_Result : Boolean;
      Match_0 : Bare_Synthetic_Identifier;
Match_1 : Bare_Identifier;
Match_2 : Bare_String_Literal;
Match_3 : Bare_Dotted_Name;
Match_4 : Bare_Defining_Name;
Match_5 : Bare_Name;
Var_Expr : Bare_Identifier;
Var_Expr_1 : Bare_Identifier;
Var_Expr_2 : Bare_String_Literal;
Var_Expr_3 : Bare_Dotted_Name;
Cast_Expr : Bare_Name;
Cast_Result : Bare_Identifier;
Fld : Symbol_Type;
Fld_1 : Symbol_Type;
Is_Equal : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Cast_Expr_1 : Bare_Name;
Cast_Result_1 : Bare_Identifier;
Fld_2 : Symbol_Type;
Fld_3 : Symbol_Type;
Is_Equal_1 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Cast_Expr_2 : Bare_Name;
Cast_Result_2 : Bare_String_Literal;
Fld_4 : Symbol_Type;
Fld_5 : Symbol_Type;
Is_Equal_2 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Cast_Expr_3 : Bare_Name;
Cast_Result_3 : Bare_Dotted_Name;
Fld_6 : Bare_Name;
Fld_7 : Bare_Name;
Fld_8 : Boolean;
Fld_9 : Bare_Base_Id;
Fld_10 : Bare_Base_Id;
Cast_Result_4 : Bare_Name;
Fld_11 : Boolean;
If_Result : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
Fld_12 : Bare_Name;
Fld_13 : Boolean;
Match_Prefix : Bare_Name;
Cast_Result_5 : Bare_Synthetic_Identifier;
Let_Result : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_6 : Bare_Identifier;
Let_Result_1 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_7 : Bare_String_Literal;
Let_Result_2 : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_8 : Bare_Dotted_Name;
Let_Result_3 : Boolean;
Scope_Result_7 : Boolean;
Cast_Result_9 : Bare_Defining_Name;
Let_Result_4 : Boolean;
Scope_Result_8 : Boolean;
Cast_Result_10 : Bare_Name;
Let_Result_5 : Boolean;
Scope_Result_9 : Boolean;
Match_Result : Boolean;
Let_Result_6 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7295 '<Block at ???>' Let_Result_6 None
--# scope-start
--# expr-start 7294 '<Match at ast.py:13730>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13730
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Name (Match_Prefix.Kind) is
         when Ada_Synthetic_Identifier =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Match_Prefix;
Match_0 := Cast_Result_5; 
--# bind id Match_0
--# expr-start 7273 '<Cast to Identifier at ast.py:13731>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13731
Cast_Expr := N; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Identifier_Range
   then
      Cast_Result := Cast_Expr;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 7273
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind other_id Var_Expr
--# expr-start 7276 '<Eq at ast.py:13738>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13738
--# expr-start 7274 '<FieldAccess for sym at ast.py:13738>' Fld /tmp/lal-23.0.0/ada/ast.py:13738
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Match_0.Synthetic_Identifier_Sym;
--# expr-done 7274
--# expr-start 7275 '<FieldAccess for sym at ast.py:13738>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13738
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_1 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Var_Expr);
--# end
--# expr-done 7275
Is_Equal := Fld = Fld_1; 
--# expr-done 7276
Scope_Result := Is_Equal;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
Scope_Result_4 := Let_Result;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Identifier =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Match_Prefix;
Match_1 := Cast_Result_6; 
--# bind id Match_1
--# expr-start 7277 '<Cast to Identifier at ast.py:13740>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:13740
Cast_Expr_1 := N; 
   if Cast_Expr_1 = null
      or else Cast_Expr_1.Kind in Ada_Identifier_Range
   then
      Cast_Result_1 := Cast_Expr_1;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 7277
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind other_id Var_Expr_1
--# expr-start 7280 '<Eq at ast.py:13741>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:13741
--# expr-start 7278 '<FieldAccess for sym at ast.py:13741>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13741
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_2 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Match_1);
--# end
--# expr-done 7278
--# expr-start 7279 '<FieldAccess for sym at ast.py:13741>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13741
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_3 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Var_Expr_1);
--# end
--# expr-done 7279
Is_Equal_1 := Fld_2 = Fld_3; 
--# expr-done 7280
Scope_Result_1 := Is_Equal_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Let_Result_1 := Result_Var_1; 
--# end
Scope_Result_5 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_String_Literal =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Match_Prefix;
Match_2 := Cast_Result_7; 
--# bind sl Match_2
--# expr-start 7281 '<Cast to StringLiteral at ast.py:13743>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:13743
Cast_Expr_2 := N; 
   if Cast_Expr_2 = null
      or else Cast_Expr_2.Kind in Ada_String_Literal_Range
   then
      Cast_Result_2 := Cast_Expr_2;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 7281
Var_Expr_2 := Cast_Result_2;
if Var_Expr_2 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind other_sl Var_Expr_2
--# expr-start 7284 '<Eq at ast.py:13744>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:13744
--# expr-start 7282 '<FieldAccess for sym at ast.py:13744>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13744
      if Match_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_4 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Match_2);
--# end
--# expr-done 7282
--# expr-start 7283 '<FieldAccess for sym at ast.py:13744>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13744
      if Var_Expr_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_5 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Var_Expr_2);
--# end
--# expr-done 7283
Is_Equal_2 := Fld_4 = Fld_5; 
--# expr-done 7284
Scope_Result_2 := Is_Equal_2;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
Let_Result_2 := Result_Var_2; 
--# end
Scope_Result_6 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Match_Prefix;
Match_3 := Cast_Result_8; 
--# bind dn Match_3
--# expr-start 7285 '<Cast to DottedName at ast.py:13746>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:13746
Cast_Expr_3 := N; 
   if Cast_Expr_3 = null
      or else Cast_Expr_3.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result_3 := Cast_Expr_3;
   else
         Cast_Result_3 := No_Bare_Ada_Node;
   end if;
--# expr-done 7285
Var_Expr_3 := Cast_Result_3;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind sn Var_Expr_3
--# expr-start 7288 '<FieldAccess for matches at ast.py:13748>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13748
--# expr-start 7286 '<FieldAccess for prefix at ast.py:13748>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13748
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Var_Expr_3.Dotted_Name_F_Prefix;
--# expr-done 7286
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7287 '<FieldAccess for prefix at ast.py:13748>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13748
      if Match_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Match_3.Dotted_Name_F_Prefix;
--# expr-done 7287
--# property-call-start Name.matches
Fld_8 := Libadalang.Implementation.Name_P_Matches (Node => Fld_6, N => Fld_7);
--# end
--# expr-done 7288
if Fld_8 then
   --# expr-start 7291 '<FieldAccess for matches at ast.py:13749>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13749
--# expr-start 7289 '<FieldAccess for suffix at ast.py:13749>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13749
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Var_Expr_3.Dotted_Name_F_Suffix;
--# expr-done 7289
      if Fld_9 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7290 '<FieldAccess for suffix at ast.py:13749>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13749
      if Match_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Match_3.Dotted_Name_F_Suffix;
--# expr-done 7290
      Cast_Result_4 := Fld_10;
--# property-call-start Name.matches
Fld_11 := Libadalang.Implementation.Name_P_Matches (Node => Fld_9, N => Cast_Result_4);
--# end
--# expr-done 7291
   If_Result := Fld_11;
else
   If_Result := False;
end if;
Scope_Result_3 := If_Result;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
Let_Result_3 := Result_Var_3; 
--# end
Scope_Result_7 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Match_Prefix;
Match_4 := Cast_Result_9; 
--# bind di Match_4
--# expr-start 7293 '<FieldAccess for matches at ast.py:13752>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:13752
      if N = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7292 '<FieldAccess for name at ast.py:13752>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13752
      if Match_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Match_4.Defining_Name_F_Name;
--# expr-done 7292
--# property-call-start Name.matches
Fld_13 := Libadalang.Implementation.Name_P_Matches (Node => N, N => Fld_12);
--# end
--# expr-done 7293
Let_Result_4 := Fld_13; 
--# end
Scope_Result_8 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_8; 
         when Ada_Attribute_Ref .. Ada_Call_Expr | Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Char_Literal | Ada_Op_Abs .. Ada_Op_Xor | Ada_Null_Literal .. Ada_Real_Literal | Ada_Target_Name .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Match_Prefix;
Match_5 := Cast_Result_10; 
--# bind _ Match_5
Let_Result_5 := False; 
--# end
Scope_Result_9 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_9; 
end case;
--# expr-done 7294
Let_Result_6 := Match_Result; 
--# end
--# expr-done 7295
      Property_Result := Let_Result_6;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Matches;
--# end
--# property-start Name.name_matches /tmp/lal-23.0.0/ada/ast.py:13757
pragma Warnings (Off, "is not referenced");
 function Name_P_Name_Matches
  (Node : Bare_Name
      ; N : Internal_Entity_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind n N
   Property_Result : Boolean;
      Fld : Bare_Name;
Fld_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7298 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7297 '<FieldAccess for matches at ast.py:13764>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13764
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7296 '<FieldAccess for node at ast.py:13764>' Fld /tmp/lal-23.0.0/ada/ast.py:13764
Fld := N.Node;
--# expr-done 7296
--# property-call-start Name.matches
Fld_1 := Libadalang.Implementation.Name_P_Matches (Node => Self, N => Fld);
--# end
--# expr-done 7297
Let_Result := Fld_1; 
--# end
--# expr-done 7298
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Name_Matches;
--# end
--# property-start Name.use_package_name_designated_env /tmp/lal-23.0.0/ada/ast.py:13767
pragma Warnings (Off, "is not referenced");
 function Name_P_Use_Package_Name_Designated_Env
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1028 with Inline_Always;
      Fld : Internal_Entity;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Use_Package_Clause;
Fld_2 : Integer;
Fld_3 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1028 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1028;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Name_Name_P_Use_Package_Name_Designated_Env,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Name,
                                As_Bare_Name => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Lexical_Env;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 7304 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7303 '<FieldAccess for designated_env at ast.py:13774>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13774
--# expr-start 7301 '<Cast to UsePackageClause at ast.py:13773>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13773
--# expr-start 7300 '<parent at ast.py:13773>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13773
--# expr-start 7299 '<parent at ast.py:13773>' Fld /tmp/lal-23.0.0/ada/ast.py:13773
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 7299
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Fld.Node, E_Info => Fld.Info);
--# expr-done 7300
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Use_Package_Clause_Range
   then
      Cast_Result := Create_Internal_Entity_Use_Package_Clause
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 7301
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7302 '<FieldAccess for child_index at ast.py:13774>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13774
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Child_Index (Node => Self);
--# expr-done 7302
--# property-call-start UsePackageClause.designated_env
Fld_3 := Libadalang.Implementation.Use_Package_Clause_P_Designated_Env (Node => Cast_Result.Node, Index => Fld_2, E_Info => Cast_Result.Info);
--# end
--# expr-done 7303
Let_Result := Fld_3; Inc_Ref (Let_Result);
--# end
--# expr-done 7304
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1028;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Lexical_Env,
                        As_Lexical_Env => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1028;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Use_Package_Name_Designated_Env;
--# end
--# property-start '[dispatcher]Name.relative_name' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Relative_Name
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Discrete_Subtype_Name | Ada_Reduce_Attribute_Ref | Ada_Synthetic_Identifier | Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.relative_name
                  Property_Result := Name_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.relative_name
                  Property_Result := Attribute_Ref_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.relative_name
                  Property_Result := Call_Expr_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
                  --# property-call-start DefiningName.relative_name
                  Property_Result := Defining_Name_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.relative_name
                  Property_Result := Dotted_Name_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_End_Name =>
                  --# property-call-start EndName.relative_name
                  Property_Result := End_Name_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.relative_name
                  Property_Result := Explicit_Deref_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Qual_Expr =>
                  --# property-call-start QualExpr.relative_name
                  Property_Result := Qual_Expr_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Char_Literal .. Ada_Real_Literal =>
                  --# property-call-start SingleTokNode.relative_name
                  Property_Result := Single_Tok_Node_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Target_Name =>
                  --# property-call-start TargetName.relative_name
                  Property_Result := Target_Name_P_Relative_Name
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Relative_Name;
--# end
--# property-start '[dispatcher]Name.name_symbol' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Name_Symbol
  (Node : Bare_Name
  )
   return Symbol_Type
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref .. Ada_Defining_Name | Ada_Discrete_Subtype_Name .. Ada_Identifier | Ada_String_Literal .. Ada_Real_Literal | Ada_Target_Name .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.name_symbol
                  Property_Result := Name_P_Name_Symbol
                    (Self
                    );
                  --# end
               when Ada_Synthetic_Defining_Name =>
                  --# property-call-start SyntheticDefiningName.name_symbol
                  Property_Result := Synthetic_Defining_Name_P_Name_Symbol
                    (Self
                    );
                  --# end
               when Ada_Op_Abs .. Ada_Op_Xor =>
                  --# property-call-start Op.name_symbol
                  Property_Result := Op_P_Name_Symbol
                    (Self
                    );
                  --# end
               when Ada_Synthetic_Identifier =>
                  --# property-call-start SyntheticIdentifier.name_symbol
                  Property_Result := Synthetic_Identifier_P_Name_Symbol
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Name_Symbol;
--# end
--# property-start Name.xref_no_overloading /tmp/lal-23.0.0/ada/ast.py:13787
pragma Warnings (Off, "is not referenced");
 function Name_P_Xref_No_Overloading
  (Node : Bare_Name
      ; Sequential : Boolean
         := True
      ; All_Els : Boolean
         := False
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind sequential Sequential
   --# bind all_els All_Els
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1031 with Inline_Always;
            procedure Finalizer_Scope_2802 with Inline_Always;
            procedure Finalizer_Scope_2803 with Inline_Always;
            procedure Finalizer_Scope_2805 with Inline_Always;
            procedure Finalizer_Scope_2806 with Inline_Always;
      Match_0 : Internal_Entity_Dotted_Name;
Match_1 : Internal_Entity_Base_Id;
Match_2 : Internal_Entity_Attribute_Ref;
Match_3 : Internal_Entity_Name;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Name;
Fld_3 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Base_Id;
Fld_5 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Symbol_Type;
Fld_7 : Boolean;
If_Result : Lookup_Kind;
Fld_8 : Bare_Name;
If_Result_1 : Bare_Name;
Cast_Result : Bare_Ada_Node;
Fld_9 : Internal_Entity_Array_Access;
Fld_10 : Logic_Var;
Domain_Equation : Logic_Equation;
Fld_11 : Logic_Var;
Fld_12 : Boolean;
If_Result_2 : Lookup_Kind;
Fld_13 : Bare_Name;
If_Result_3 : Bare_Name;
Cast_Result_1 : Bare_Ada_Node;
Fld_14 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_15 : Boolean;
If_Result_4 : Boolean;
If_Result_5 : Logic_Equation;
Fld_16 : Internal_Entity_Name;
Fld_17 : Logic_Equation;
Fld_18 : Internal_Entity_Identifier;
Fld_19 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_20 : Internal_Entity_Name;
Fld_21 : Logic_Var;
Fld_22 : Logic_Var;
Bind_Result_1 : Logic_Equation;
Fld_23 : Internal_Entity_Identifier;
Fld_24 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
Fld_25 : Internal_Entity_Name;
Fld_26 : Logic_Var;
Fld_27 : Logic_Var;
Bind_Result_2 : Logic_Equation;
True_Rel : Logic_Equation;
If_Result_6 : Logic_Equation;
If_Result_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
False_Rel : Logic_Equation;
Match_Prefix : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity_Dotted_Name;
Let_Result : Logic_Equation;
Scope_Result : Logic_Equation;
Cast_Result_3 : Internal_Entity_Base_Id;
Let_Result_1 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_4 : Internal_Entity_Attribute_Ref;
Let_Result_2 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_5 : Internal_Entity_Name;
Let_Result_3 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Match_Result : Logic_Equation;
Let_Result_4 : Logic_Equation;
            procedure Finalizer_Scope_1031 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1031;
            procedure Finalizer_Scope_2802 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_2802;
            procedure Finalizer_Scope_2803 is
            begin
                     Dec_Ref (Fld_9);
                     Dec_Ref (Domain_Equation);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (If_Result_5);
            end Finalizer_Scope_2803;
            procedure Finalizer_Scope_2805 is
            begin
                     Dec_Ref (Fld_17);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2805;
            procedure Finalizer_Scope_2806 is
            begin
                     Dec_Ref (False_Rel);
            end Finalizer_Scope_2806;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7351 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 7350 '<Match at ast.py:13796>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13796
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Name (Match_Prefix.Node.Kind) is
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Dotted_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind dn Match_0
--# expr-start 7312 '<And at ast.py:13799>' And_Pred /tmp/lal-23.0.0/ada/ast.py:13799
--# expr-start 7306 '<FieldAccess for xref_no_overloading at ast.py:13799>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13799
--# expr-start 7305 '<FieldAccess for prefix at ast.py:13799>' Fld /tmp/lal-23.0.0/ada/ast.py:13799
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Match_0.Node.Dotted_Name_F_Prefix, Info => Match_0.Info);
--# expr-done 7305
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, Sequential => Sequential, All_Els => All_Els, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 7306
--# expr-start 7311 '<bind at ast.py:13800>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:13800
--# expr-start 7308 '<FieldAccess for designated_env at ast.py:13801>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13801
--# expr-start 7307 '<FieldAccess for prefix at ast.py:13801>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13801
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Match_0.Node.Dotted_Name_F_Prefix, Info => Match_0.Info);
--# expr-done 7307
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld_2.Node, Env => Env, Origin => Origin, No_Visibility => False, E_Info => Fld_2.Info);
--# end
--# expr-done 7308
Bound_Env := Fld_3; Inc_Ref (Bound_Env);
--# expr-start 7310 '<FieldAccess for xref_no_overloading at ast.py:13802>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13802
--# expr-start 7309 '<FieldAccess for suffix at ast.py:13802>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13802
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Base_Id (Node => Match_0.Node.Dotted_Name_F_Suffix, Info => Match_0.Info);
--# expr-done 7309
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_5 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_4.Node, Sequential => Sequential, All_Els => All_Els, Env => Bound_Env, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 7310
Dyn_Var_Bind_Result := Fld_5; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 7311
And_Pred := Create_And (Fld_1, Dyn_Var_Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13799") else null)); 
--# expr-done 7312
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2802;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Char_Literal .. Ada_String_Literal =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Base_Id
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind i Match_1
--# expr-start 7329 '<If at ast.py:13804>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:13804
if All_Els then
   --# expr-start 7313 '<FieldAccess for is_suffix at ast.py:13805>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:13805
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_suffix
Fld_15 := Libadalang.Implementation.Name_P_Is_Suffix (Node => Self);
--# end
--# expr-done 7313
   If_Result_4 := Fld_15;
else
   If_Result_4 := False;
end if;
if If_Result_4 then
   --# expr-start 7321 '<domain at ast.py:13806>' Domain_Equation /tmp/lal-23.0.0/ada/ast.py:13806
--# expr-start 7319 '<FieldAccess for env_get at ast.py:13807>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13807
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7314 '<FieldAccess for name_symbol at ast.py:13809>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13809
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Match_1.Node);
--# end
--# expr-done 7314
--# expr-start 7316 '<If at ast.py:13811>' If_Result /tmp/lal-23.0.0/ada/ast.py:13811
--# expr-start 7315 '<FieldAccess for is_prefix at ast.py:13811>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13811
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld_7 := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 7315
if Fld_7 then
   If_Result := Recursive;
else
   If_Result := Flat;
end if;
--# expr-done 7316
--# expr-start 7318 '<If at ast.py:13810>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:13810
if Sequential then
   --# expr-start 7317 '<FieldAccess for node at ast.py:13810>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13810
Fld_8 := Ent.Node;
--# expr-done 7317
   If_Result_1 := Fld_8;
else
   If_Result_1 := No_Bare_Ada_Node;
end if;
--# expr-done 7318
      Cast_Result := If_Result_1;
--# property-call-start AdaNode.env_get
Fld_9 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Env, Symbol => Fld_6, Lookup => If_Result, From_Node => Cast_Result);
--# end
--# expr-done 7319
--# expr-start 7320 '<FieldAccess for ref_var at ast.py:13806>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13806
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_10 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Match_1.Node);
--# end
--# expr-done 7320
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
declare
   Dom : Internal_Entity_Array_Access := Fld_9;
   A   : Entity_Vars.Value_Array (1 .. Length (Dom));
begin
   for J in 0 .. Length (Dom) - 1 loop
      declare
         Item : constant Internal_Entity := Get (Self, Dom, J);
      begin
         A (J + 1) := (Node => Item.Node, Info => Item.Info);
      end;
   end loop;
   Domain_Equation := Solver.Create_Domain
     (Fld_10, A, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13806") else null));
end;
--# expr-done 7321
   If_Result_5 := Domain_Equation;
else
   --# expr-start 7328 '<Bind at ast.py:13814>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:13814
--# expr-start 7322 '<FieldAccess for ref_var at ast.py:13815>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13815
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_11 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Match_1.Node);
--# end
--# expr-done 7322
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
--# expr-start 7327 '<FieldAccess for env_get_first_visible at ast.py:13816>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:13816
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7324 '<If at ast.py:13819>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:13819
--# expr-start 7323 '<FieldAccess for is_prefix at ast.py:13819>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13819
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld_12 := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 7323
if Fld_12 then
   If_Result_2 := Recursive;
else
   If_Result_2 := Flat;
end if;
--# expr-done 7324
--# expr-start 7326 '<If at ast.py:13818>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:13818
if Sequential then
   --# expr-start 7325 '<FieldAccess for node at ast.py:13818>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:13818
Fld_13 := Ent.Node;
--# expr-done 7325
   If_Result_3 := Fld_13;
else
   If_Result_3 := No_Bare_Ada_Node;
end if;
--# expr-done 7326
      Cast_Result_1 := If_Result_3;
--# property-call-start SingleTokNode.env_get_first_visible
Fld_14 := Libadalang.Implementation.Single_Tok_Node_P_Env_Get_First_Visible (Node => Match_1.Node, Lex_Env => Env, Lookup_Type => If_Result_2, From_Node => Cast_Result_1, No_Visibility => False);
--# end
--# expr-done 7327
Bind_Result := Solver.Create_Assign (Fld_11, Fld_14, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13814") else null)); 
--# expr-done 7328
   If_Result_5 := Bind_Result;
end if;
      Inc_Ref (If_Result_5);
--# expr-done 7329
Let_Result_1 := If_Result_5; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2803;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind ar Match_2
--# expr-start 7349 '<And at ast.py:13828>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:13828
--# expr-start 7331 '<FieldAccess for xref_no_overloading at ast.py:13828>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:13828
--# expr-start 7330 '<FieldAccess for prefix at ast.py:13828>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:13828
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 7330
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_17 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_16.Node, Sequential => Sequential, All_Els => All_Els, Env => Env, Origin => Origin, E_Info => Fld_16.Info);
--# end
--# expr-done 7331
--# expr-start 7348 '<Cond at ast.py:13829>' If_Result_7 /tmp/lal-23.0.0/ada/ast.py:13829
--# expr-start 7335 '<Eq at ast.py:13830>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13830
--# expr-start 7333 '<FieldAccess for sym at ast.py:13830>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:13830
--# expr-start 7332 '<FieldAccess for attribute at ast.py:13830>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:13830
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 7332
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_19 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_18.Node);
--# end
--# expr-done 7333
--# expr-start 7334 '<Symbol Class at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Class); 
--# expr-done 7334
Is_Equal := Fld_19 = Sym; 
--# expr-done 7335
if Is_Equal then
   --# expr-start 7339 '<Bind at ast.py:13831>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:13831
--# expr-start 7337 '<FieldAccess for ref_var at ast.py:13831>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:13831
--# expr-start 7336 '<FieldAccess for prefix at ast.py:13831>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:13831
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 7336
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_21 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_20.Node);
--# end
--# expr-done 7337
Fld_21.Value := No_Entity;
Entity_Vars.Reset (Fld_21);
--# expr-start 7338 '<FieldAccess for ref_var at ast.py:13831>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:13831
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_22 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Match_2.Node);
--# end
--# expr-done 7338
Fld_22.Value := No_Entity;
Entity_Vars.Reset (Fld_22);
Bind_Result_1 := Solver.Create_Propagate (Fld_21, Fld_22, Logic_Functor_638'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13831") else null)); 
--# expr-done 7339
   If_Result_7 := Bind_Result_1;
else
--# expr-start 7343 '<Eq at ast.py:13834>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:13834
--# expr-start 7341 '<FieldAccess for sym at ast.py:13834>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:13834
--# expr-start 7340 '<FieldAccess for attribute at ast.py:13834>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:13834
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Create_Internal_Entity_Identifier (Node => Match_2.Node.Attribute_Ref_F_Attribute, Info => Match_2.Info);
--# expr-done 7340
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_24 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_23.Node);
--# end
--# expr-done 7341
--# expr-start 7342 '<Symbol Base at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Base); 
--# expr-done 7342
Is_Equal_1 := Fld_24 = Sym_1; 
--# expr-done 7343
if Is_Equal_1 then
   --# expr-start 7347 '<Bind at ast.py:13835>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:13835
--# expr-start 7345 '<FieldAccess for ref_var at ast.py:13835>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:13835
--# expr-start 7344 '<FieldAccess for prefix at ast.py:13835>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:13835
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Name (Node => Match_2.Node.Attribute_Ref_F_Prefix, Info => Match_2.Info);
--# expr-done 7344
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_26 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_25.Node);
--# end
--# expr-done 7345
Fld_26.Value := No_Entity;
Entity_Vars.Reset (Fld_26);
--# expr-start 7346 '<FieldAccess for ref_var at ast.py:13835>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:13835
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_27 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Match_2.Node);
--# end
--# expr-done 7346
Fld_27.Value := No_Entity;
Entity_Vars.Reset (Fld_27);
Bind_Result_2 := Solver.Create_Propagate (Fld_26, Fld_27, Logic_Functor_639'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13835") else null)); 
--# expr-done 7347
   If_Result_6 := Bind_Result_2;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13838") else null)); 
   If_Result_6 := True_Rel;
end if;
      Inc_Ref (If_Result_6);
   If_Result_7 := If_Result_6;
end if;
      Inc_Ref (If_Result_7);
--# expr-done 7348
And_Pred_1 := Create_And (Fld_17, If_Result_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13828") else null)); 
--# expr-done 7349
Let_Result_2 := And_Pred_1; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2805;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Call_Expr .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Reduce_Attribute_Ref | Ada_Null_Literal .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_5; 
--# bind _ Match_3
False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:13841") else null)); 
Let_Result_3 := False_Rel; Inc_Ref (Let_Result_3);
--# end
Scope_Result_3 := Let_Result_3;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2806;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
end case;
--# expr-done 7350
Let_Result_4 := Match_Result; Inc_Ref (Let_Result_4);
--# end
--# expr-done 7351
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1031;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1031;
               Finalizer_Scope_2802;
               Finalizer_Scope_2803;
               Finalizer_Scope_2805;
               Finalizer_Scope_2806;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Xref_No_Overloading;
--# end
--# property-start Name.is_prefix /tmp/lal-23.0.0/ada/ast.py:13845
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Prefix
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Dotted_Name;
Fld_2 : Bare_Name;
Cast_Result_1 : Bare_Name;
Is_Equal : Boolean;
If_Result : Boolean;
Fld_3 : Bare_Ada_Node;
Cast_Result_2 : Bare_Name;
Fld_4 : Boolean;
If_Result_1 : Boolean;
Fld_5 : Bare_Ada_Node;
Is_A_1 : Boolean;
Not_Val : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Name_Name_P_Is_Prefix,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Name,
                                As_Bare_Name => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 7364 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7353 '<IsA DottedName at ast.py:13852>' Is_A /tmp/lal-23.0.0/ada/ast.py:13852
--# expr-start 7352 '<parent at ast.py:13852>' Fld /tmp/lal-23.0.0/ada/ast.py:13852
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 7352
Is_A := Fld /= null 
and then Fld.Kind in Ada_Dotted_Name_Range; 
--# expr-done 7353
if Is_A then
   --# expr-start 7357 '<Eq at ast.py:13853>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13853
--# expr-start 7356 '<FieldAccess for prefix at ast.py:13853>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13853
--# expr-start 7355 '<Cast to DottedName at ast.py:13853>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13853
--# expr-start 7354 '<parent at ast.py:13853>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13853
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Parent; 
--# expr-done 7354
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 7355
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Dotted_Name_F_Prefix;
--# expr-done 7356
      Cast_Result_1 := Fld_2;
Is_Equal := Cast_Result_1 = Self; 
--# expr-done 7357
   If_Result := Is_Equal;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 7360 '<FieldAccess for is_prefix at ast.py:13854>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13854
--# expr-start 7359 '<Cast to Name at ast.py:13854>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:13854
--# expr-start 7358 '<parent at ast.py:13854>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13854
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Parent; 
--# expr-done 7358
   if Fld_3 = null
      or else Fld_3.Kind in Ada_Name
   then
      Cast_Result_2 := Fld_3;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 7359
      if Cast_Result_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld_4 := Libadalang.Implementation.Name_P_Is_Prefix (Node => Cast_Result_2);
--# end
--# expr-done 7360
   If_Result_1 := Fld_4;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 7363 '<Not at ast.py:13855>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13855
--# expr-start 7362 '<IsA DottedName at ast.py:13855>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13855
--# expr-start 7361 '<parent at ast.py:13855>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13855
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Parent; 
--# expr-done 7361
Is_A_1 := Fld_5 /= null 
and then Fld_5.Kind in Ada_Dotted_Name_Range; 
--# expr-done 7362
Not_Val := not (Is_A_1); 
--# expr-done 7363
   If_Result_2 := Not_Val;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 7364
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Prefix;
--# end
--# property-start Name.is_suffix /tmp/lal-23.0.0/ada/ast.py:13859
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Suffix
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Dotted_Name;
Fld_2 : Bare_Base_Id;
Cast_Result_1 : Bare_Name;
Is_Equal : Boolean;
If_Result : Boolean;
Fld_3 : Bare_Ada_Node;
Cast_Result_2 : Bare_Name;
Fld_4 : Boolean;
If_Result_1 : Boolean;
Fld_5 : Bare_Ada_Node;
Is_A_1 : Boolean;
Not_Val : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Name_Name_P_Is_Suffix,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Name,
                                As_Bare_Name => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 7377 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7366 '<IsA DottedName at ast.py:13864>' Is_A /tmp/lal-23.0.0/ada/ast.py:13864
--# expr-start 7365 '<parent at ast.py:13864>' Fld /tmp/lal-23.0.0/ada/ast.py:13864
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 7365
Is_A := Fld /= null 
and then Fld.Kind in Ada_Dotted_Name_Range; 
--# expr-done 7366
if Is_A then
   --# expr-start 7370 '<Eq at ast.py:13865>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13865
--# expr-start 7369 '<FieldAccess for suffix at ast.py:13865>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13865
--# expr-start 7368 '<Cast to DottedName at ast.py:13865>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13865
--# expr-start 7367 '<parent at ast.py:13865>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13865
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Parent; 
--# expr-done 7367
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 7368
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Cast_Result.Dotted_Name_F_Suffix;
--# expr-done 7369
      Cast_Result_1 := Fld_2;
Is_Equal := Cast_Result_1 = Self; 
--# expr-done 7370
   If_Result := Is_Equal;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 7373 '<FieldAccess for is_suffix at ast.py:13866>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13866
--# expr-start 7372 '<Cast to Name at ast.py:13866>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:13866
--# expr-start 7371 '<parent at ast.py:13866>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13866
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Parent; 
--# expr-done 7371
   if Fld_3 = null
      or else Fld_3.Kind in Ada_Name
   then
      Cast_Result_2 := Fld_3;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 7372
      if Cast_Result_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_suffix
Fld_4 := Libadalang.Implementation.Name_P_Is_Suffix (Node => Cast_Result_2);
--# end
--# expr-done 7373
   If_Result_1 := Fld_4;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 7376 '<Not at ast.py:13868>' Not_Val /tmp/lal-23.0.0/ada/ast.py:13868
--# expr-start 7375 '<IsA DottedName at ast.py:13868>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:13868
--# expr-start 7374 '<parent at ast.py:13868>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13868
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Parent; 
--# expr-done 7374
Is_A_1 := Fld_5 /= null 
and then Fld_5.Kind in Ada_Dotted_Name_Range; 
--# expr-done 7375
Not_Val := not (Is_A_1); 
--# expr-done 7376
   If_Result_2 := Not_Val;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 7377
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Suffix;
--# end
--# property-start Name.is_operator_name /tmp/lal-23.0.0/ada/ast.py:13872
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Operator_Name
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_1 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_2 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_3 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_4 : Symbol_Type;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_3 : Boolean;
Fld_5 : Symbol_Type;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_4 : Boolean;
Fld_6 : Symbol_Type;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_5 : Boolean;
Fld_7 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_6 : Boolean;
Fld_8 : Symbol_Type;
Sym_8 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_7 : Boolean;
Fld_9 : Symbol_Type;
Sym_9 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_8 : Boolean;
Fld_10 : Symbol_Type;
Sym_10 : Symbol_Type;
Is_Equal_10 : Boolean;
If_Result_9 : Boolean;
Fld_11 : Symbol_Type;
Sym_11 : Symbol_Type;
Is_Equal_11 : Boolean;
If_Result_10 : Boolean;
Fld_12 : Symbol_Type;
Sym_12 : Symbol_Type;
Is_Equal_12 : Boolean;
If_Result_11 : Boolean;
Fld_13 : Symbol_Type;
Sym_13 : Symbol_Type;
Is_Equal_13 : Boolean;
If_Result_12 : Boolean;
Fld_14 : Symbol_Type;
Sym_14 : Symbol_Type;
Is_Equal_14 : Boolean;
If_Result_13 : Boolean;
Fld_15 : Symbol_Type;
Sym_15 : Symbol_Type;
Is_Equal_15 : Boolean;
If_Result_14 : Boolean;
Fld_16 : Symbol_Type;
Sym_16 : Symbol_Type;
Is_Equal_16 : Boolean;
If_Result_15 : Boolean;
Fld_17 : Symbol_Type;
Sym_17 : Symbol_Type;
Is_Equal_17 : Boolean;
If_Result_16 : Boolean;
Fld_18 : Symbol_Type;
Sym_18 : Symbol_Type;
Is_Equal_18 : Boolean;
If_Result_17 : Boolean;
Fld_19 : Symbol_Type;
Sym_19 : Symbol_Type;
Is_Equal_19 : Boolean;
If_Result_18 : Boolean;
Fld_20 : Symbol_Type;
Sym_20 : Symbol_Type;
Is_Equal_20 : Boolean;
If_Result_19 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7441 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7380 '<Eq at ast.py:13876>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7378 '<FieldAccess for name_symbol at ast.py:13876>' Fld /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7378
--# expr-start 7379 '<Symbol "=" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 7379
Is_Equal := Fld = Sym; 
--# expr-done 7380
if Is_Equal then
   If_Result := True;
else
   --# expr-start 7383 '<Eq at ast.py:13876>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7381 '<FieldAccess for name_symbol at ast.py:13876>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7381
--# expr-start 7382 '<Symbol "=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 7382
Is_Equal_1 := Fld_1 = Sym_1; 
--# expr-done 7383
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 7386 '<Eq at ast.py:13876>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7384 '<FieldAccess for name_symbol at ast.py:13876>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7384
--# expr-start 7385 '<Symbol "/=" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 7385
Is_Equal_2 := Fld_2 = Sym_2; 
--# expr-done 7386
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 7389 '<Eq at ast.py:13876>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7387 '<FieldAccess for name_symbol at ast.py:13876>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7387
--# expr-start 7388 '<Symbol "<" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 7388
Is_Equal_3 := Fld_3 = Sym_3; 
--# expr-done 7389
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 7392 '<Eq at ast.py:13876>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7390 '<FieldAccess for name_symbol at ast.py:13876>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7390
--# expr-start 7391 '<Symbol "<=" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 7391
Is_Equal_4 := Fld_4 = Sym_4; 
--# expr-done 7392
   If_Result_3 := Is_Equal_4;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 7395 '<Eq at ast.py:13876>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7393 '<FieldAccess for name_symbol at ast.py:13876>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7393
--# expr-start 7394 '<Symbol ">" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 7394
Is_Equal_5 := Fld_5 = Sym_5; 
--# expr-done 7395
   If_Result_4 := Is_Equal_5;
end if;
if If_Result_4 then
   If_Result_5 := True;
else
   --# expr-start 7398 '<Eq at ast.py:13876>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7396 '<FieldAccess for name_symbol at ast.py:13876>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7396
--# expr-start 7397 '<Symbol ">=" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 7397
Is_Equal_6 := Fld_6 = Sym_6; 
--# expr-done 7398
   If_Result_5 := Is_Equal_6;
end if;
if If_Result_5 then
   If_Result_6 := True;
else
   --# expr-start 7401 '<Eq at ast.py:13876>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7399 '<FieldAccess for name_symbol at ast.py:13876>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7399
--# expr-start 7400 '<Symbol "and" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_And); 
--# expr-done 7400
Is_Equal_7 := Fld_7 = Sym_7; 
--# expr-done 7401
   If_Result_6 := Is_Equal_7;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 7404 '<Eq at ast.py:13876>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7402 '<FieldAccess for name_symbol at ast.py:13876>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7402
--# expr-start 7403 '<Symbol "or" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Or); 
--# expr-done 7403
Is_Equal_8 := Fld_8 = Sym_8; 
--# expr-done 7404
   If_Result_7 := Is_Equal_8;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 7407 '<Eq at ast.py:13876>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7405 '<FieldAccess for name_symbol at ast.py:13876>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_9 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7405
--# expr-start 7406 '<Symbol "xor" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Xor); 
--# expr-done 7406
Is_Equal_9 := Fld_9 = Sym_9; 
--# expr-done 7407
   If_Result_8 := Is_Equal_9;
end if;
if If_Result_8 then
   If_Result_9 := True;
else
   --# expr-start 7410 '<Eq at ast.py:13876>' Is_Equal_10 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7408 '<FieldAccess for name_symbol at ast.py:13876>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_10 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7408
--# expr-start 7409 '<Symbol "abs" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 7409
Is_Equal_10 := Fld_10 = Sym_10; 
--# expr-done 7410
   If_Result_9 := Is_Equal_10;
end if;
if If_Result_9 then
   If_Result_10 := True;
else
   --# expr-start 7413 '<Eq at ast.py:13876>' Is_Equal_11 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7411 '<FieldAccess for name_symbol at ast.py:13876>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_11 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7411
--# expr-start 7412 '<Symbol "*" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 7412
Is_Equal_11 := Fld_11 = Sym_11; 
--# expr-done 7413
   If_Result_10 := Is_Equal_11;
end if;
if If_Result_10 then
   If_Result_11 := True;
else
   --# expr-start 7416 '<Eq at ast.py:13876>' Is_Equal_12 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7414 '<FieldAccess for name_symbol at ast.py:13876>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_12 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7414
--# expr-start 7415 '<Symbol "/" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 7415
Is_Equal_12 := Fld_12 = Sym_12; 
--# expr-done 7416
   If_Result_11 := Is_Equal_12;
end if;
if If_Result_11 then
   If_Result_12 := True;
else
   --# expr-start 7419 '<Eq at ast.py:13876>' Is_Equal_13 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7417 '<FieldAccess for name_symbol at ast.py:13876>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_13 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7417
--# expr-start 7418 '<Symbol "mod" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod); 
--# expr-done 7418
Is_Equal_13 := Fld_13 = Sym_13; 
--# expr-done 7419
   If_Result_12 := Is_Equal_13;
end if;
if If_Result_12 then
   If_Result_13 := True;
else
   --# expr-start 7422 '<Eq at ast.py:13876>' Is_Equal_14 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7420 '<FieldAccess for name_symbol at ast.py:13876>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_14 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7420
--# expr-start 7421 '<Symbol "rem" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rem); 
--# expr-done 7421
Is_Equal_14 := Fld_14 = Sym_14; 
--# expr-done 7422
   If_Result_13 := Is_Equal_14;
end if;
if If_Result_13 then
   If_Result_14 := True;
else
   --# expr-start 7425 '<Eq at ast.py:13876>' Is_Equal_15 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7423 '<FieldAccess for name_symbol at ast.py:13876>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_15 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7423
--# expr-start 7424 '<Symbol "+" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 7424
Is_Equal_15 := Fld_15 = Sym_15; 
--# expr-done 7425
   If_Result_14 := Is_Equal_15;
end if;
if If_Result_14 then
   If_Result_15 := True;
else
   --# expr-start 7428 '<Eq at ast.py:13876>' Is_Equal_16 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7426 '<FieldAccess for name_symbol at ast.py:13876>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_16 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7426
--# expr-start 7427 '<Symbol "-" at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 7427
Is_Equal_16 := Fld_16 = Sym_16; 
--# expr-done 7428
   If_Result_15 := Is_Equal_16;
end if;
if If_Result_15 then
   If_Result_16 := True;
else
   --# expr-start 7431 '<Eq at ast.py:13876>' Is_Equal_17 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7429 '<FieldAccess for name_symbol at ast.py:13876>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_17 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7429
--# expr-start 7430 '<Symbol "&""+" at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_1); 
--# expr-done 7430
Is_Equal_17 := Fld_17 = Sym_17; 
--# expr-done 7431
   If_Result_16 := Is_Equal_17;
end if;
if If_Result_16 then
   If_Result_17 := True;
else
   --# expr-start 7434 '<Eq at ast.py:13876>' Is_Equal_18 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7432 '<FieldAccess for name_symbol at ast.py:13876>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_18 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7432
--# expr-start 7433 '<Symbol "-" at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 7433
Is_Equal_18 := Fld_18 = Sym_18; 
--# expr-done 7434
   If_Result_17 := Is_Equal_18;
end if;
if If_Result_17 then
   If_Result_18 := True;
else
   --# expr-start 7437 '<Eq at ast.py:13876>' Is_Equal_19 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7435 '<FieldAccess for name_symbol at ast.py:13876>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_19 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7435
--# expr-start 7436 '<Symbol "not" at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Not); 
--# expr-done 7436
Is_Equal_19 := Fld_19 = Sym_19; 
--# expr-done 7437
   If_Result_18 := Is_Equal_19;
end if;
if If_Result_18 then
   If_Result_19 := True;
else
   --# expr-start 7440 '<Eq at ast.py:13876>' Is_Equal_20 /tmp/lal-23.0.0/ada/ast.py:13876
--# expr-start 7438 '<FieldAccess for name_symbol at ast.py:13876>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:13876
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_20 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 7438
--# expr-start 7439 '<Symbol "abs" at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 7439
Is_Equal_20 := Fld_20 = Sym_20; 
--# expr-done 7440
   If_Result_19 := Is_Equal_20;
end if;
Let_Result := If_Result_19; 
--# end
--# expr-done 7441
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Operator_Name;
--# end
--# property-start Name.is_write_reference /tmp/lal-23.0.0/ada/ast.py:13884
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Write_Reference
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
            procedure Finalizer_Scope_2810 with Inline_Always;
            procedure Finalizer_Scope_2813 with Inline_Always;
      Match_0 : Internal_Entity_Assign_Stmt;
Match_1 : Internal_Entity_Call_Expr;
Match_2 : Internal_Entity_Dotted_Name;
Match_3 : Internal_Entity_Param_Assoc;
Match_4 : Internal_Entity_Attribute_Ref;
Match_5 : Internal_Entity_Alternatives_List;
Match_6 : Internal_Entity;
Var_Expr : Internal_Entity_Base_Formal_Param_Holder;
Var_Expr_1 : Internal_Entity_Mode;
Var_Expr_2 : Internal_Entity_Param_Spec;
Var_Expr_3 : Internal_Entity_Call_Expr;
Var_Expr_4 : Internal_Entity_Mode;
Var_Expr_5 : Internal_Entity_Param_Spec;
Fld : Internal_Entity;
Fld_1 : Internal_Entity_Name;
Cast_Result : Internal_Entity;
Cast_Expr : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Fld_2 : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Name;
Cast_Result_3 : Internal_Entity;
Is_Equiv_1 : Boolean;
Fld_3 : Boolean;
If_Result : Boolean;
Fld_4 : Boolean;
Fld_5 : Internal_Entity_Name;
Cast_Result_4 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Name;
Cast_Result_5 : Internal_Entity;
Is_Equiv_2 : Boolean;
Fld_6 : Internal_Entity_Base_Id;
Fld_7 : Internal_Entity_Base_Formal_Param_Holder;
Fld_8 : Internal_Entity_Info;
Fld_9 : Internal_Metadata;
Fld_10 : Boolean;
Fld_11 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Get_Result : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_6 : Internal_Entity_Param_Spec;
Fld_12 : Internal_Entity_Mode;
Scope_Result : Internal_Entity_Mode;
Result_Var : Internal_Entity_Mode;
Fld_13 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Fld_14 : Internal_Entity;
Fld_15 : Internal_Entity;
Cast_Result_7 : Internal_Entity_Call_Expr;
Fld_16 : Boolean;
Fld_17 : Internal_Entity_Defining_Name_Array_Access;
Fld_18 : Internal_Entity_Basic_Decl;
Cast_Result_8 : Internal_Entity_Param_Spec;
Fld_19 : Internal_Entity_Mode;
Scope_Result_3 : Internal_Entity_Mode;
Result_Var_3 : Internal_Entity_Mode;
Fld_20 : Boolean;
Scope_Result_4 : Boolean;
Result_Var_4 : Boolean;
Quantifier_Result : Boolean;
Fld_21 : Internal_Entity;
Fld_22 : Internal_Entity;
Cast_Result_9 : Internal_Entity_Call_Expr;
Fld_23 : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
If_Result_4 : Boolean;
Fld_24 : Internal_Entity_Name;
Cast_Result_10 : Internal_Entity;
Cast_Expr_3 : Internal_Entity_Name;
Cast_Result_11 : Internal_Entity;
Is_Equiv_3 : Boolean;
Fld_25 : Boolean;
If_Result_5 : Boolean;
Fld_26 : Internal_Entity;
Is_A : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result_12 : Internal_Entity_Assign_Stmt;
Let_Result : Boolean;
Scope_Result_6 : Boolean;
Cast_Result_13 : Internal_Entity_Call_Expr;
Let_Result_1 : Boolean;
Scope_Result_7 : Boolean;
Cast_Result_14 : Internal_Entity_Dotted_Name;
Let_Result_2 : Boolean;
Scope_Result_8 : Boolean;
Cast_Result_15 : Internal_Entity_Param_Assoc;
Let_Result_3 : Boolean;
Scope_Result_9 : Boolean;
Cast_Result_16 : Internal_Entity_Attribute_Ref;
Let_Result_4 : Boolean;
Scope_Result_10 : Boolean;
Cast_Result_17 : Internal_Entity_Alternatives_List;
Let_Result_5 : Boolean;
Scope_Result_11 : Boolean;
Cast_Result_18 : Internal_Entity;
Let_Result_6 : Boolean;
Scope_Result_12 : Boolean;
Match_Result : Boolean;
Let_Result_7 : Boolean;
            procedure Finalizer_Scope_2810 is
            begin
                     Dec_Ref (Fld_11);
            end Finalizer_Scope_2810;
            procedure Finalizer_Scope_2813 is
            begin
                     Dec_Ref (Fld_17);
            end Finalizer_Scope_2813;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7482 '<Block at ???>' Let_Result_7 None
--# scope-start
--# expr-start 7481 '<Match at ast.py:13901>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13901
--# expr-start 7442 '<parent at ast.py:13901>' Fld /tmp/lal-23.0.0/ada/ast.py:13901
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 7442
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Assign_Stmt =>
   --# scope-start
--# scope-start
      Cast_Result_12 := Create_Internal_Entity_Assign_Stmt
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_12; 
--# bind a Match_0
--# expr-start 7444 '<Eq at ast.py:13904>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:13904
--# expr-start 7443 '<FieldAccess for dest at ast.py:13904>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13904
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Match_0.Node.Assign_Stmt_F_Dest, Info => Match_0.Info);
--# expr-done 7443
      Cast_Result := Create_Internal_Entity
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
Cast_Expr := Ent; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 7444
Let_Result := Is_Equiv; 
--# end
Scope_Result_6 := Let_Result;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_13 := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_13; 
--# bind c Match_1
--# expr-start 7446 '<Eq at ast.py:13909>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:13909
--# expr-start 7445 '<FieldAccess for name at ast.py:13909>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13909
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Match_1.Node.Call_Expr_F_Name, Info => Match_1.Info);
--# expr-done 7445
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv_1 := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 7446
if Is_Equiv_1 then
   --# expr-start 7447 '<FieldAccess for is_write_reference at ast.py:13910>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13910
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_write_reference
Fld_3 := Libadalang.Implementation.Name_P_Is_Write_Reference (Node => Match_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_1.Info);
--# end
--# expr-done 7447
   If_Result := Fld_3;
else
   If_Result := False;
end if;
Let_Result_1 := If_Result; 
--# end
Scope_Result_7 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_14 := Create_Internal_Entity_Dotted_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_14; 
--# bind d Match_2
--# expr-start 7448 '<FieldAccess for is_write_reference at ast.py:13920>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13920
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_write_reference
Fld_4 := Libadalang.Implementation.Name_P_Is_Write_Reference (Node => Match_2.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_2.Info);
--# end
--# expr-done 7448
if Fld_4 then
   If_Result_3 := True;
else
--# expr-start 7450 '<Eq at ast.py:13923>' Is_Equiv_2 /tmp/lal-23.0.0/ada/ast.py:13923
--# expr-start 7449 '<FieldAccess for prefix at ast.py:13923>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13923
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Match_2.Node.Dotted_Name_F_Prefix, Info => Match_2.Info);
--# expr-done 7449
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Cast_Expr_2 := Ent; 
      Cast_Result_5 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv_2 := Equivalent (Cast_Result_4, Cast_Result_5); 
--# expr-done 7450
if Is_Equiv_2 then
--# expr-start 7452 '<FieldAccess for called_subp_spec at ast.py:13923>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13923
--# expr-start 7451 '<FieldAccess for suffix at ast.py:13923>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13923
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Base_Id (Node => Match_2.Node.Dotted_Name_F_Suffix, Info => Match_2.Info);
--# expr-done 7451
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_7 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 7452
Var_Expr := Fld_7;
if Var_Expr /= No_Entity_Base_Formal_Param_Holder then
   --# scope-start
   --# bind spec Var_Expr
--# expr-start 7455 '<FieldAccess for dottable_subp at ast.py:13925>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13925
--# expr-start 7454 '<FieldAccess for md at ast.py:13925>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13925
--# expr-start 7453 '<FieldAccess for info at ast.py:13925>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13925
Fld_8 := Var_Expr.Info;
--# expr-done 7453
Fld_9 := Fld_8.Md;
--# expr-done 7454
Fld_10 := Fld_9.Dottable_Subp;
--# expr-done 7455
if Fld_10 then
--# expr-start 7458 '<Cast to ParamSpec at ast.py:13927>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:13927
--# expr-start 7457 '<at at ast.py:13926>' Get_Result /tmp/lal-23.0.0/ada/ast.py:13926
--# expr-start 7456 '<FieldAccess for abstract_formal_params at ast.py:13926>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13926
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_11 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7456
Get_Result := Get (Self, Fld_11, 0, True); 
--# expr-done 7457
   if Get_Result.Node = null
      or else Get_Result.Node.Kind in Ada_Param_Spec_Range
   then
      Cast_Result_6 := Create_Internal_Entity_Param_Spec
        (Node => Get_Result.Node,
         Info => Get_Result.Info);
   else
         Cast_Result_6 := No_Entity_Param_Spec;
   end if;
--# expr-done 7458
Var_Expr_2 := Cast_Result_6;
if Var_Expr_2 /= No_Entity_Param_Spec then
   --# scope-start
--# expr-start 7459 '<FieldAccess for mode at ast.py:13927>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13927
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Mode (Node => Var_Expr_2.Node.Param_Spec_F_Mode, Info => Var_Expr_2.Info);
--# expr-done 7459
Scope_Result := Fld_12;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Mode;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Mode then
   --# scope-start
--# expr-start 7460 '<FieldAccess for is_writable at ast.py:13927>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:13927
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Mode.is_writable
Fld_13 := Libadalang.Implementation.Mode_P_Is_Writable (Node => Var_Expr_1.Node);
--# end
--# expr-done 7460
Scope_Result_1 := Fld_13;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_1 := Result_Var_1;
else
   If_Result_1 := False;
end if;
Scope_Result_2 := If_Result_1;
   --# end
      Finalizer_Scope_2810;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
   If_Result_2 := Result_Var_2;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
Let_Result_2 := If_Result_3; 
--# end
Scope_Result_8 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_8; 
         when Ada_Param_Assoc =>
   --# scope-start
--# scope-start
      Cast_Result_15 := Create_Internal_Entity_Param_Assoc
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_15; 
--# bind p Match_3
--# expr-start 7475 '<If at ast.py:13932>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:13932
--# expr-start 7463 '<Cast to CallExpr at ast.py:13933>' Cast_Result_9 /tmp/lal-23.0.0/ada/ast.py:13933
--# expr-start 7462 '<parent at ast.py:13933>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:13933
--# expr-start 7461 '<parent at ast.py:13933>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:13933
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Libadalang.Implementation.Parent (Node => Match_3.Node, E_Info => Match_3.Info);
--# expr-done 7461
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Libadalang.Implementation.Parent (Node => Fld_21.Node, E_Info => Fld_21.Info);
--# expr-done 7462
   if Fld_22.Node = null
      or else Fld_22.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_9 := Create_Internal_Entity_Call_Expr
        (Node => Fld_22.Node,
         Info => Fld_22.Info);
   else
         Cast_Result_9 := No_Entity_Call_Expr;
   end if;
--# expr-done 7463
Var_Expr_3 := Cast_Result_9;
if Var_Expr_3 /= No_Entity_Call_Expr then
   --# scope-start
--# expr-start 7464 '<FieldAccess for is_type_conversion at ast.py:13933>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:13933
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.is_type_conversion
Fld_23 := Libadalang.Implementation.Call_Expr_P_Is_Type_Conversion (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 7464
Scope_Result_5 := Fld_23;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
if Result_Var_5 then
   --# expr-start 7468 '<FieldAccess for is_write_reference at ast.py:13934>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:13934
--# expr-start 7467 '<Cast to CallExpr at ast.py:13934>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:13934
--# expr-start 7466 '<parent at ast.py:13934>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:13934
--# expr-start 7465 '<parent at ast.py:13934>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:13934
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Parent (Node => Match_3.Node, E_Info => Match_3.Info);
--# expr-done 7465
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Parent (Node => Fld_14.Node, E_Info => Fld_14.Info);
--# expr-done 7466
   if Fld_15.Node = null
      or else Fld_15.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_7 := Create_Internal_Entity_Call_Expr
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
   else
         Cast_Result_7 := No_Entity_Call_Expr;
   end if;
--# expr-done 7467
      if Cast_Result_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_write_reference
Fld_16 := Libadalang.Implementation.Name_P_Is_Write_Reference (Node => Cast_Result_7.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result_7.Info);
--# end
--# expr-done 7468
   If_Result_4 := Fld_16;
else
   --# expr-start 7474 '<AnyQuantifier at ast.py:13935>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:13935
   --# expr-start 7469 '<FieldAccess for get_params at ast.py:13935>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:13935
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicAssoc.get_params
Fld_17 := Libadalang.Implementation.Basic_Assoc_P_Get_Params (Node => Match_3.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Match_3.Info);
--# end
--# expr-done 7469
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_17;
      begin
         for Item_245 of
               Collection.Items
         loop
   --# scope-start
               --# bind m Item_245
--# expr-start 7471 '<Cast to ParamSpec at ast.py:13937>' Cast_Result_8 /tmp/lal-23.0.0/ada/ast.py:13937
--# expr-start 7470 '<FieldAccess for basic_decl at ast.py:13937>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:13937
      if Item_245.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_18 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Item_245.Node, E_Info => Item_245.Info);
--# end
--# expr-done 7470
   if Fld_18.Node = null
      or else Fld_18.Node.Kind in Ada_Param_Spec_Range
   then
      Cast_Result_8 := Create_Internal_Entity_Param_Spec
        (Node => Fld_18.Node,
         Info => Fld_18.Info);
   else
         Cast_Result_8 := No_Entity_Param_Spec;
   end if;
--# expr-done 7471
Var_Expr_5 := Cast_Result_8;
if Var_Expr_5 /= No_Entity_Param_Spec then
   --# scope-start
--# expr-start 7472 '<FieldAccess for mode at ast.py:13937>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:13937
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Mode (Node => Var_Expr_5.Node.Param_Spec_F_Mode, Info => Var_Expr_5.Info);
--# expr-done 7472
Scope_Result_3 := Fld_19;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Entity_Mode;
end if;
Var_Expr_4 := Result_Var_3;
if Var_Expr_4 /= No_Entity_Mode then
   --# scope-start
--# expr-start 7473 '<FieldAccess for is_writable at ast.py:13937>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:13937
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Mode.is_writable
Fld_20 := Libadalang.Implementation.Mode_P_Is_Writable (Node => Var_Expr_4.Node);
--# end
--# expr-done 7473
Scope_Result_4 := Fld_20;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := False;
end if;
      Quantifier_Result := Result_Var_4;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 7474
   If_Result_4 := Quantifier_Result;
end if;
--# expr-done 7475
Let_Result_3 := If_Result_4; 
--# end
Scope_Result_9 := Let_Result_3;
   --# end
      Finalizer_Scope_2813;
            Match_Result := Scope_Result_9; 
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_16 := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_16; 
--# bind a Match_4
--# expr-start 7477 '<Eq at ast.py:13942>' Is_Equiv_3 /tmp/lal-23.0.0/ada/ast.py:13942
--# expr-start 7476 '<FieldAccess for prefix at ast.py:13942>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:13942
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Create_Internal_Entity_Name (Node => Match_4.Node.Attribute_Ref_F_Prefix, Info => Match_4.Info);
--# expr-done 7476
      Cast_Result_10 := Create_Internal_Entity
        (Node => Fld_24.Node,
         Info => Fld_24.Info);
Cast_Expr_3 := Ent; 
      Cast_Result_11 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
Is_Equiv_3 := Equivalent (Cast_Result_10, Cast_Result_11); 
--# expr-done 7477
if Is_Equiv_3 then
   --# expr-start 7478 '<FieldAccess for is_access_attr at ast.py:13942>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:13942
      if Match_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.is_access_attr
Fld_25 := Libadalang.Implementation.Attribute_Ref_P_Is_Access_Attr (Node => Match_4.Node);
--# end
--# expr-done 7478
   If_Result_5 := Fld_25;
else
   If_Result_5 := False;
end if;
Let_Result_4 := If_Result_5; 
--# end
Scope_Result_10 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_10; 
         when Ada_Alternatives_List =>
   --# scope-start
--# scope-start
      Cast_Result_17 := Create_Internal_Entity_Alternatives_List
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_5 := Cast_Result_17; 
--# bind l Match_5
--# expr-start 7480 '<IsA AggregateAssoc at ast.py:13944>' Is_A /tmp/lal-23.0.0/ada/ast.py:13944
--# expr-start 7479 '<parent at ast.py:13944>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:13944
      if Match_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Libadalang.Implementation.Parent (Node => Match_5.Node, E_Info => Match_5.Info);
--# expr-done 7479
Is_A := Fld_26.Node /= null 
and then Fld_26.Node.Kind in Ada_Aggregate_Assoc_Range; 
--# expr-done 7480
Let_Result_5 := Is_A; 
--# end
Scope_Result_11 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_11; 
         when Ada_Abort_Absent .. Ada_Abstract_State_Decl_List | Ada_Constraint_List .. Ada_Iterated_Assoc | Ada_Abstract_State_Decl .. Ada_Membership_Expr | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Abort_Stmt | Ada_Call_Stmt .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_18 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_6 := Cast_Result_18; 
--# bind _ Match_6
Let_Result_6 := False; 
--# end
Scope_Result_12 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_12; 
end case;
--# expr-done 7481
Let_Result_7 := Match_Result; 
--# end
--# expr-done 7482
      Property_Result := Let_Result_7;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2810;
               Finalizer_Scope_2813;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Write_Reference;
--# end
--# property-start Name.potential_actuals_for_dispatch /tmp/lal-23.0.0/ada/ast.py:13950
pragma Warnings (Off, "is not referenced");
 function Name_P_Potential_Actuals_For_Dispatch
  (Node : Bare_Name
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Expected_Type_For_Expr_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind spec Spec
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Expected_Type_For_Expr_Array_Access;
            procedure Finalizer_Scope_1036 with Inline_Always;
            procedure Finalizer_Scope_2821 with Inline_Always;
            procedure Finalizer_Scope_2826 with Inline_Always;
            procedure Finalizer_Scope_2828 with Inline_Always;
      Block_Var : Internal_Expected_Type_For_Expr_Array_Access;
Block_Var_1 : Internal_Expected_Type_For_Expr_Array_Access;
Var_Expr : Boolean;
Var_Expr_1 : Internal_Entity_Dotted_Name;
Match_0 : Internal_Entity_Call_Expr;
Match_1 : Internal_Entity_Dotted_Name;
Match_2 : Internal_Entity_Identifier;
Match_3 : Internal_Entity_Name;
Var_Expr_2 : Internal_Entity_Assoc_List;
Var_Expr_3 : Internal_Entity_Call_Expr;
Fld : Boolean;
Fld_1 : Internal_Entity_Name;
Cast_Result : Internal_Entity_Dotted_Name;
Fld_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Dotted_Name;
Match_Prefix : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity_Call_Expr;
Let_Result : Internal_Entity_Dotted_Name;
Scope_Result : Internal_Entity_Dotted_Name;
Cast_Result_3 : Internal_Entity_Dotted_Name;
Let_Result_1 : Internal_Entity_Dotted_Name;
Scope_Result_1 : Internal_Entity_Dotted_Name;
Cast_Result_4 : Internal_Entity_Identifier;
Let_Result_2 : Internal_Entity_Dotted_Name;
Scope_Result_2 : Internal_Entity_Dotted_Name;
Cast_Result_5 : Internal_Entity_Name;
Let_Result_3 : Internal_Entity_Dotted_Name;
Scope_Result_3 : Internal_Entity_Dotted_Name;
Match_Result : Internal_Entity_Dotted_Name;
Fld_3 : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_4 : Internal_Entity_Base_Formal_Param_Decl;
Fld_5 : Internal_Entity_Type_Expr;
Fld_6 : Internal_Entity_Name;
Cast_Result_6 : Internal_Entity_Expr;
New_Struct : Internal_Expected_Type_For_Expr;
Singleton : Internal_Expected_Type_For_Expr_Array_Access;
Scope_Result_4 : Internal_Expected_Type_For_Expr_Array_Access;
Result_Var : Internal_Expected_Type_For_Expr_Array_Access;
Scope_Result_5 : Internal_Expected_Type_For_Expr_Array_Access;
Result_Var_1 : Internal_Expected_Type_For_Expr_Array_Access;
Cast_Expr : Internal_Entity_Name;
Cast_Result_7 : Internal_Entity_Call_Expr;
Fld_7 : Internal_Entity_Assoc_List;
Scope_Result_6 : Internal_Entity_Assoc_List;
Result_Var_2 : Internal_Entity_Assoc_List;
Fld_8 : Internal_Param_Actual_Array_Access;
Scope_Result_7 : Internal_Param_Actual_Array_Access;
Result_Var_3 : Internal_Param_Actual_Array_Access;
Fld_9 : Internal_Entity_Defining_Name;
Fld_10 : Internal_Entity_Basic_Decl;
Fld_11 : Internal_Entity_Type_Expr;
Fld_12 : Internal_Entity_Expr;
New_Struct_1 : Internal_Expected_Type_For_Expr;
Map_Result : Internal_Expected_Type_For_Expr_Array_Access;
Concat_Result : Internal_Expected_Type_For_Expr_Array_Access;
Let_Result_4 : Internal_Expected_Type_For_Expr_Array_Access;
            procedure Finalizer_Scope_1036 is
            begin
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1036;
            procedure Finalizer_Scope_2821 is
            begin
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_2821;
            procedure Finalizer_Scope_2826 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2826;
            procedure Finalizer_Scope_2828 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_2828;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7505 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 7483 '<FieldAccess for is_dot_call at ast.py:13960>' Fld /tmp/lal-23.0.0/ada/ast.py:13960
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_dot_call
Fld := Libadalang.Implementation.Name_P_Is_Dot_Call (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7483
Var_Expr := Fld;
if Var_Expr /= False then
   --# scope-start
   --# bind _ Var_Expr
--# expr-start 7488 '<Match at ast.py:13960>' Match_Result /tmp/lal-23.0.0/ada/ast.py:13960
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Name (Match_Prefix.Node.Kind) is
         when Ada_Call_Expr =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Call_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind c Match_0
--# expr-start 7485 '<Cast to DottedName at ast.py:13961>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13961
--# expr-start 7484 '<FieldAccess for name at ast.py:13961>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13961
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Match_0.Node.Call_Expr_F_Name, Info => Match_0.Info);
--# expr-done 7484
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Create_Internal_Entity_Dotted_Name
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 7485
Let_Result := Cast_Result; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Dotted_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind d Match_1
Let_Result_1 := Match_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Identifier =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Identifier
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind i Match_2
--# expr-start 7487 '<Cast to DottedName at ast.py:13963>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:13963
--# expr-start 7486 '<parent at ast.py:13963>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13963
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Match_2.Node, E_Info => Match_2.Info);
--# expr-done 7486
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Dotted_Name
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 7487
Let_Result_2 := Cast_Result_1; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Attribute_Ref | Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Char_Literal | Ada_Op_Abs .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_5; 
--# bind _ Match_3
Let_Result_3 := No_Entity_Dotted_Name; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 7488
Var_Expr_1 := Match_Result;
if Var_Expr_1 /= No_Entity_Dotted_Name then
   --# scope-start
   --# bind d Var_Expr_1
--# expr-start 7494 '<New ExpectedTypeForExpr at ast.py:13965>' New_Struct /tmp/lal-23.0.0/ada/ast.py:13965
--# expr-start 7492 '<FieldAccess for type_expression at ast.py:13967>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:13967
--# expr-start 7491 '<FieldAccess for formal_decl at ast.py:13967>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13967
--# expr-start 7490 '<at at ast.py:13966>' Get_Result /tmp/lal-23.0.0/ada/ast.py:13966
--# expr-start 7489 '<FieldAccess for unpacked_formal_params at ast.py:13966>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13966
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_3 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Spec.Node, E_Info => Spec.Info);
--# end
--# expr-done 7489
Get_Result := Get (Self, Fld_3, 0, True); 
--# expr-done 7490
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_4 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 7491
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_5 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 7492
--# expr-start 7493 '<FieldAccess for prefix at ast.py:13968>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:13968
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Dotted_Name_F_Prefix, Info => Var_Expr_1.Info);
--# expr-done 7493
      Cast_Result_6 := Create_Internal_Entity_Expr
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
New_Struct := (Expected_Type => Fld_5, Expr => Cast_Result_6); 
--# expr-done 7494
                Singleton := Create_Internal_Expected_Type_For_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
Scope_Result_4 := Singleton;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2826;
   Result_Var := Scope_Result_4;
else
   Result_Var := No_Internal_Expected_Type_For_Expr_Array_Type;
end if;
      Inc_Ref (Result_Var);
Scope_Result_5 := Result_Var;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2821;
   Result_Var_1 := Scope_Result_5;
else
   Result_Var_1 := No_Internal_Expected_Type_For_Expr_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Block_Var := Result_Var_1; Inc_Ref (Block_Var);
--# bind prefix Block_Var
--# expr-start 7503 '<Map at ast.py:13975>' Map_Result /tmp/lal-23.0.0/ada/ast.py:13975
--# expr-start 7495 '<Cast to CallExpr at ast.py:13975>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:13975
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_7 := Create_Internal_Entity_Call_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_7 := No_Entity_Call_Expr;
   end if;
--# expr-done 7495
Var_Expr_3 := Cast_Result_7;
if Var_Expr_3 /= No_Entity_Call_Expr then
   --# scope-start
--# expr-start 7496 '<FieldAccess for params at ast.py:13975>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:13975
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_7 := Libadalang.Implementation.Call_Expr_P_Params (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 7496
Scope_Result_6 := Fld_7;
   --# end
   Result_Var_2 := Scope_Result_6;
else
   Result_Var_2 := No_Entity_Assoc_List;
end if;
Var_Expr_2 := Result_Var_2;
if Var_Expr_2 /= No_Entity_Assoc_List then
   --# scope-start
--# expr-start 7497 '<FieldAccess for zip_with_params at ast.py:13975>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:13975
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AssocList.zip_with_params
Fld_8 := Libadalang.Implementation.Assoc_List_P_Zip_With_Params (Node => Var_Expr_2.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 7497
Scope_Result_7 := Fld_8;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_2828;
   Result_Var_3 := Scope_Result_7;
else
   Result_Var_3 := No_Internal_Param_Actual_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
      declare
         Map_Result_Vec : Internal_Expected_Type_For_Expr_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Result_Var_3;
      begin
         for Item_246 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_246
      --# expr-start 7502 '<New ExpectedTypeForExpr at ast.py:13976>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:13976
--# expr-start 7500 '<FieldAccess for type_expression at ast.py:13977>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:13977
--# expr-start 7499 '<FieldAccess for basic_decl at ast.py:13977>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:13977
--# expr-start 7498 '<FieldAccess for param at ast.py:13977>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:13977
Fld_9 := Item_246.Param;
--# expr-done 7498
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_10 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Fld_9.Node, E_Info => Fld_9.Info);
--# end
--# expr-done 7499
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_11 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Fld_10.Node, E_Info => Fld_10.Info);
--# end
--# expr-done 7500
--# expr-start 7501 '<FieldAccess for actual at ast.py:13978>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:13978
Fld_12 := Item_246.Actual;
--# expr-done 7501
New_Struct_1 := (Expected_Type => Fld_11, Expr => Fld_12); 
--# expr-done 7502
         declare
            Item_To_Append : constant Internal_Expected_Type_For_Expr := New_Struct_1;
         begin
            Internal_Expected_Type_For_Expr_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Expected_Type_For_Expr_Array
           (Items_Count => Natural (Internal_Expected_Type_For_Expr_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Expected_Type_For_Expr_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Expected_Type_For_Expr_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Expected_Type_For_Expr_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 7503
Block_Var_1 := Map_Result; Inc_Ref (Block_Var_1);
--# bind args Block_Var_1
--# expr-start 7504 '<Concat at ast.py:13983>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:13983
Concat_Result := Concat (Block_Var, Block_Var_1); 
--# expr-done 7504
Let_Result_4 := Concat_Result; Inc_Ref (Let_Result_4);
--# end
--# expr-done 7505
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1036;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1036;
               Finalizer_Scope_2821;
               Finalizer_Scope_2826;
               Finalizer_Scope_2828;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Potential_Actuals_For_Dispatch;
--# end
--# property-start Name.is_dispatching_call /tmp/lal-23.0.0/ada/ast.py:13986
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Dispatching_Call
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Name;
Fld : Boolean;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Call_Expr;
Cast_Result : Internal_Entity_Name;
Scope_Result : Internal_Entity_Name;
Result_Var : Internal_Entity_Name;
Fld_3 : Internal_Entity_Basic_Decl;
Fld_4 : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7512 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7506 '<FieldAccess for is_access_call at ast.py:13988>' Fld /tmp/lal-23.0.0/ada/ast.py:13988
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_access_call
Fld := Libadalang.Implementation.Name_P_Is_Access_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7506
if Fld then
   If_Result_1 := True;
else
--# expr-start 7507 '<FieldAccess for is_direct_call at ast.py:13989>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:13989
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_direct_call
Fld_1 := Libadalang.Implementation.Name_P_Is_Direct_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7507
if Fld_1 then
   --# expr-start 7511 '<FieldAccess for is_dispatching_call_impl at ast.py:13991>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:13991
--# expr-start 7509 '<Cast to Name.entity at ast.py:13990>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:13990
--# expr-start 7508 '<FieldAccess for parent_callexpr at ast.py:13990>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:13990
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_callexpr
Fld_2 := Libadalang.Implementation.Name_P_Parent_Callexpr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7508
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
--# expr-done 7509
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind e Var_Expr
Scope_Result := Var_Expr;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := Ent;
end if;
      if Result_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7510 '<FieldAccess for referenced_decl at ast.py:13991>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:13991
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_3 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7510
--# property-call-start Expr.is_dispatching_call_impl
Fld_4 := Libadalang.Implementation.Expr_P_Is_Dispatching_Call_Impl (Node => Result_Var.Node, Decl => Fld_3, Imprecise_Fallback => Imprecise_Fallback, E_Info => Result_Var.Info);
--# end
--# expr-done 7511
   If_Result := Fld_4;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 7512
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Dispatching_Call;
--# end
--# property-start Name.is_static_call /tmp/lal-23.0.0/ada/ast.py:13996
pragma Warnings (Off, "is not referenced");
 function Name_P_Is_Static_Call
  (Node : Bare_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7516 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7513 '<FieldAccess for is_call at ast.py:14005>' Fld /tmp/lal-23.0.0/ada/ast.py:14005
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_call
Fld := Libadalang.Implementation.Name_P_Is_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7513
if Fld then
   --# expr-start 7515 '<Not at ast.py:14005>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14005
--# expr-start 7514 '<FieldAccess for is_dispatching_call at ast.py:14005>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14005
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.is_dispatching_call'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Is_Dispatching_Call (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 7514
Not_Val := not (Fld_1); 
--# expr-done 7515
   If_Result := Not_Val;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 7516
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Is_Static_Call;
--# end
--# property-start Name.as_single_tok_node_array /tmp/lal-23.0.0/ada/ast.py:14008
pragma Warnings (Off, "is not referenced");
 function Name_P_As_Single_Tok_Node_Array
  (Node : Bare_Name
  )
   return Bare_Single_Tok_Node_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Single_Tok_Node_Array_Access;
            procedure Finalizer_Scope_1039 with Inline_Always;
            procedure Finalizer_Scope_2831 with Inline_Always;
            procedure Finalizer_Scope_2832 with Inline_Always;
            procedure Finalizer_Scope_2833 with Inline_Always;
      Match_0 : Bare_Defining_Name;
Match_1 : Bare_Single_Tok_Node;
Match_2 : Bare_Dotted_Name;
Match_3 : Bare_Name;
Fld : Bare_Name;
Fld_1 : Bare_Single_Tok_Node_Array_Access;
Singleton : Bare_Single_Tok_Node_Array_Access;
Fld_2 : Bare_Name;
Fld_3 : Bare_Single_Tok_Node_Array_Access;
Fld_4 : Bare_Base_Id;
Fld_5 : Bare_Single_Tok_Node_Array_Access;
Concat_Result : Bare_Single_Tok_Node_Array_Access;
Match_Prefix : Bare_Name;
Cast_Result : Bare_Defining_Name;
Let_Result : Bare_Single_Tok_Node_Array_Access;
Scope_Result : Bare_Single_Tok_Node_Array_Access;
Cast_Result_1 : Bare_Single_Tok_Node;
Let_Result_1 : Bare_Single_Tok_Node_Array_Access;
Scope_Result_1 : Bare_Single_Tok_Node_Array_Access;
Cast_Result_2 : Bare_Dotted_Name;
Let_Result_2 : Bare_Single_Tok_Node_Array_Access;
Scope_Result_2 : Bare_Single_Tok_Node_Array_Access;
Cast_Result_3 : Bare_Name;
Let_Result_3 : Bare_Single_Tok_Node_Array_Access;
Scope_Result_3 : Bare_Single_Tok_Node_Array_Access;
Match_Result : Bare_Single_Tok_Node_Array_Access;
Let_Result_4 : Bare_Single_Tok_Node_Array_Access;
            procedure Finalizer_Scope_1039 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1039;
            procedure Finalizer_Scope_2831 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2831;
            procedure Finalizer_Scope_2832 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2832;
            procedure Finalizer_Scope_2833 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_2833;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7525 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 7524 '<Match at ast.py:14015>' Match_Result /tmp/lal-23.0.0/ada/ast.py:14015
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Name (Match_Prefix.Kind) is
         when Ada_Defining_Name .. Ada_Synthetic_Defining_Name =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind dname Match_0
--# expr-start 7518 '<FieldAccess for as_single_tok_node_array at ast.py:14016>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14016
--# expr-start 7517 '<FieldAccess for name at ast.py:14016>' Fld /tmp/lal-23.0.0/ada/ast.py:14016
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Match_0.Defining_Name_F_Name;
--# expr-done 7517
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.as_single_tok_node_array
Fld_1 := Libadalang.Implementation.Name_P_As_Single_Tok_Node_Array (Node => Fld);
--# end
--# expr-done 7518
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2831;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Char_Literal .. Ada_Real_Literal =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind tok Match_1
                Singleton := Create_Bare_Single_Tok_Node_Array (Items_Count => 1);
                Singleton.Items (1) := Match_1;
Let_Result_1 := Singleton; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2832;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Dotted_Name =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind dot Match_2
--# expr-start 7523 '<Concat at ast.py:14019>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:14019
--# expr-start 7520 '<FieldAccess for as_single_tok_node_array at ast.py:14019>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14019
--# expr-start 7519 '<FieldAccess for prefix at ast.py:14019>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14019
      if Match_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Match_2.Dotted_Name_F_Prefix;
--# expr-done 7519
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.as_single_tok_node_array
Fld_3 := Libadalang.Implementation.Name_P_As_Single_Tok_Node_Array (Node => Fld_2);
--# end
--# expr-done 7520
--# expr-start 7522 '<FieldAccess for as_single_tok_node_array at ast.py:14020>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14020
--# expr-start 7521 '<FieldAccess for suffix at ast.py:14020>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14020
      if Match_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Match_2.Dotted_Name_F_Suffix;
--# expr-done 7521
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.as_single_tok_node_array
Fld_5 := Libadalang.Implementation.Name_P_As_Single_Tok_Node_Array (Node => Fld_4);
--# end
--# expr-done 7522
Concat_Result := Concat (Fld_3, Fld_5); 
--# expr-done 7523
Let_Result_2 := Concat_Result; Inc_Ref (Let_Result_2);
--# end
Scope_Result_2 := Let_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2833;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref .. Ada_Call_Expr | Ada_Discrete_Subtype_Name | Ada_End_Name .. Ada_Reduce_Attribute_Ref | Ada_Synthetic_Identifier .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_3 := Cast_Result_3; 
--# bind _ Match_3
Let_Result_3 := raise Property_Error; Inc_Ref (Let_Result_3);
--# end
Scope_Result_3 := Let_Result_3;
   Inc_Ref (Scope_Result_3);
   --# end
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
end case;
--# expr-done 7524
Let_Result_4 := Match_Result; Inc_Ref (Let_Result_4);
--# end
--# expr-done 7525
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1039;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1039;
               Finalizer_Scope_2831;
               Finalizer_Scope_2832;
               Finalizer_Scope_2833;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_As_Single_Tok_Node_Array;
--# end
--# property-start '[dispatcher]Name.as_symbol_array' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_As_Symbol_Array
  (Node : Bare_Name
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref .. Ada_Defining_Name | Ada_Discrete_Subtype_Name .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.as_symbol_array
                  Property_Result := Name_P_As_Symbol_Array
                    (Self
                    );
                  --# end
               when Ada_Synthetic_Defining_Name =>
                  --# property-call-start SyntheticDefiningName.as_symbol_array
                  Property_Result := Synthetic_Defining_Name_P_As_Symbol_Array
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_As_Symbol_Array;
--# end
--# property-start '[dispatcher]Name.canonical_text' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Canonical_Text
  (Node : Bare_Name
  )
   return Symbol_Type
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Attribute_Ref .. Ada_Reduce_Attribute_Ref | Ada_Synthetic_Identifier .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.canonical_text
                  Property_Result := Name_P_Canonical_Text
                    (Self
                    );
                  --# end
               when Ada_Char_Literal .. Ada_Real_Literal =>
                  --# property-call-start SingleTokNode.canonical_text
                  Property_Result := Single_Tok_Node_P_Canonical_Text
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Canonical_Text;
--# end
--# property-start '[dispatcher]Name.is_constant' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Name_P_Is_Constant
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Name (Self.Kind) is
               when Ada_Defining_Name .. Ada_Discrete_Subtype_Name | Ada_End_Name | Ada_Reduce_Attribute_Ref .. Ada_Char_Literal | Ada_Op_Abs .. Ada_Null_Literal | Ada_Synthetic_Identifier .. Ada_Update_Attribute_Ref =>
                  --# property-call-start Name.is_constant
                  Property_Result := Name_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Attribute_Ref =>
                  --# property-call-start AttributeRef.is_constant
                  Property_Result := Attribute_Ref_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Call_Expr =>
                  --# property-call-start CallExpr.is_constant
                  Property_Result := Call_Expr_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Dotted_Name =>
                  --# property-call-start DottedName.is_constant
                  Property_Result := Dotted_Name_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Explicit_Deref =>
                  --# property-call-start ExplicitDeref.is_constant
                  Property_Result := Explicit_Deref_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Qual_Expr =>
                  --# property-call-start QualExpr.is_constant
                  Property_Result := Qual_Expr_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Identifier =>
                  --# property-call-start Identifier.is_constant
                  Property_Result := Identifier_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Int_Literal .. Ada_Real_Literal =>
                  --# property-call-start NumLiteral.is_constant
                  Property_Result := Num_Literal_P_Is_Constant
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Name_P_Is_Constant;
--# end
--# property-start Name.call_params /tmp/lal-23.0.0/ada/ast.py:14057
pragma Warnings (Off, "is not referenced");
 function Name_P_Call_Params
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Actual_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Name :=
     Internal_Entity_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_1043 with Inline_Always;
            procedure Finalizer_Scope_2837 with Inline_Always;
            procedure Finalizer_Scope_2841 with Inline_Always;
      Offset : Integer;
Aparams : Internal_Entity_Assoc_List;
Dparams : Internal_Param_Actual_Array_Access;
Var_Expr : Internal_Entity_Call_Expr;
Var_Expr_1 : Internal_Entity_Call_Expr;
Var_Expr_2 : Internal_Entity_Param_Spec;
Var_Expr_3 : Internal_Entity_Assoc_List;
Fld : Boolean;
If_Result : Integer;
Cast_Expr : Internal_Entity_Name;
Cast_Result : Internal_Entity_Call_Expr;
Fld_1 : Internal_Entity_Assoc_List;
Scope_Result : Internal_Entity_Assoc_List;
Result_Var : Internal_Entity_Assoc_List;
Fld_2 : Internal_Entity_Base_Formal_Param_Holder;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_4 : Internal_Entity_Defining_Name_Array_Access;
Cast_Expr_1 : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Call_Expr;
Fld_5 : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity_Dotted_Name;
Fld_6 : Internal_Entity_Name;
Scope_Result_1 : Internal_Entity_Name;
Cast_Expr_2 : Internal_Entity_Name;
Cast_Result_3 : Internal_Entity_Dotted_Name;
Fld_7 : Internal_Entity_Name;
Result_Var_1 : Internal_Entity_Name;
Cast_Expr_3 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_4 : Internal_Entity_Param_Spec;
Fld_8 : Internal_Entity_Expr;
Scope_Result_2 : Internal_Entity_Expr;
Result_Var_2 : Internal_Entity_Expr;
Cast_Result_5 : Internal_Entity_Expr;
Fld_9 : Boolean;
Is_Equal : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Internal_Entity_Expr;
New_Struct : Internal_Param_Actual;
Map_Result : Internal_Param_Actual_Array_Access;
Index_249 : Integer;
Map_Result_1 : Internal_Param_Actual_Array_Access;
Fld_10 : Internal_Entity_Defining_Name;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Internal_Entity_Defining_Name;
Arith_Result : Integer;
Fld_13 : Internal_Entity_Expr;
Fld_14 : Internal_Entity_Expr;
Fld_15 : Boolean;
Is_Equal_1 : Boolean;
If_Result_3 : Boolean;
If_Result_4 : Internal_Entity_Expr;
New_Struct_1 : Internal_Param_Actual;
Index_252 : Integer;
Map_Result_2 : Internal_Param_Actual_Array_Access;
Scope_Result_3 : Internal_Param_Actual_Array_Access;
Result_Var_3 : Internal_Param_Actual_Array_Access;
Let_Result : Internal_Param_Actual_Array_Access;
Fld_16 : Boolean;
If_Result_5 : Internal_Param_Actual_Array_Access;
Let_Result_1 : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_1043 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Dparams);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Let_Result);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_1043;
            procedure Finalizer_Scope_2837 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2837;
            procedure Finalizer_Scope_2841 is
            begin
                     Dec_Ref (Map_Result_2);
            end Finalizer_Scope_2841;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7561 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 7560 '<If at ast.py:14062>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:14062
--# expr-start 7526 '<FieldAccess for is_call at ast.py:14063>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14063
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_call
Fld_16 := Libadalang.Implementation.Name_P_Is_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7526
if Fld_16 then
   --# expr-start 7559 '<Let at ast.py:14065>' Let_Result /tmp/lal-23.0.0/ada/ast.py:14065
--# scope-start
--# expr-start 7528 '<If at ast.py:14066>' If_Result /tmp/lal-23.0.0/ada/ast.py:14066
--# expr-start 7527 '<FieldAccess for is_dot_call at ast.py:14066>' Fld /tmp/lal-23.0.0/ada/ast.py:14066
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_dot_call
Fld := Libadalang.Implementation.Name_P_Is_Dot_Call (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 7527
if Fld then
   If_Result := 1;
else
   If_Result := 0;
end if;
--# expr-done 7528
Offset := If_Result; 
--# bind offset Offset
--# expr-start 7529 '<Cast to CallExpr at ast.py:14068>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14068
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result := Create_Internal_Entity_Call_Expr
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Call_Expr;
   end if;
--# expr-done 7529
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Call_Expr then
   --# scope-start
--# expr-start 7530 '<FieldAccess for params at ast.py:14068>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14068
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_1 := Libadalang.Implementation.Call_Expr_P_Params (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7530
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Assoc_List;
end if;
Aparams := Result_Var; 
--# bind aparams Aparams
--# expr-start 7547 '<Mapcat at ast.py:14071>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:14071
   --# expr-start 7532 '<FieldAccess for abstract_formal_params at ast.py:14071>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14071
--# expr-start 7531 '<FieldAccess for called_subp_spec at ast.py:14071>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14071
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.called_subp_spec
Fld_2 := Libadalang.Implementation.Name_P_Called_Subp_Spec (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 7531
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 7532
      declare
         Map_Result_1_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
         Index_249 := 0;
      declare
         Collection : constant Internal_Entity_Base_Formal_Param_Decl_Array_Access := Fld_3;
      begin
         for Item_248 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_248
               --# bind i Index_249
      --# expr-start 7546 '<Map at ast.py:14072>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14072
   --# expr-start 7533 '<FieldAccess for defining_names at ast.py:14072>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14072
      if Item_248.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Item_248.Node, E_Info => Item_248.Info);
--# end
--# expr-done 7533
      declare
         Map_Result_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_4;
      begin
         for Item_250 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_250
      --# expr-start 7545 '<New ParamActual at ast.py:14073>' New_Struct /tmp/lal-23.0.0/ada/ast.py:14073
--# expr-start 7544 '<If at ast.py:14075>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:14075
--# expr-start 7534 '<FieldAccess for is_dot_call at ast.py:14078>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14078
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_dot_call
Fld_9 := Libadalang.Implementation.Name_P_Is_Dot_Call (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 7534
if Fld_9 then
   --# expr-start 7535 '<Eq at ast.py:14078>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14078
Is_Equal := Index_249 = 0; 
--# expr-done 7535
   If_Result_1 := Is_Equal;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
--# expr-start 7536 '<Cast to CallExpr at ast.py:14080>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:14080
Cast_Expr_1 := Ent; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Call_Expr
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Call_Expr;
   end if;
--# expr-done 7536
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Call_Expr then
   --# scope-start
   --# bind c Var_Expr_1
--# expr-start 7539 '<FieldAccess for prefix at ast.py:14081>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14081
--# expr-start 7538 '<Cast to DottedName at ast.py:14081>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:14081
--# expr-start 7537 '<FieldAccess for name at ast.py:14081>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14081
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Call_Expr_F_Name, Info => Var_Expr_1.Info);
--# expr-done 7537
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Dotted_Name
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_2 := No_Entity_Dotted_Name;
   end if;
--# expr-done 7538
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Name (Node => Cast_Result_2.Node.Dotted_Name_F_Prefix, Info => Cast_Result_2.Info);
--# expr-done 7539
Scope_Result_1 := Fld_6;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 7541 '<FieldAccess for prefix at ast.py:14082>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14082
--# expr-start 7540 '<Cast to DottedName at ast.py:14082>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:14082
Cast_Expr_2 := Ent; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Dotted_Name
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_3 := No_Entity_Dotted_Name;
   end if;
--# expr-done 7540
      if Cast_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Cast_Result_3.Node.Dotted_Name_F_Prefix, Info => Cast_Result_3.Info);
--# expr-done 7541
   Result_Var_1 := Fld_7;
end if;
      Cast_Result_5 := Create_Internal_Entity_Expr
        (Node => Result_Var_1.Node,
         Info => Result_Var_1.Info);
   If_Result_2 := Cast_Result_5;
else
--# expr-start 7542 '<Cast to ParamSpec at ast.py:14085>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:14085
Cast_Expr_3 := Item_248; 
   if Cast_Expr_3.Node = null
      or else Cast_Expr_3.Node.Kind in Ada_Param_Spec_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Param_Spec
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
   else
         Cast_Result_4 := No_Entity_Param_Spec;
   end if;
--# expr-done 7542
Var_Expr_2 := Cast_Result_4;
if Var_Expr_2 /= No_Entity_Param_Spec then
   --# scope-start
--# expr-start 7543 '<FieldAccess for default_expr at ast.py:14085>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14085
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Var_Expr_2.Node.Param_Spec_F_Default_Expr, Info => Var_Expr_2.Info);
--# expr-done 7543
Scope_Result_2 := Fld_8;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Expr;
end if;
   If_Result_2 := Result_Var_2;
end if;
--# expr-done 7544
New_Struct := (Actual => If_Result_2, Param => Item_250); 
--# expr-done 7545
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 7546
         for Item_To_Append of
               Map_Result.Items
         loop
            Internal_Param_Actual_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2837;
               Index_249 := Index_249 + 1;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 7547
Dparams := Map_Result_1; Inc_Ref (Dparams);
--# bind dparams Dparams
Var_Expr_3 := Aparams;
if Var_Expr_3 /= No_Entity_Assoc_List then
   --# scope-start
   --# bind ap Var_Expr_3
--# expr-start 7558 '<Map at ast.py:14094>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:14094
      declare
         Map_Result_2_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
         Index_252 := 0;
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Dparams;
      begin
         for Item_251 of
               Collection.Items
         loop
   --# scope-start
               --# bind dp Item_251
               --# bind i Index_252
      --# expr-start 7557 '<New ParamActual at ast.py:14095>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:14095
--# expr-start 7555 '<If at ast.py:14099>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:14099
--# expr-start 7548 '<FieldAccess for is_dot_call at ast.py:14102>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14102
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_dot_call
Fld_15 := Libadalang.Implementation.Name_P_Is_Dot_Call (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 7548
if Fld_15 then
   --# expr-start 7549 '<Eq at ast.py:14102>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:14102
Is_Equal_1 := Index_252 = 0; 
--# expr-done 7549
   If_Result_3 := Is_Equal_1;
else
   If_Result_3 := False;
end if;
if If_Result_3 then
   --# expr-start 7550 '<FieldAccess for actual at ast.py:14104>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14104
Fld_11 := Item_251.Actual;
--# expr-done 7550
   If_Result_4 := Fld_11;
else
   --# expr-start 7554 '<FieldAccess for actual_for_param_at at ast.py:14106>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14106
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7551 '<FieldAccess for param at ast.py:14107>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14107
Fld_12 := Item_251.Param;
--# expr-done 7551
--# expr-start 7552 '<Arithmetic - at ast.py:14107>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:14107
Arith_Result := (Index_252 - Offset); 
--# expr-done 7552
--# expr-start 7553 '<FieldAccess for actual at ast.py:14107>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14107
Fld_13 := Item_251.Actual;
--# expr-done 7553
--# property-call-start AssocList.actual_for_param_at
Fld_14 := Libadalang.Implementation.Assoc_List_P_Actual_For_Param_At (Node => Var_Expr_3.Node, Param => Fld_12, Pos => Arith_Result, Default_Expr => Fld_13, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 7554
   If_Result_4 := Fld_14;
end if;
--# expr-done 7555
--# expr-start 7556 '<FieldAccess for param at ast.py:14096>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14096
Fld_10 := Item_251.Param;
--# expr-done 7556
New_Struct_1 := (Actual => If_Result_4, Param => Fld_10); 
--# expr-done 7557
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct_1;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
               Index_252 := Index_252 + 1;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 7558
Scope_Result_3 := Map_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2841;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := Dparams;
end if;
      Inc_Ref (Result_Var_3);
Let_Result := Result_Var_3; Inc_Ref (Let_Result);
--# end
--# expr-done 7559
   If_Result_5 := Let_Result;
else
   If_Result_5 := raise Property_Error with "this name doesn't reference a call expression";
end if;
      Inc_Ref (If_Result_5);
--# expr-done 7560
Let_Result_1 := If_Result_5; Inc_Ref (Let_Result_1);
--# end
--# expr-done 7561
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1043;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1043;
               Finalizer_Scope_2837;
               Finalizer_Scope_2841;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Call_Params;
--# end
 function Name_P_Parent_Scope
  (Node : Bare_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is (raise Property_Error
    with "Property Name.parent_scope not implemented on type "
    & Kind_Name (Node));
 function Name_P_All_Env_Els_Impl
  (Node : Bare_Name
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is (raise Property_Error
    with "Property Name.all_env_els_impl not implemented on type "
    & Kind_Name (Node));
--# property-start Name.scope /tmp/lal-23.0.0/ada/ast.py:13532
pragma Warnings (Off, "is not referenced");
 function Name_P_Scope
  (Node : Bare_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Empty_Env;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Scope;
--# end
 function Name_P_Ref_Var
  (Node : Bare_Name
  )
   return Logic_Var
is (raise Property_Error
    with "Property Name.ref_var not implemented on type "
    & Kind_Name (Node));
 function Name_P_Subp_Spec_Var
  (Node : Bare_Name
  )
   return Logic_Var
is (raise Property_Error
    with "Property Name.subp_spec_var not implemented on type "
    & Kind_Name (Node));
--# property-start Name.defines_subp_spec_var /tmp/lal-23.0.0/ada/ast.py:13565
pragma Warnings (Off, "is not referenced");
 function Name_P_Defines_Subp_Spec_Var
  (Node : Bare_Name
  )
   return Boolean
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7562 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 7562
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Defines_Subp_Spec_Var;
--# end
--# property-start Name.designated_type_impl /tmp/lal-23.0.0/ada/ast.py:13676
pragma Warnings (Off, "is not referenced");
 function Name_P_Designated_Type_Impl
  (Node : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Base_Type_Decl;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Designated_Type_Impl;
--# end
 function Name_P_Relative_Name
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is (raise Property_Error
    with "Property Name.relative_name not implemented on type "
    & Kind_Name (Node));
--# property-start Name.name_symbol /tmp/lal-23.0.0/ada/ast.py:13784
pragma Warnings (Off, "is not referenced");
 function Name_P_Name_Symbol
  (Node : Bare_Name
  )
   return Symbol_Type
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld : Internal_Entity_Single_Tok_Node;
Fld_1 : Bare_Single_Tok_Node;
Sym : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7565 '<GetSymbol at ast.py:13784>' Sym /tmp/lal-23.0.0/ada/ast.py:13784
--# expr-start 7564 '<FieldAccess for relative_name at ast.py:13784>' Fld /tmp/lal-23.0.0/ada/ast.py:13784
--# expr-start 7563 '<as_bare_entity at ast.py:13784>' If_Result /tmp/lal-23.0.0/ada/ast.py:13784
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 7563
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 7564
Fld_1 := Fld.Node; 
Sym := Get_Symbol (Fld_1); 
--# expr-done 7565
      Property_Result := Sym;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Name_Symbol;
--# end
--# property-start Name.as_symbol_array /tmp/lal-23.0.0/ada/ast.py:14026
pragma Warnings (Off, "is not referenced");
 function Name_P_As_Symbol_Array
  (Node : Bare_Name
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1040 with Inline_Always;
      Fld : Bare_Single_Tok_Node_Array_Access;
Sym : Symbol_Type;
Map_Result : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1040 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1040;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7569 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7568 '<Map at ast.py:14036>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14036
   --# expr-start 7566 '<FieldAccess for as_single_tok_node_array at ast.py:14036>' Fld /tmp/lal-23.0.0/ada/ast.py:14036
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.as_single_tok_node_array
Fld := Libadalang.Implementation.Name_P_As_Single_Tok_Node_Array (Node => Self);
--# end
--# expr-done 7566
      declare
         Map_Result_Vec : Symbol_Type_Vectors.Vector;
      begin
      declare
         Collection : constant Bare_Single_Tok_Node_Array_Access := Fld;
      begin
         for Item_247 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_247
      --# expr-start 7567 '<GetSymbol at ast.py:14036>' Sym /tmp/lal-23.0.0/ada/ast.py:14036
Sym := Get_Symbol (Item_247); 
--# expr-done 7567
         declare
            Item_To_Append : constant Symbol_Type := Sym;
         begin
            Symbol_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Symbol_Type_Array
           (Items_Count => Natural (Symbol_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Symbol_Type_Vectors.Get
              (Map_Result_Vec,
               I + Symbol_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Symbol_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 7568
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 7569
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1040;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1040;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_As_Symbol_Array;
--# end
--# property-start Name.canonical_text /tmp/lal-23.0.0/ada/ast.py:14039
pragma Warnings (Off, "is not referenced");
 function Name_P_Canonical_Text
  (Node : Bare_Name
  )
   return Symbol_Type
is
   Self : Bare_Name := Bare_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
            procedure Finalizer_Scope_1041 with Inline_Always;
      Fld : Symbol_Type_Array_Access;
Str : String_Type;
Fld_1 : String_Type;
Sym : Symbol_Type;
Let_Result : Symbol_Type;
            procedure Finalizer_Scope_1041 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Str);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1041;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7574 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7573 '<to_symbol at ast.py:14046>' Sym /tmp/lal-23.0.0/ada/ast.py:14046
--# expr-start 7572 '<FieldAccess for sym_join at ast.py:14046>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14046
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7570 '<FieldAccess for as_symbol_array at ast.py:14046>' Fld /tmp/lal-23.0.0/ada/ast.py:14046
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Self);
--# end
--# expr-done 7570
--# expr-start 7571 '<String at ast.py:14046>' Str /tmp/lal-23.0.0/ada/ast.py:14046
Str := Create_String ("."); 
--# expr-done 7571
--# property-call-start AdaNode.sym_join
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sym_Join (Node => Self, Syms => Fld, Sep => Str);
--# end
--# expr-done 7572
Sym := String_To_Symbol (Self, Self.Unit.Context, Fld_1); 
--# expr-done 7573
Let_Result := Sym; 
--# end
--# expr-done 7574
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1041;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1041;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Name_P_Canonical_Text;
--# end
 function Name_P_Is_Constant
  (Node : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is (raise Property_Error
    with "Property Name.is_constant not implemented on type "
    & Kind_Name (Node));
function Name_P_Name_Designated_Type_Env
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Name_P_Name_Designated_Type_Env (E.Node, E_Info);
begin
      return Result;
end;
function Name_P_Use_Package_Name_Designated_Env
  (E : Entity
  ) return Lexical_Env
is
      E_Info : Internal_Entity_Info :=
         Shed_Rebindings (E.Info, Node_Env (E.Node));
   Result : constant Lexical_Env :=
      Name_P_Use_Package_Name_Designated_Env (E.Node, E_Info);
begin
      return Result;
end;
   --
   --  Primitives for Bare_Attribute_Ref
   --
      procedure Initialize_Fields_For_Attribute_Ref
        (Self : Bare_Attribute_Ref
         ; Attribute_Ref_F_Prefix : Bare_Name
         ; Attribute_Ref_F_Attribute : Bare_Identifier
         ; Attribute_Ref_F_Args : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Attribute_Ref_F_Prefix := Attribute_Ref_F_Prefix;
            Self.Attribute_Ref_F_Attribute := Attribute_Ref_F_Attribute;
            Self.Attribute_Ref_F_Args := Attribute_Ref_F_Args;
      Self.Attribute_Ref_R_Ref_Var := Null_Var_Record;
      end Initialize_Fields_For_Attribute_Ref;
   function Attribute_Ref_F_Prefix
     (Node : Bare_Attribute_Ref) return Bare_Name
   is
   begin
         return Node.Attribute_Ref_F_Prefix;
   end;
   function Attribute_Ref_F_Attribute
     (Node : Bare_Attribute_Ref) return Bare_Identifier
   is
   begin
         return Node.Attribute_Ref_F_Attribute;
   end;
   function Attribute_Ref_F_Args
     (Node : Bare_Attribute_Ref) return Bare_Assoc_List
   is
   begin
         return Node.Attribute_Ref_F_Args;
   end;
--# property-start AttributeRef.ref_var /tmp/lal-23.0.0/ada/ast.py:18052
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Ref_Var
  (Node : Bare_Attribute_Ref
  )
   return Logic_Var
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7575 '<FieldAccess for r_ref_var at ast.py:18052>' Fld /tmp/lal-23.0.0/ada/ast.py:18052
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Attribute_Ref_R_Ref_Var'Unrestricted_Access;
--# expr-done 7575
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Ref_Var;
--# end
--# property-start AttributeRef.relative_name /tmp/lal-23.0.0/ada/ast.py:18055
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Relative_Name
  (Node : Bare_Attribute_Ref
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7577 '<FieldAccess for relative_name at ast.py:18055>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18055
--# expr-start 7576 '<FieldAccess for prefix at ast.py:18055>' Fld /tmp/lal-23.0.0/ada/ast.py:18055
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7576
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 7577
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Relative_Name;
--# end
--# property-start AttributeRef.is_constant /tmp/lal-23.0.0/ada/ast.py:18057
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Is_Constant
  (Node : Bare_Attribute_Ref
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Is_Constant;
--# end
--# property-start AttributeRef.designated_type_impl /tmp/lal-23.0.0/ada/ast.py:18059
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Designated_Type_Impl
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Bare_Identifier;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Classwide_Type_Decl;
Scope_Result : Internal_Entity_Classwide_Type_Decl;
Result_Var : Internal_Entity_Classwide_Type_Decl;
Fld_5 : Bare_Identifier;
Fld_6 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
Fld_7 : Internal_Entity_Name;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Internal_Entity_Discrete_Base_Subtype_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
If_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
If_Result_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7592 '<Cond at ast.py:18059>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:18059
--# expr-start 7581 '<Eq at ast.py:18060>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18060
--# expr-start 7579 '<FieldAccess for sym at ast.py:18060>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18060
--# expr-start 7578 '<FieldAccess for attribute at ast.py:18060>' Fld /tmp/lal-23.0.0/ada/ast.py:18060
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Attribute_Ref_F_Attribute;
--# expr-done 7578
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_1 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld);
--# end
--# expr-done 7579
--# expr-start 7580 '<Symbol Class at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Class); 
--# expr-done 7580
Is_Equal := Fld_1 = Sym; 
--# expr-done 7581
if Is_Equal then
--# expr-start 7583 '<FieldAccess for designated_type_impl at ast.py:18061>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18061
--# expr-start 7582 '<FieldAccess for prefix at ast.py:18061>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18061
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7582
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 7583
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7584 '<FieldAccess for classwide_type at ast.py:18061>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18061
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 7584
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Classwide_Type_Decl;
end if;
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   If_Result_1 := Cast_Result_1;
else
--# expr-start 7588 '<Eq at ast.py:18063>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:18063
--# expr-start 7586 '<FieldAccess for sym at ast.py:18063>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18063
--# expr-start 7585 '<FieldAccess for attribute at ast.py:18063>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18063
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Attribute_Ref_F_Attribute;
--# expr-done 7585
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_6 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_5);
--# end
--# expr-done 7586
--# expr-start 7587 '<Symbol Base at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Base); 
--# expr-done 7587
Is_Equal_1 := Fld_6 = Sym_1; 
--# expr-done 7588
if Is_Equal_1 then
--# expr-start 7591 '<FieldAccess for scalar_base_subtype at ast.py:18064>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18064
--# expr-start 7590 '<FieldAccess for name_designated_type at ast.py:18064>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18064
--# expr-start 7589 '<FieldAccess for prefix at ast.py:18064>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18064
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7589
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_8 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# end
--# expr-done 7590
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.scalar_base_subtype
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Scalar_Base_Subtype (Node => Fld_8.Node, E_Info => Fld_8.Info);
--# end
--# expr-done 7591
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   If_Result := Cast_Result;
else
   If_Result := No_Entity_Base_Type_Decl;
end if;
   If_Result_1 := If_Result;
end if;
--# expr-done 7592
      Property_Result := If_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Designated_Type_Impl;
--# end
--# property-start AttributeRef.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:18069
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Has_Context_Free_Type
  (Node : Bare_Attribute_Ref
  )
   return Boolean
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 7594 '<Not at ast.py:18069>' Not_Val /tmp/lal-23.0.0/ada/ast.py:18069
--# expr-start 7593 '<FieldAccess for is_access_attr at ast.py:18069>' Fld /tmp/lal-23.0.0/ada/ast.py:18069
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.is_access_attr
Fld := Libadalang.Implementation.Attribute_Ref_P_Is_Access_Attr (Node => Self);
--# end
--# expr-done 7593
Not_Val := not (Fld); 
--# expr-done 7594
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Has_Context_Free_Type;
--# end
--# property-start AttributeRef.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:18072
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Env_Elements_Impl
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1302 with Inline_Always;
      Fld : Bare_Identifier;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Array_Access;
If_Result : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1302 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1302;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7602 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7601 '<Cond at ast.py:18073>' If_Result /tmp/lal-23.0.0/ada/ast.py:18073
--# expr-start 7598 '<Eq at ast.py:18074>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18074
--# expr-start 7596 '<FieldAccess for sym at ast.py:18074>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18074
--# expr-start 7595 '<FieldAccess for attribute at ast.py:18074>' Fld /tmp/lal-23.0.0/ada/ast.py:18074
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Attribute_Ref_F_Attribute;
--# expr-done 7595
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_1 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld);
--# end
--# expr-done 7596
--# expr-start 7597 '<Symbol Unrestricted_Access at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unrestricted_Access); 
--# expr-done 7597
Is_Equal := Fld_1 = Sym; 
--# expr-done 7598
if Is_Equal then
   --# expr-start 7600 '<FieldAccess for env_elements_impl at ast.py:18079>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18079
--# expr-start 7599 '<FieldAccess for prefix at ast.py:18079>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18079
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7599
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Fld_2.Node, Env => Env, E_Info => Fld_2.Info);
--# end
--# expr-done 7600
   If_Result := Fld_3;
else
   If_Result := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 7601
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 7602
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1302;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1302;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Env_Elements_Impl;
--# end
--# property-start AttributeRef.is_access_attr /tmp/lal-23.0.0/ada/ast.py:18084
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Is_Access_Attr
  (Node : Bare_Attribute_Ref
  )
   return Boolean
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Identifier;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_2 : Bare_Identifier;
Fld_3 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_4 : Bare_Identifier;
Fld_5 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 7606 '<Eq at ast.py:18085>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18085
--# expr-start 7604 '<FieldAccess for name_symbol at ast.py:18085>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18085
--# expr-start 7603 '<FieldAccess for attribute at ast.py:18085>' Fld /tmp/lal-23.0.0/ada/ast.py:18085
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Attribute_Ref_F_Attribute;
--# expr-done 7603
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld);
--# end
--# expr-done 7604
--# expr-start 7605 '<Symbol Access at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Access); 
--# expr-done 7605
Is_Equal := Fld_1 = Sym; 
--# expr-done 7606
if Is_Equal then
   If_Result := True;
else
   --# expr-start 7610 '<Eq at ast.py:18085>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:18085
--# expr-start 7608 '<FieldAccess for name_symbol at ast.py:18085>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18085
--# expr-start 7607 '<FieldAccess for attribute at ast.py:18085>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18085
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Attribute_Ref_F_Attribute;
--# expr-done 7607
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_2);
--# end
--# expr-done 7608
--# expr-start 7609 '<Symbol Unchecked_Access at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unchecked_Access); 
--# expr-done 7609
Is_Equal_1 := Fld_3 = Sym_1; 
--# expr-done 7610
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 7614 '<Eq at ast.py:18085>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:18085
--# expr-start 7612 '<FieldAccess for name_symbol at ast.py:18085>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18085
--# expr-start 7611 '<FieldAccess for attribute at ast.py:18085>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18085
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Attribute_Ref_F_Attribute;
--# expr-done 7611
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_4);
--# end
--# expr-done 7612
--# expr-start 7613 '<Symbol Unrestricted_Access at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unrestricted_Access); 
--# expr-done 7613
Is_Equal_2 := Fld_5 = Sym_2; 
--# expr-done 7614
   If_Result_1 := Is_Equal_2;
end if;
      Property_Result := If_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Is_Access_Attr;
--# end
--# property-start AttributeRef.designated_env /tmp/lal-23.0.0/ada/ast.py:18091
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Designated_Env
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1304 with Inline_Always;
      Fld : Boolean;
Fld_1 : Internal_Entity_Name;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Internal_Entity_Identifier;
Sym : Symbol_Type;
Fld_4 : Boolean;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Base_Subp_Spec;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Lexical_Env := Empty_Env;
If_Result_1 : Lexical_Env := Empty_Env;
If_Result_2 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1304 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Node_Parents);
                     Dec_Ref (Fld_7);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1304;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7630 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7629 '<Cond at ast.py:18092>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:18092
--# expr-start 7615 '<FieldAccess for is_access_attr at ast.py:18093>' Fld /tmp/lal-23.0.0/ada/ast.py:18093
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.is_access_attr
Fld := Libadalang.Implementation.Attribute_Ref_P_Is_Access_Attr (Node => Ent.Node);
--# end
--# expr-done 7615
if Fld then
   --# expr-start 7617 '<FieldAccess for designated_env at ast.py:18094>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18094
--# expr-start 7616 '<FieldAccess for prefix at ast.py:18094>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18094
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7616
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_2 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld_1.Node, Env => Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Fld_1.Info);
--# end
--# expr-done 7617
   If_Result_2 := Fld_2;
else
--# expr-start 7620 '<FieldAccess for name_is at ast.py:18096>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18096
--# expr-start 7618 '<FieldAccess for attribute at ast.py:18096>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18096
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Identifier (Node => Ent.Node.Attribute_Ref_F_Attribute, Info => Ent.Info);
--# expr-done 7618
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7619 '<Symbol Result at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Result); 
--# expr-done 7619
--# property-call-start Name.name_is
Fld_4 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_3.Node, Sym => Sym);
--# end
--# expr-done 7620
if Fld_4 then
   --# expr-start 7628 '<FieldAccess for defining_env at ast.py:18099>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18099
--# expr-start 7627 '<FieldAccess for return_type at ast.py:18099>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18099
--# expr-start 7626 '<FieldAccess for subp_spec_or_null at ast.py:18098>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18098
--# expr-start 7625 '<Cast to BasicDecl at ast.py:18098>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18098
--# expr-start 7624 '<as_entity at ast.py:18098>' If_Result /tmp/lal-23.0.0/ada/ast.py:18098
--# expr-start 7623 '<Find at ast.py:18097>' Find_Result /tmp/lal-23.0.0/ada/ast.py:18097
   --# expr-start 7621 '<FieldAccess for parents at ast.py:18097>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:18097
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 7621
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_253 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_253
      --# expr-start 7622 '<IsA BasicSubpDecl, SubpBody at ast.py:18097>' Is_A /tmp/lal-23.0.0/ada/ast.py:18097
Is_A := Item_253 /= null 
and then Item_253.Kind in Ada_Basic_Subp_Decl | Ada_Subp_Body_Range; 
--# expr-done 7622
      if Is_A then
         Find_Result := Item_253;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 7623
Is_Null := Find_Result = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Find_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 7624
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 7625
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 7626
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_6 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld_5.Node, Origin => Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 7627
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld_6.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Fld_6.Info);
--# end
--# expr-done 7628
   If_Result_1 := Fld_7;
else
   If_Result_1 := Empty_Env;
end if;
      Inc_Ref (If_Result_1);
   If_Result_2 := If_Result_1;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 7629
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 7630
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1304;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1304;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Designated_Env;
--# end
--# property-start AttributeRef.synthesize_attribute_subprogram /tmp/lal-23.0.0/ada/ast.py:18105
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Synthesize_Attribute_Subprogram
  (Node : Bare_Attribute_Ref
      ; Typ : Internal_Entity_Base_Type_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Subp_Decl
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   Property_Result : Internal_Entity_Basic_Subp_Decl;
      Block_Var : Symbol_Type;
Block_Var_1 : Bare_Type_Attributes_Repository;
Block_Var_2 : Bare_Basic_Subp_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Identifier;
Fld_1 : Symbol_Type;
Fld_2 : Bare_Type_Attributes_Repository;
Scope_Result : Bare_Type_Attributes_Repository;
Result_Var : Bare_Type_Attributes_Repository;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_3 : Bare_Basic_Subp_Decl;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
Fld_4 : Bare_Basic_Subp_Decl;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
Fld_5 : Bare_Basic_Subp_Decl;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
Fld_6 : Bare_Basic_Subp_Decl;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
Fld_7 : Bare_Basic_Subp_Decl;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
Fld_8 : Bare_Basic_Subp_Decl;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
Fld_9 : Bare_Basic_Subp_Decl;
Sym_7 : Symbol_Type;
Is_Equal_7 : Boolean;
Fld_10 : Bare_Basic_Subp_Decl;
Sym_8 : Symbol_Type;
Is_Equal_8 : Boolean;
Fld_11 : Bare_Basic_Subp_Decl;
Sym_9 : Symbol_Type;
Is_Equal_9 : Boolean;
Fld_12 : Bare_Basic_Subp_Decl;
Sym_10 : Symbol_Type;
Is_Equal_10 : Boolean;
Fld_13 : Bare_Basic_Subp_Decl;
Sym_11 : Symbol_Type;
Is_Equal_11 : Boolean;
Fld_14 : Bare_Basic_Subp_Decl;
Sym_12 : Symbol_Type;
Is_Equal_12 : Boolean;
Fld_15 : Bare_Basic_Subp_Decl;
Sym_13 : Symbol_Type;
Is_Equal_13 : Boolean;
Fld_16 : Bare_Basic_Subp_Decl;
Sym_14 : Symbol_Type;
Is_Equal_14 : Boolean;
Fld_17 : Bare_Basic_Subp_Decl;
Sym_15 : Symbol_Type;
Is_Equal_15 : Boolean;
Fld_18 : Bare_Basic_Subp_Decl;
Sym_16 : Symbol_Type;
Is_Equal_16 : Boolean;
Fld_19 : Bare_Basic_Subp_Decl;
Sym_17 : Symbol_Type;
Is_Equal_17 : Boolean;
Fld_20 : Bare_Basic_Subp_Decl;
Sym_18 : Symbol_Type;
Is_Equal_18 : Boolean;
Fld_21 : Bare_Basic_Subp_Decl;
Sym_19 : Symbol_Type;
Is_Equal_19 : Boolean;
Fld_22 : Bare_Basic_Subp_Decl;
Sym_20 : Symbol_Type;
Is_Equal_20 : Boolean;
Fld_23 : Bare_Basic_Subp_Decl;
Sym_21 : Symbol_Type;
Is_Equal_21 : Boolean;
Fld_24 : Bare_Basic_Subp_Decl;
Sym_22 : Symbol_Type;
Is_Equal_22 : Boolean;
Fld_25 : Bare_Basic_Subp_Decl;
Sym_23 : Symbol_Type;
Is_Equal_23 : Boolean;
Fld_26 : Bare_Basic_Subp_Decl;
Sym_24 : Symbol_Type;
Is_Equal_24 : Boolean;
Fld_27 : Bare_Basic_Subp_Decl;
Sym_25 : Symbol_Type;
Is_Equal_25 : Boolean;
Fld_28 : Bare_Basic_Subp_Decl;
Sym_26 : Symbol_Type;
Is_Equal_26 : Boolean;
Fld_29 : Bare_Basic_Subp_Decl;
Sym_27 : Symbol_Type;
Is_Equal_27 : Boolean;
Fld_30 : Bare_Basic_Subp_Decl;
Sym_28 : Symbol_Type;
Is_Equal_28 : Boolean;
Fld_31 : Bare_Basic_Subp_Decl;
Sym_29 : Symbol_Type;
Is_Equal_29 : Boolean;
Fld_32 : Bare_Basic_Subp_Decl;
Sym_30 : Symbol_Type;
Is_Equal_30 : Boolean;
Fld_33 : Bare_Basic_Subp_Decl;
Sym_31 : Symbol_Type;
Is_Equal_31 : Boolean;
Fld_34 : Bare_Basic_Subp_Decl;
Sym_32 : Symbol_Type;
Is_Equal_32 : Boolean;
Fld_35 : Bare_Basic_Subp_Decl;
Sym_33 : Symbol_Type;
Is_Equal_33 : Boolean;
Fld_36 : Bare_Basic_Subp_Decl;
Sym_34 : Symbol_Type;
Is_Equal_34 : Boolean;
Fld_37 : Bare_Basic_Subp_Decl;
Sym_35 : Symbol_Type;
Is_Equal_35 : Boolean;
Fld_38 : Bare_Basic_Subp_Decl;
Sym_36 : Symbol_Type;
Is_Equal_36 : Boolean;
Fld_39 : Bare_Basic_Subp_Decl;
If_Result : Bare_Basic_Subp_Decl;
If_Result_1 : Bare_Basic_Subp_Decl;
If_Result_2 : Bare_Basic_Subp_Decl;
If_Result_3 : Bare_Basic_Subp_Decl;
If_Result_4 : Bare_Basic_Subp_Decl;
If_Result_5 : Bare_Basic_Subp_Decl;
If_Result_6 : Bare_Basic_Subp_Decl;
If_Result_7 : Bare_Basic_Subp_Decl;
If_Result_8 : Bare_Basic_Subp_Decl;
If_Result_9 : Bare_Basic_Subp_Decl;
If_Result_10 : Bare_Basic_Subp_Decl;
If_Result_11 : Bare_Basic_Subp_Decl;
If_Result_12 : Bare_Basic_Subp_Decl;
If_Result_13 : Bare_Basic_Subp_Decl;
If_Result_14 : Bare_Basic_Subp_Decl;
If_Result_15 : Bare_Basic_Subp_Decl;
If_Result_16 : Bare_Basic_Subp_Decl;
If_Result_17 : Bare_Basic_Subp_Decl;
If_Result_18 : Bare_Basic_Subp_Decl;
If_Result_19 : Bare_Basic_Subp_Decl;
If_Result_20 : Bare_Basic_Subp_Decl;
If_Result_21 : Bare_Basic_Subp_Decl;
If_Result_22 : Bare_Basic_Subp_Decl;
If_Result_23 : Bare_Basic_Subp_Decl;
If_Result_24 : Bare_Basic_Subp_Decl;
If_Result_25 : Bare_Basic_Subp_Decl;
If_Result_26 : Bare_Basic_Subp_Decl;
If_Result_27 : Bare_Basic_Subp_Decl;
If_Result_28 : Bare_Basic_Subp_Decl;
If_Result_29 : Bare_Basic_Subp_Decl;
If_Result_30 : Bare_Basic_Subp_Decl;
If_Result_31 : Bare_Basic_Subp_Decl;
If_Result_32 : Bare_Basic_Subp_Decl;
If_Result_33 : Bare_Basic_Subp_Decl;
If_Result_34 : Bare_Basic_Subp_Decl;
If_Result_35 : Bare_Basic_Subp_Decl;
If_Result_36 : Bare_Basic_Subp_Decl;
Fld_40 : Internal_Entity_Info;
Fld_41 : Env_Rebindings;
Fld_42 : Internal_Entity_Info;
Fld_43 : Boolean;
New_Struct : Internal_Entity_Info;
New_Struct_1 : Internal_Entity_Basic_Subp_Decl;
Let_Result : Internal_Entity_Basic_Subp_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7752 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7632 '<FieldAccess for name_symbol at ast.py:18106>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18106
--# expr-start 7631 '<FieldAccess for attribute at ast.py:18106>' Fld /tmp/lal-23.0.0/ada/ast.py:18106
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Attribute_Ref_F_Attribute, Info => Ent.Info);
--# expr-done 7631
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 7632
Block_Var := Fld_1; 
--# bind rel_name Block_Var
Var_Expr := Typ;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7633 '<FieldAccess for attributes_repo at ast.py:18107>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18107
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.attributes_repo
Fld_2 := Libadalang.Implementation.Base_Type_Decl_F_Attributes_Repo (Node => Var_Expr.Node);
--# end
--# expr-done 7633
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Block_Var_1 := Result_Var; 
--# bind repo Block_Var_1
--# expr-start 7745 '<Cond at ast.py:18108>' If_Result_36 /tmp/lal-23.0.0/ada/ast.py:18108
--# expr-start 7635 '<Eq at ast.py:18109>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18109
--# expr-start 7634 '<Symbol succ at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Succ_354); 
--# expr-done 7634
Is_Equal := Block_Var = Sym; 
--# expr-done 7635
if Is_Equal then
   --# expr-start 7636 '<FieldAccess for succ at ast.py:18109>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18109
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.succ
Fld_3 := Libadalang.Implementation.Type_Attributes_Repository_F_Succ (Node => Block_Var_1);
--# end
--# expr-done 7636
   If_Result_36 := Fld_3;
else
--# expr-start 7638 '<Eq at ast.py:18110>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:18110
--# expr-start 7637 '<Symbol pred at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pred_328); 
--# expr-done 7637
Is_Equal_1 := Block_Var = Sym_1; 
--# expr-done 7638
if Is_Equal_1 then
   --# expr-start 7639 '<FieldAccess for pred at ast.py:18110>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18110
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.pred
Fld_4 := Libadalang.Implementation.Type_Attributes_Repository_F_Pred (Node => Block_Var_1);
--# end
--# expr-done 7639
   If_Result_35 := Fld_4;
else
--# expr-start 7641 '<Eq at ast.py:18111>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:18111
--# expr-start 7640 '<Symbol min at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Min_314); 
--# expr-done 7640
Is_Equal_2 := Block_Var = Sym_2; 
--# expr-done 7641
if Is_Equal_2 then
   --# expr-start 7642 '<FieldAccess for min at ast.py:18111>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18111
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.min
Fld_5 := Libadalang.Implementation.Type_Attributes_Repository_F_Min (Node => Block_Var_1);
--# end
--# expr-done 7642
   If_Result_34 := Fld_5;
else
--# expr-start 7644 '<Eq at ast.py:18112>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:18112
--# expr-start 7643 '<Symbol max at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Max_313); 
--# expr-done 7643
Is_Equal_3 := Block_Var = Sym_3; 
--# expr-done 7644
if Is_Equal_3 then
   --# expr-start 7645 '<FieldAccess for max at ast.py:18112>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18112
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.max
Fld_6 := Libadalang.Implementation.Type_Attributes_Repository_F_Max (Node => Block_Var_1);
--# end
--# expr-done 7645
   If_Result_33 := Fld_6;
else
--# expr-start 7647 '<Eq at ast.py:18114>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:18114
--# expr-start 7646 '<Symbol rounding at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rounding_347); 
--# expr-done 7646
Is_Equal_4 := Block_Var = Sym_4; 
--# expr-done 7647
if Is_Equal_4 then
   --# expr-start 7648 '<FieldAccess for rounding at ast.py:18114>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18114
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.rounding
Fld_7 := Libadalang.Implementation.Type_Attributes_Repository_F_Rounding (Node => Block_Var_1);
--# end
--# expr-done 7648
   If_Result_32 := Fld_7;
else
--# expr-start 7650 '<Eq at ast.py:18115>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:18115
--# expr-start 7649 '<Symbol ceiling at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ceiling_276); 
--# expr-done 7649
Is_Equal_5 := Block_Var = Sym_5; 
--# expr-done 7650
if Is_Equal_5 then
   --# expr-start 7651 '<FieldAccess for ceiling at ast.py:18115>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18115
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.ceiling
Fld_8 := Libadalang.Implementation.Type_Attributes_Repository_F_Ceiling (Node => Block_Var_1);
--# end
--# expr-done 7651
   If_Result_31 := Fld_8;
else
--# expr-start 7653 '<Eq at ast.py:18116>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:18116
--# expr-start 7652 '<Symbol floor at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Floor_295); 
--# expr-done 7652
Is_Equal_6 := Block_Var = Sym_6; 
--# expr-done 7653
if Is_Equal_6 then
   --# expr-start 7654 '<FieldAccess for floor at ast.py:18116>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18116
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.floor
Fld_9 := Libadalang.Implementation.Type_Attributes_Repository_F_Floor (Node => Block_Var_1);
--# end
--# expr-done 7654
   If_Result_30 := Fld_9;
else
--# expr-start 7656 '<Eq at ast.py:18117>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:18117
--# expr-start 7655 '<Symbol truncation at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Truncation_361); 
--# expr-done 7655
Is_Equal_7 := Block_Var = Sym_7; 
--# expr-done 7656
if Is_Equal_7 then
   --# expr-start 7657 '<FieldAccess for truncation at ast.py:18117>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18117
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.truncation
Fld_10 := Libadalang.Implementation.Type_Attributes_Repository_F_Truncation (Node => Block_Var_1);
--# end
--# expr-done 7657
   If_Result_29 := Fld_10;
else
--# expr-start 7659 '<Eq at ast.py:18118>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:18118
--# expr-start 7658 '<Symbol machine at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_311); 
--# expr-done 7658
Is_Equal_8 := Block_Var = Sym_8; 
--# expr-done 7659
if Is_Equal_8 then
   --# expr-start 7660 '<FieldAccess for machine at ast.py:18118>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18118
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.machine
Fld_11 := Libadalang.Implementation.Type_Attributes_Repository_F_Machine (Node => Block_Var_1);
--# end
--# expr-done 7660
   If_Result_28 := Fld_11;
else
--# expr-start 7662 '<Eq at ast.py:18119>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:18119
--# expr-start 7661 '<Symbol machine_rounding at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Rounding_312); 
--# expr-done 7661
Is_Equal_9 := Block_Var = Sym_9; 
--# expr-done 7662
if Is_Equal_9 then
   --# expr-start 7663 '<FieldAccess for machine_rounding at ast.py:18119>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18119
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.machine_rounding
Fld_12 := Libadalang.Implementation.Type_Attributes_Repository_F_Machine_Rounding (Node => Block_Var_1);
--# end
--# expr-done 7663
   If_Result_27 := Fld_12;
else
--# expr-start 7665 '<Eq at ast.py:18120>' Is_Equal_10 /tmp/lal-23.0.0/ada/ast.py:18120
--# expr-start 7664 '<Symbol fraction at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fraction_297); 
--# expr-done 7664
Is_Equal_10 := Block_Var = Sym_10; 
--# expr-done 7665
if Is_Equal_10 then
   --# expr-start 7666 '<FieldAccess for fraction at ast.py:18120>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18120
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.fraction
Fld_13 := Libadalang.Implementation.Type_Attributes_Repository_F_Fraction (Node => Block_Var_1);
--# end
--# expr-done 7666
   If_Result_26 := Fld_13;
else
--# expr-start 7668 '<Eq at ast.py:18121>' Is_Equal_11 /tmp/lal-23.0.0/ada/ast.py:18121
--# expr-start 7667 '<Symbol exponent at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exponent_293); 
--# expr-done 7667
Is_Equal_11 := Block_Var = Sym_11; 
--# expr-done 7668
if Is_Equal_11 then
   --# expr-start 7669 '<FieldAccess for exponent at ast.py:18121>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18121
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.exponent
Fld_14 := Libadalang.Implementation.Type_Attributes_Repository_F_Exponent (Node => Block_Var_1);
--# end
--# expr-done 7669
   If_Result_25 := Fld_14;
else
--# expr-start 7671 '<Eq at ast.py:18123>' Is_Equal_12 /tmp/lal-23.0.0/ada/ast.py:18123
--# expr-start 7670 '<Symbol copy_sign at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Copy_Sign_279); 
--# expr-done 7670
Is_Equal_12 := Block_Var = Sym_12; 
--# expr-done 7671
if Is_Equal_12 then
   --# expr-start 7672 '<FieldAccess for copy_sign at ast.py:18123>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:18123
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.copy_sign
Fld_15 := Libadalang.Implementation.Type_Attributes_Repository_F_Copy_Sign (Node => Block_Var_1);
--# end
--# expr-done 7672
   If_Result_24 := Fld_15;
else
--# expr-start 7674 '<Eq at ast.py:18124>' Is_Equal_13 /tmp/lal-23.0.0/ada/ast.py:18124
--# expr-start 7673 '<Symbol remainder at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Remainder_338); 
--# expr-done 7673
Is_Equal_13 := Block_Var = Sym_13; 
--# expr-done 7674
if Is_Equal_13 then
   --# expr-start 7675 '<FieldAccess for remainder at ast.py:18124>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:18124
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.remainder
Fld_16 := Libadalang.Implementation.Type_Attributes_Repository_F_Remainder (Node => Block_Var_1);
--# end
--# expr-done 7675
   If_Result_23 := Fld_16;
else
--# expr-start 7677 '<Eq at ast.py:18125>' Is_Equal_14 /tmp/lal-23.0.0/ada/ast.py:18125
--# expr-start 7676 '<Symbol adjacent at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Adjacent_265); 
--# expr-done 7676
Is_Equal_14 := Block_Var = Sym_14; 
--# expr-done 7677
if Is_Equal_14 then
   --# expr-start 7678 '<FieldAccess for adjacent at ast.py:18125>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:18125
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.adjacent
Fld_17 := Libadalang.Implementation.Type_Attributes_Repository_F_Adjacent (Node => Block_Var_1);
--# end
--# expr-done 7678
   If_Result_22 := Fld_17;
else
--# expr-start 7680 '<Eq at ast.py:18126>' Is_Equal_15 /tmp/lal-23.0.0/ada/ast.py:18126
--# expr-start 7679 '<Symbol scaling at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Scaling_348); 
--# expr-done 7679
Is_Equal_15 := Block_Var = Sym_15; 
--# expr-done 7680
if Is_Equal_15 then
   --# expr-start 7681 '<FieldAccess for scaling at ast.py:18126>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:18126
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.scaling
Fld_18 := Libadalang.Implementation.Type_Attributes_Repository_F_Scaling (Node => Block_Var_1);
--# end
--# expr-done 7681
   If_Result_21 := Fld_18;
else
--# expr-start 7683 '<Eq at ast.py:18127>' Is_Equal_16 /tmp/lal-23.0.0/ada/ast.py:18127
--# expr-start 7682 '<Symbol compose at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Compose_277); 
--# expr-done 7682
Is_Equal_16 := Block_Var = Sym_16; 
--# expr-done 7683
if Is_Equal_16 then
   --# expr-start 7684 '<FieldAccess for compose at ast.py:18127>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:18127
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.compose
Fld_19 := Libadalang.Implementation.Type_Attributes_Repository_F_Compose (Node => Block_Var_1);
--# end
--# expr-done 7684
   If_Result_20 := Fld_19;
else
--# expr-start 7686 '<Eq at ast.py:18129>' Is_Equal_17 /tmp/lal-23.0.0/ada/ast.py:18129
--# expr-start 7685 '<Symbol mod at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod_315); 
--# expr-done 7685
Is_Equal_17 := Block_Var = Sym_17; 
--# expr-done 7686
if Is_Equal_17 then
   --# expr-start 7687 '<FieldAccess for mod at ast.py:18129>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:18129
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.mod
Fld_20 := Libadalang.Implementation.Type_Attributes_Repository_F_Mod (Node => Block_Var_1);
--# end
--# expr-done 7687
   If_Result_19 := Fld_20;
else
--# expr-start 7689 '<Eq at ast.py:18131>' Is_Equal_18 /tmp/lal-23.0.0/ada/ast.py:18131
--# expr-start 7688 '<Symbol image at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Image_302); 
--# expr-done 7688
Is_Equal_18 := Block_Var = Sym_18; 
--# expr-done 7689
if Is_Equal_18 then
   --# expr-start 7690 '<FieldAccess for image at ast.py:18131>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:18131
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.image
Fld_21 := Libadalang.Implementation.Type_Attributes_Repository_F_Image (Node => Block_Var_1);
--# end
--# expr-done 7690
   If_Result_18 := Fld_21;
else
--# expr-start 7692 '<Eq at ast.py:18132>' Is_Equal_19 /tmp/lal-23.0.0/ada/ast.py:18132
--# expr-start 7691 '<Symbol wide_image at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Image_369); 
--# expr-done 7691
Is_Equal_19 := Block_Var = Sym_19; 
--# expr-done 7692
if Is_Equal_19 then
   --# expr-start 7693 '<FieldAccess for wide_image at ast.py:18132>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:18132
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.wide_image
Fld_22 := Libadalang.Implementation.Type_Attributes_Repository_F_Wide_Image (Node => Block_Var_1);
--# end
--# expr-done 7693
   If_Result_17 := Fld_22;
else
--# expr-start 7695 '<Eq at ast.py:18133>' Is_Equal_20 /tmp/lal-23.0.0/ada/ast.py:18133
--# expr-start 7694 '<Symbol wide_wide_image at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Image_372); 
--# expr-done 7694
Is_Equal_20 := Block_Var = Sym_20; 
--# expr-done 7695
if Is_Equal_20 then
   --# expr-start 7696 '<FieldAccess for wide_wide_image at ast.py:18133>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:18133
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.wide_wide_image
Fld_23 := Libadalang.Implementation.Type_Attributes_Repository_F_Wide_Wide_Image (Node => Block_Var_1);
--# end
--# expr-done 7696
   If_Result_16 := Fld_23;
else
--# expr-start 7698 '<Eq at ast.py:18134>' Is_Equal_21 /tmp/lal-23.0.0/ada/ast.py:18134
--# expr-start 7697 '<Symbol put_image at ???>' Sym_21 None
Sym_21 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image_332); 
--# expr-done 7697
Is_Equal_21 := Block_Var = Sym_21; 
--# expr-done 7698
if Is_Equal_21 then
   --# expr-start 7699 '<FieldAccess for put_image at ast.py:18134>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:18134
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.put_image
Fld_24 := Libadalang.Implementation.Type_Attributes_Repository_F_Put_Image (Node => Block_Var_1);
--# end
--# expr-done 7699
   If_Result_15 := Fld_24;
else
--# expr-start 7701 '<Eq at ast.py:18136>' Is_Equal_22 /tmp/lal-23.0.0/ada/ast.py:18136
--# expr-start 7700 '<Symbol value at ???>' Sym_22 None
Sym_22 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value_366); 
--# expr-done 7700
Is_Equal_22 := Block_Var = Sym_22; 
--# expr-done 7701
if Is_Equal_22 then
   --# expr-start 7702 '<FieldAccess for value at ast.py:18136>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:18136
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.value
Fld_25 := Libadalang.Implementation.Type_Attributes_Repository_F_Value (Node => Block_Var_1);
--# end
--# expr-done 7702
   If_Result_14 := Fld_25;
else
--# expr-start 7704 '<Eq at ast.py:18137>' Is_Equal_23 /tmp/lal-23.0.0/ada/ast.py:18137
--# expr-start 7703 '<Symbol wide_value at ???>' Sym_23 None
Sym_23 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Value_371); 
--# expr-done 7703
Is_Equal_23 := Block_Var = Sym_23; 
--# expr-done 7704
if Is_Equal_23 then
   --# expr-start 7705 '<FieldAccess for wide_value at ast.py:18137>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:18137
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.wide_value
Fld_26 := Libadalang.Implementation.Type_Attributes_Repository_F_Wide_Value (Node => Block_Var_1);
--# end
--# expr-done 7705
   If_Result_13 := Fld_26;
else
--# expr-start 7707 '<Eq at ast.py:18138>' Is_Equal_24 /tmp/lal-23.0.0/ada/ast.py:18138
--# expr-start 7706 '<Symbol wide_wide_value at ???>' Sym_24 None
Sym_24 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Value_374); 
--# expr-done 7706
Is_Equal_24 := Block_Var = Sym_24; 
--# expr-done 7707
if Is_Equal_24 then
   --# expr-start 7708 '<FieldAccess for wide_wide_value at ast.py:18138>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:18138
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.wide_wide_value
Fld_27 := Libadalang.Implementation.Type_Attributes_Repository_F_Wide_Wide_Value (Node => Block_Var_1);
--# end
--# expr-done 7708
   If_Result_12 := Fld_27;
else
--# expr-start 7710 '<Eq at ast.py:18140>' Is_Equal_25 /tmp/lal-23.0.0/ada/ast.py:18140
--# expr-start 7709 '<Symbol fixed_value at ???>' Sym_25 None
Sym_25 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fixed_Value_294); 
--# expr-done 7709
Is_Equal_25 := Block_Var = Sym_25; 
--# expr-done 7710
if Is_Equal_25 then
   --# expr-start 7711 '<FieldAccess for fixed_value at ast.py:18140>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:18140
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.fixed_value
Fld_28 := Libadalang.Implementation.Type_Attributes_Repository_F_Fixed_Value (Node => Block_Var_1);
--# end
--# expr-done 7711
   If_Result_11 := Fld_28;
else
--# expr-start 7713 '<Eq at ast.py:18141>' Is_Equal_26 /tmp/lal-23.0.0/ada/ast.py:18141
--# expr-start 7712 '<Symbol integer_value at ???>' Sym_26 None
Sym_26 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Integer_Value_305); 
--# expr-done 7712
Is_Equal_26 := Block_Var = Sym_26; 
--# expr-done 7713
if Is_Equal_26 then
   --# expr-start 7714 '<FieldAccess for integer_value at ast.py:18141>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:18141
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.integer_value
Fld_29 := Libadalang.Implementation.Type_Attributes_Repository_F_Integer_Value (Node => Block_Var_1);
--# end
--# expr-done 7714
   If_Result_10 := Fld_29;
else
--# expr-start 7716 '<Eq at ast.py:18143>' Is_Equal_27 /tmp/lal-23.0.0/ada/ast.py:18143
--# expr-start 7715 '<Symbol pos at ???>' Sym_27 None
Sym_27 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pos_326); 
--# expr-done 7715
Is_Equal_27 := Block_Var = Sym_27; 
--# expr-done 7716
if Is_Equal_27 then
   --# expr-start 7717 '<FieldAccess for pos at ast.py:18143>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:18143
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.pos
Fld_30 := Libadalang.Implementation.Type_Attributes_Repository_F_Pos (Node => Block_Var_1);
--# end
--# expr-done 7717
   If_Result_9 := Fld_30;
else
--# expr-start 7719 '<Eq at ast.py:18144>' Is_Equal_28 /tmp/lal-23.0.0/ada/ast.py:18144
--# expr-start 7718 '<Symbol val at ???>' Sym_28 None
Sym_28 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val_365); 
--# expr-done 7718
Is_Equal_28 := Block_Var = Sym_28; 
--# expr-done 7719
if Is_Equal_28 then
   --# expr-start 7720 '<FieldAccess for val_attr at ast.py:18144>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:18144
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.val_attr
Fld_31 := Libadalang.Implementation.Type_Attributes_Repository_F_Val_Attr (Node => Block_Var_1);
--# end
--# expr-done 7720
   If_Result_8 := Fld_31;
else
--# expr-start 7722 '<Eq at ast.py:18145>' Is_Equal_29 /tmp/lal-23.0.0/ada/ast.py:18145
--# expr-start 7721 '<Symbol enum_rep at ???>' Sym_29 None
Sym_29 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Enum_Rep_289); 
--# expr-done 7721
Is_Equal_29 := Block_Var = Sym_29; 
--# expr-done 7722
if Is_Equal_29 then
   --# expr-start 7723 '<FieldAccess for enum_rep at ast.py:18145>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:18145
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.enum_rep
Fld_32 := Libadalang.Implementation.Type_Attributes_Repository_F_Enum_Rep (Node => Block_Var_1);
--# end
--# expr-done 7723
   If_Result_7 := Fld_32;
else
--# expr-start 7725 '<Eq at ast.py:18146>' Is_Equal_30 /tmp/lal-23.0.0/ada/ast.py:18146
--# expr-start 7724 '<Symbol enum_val at ???>' Sym_30 None
Sym_30 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Enum_Val_290); 
--# expr-done 7724
Is_Equal_30 := Block_Var = Sym_30; 
--# expr-done 7725
if Is_Equal_30 then
   --# expr-start 7726 '<FieldAccess for enum_val at ast.py:18146>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:18146
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.enum_val
Fld_33 := Libadalang.Implementation.Type_Attributes_Repository_F_Enum_Val (Node => Block_Var_1);
--# end
--# expr-done 7726
   If_Result_6 := Fld_33;
else
--# expr-start 7728 '<Eq at ast.py:18148>' Is_Equal_31 /tmp/lal-23.0.0/ada/ast.py:18148
--# expr-start 7727 '<Symbol read at ???>' Sym_31 None
Sym_31 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Read_335); 
--# expr-done 7727
Is_Equal_31 := Block_Var = Sym_31; 
--# expr-done 7728
if Is_Equal_31 then
   --# expr-start 7729 '<FieldAccess for read at ast.py:18148>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:18148
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.read
Fld_34 := Libadalang.Implementation.Type_Attributes_Repository_F_Read (Node => Block_Var_1);
--# end
--# expr-done 7729
   If_Result_5 := Fld_34;
else
--# expr-start 7731 '<Eq at ast.py:18149>' Is_Equal_32 /tmp/lal-23.0.0/ada/ast.py:18149
--# expr-start 7730 '<Symbol write at ???>' Sym_32 None
Sym_32 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Write_376); 
--# expr-done 7730
Is_Equal_32 := Block_Var = Sym_32; 
--# expr-done 7731
if Is_Equal_32 then
   --# expr-start 7732 '<FieldAccess for write at ast.py:18149>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:18149
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.write
Fld_35 := Libadalang.Implementation.Type_Attributes_Repository_F_Write (Node => Block_Var_1);
--# end
--# expr-done 7732
   If_Result_4 := Fld_35;
else
--# expr-start 7734 '<Eq at ast.py:18150>' Is_Equal_33 /tmp/lal-23.0.0/ada/ast.py:18150
--# expr-start 7733 '<Symbol input at ???>' Sym_33 None
Sym_33 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Input_304); 
--# expr-done 7733
Is_Equal_33 := Block_Var = Sym_33; 
--# expr-done 7734
if Is_Equal_33 then
   --# expr-start 7735 '<FieldAccess for input at ast.py:18150>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:18150
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.input
Fld_36 := Libadalang.Implementation.Type_Attributes_Repository_F_Input (Node => Block_Var_1);
--# end
--# expr-done 7735
   If_Result_3 := Fld_36;
else
--# expr-start 7737 '<Eq at ast.py:18151>' Is_Equal_34 /tmp/lal-23.0.0/ada/ast.py:18151
--# expr-start 7736 '<Symbol output at ???>' Sym_34 None
Sym_34 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Output_323); 
--# expr-done 7736
Is_Equal_34 := Block_Var = Sym_34; 
--# expr-done 7737
if Is_Equal_34 then
   --# expr-start 7738 '<FieldAccess for output at ast.py:18151>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:18151
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.output
Fld_37 := Libadalang.Implementation.Type_Attributes_Repository_F_Output (Node => Block_Var_1);
--# end
--# expr-done 7738
   If_Result_2 := Fld_37;
else
--# expr-start 7740 '<Eq at ast.py:18153>' Is_Equal_35 /tmp/lal-23.0.0/ada/ast.py:18153
--# expr-start 7739 '<Symbol asm_input at ???>' Sym_35 None
Sym_35 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Input_270); 
--# expr-done 7739
Is_Equal_35 := Block_Var = Sym_35; 
--# expr-done 7740
if Is_Equal_35 then
   --# expr-start 7741 '<FieldAccess for asm_input at ast.py:18153>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:18153
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.asm_input
Fld_38 := Libadalang.Implementation.Type_Attributes_Repository_F_Asm_Input (Node => Block_Var_1);
--# end
--# expr-done 7741
   If_Result_1 := Fld_38;
else
--# expr-start 7743 '<Eq at ast.py:18154>' Is_Equal_36 /tmp/lal-23.0.0/ada/ast.py:18154
--# expr-start 7742 '<Symbol asm_output at ???>' Sym_36 None
Sym_36 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Output_271); 
--# expr-done 7742
Is_Equal_36 := Block_Var = Sym_36; 
--# expr-done 7743
if Is_Equal_36 then
   --# expr-start 7744 '<FieldAccess for asm_output at ast.py:18154>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:18154
      if Block_Var_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.asm_output
Fld_39 := Libadalang.Implementation.Type_Attributes_Repository_F_Asm_Output (Node => Block_Var_1);
--# end
--# expr-done 7744
   If_Result := Fld_39;
else
   If_Result := No_Bare_Ada_Node;
end if;
   If_Result_1 := If_Result;
end if;
   If_Result_2 := If_Result_1;
end if;
   If_Result_3 := If_Result_2;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
   If_Result_6 := If_Result_5;
end if;
   If_Result_7 := If_Result_6;
end if;
   If_Result_8 := If_Result_7;
end if;
   If_Result_9 := If_Result_8;
end if;
   If_Result_10 := If_Result_9;
end if;
   If_Result_11 := If_Result_10;
end if;
   If_Result_12 := If_Result_11;
end if;
   If_Result_13 := If_Result_12;
end if;
   If_Result_14 := If_Result_13;
end if;
   If_Result_15 := If_Result_14;
end if;
   If_Result_16 := If_Result_15;
end if;
   If_Result_17 := If_Result_16;
end if;
   If_Result_18 := If_Result_17;
end if;
   If_Result_19 := If_Result_18;
end if;
   If_Result_20 := If_Result_19;
end if;
   If_Result_21 := If_Result_20;
end if;
   If_Result_22 := If_Result_21;
end if;
   If_Result_23 := If_Result_22;
end if;
   If_Result_24 := If_Result_23;
end if;
   If_Result_25 := If_Result_24;
end if;
   If_Result_26 := If_Result_25;
end if;
   If_Result_27 := If_Result_26;
end if;
   If_Result_28 := If_Result_27;
end if;
   If_Result_29 := If_Result_28;
end if;
   If_Result_30 := If_Result_29;
end if;
   If_Result_31 := If_Result_30;
end if;
   If_Result_32 := If_Result_31;
end if;
   If_Result_33 := If_Result_32;
end if;
   If_Result_34 := If_Result_33;
end if;
   If_Result_35 := If_Result_34;
end if;
   If_Result_36 := If_Result_35;
end if;
--# expr-done 7745
Block_Var_2 := If_Result_36; 
--# bind subp Block_Var_2
--# expr-start 7751 '<New BasicSubpDecl.entity at ???>' New_Struct_1 None
--# expr-start 7750 '<New EntityInfo at ast.py:18160>' New_Struct /tmp/lal-23.0.0/ada/ast.py:18160
--# expr-start 7747 '<FieldAccess for from_rebound at ast.py:18163>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:18163
--# expr-start 7746 '<FieldAccess for info at ast.py:18163>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:18163
Fld_42 := Typ.Info;
--# expr-done 7746
Fld_43 := Fld_42.From_Rebound;
--# expr-done 7747
--# expr-start 7749 '<FieldAccess for rebindings at ast.py:18161>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:18161
--# expr-start 7748 '<FieldAccess for info at ast.py:18161>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:18161
Fld_40 := Typ.Info;
--# expr-done 7748
Fld_41 := Fld_40.Rebindings;
--# expr-done 7749
New_Struct := (From_Rebound => Fld_43, Md => No_Metadata, Rebindings => Fld_41); 
--# expr-done 7750
New_Struct_1 := (Info => New_Struct, Node => Block_Var_2); 
--# expr-done 7751
Let_Result := New_Struct_1; 
--# end
--# expr-done 7752
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Synthesize_Attribute_Subprogram;
--# end
--# property-start AttributeRef.attribute_subprogram /tmp/lal-23.0.0/ada/ast.py:18168
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Attribute_Subprogram
  (Node : Bare_Attribute_Ref
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Block_Var : Symbol_Type;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Attribute_Def_Clause;
Var_Expr_1 : Internal_Entity_Name;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Identifier;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Sym : Symbol_Type;
Is_Equal : Boolean;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_4 : Internal_Entity_Identifier;
Fld_5 : Symbol_Type;
Fld_6 : Internal_Entity_Attribute_Def_Clause;
Fld_7 : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_8 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Fld_9 : Internal_Entity_Basic_Subp_Decl;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
Sym_5 : Symbol_Type;
Fld_10 : Internal_Aspect;
Fld_11 : Internal_Entity_Expr;
Scope_Result_1 : Internal_Entity_Expr;
Result_Var_1 : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity_Name;
Fld_12 : Internal_Entity_Basic_Decl;
Scope_Result_2 : Internal_Entity_Basic_Decl;
Fld_13 : Internal_Entity_Basic_Subp_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Result_Var_2 : Internal_Entity_Basic_Decl;
Fld_14 : Internal_Entity_Basic_Subp_Decl;
Cast_Result_4 : Internal_Entity_Basic_Decl;
If_Result_3 : Internal_Entity_Basic_Decl;
If_Result_4 : Internal_Entity_Basic_Decl;
If_Result_5 : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 7783 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7754 '<FieldAccess for name_symbol at ast.py:18169>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18169
--# expr-start 7753 '<FieldAccess for attribute at ast.py:18169>' Fld /tmp/lal-23.0.0/ada/ast.py:18169
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Attribute_Ref_F_Attribute, Info => Ent.Info);
--# expr-done 7753
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 7754
Block_Var := Fld_1; 
--# bind rel_name Block_Var
--# expr-start 7756 '<FieldAccess for name_designated_type at ast.py:18170>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18170
--# expr-start 7755 '<FieldAccess for prefix at ast.py:18170>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18170
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7755
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 7756
Block_Var_1 := Fld_3; 
--# bind typ Block_Var_1
--# expr-start 7782 '<Cond at ast.py:18171>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:18171
--# expr-start 7757 '<IsNull at ast.py:18172>' Is_Null /tmp/lal-23.0.0/ada/ast.py:18172
Is_Null := Block_Var_1.Node = null; 
--# expr-done 7757
if Is_Null then
   If_Result_5 := No_Entity_Basic_Decl;
else
--# expr-start 7759 '<Eq at ast.py:18175>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18175
--# expr-start 7758 '<Symbol read at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Read_335); 
--# expr-done 7758
Is_Equal := Block_Var = Sym; 
--# expr-done 7759
if Is_Equal then
   If_Result := True;
else
   --# expr-start 7761 '<Eq at ast.py:18175>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:18175
--# expr-start 7760 '<Symbol write at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Write_376); 
--# expr-done 7760
Is_Equal_1 := Block_Var = Sym_1; 
--# expr-done 7761
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 7763 '<Eq at ast.py:18175>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:18175
--# expr-start 7762 '<Symbol input at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Input_304); 
--# expr-done 7762
Is_Equal_2 := Block_Var = Sym_2; 
--# expr-done 7763
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 7765 '<Eq at ast.py:18175>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:18175
--# expr-start 7764 '<Symbol output at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Output_323); 
--# expr-done 7764
Is_Equal_3 := Block_Var = Sym_3; 
--# expr-done 7765
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
--# expr-start 7768 '<FieldAccess for get_representation_clause at ast.py:18176>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18176
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7767 '<FieldAccess for name_symbol at ast.py:18176>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18176
--# expr-start 7766 '<FieldAccess for attribute at ast.py:18176>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18176
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Ent.Node.Attribute_Ref_F_Attribute, Info => Ent.Info);
--# expr-done 7766
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_4.Node);
--# end
--# expr-done 7767
--# property-call-start BasicDecl.get_representation_clause
Fld_6 := Libadalang.Implementation.Basic_Decl_P_Get_Representation_Clause (Node => Block_Var_1.Node, Name => Fld_5, Imprecise_Fallback => False, E_Info => Block_Var_1.Info);
--# end
--# expr-done 7768
Var_Expr := Fld_6;
if Var_Expr /= No_Entity_Attribute_Def_Clause then
   --# scope-start
   --# bind x Var_Expr
--# expr-start 7771 '<FieldAccess for referenced_decl at ast.py:18177>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18177
--# expr-start 7770 '<Cast to Name at ast.py:18177>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18177
--# expr-start 7769 '<FieldAccess for expr at ast.py:18177>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18177
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Attribute_Def_Clause_F_Expr, Info => Var_Expr.Info);
--# expr-done 7769
   if Fld_7.Node = null
      or else Fld_7.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 7770
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_8 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Cast_Result.Node, Imprecise_Fallback => False, E_Info => Cast_Result.Info);
--# end
--# expr-done 7771
Scope_Result := Fld_8;
   --# end
   Result_Var := Scope_Result;
else
--# expr-start 7772 '<FieldAccess for synthesize_attribute_subprogram at ast.py:18178>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18178
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.synthesize_attribute_subprogram
Fld_9 := Libadalang.Implementation.Attribute_Ref_P_Synthesize_Attribute_Subprogram (Node => Ent.Node, Typ => Block_Var_1, E_Info => Ent.Info);
--# end
--# expr-done 7772
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   Result_Var := Cast_Result_1;
end if;
   If_Result_4 := Result_Var;
else
--# expr-start 7774 '<Eq at ast.py:18181>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:18181
--# expr-start 7773 '<Symbol put_image at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image_332); 
--# expr-done 7773
Is_Equal_4 := Block_Var = Sym_4; 
--# expr-done 7774
if Is_Equal_4 then
--# expr-start 7778 '<Cast to Name at ast.py:18182>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:18182
Var_Expr_2 := Block_Var_1;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 7777 '<FieldAccess for value at ast.py:18182>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18182
--# expr-start 7776 '<FieldAccess for get_aspect at ast.py:18182>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18182
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7775 '<Symbol put_image at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image_332); 
--# expr-done 7775
--# property-call-start BasicDecl.get_aspect
Fld_10 := Libadalang.Implementation.Basic_Decl_P_Get_Aspect (Node => Var_Expr_2.Node, Name => Sym_5, Imprecise_Fallback => False, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 7776
Fld_11 := Fld_10.Value;
--# expr-done 7777
Scope_Result_1 := Fld_11;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Expr;
end if;
   if Result_Var_1.Node = null
      or else Result_Var_1.Node.Kind in Ada_Name
   then
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Result_Var_1.Node,
         Info => Result_Var_1.Info);
   else
         Cast_Result_2 := No_Entity_Name;
   end if;
--# expr-done 7778
Var_Expr_1 := Cast_Result_2;
if Var_Expr_1 /= No_Entity_Name then
   --# scope-start
   --# bind n Var_Expr_1
--# expr-start 7779 '<FieldAccess for referenced_decl at ast.py:18183>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18183
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_12 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Var_Expr_1.Node, Imprecise_Fallback => False, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 7779
Scope_Result_2 := Fld_12;
   --# end
   Result_Var_2 := Scope_Result_2;
else
--# expr-start 7780 '<FieldAccess for synthesize_attribute_subprogram at ast.py:18184>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18184
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.synthesize_attribute_subprogram
Fld_13 := Libadalang.Implementation.Attribute_Ref_P_Synthesize_Attribute_Subprogram (Node => Ent.Node, Typ => Block_Var_1, E_Info => Ent.Info);
--# end
--# expr-done 7780
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_13.Node,
         Info => Fld_13.Info);
   Result_Var_2 := Cast_Result_3;
end if;
   If_Result_3 := Result_Var_2;
else
--# expr-start 7781 '<FieldAccess for synthesize_attribute_subprogram at ast.py:18187>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18187
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.synthesize_attribute_subprogram
Fld_14 := Libadalang.Implementation.Attribute_Ref_P_Synthesize_Attribute_Subprogram (Node => Ent.Node, Typ => Block_Var_1, E_Info => Ent.Info);
--# end
--# expr-done 7781
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_14.Node,
         Info => Fld_14.Info);
   If_Result_3 := Cast_Result_4;
end if;
   If_Result_4 := If_Result_3;
end if;
   If_Result_5 := If_Result_4;
end if;
--# expr-done 7782
Let_Result := If_Result_5; 
--# end
--# expr-done 7783
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Attribute_Subprogram;
--# end
--# property-start AttributeRef.xref_equation /tmp/lal-23.0.0/ada/ast.py:18191
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Xref_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1307 with Inline_Always;
      Block_Var : Symbol_Type;
Fld : Internal_Entity_Identifier;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_2 : Logic_Equation;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_3 : Boolean;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_4 : Boolean;
Sym_7 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_5 : Boolean;
Sym_8 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_6 : Boolean;
Sym_9 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_7 : Boolean;
Sym_10 : Symbol_Type;
Is_Equal_10 : Boolean;
If_Result_8 : Boolean;
Sym_11 : Symbol_Type;
Is_Equal_11 : Boolean;
If_Result_9 : Boolean;
Sym_12 : Symbol_Type;
Is_Equal_12 : Boolean;
If_Result_10 : Boolean;
Sym_13 : Symbol_Type;
Is_Equal_13 : Boolean;
If_Result_11 : Boolean;
Sym_14 : Symbol_Type;
Is_Equal_14 : Boolean;
If_Result_12 : Boolean;
Sym_15 : Symbol_Type;
Is_Equal_15 : Boolean;
If_Result_13 : Boolean;
Sym_16 : Symbol_Type;
Is_Equal_16 : Boolean;
If_Result_14 : Boolean;
Sym_17 : Symbol_Type;
Is_Equal_17 : Boolean;
If_Result_15 : Boolean;
Sym_18 : Symbol_Type;
Is_Equal_18 : Boolean;
If_Result_16 : Boolean;
Sym_19 : Symbol_Type;
Is_Equal_19 : Boolean;
If_Result_17 : Boolean;
Sym_20 : Symbol_Type;
Is_Equal_20 : Boolean;
If_Result_18 : Boolean;
Sym_21 : Symbol_Type;
Is_Equal_21 : Boolean;
If_Result_19 : Boolean;
Sym_22 : Symbol_Type;
Is_Equal_22 : Boolean;
If_Result_20 : Boolean;
Sym_23 : Symbol_Type;
Is_Equal_23 : Boolean;
If_Result_21 : Boolean;
Sym_24 : Symbol_Type;
Is_Equal_24 : Boolean;
If_Result_22 : Boolean;
Sym_25 : Symbol_Type;
Is_Equal_25 : Boolean;
If_Result_23 : Boolean;
Sym_26 : Symbol_Type;
Is_Equal_26 : Boolean;
If_Result_24 : Boolean;
Sym_27 : Symbol_Type;
Is_Equal_27 : Boolean;
If_Result_25 : Boolean;
Sym_28 : Symbol_Type;
Is_Equal_28 : Boolean;
If_Result_26 : Boolean;
Sym_29 : Symbol_Type;
Is_Equal_29 : Boolean;
If_Result_27 : Boolean;
Sym_30 : Symbol_Type;
Is_Equal_30 : Boolean;
If_Result_28 : Boolean;
Sym_31 : Symbol_Type;
Is_Equal_31 : Boolean;
If_Result_29 : Boolean;
Sym_32 : Symbol_Type;
Is_Equal_32 : Boolean;
If_Result_30 : Boolean;
Sym_33 : Symbol_Type;
Is_Equal_33 : Boolean;
If_Result_31 : Boolean;
Sym_34 : Symbol_Type;
Is_Equal_34 : Boolean;
If_Result_32 : Boolean;
Sym_35 : Symbol_Type;
Is_Equal_35 : Boolean;
If_Result_33 : Boolean;
Sym_36 : Symbol_Type;
Is_Equal_36 : Boolean;
If_Result_34 : Boolean;
Fld_3 : Logic_Equation;
Sym_37 : Symbol_Type;
Is_Equal_37 : Boolean;
Sym_38 : Symbol_Type;
Is_Equal_38 : Boolean;
If_Result_35 : Boolean;
Fld_4 : Logic_Equation;
Sym_39 : Symbol_Type;
Is_Equal_39 : Boolean;
Sym_40 : Symbol_Type;
Is_Equal_40 : Boolean;
If_Result_36 : Boolean;
Sym_41 : Symbol_Type;
Is_Equal_41 : Boolean;
If_Result_37 : Boolean;
Sym_42 : Symbol_Type;
Is_Equal_42 : Boolean;
If_Result_38 : Boolean;
Sym_43 : Symbol_Type;
Is_Equal_43 : Boolean;
If_Result_39 : Boolean;
Fld_5 : Logic_Equation;
Sym_44 : Symbol_Type;
Is_Equal_44 : Boolean;
Sym_45 : Symbol_Type;
Is_Equal_45 : Boolean;
If_Result_40 : Boolean;
Sym_46 : Symbol_Type;
Is_Equal_46 : Boolean;
If_Result_41 : Boolean;
Fld_6 : Logic_Equation;
Sym_47 : Symbol_Type;
Is_Equal_47 : Boolean;
Sym_48 : Symbol_Type;
Fld_7 : Internal_Entity;
Fld_8 : Logic_Equation;
Sym_49 : Symbol_Type;
Is_Equal_48 : Boolean;
Sym_50 : Symbol_Type;
Fld_9 : Internal_Entity;
Fld_10 : Logic_Equation;
Sym_51 : Symbol_Type;
Is_Equal_49 : Boolean;
Sym_52 : Symbol_Type;
Fld_11 : Internal_Entity;
Fld_12 : Logic_Equation;
Sym_53 : Symbol_Type;
Is_Equal_50 : Boolean;
Fld_13 : Logic_Equation;
Sym_54 : Symbol_Type;
Is_Equal_51 : Boolean;
Fld_14 : Logic_Equation;
Sym_55 : Symbol_Type;
Is_Equal_52 : Boolean;
Fld_15 : Logic_Equation;
Sym_56 : Symbol_Type;
Is_Equal_53 : Boolean;
Fld_16 : Logic_Equation;
Sym_57 : Symbol_Type;
Is_Equal_54 : Boolean;
Sym_58 : Symbol_Type;
Is_Equal_55 : Boolean;
If_Result_42 : Boolean;
Sym_59 : Symbol_Type;
Is_Equal_56 : Boolean;
If_Result_43 : Boolean;
Sym_60 : Symbol_Type;
Is_Equal_57 : Boolean;
If_Result_44 : Boolean;
Sym_61 : Symbol_Type;
Is_Equal_58 : Boolean;
If_Result_45 : Boolean;
Sym_62 : Symbol_Type;
Is_Equal_59 : Boolean;
If_Result_46 : Boolean;
Sym_63 : Symbol_Type;
Is_Equal_60 : Boolean;
If_Result_47 : Boolean;
Sym_64 : Symbol_Type;
Is_Equal_61 : Boolean;
If_Result_48 : Boolean;
Fld_17 : Logic_Equation;
Sym_65 : Symbol_Type;
Is_Equal_62 : Boolean;
Sym_66 : Symbol_Type;
Fld_18 : Internal_Entity;
Fld_19 : Logic_Equation;
Sym_67 : Symbol_Type;
Is_Equal_63 : Boolean;
Fld_20 : Logic_Equation;
Sym_68 : Symbol_Type;
Is_Equal_64 : Boolean;
Fld_21 : Logic_Equation;
Sym_69 : Symbol_Type;
Is_Equal_65 : Boolean;
Sym_70 : Symbol_Type;
Is_Equal_66 : Boolean;
If_Result_49 : Boolean;
Fld_22 : Logic_Equation;
Sym_71 : Symbol_Type;
Is_Equal_67 : Boolean;
Sym_72 : Symbol_Type;
Is_Equal_68 : Boolean;
If_Result_50 : Boolean;
Fld_23 : Internal_Entity_Name;
Fld_24 : Logic_Equation;
Sym_73 : Symbol_Type;
Is_Equal_69 : Boolean;
Sym_74 : Symbol_Type;
Is_Equal_70 : Boolean;
If_Result_51 : Boolean;
Sym_75 : Symbol_Type;
Is_Equal_71 : Boolean;
If_Result_52 : Boolean;
Sym_76 : Symbol_Type;
Is_Equal_72 : Boolean;
If_Result_53 : Boolean;
Sym_77 : Symbol_Type;
Is_Equal_73 : Boolean;
If_Result_54 : Boolean;
Sym_78 : Symbol_Type;
Is_Equal_74 : Boolean;
If_Result_55 : Boolean;
Sym_79 : Symbol_Type;
Is_Equal_75 : Boolean;
If_Result_56 : Boolean;
Sym_80 : Symbol_Type;
Is_Equal_76 : Boolean;
If_Result_57 : Boolean;
Sym_81 : Symbol_Type;
Is_Equal_77 : Boolean;
If_Result_58 : Boolean;
Sym_82 : Symbol_Type;
Is_Equal_78 : Boolean;
If_Result_59 : Boolean;
Fld_25 : Internal_Entity_Name;
Fld_26 : Logic_Equation;
Fld_27 : Logic_Var;
Fld_28 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Sym_83 : Symbol_Type;
Is_Equal_79 : Boolean;
Sym_84 : Symbol_Type;
Is_Equal_80 : Boolean;
If_Result_60 : Boolean;
Sym_85 : Symbol_Type;
Is_Equal_81 : Boolean;
If_Result_61 : Boolean;
Sym_86 : Symbol_Type;
Is_Equal_82 : Boolean;
If_Result_62 : Boolean;
Sym_87 : Symbol_Type;
Is_Equal_83 : Boolean;
If_Result_63 : Boolean;
Sym_88 : Symbol_Type;
Is_Equal_84 : Boolean;
If_Result_64 : Boolean;
Sym_89 : Symbol_Type;
Is_Equal_85 : Boolean;
If_Result_65 : Boolean;
Sym_90 : Symbol_Type;
Is_Equal_86 : Boolean;
If_Result_66 : Boolean;
Sym_91 : Symbol_Type;
Is_Equal_87 : Boolean;
If_Result_67 : Boolean;
Sym_92 : Symbol_Type;
Is_Equal_88 : Boolean;
If_Result_68 : Boolean;
Sym_93 : Symbol_Type;
Is_Equal_89 : Boolean;
If_Result_69 : Boolean;
Sym_94 : Symbol_Type;
Is_Equal_90 : Boolean;
If_Result_70 : Boolean;
Sym_95 : Symbol_Type;
Is_Equal_91 : Boolean;
If_Result_71 : Boolean;
Sym_96 : Symbol_Type;
Is_Equal_92 : Boolean;
If_Result_72 : Boolean;
Sym_97 : Symbol_Type;
Is_Equal_93 : Boolean;
If_Result_73 : Boolean;
Sym_98 : Symbol_Type;
Is_Equal_94 : Boolean;
If_Result_74 : Boolean;
Sym_99 : Symbol_Type;
Is_Equal_95 : Boolean;
If_Result_75 : Boolean;
Sym_100 : Symbol_Type;
Is_Equal_96 : Boolean;
If_Result_76 : Boolean;
Sym_101 : Symbol_Type;
Is_Equal_97 : Boolean;
If_Result_77 : Boolean;
Sym_102 : Symbol_Type;
Is_Equal_98 : Boolean;
If_Result_78 : Boolean;
Sym_103 : Symbol_Type;
Is_Equal_99 : Boolean;
If_Result_79 : Boolean;
Sym_104 : Symbol_Type;
Is_Equal_100 : Boolean;
If_Result_80 : Boolean;
Sym_105 : Symbol_Type;
Is_Equal_101 : Boolean;
If_Result_81 : Boolean;
Sym_106 : Symbol_Type;
Is_Equal_102 : Boolean;
If_Result_82 : Boolean;
Sym_107 : Symbol_Type;
Is_Equal_103 : Boolean;
If_Result_83 : Boolean;
Sym_108 : Symbol_Type;
Is_Equal_104 : Boolean;
If_Result_84 : Boolean;
Sym_109 : Symbol_Type;
Is_Equal_105 : Boolean;
If_Result_85 : Boolean;
Fld_29 : Internal_Entity_Name;
Fld_30 : Logic_Equation;
Fld_31 : Logic_Var;
Fld_32 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Sym_110 : Symbol_Type;
Is_Equal_106 : Boolean;
Fld_33 : Logic_Var;
Sym_111 : Symbol_Type;
Fld_34 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Sym_112 : Symbol_Type;
Is_Equal_107 : Boolean;
Fld_35 : Logic_Equation;
Sym_113 : Symbol_Type;
Is_Equal_108 : Boolean;
Fld_36 : Logic_Equation;
Sym_114 : Symbol_Type;
Is_Equal_109 : Boolean;
Fld_37 : Logic_Equation;
Sym_115 : Symbol_Type;
Is_Equal_110 : Boolean;
Sym_116 : Symbol_Type;
Is_Equal_111 : Boolean;
If_Result_86 : Boolean;
Fld_38 : Internal_Entity_Name;
Fld_39 : Logic_Equation;
Fld_40 : Logic_Var;
Fld_41 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Sym_117 : Symbol_Type;
Is_Equal_112 : Boolean;
Fld_42 : Internal_Entity_Name;
Fld_43 : Logic_Equation;
Fld_44 : Logic_Var;
Fld_45 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Sym_118 : Symbol_Type;
Is_Equal_113 : Boolean;
Fld_46 : Internal_Entity_Name;
Fld_47 : Logic_Equation;
Fld_48 : Logic_Var;
Fld_49 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_3 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Sym_119 : Symbol_Type;
Is_Equal_114 : Boolean;
Fld_50 : Logic_Equation;
Sym_120 : Symbol_Type;
Is_Equal_115 : Boolean;
Fld_51 : Logic_Equation;
Sym_121 : Symbol_Type;
Is_Equal_116 : Boolean;
Fld_52 : Logic_Equation;
Sym_122 : Symbol_Type;
Is_Equal_117 : Boolean;
Fld_53 : Logic_Var;
Sym_123 : Symbol_Type;
Fld_54 : Internal_Entity;
Bind_Result_4 : Logic_Equation;
Fld_55 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_5 : Logic_Equation;
And_Pred_5 : Logic_Equation;
If_Result_87 : Logic_Equation;
If_Result_88 : Logic_Equation;
If_Result_89 : Logic_Equation;
If_Result_90 : Logic_Equation;
If_Result_91 : Logic_Equation;
If_Result_92 : Logic_Equation;
If_Result_93 : Logic_Equation;
If_Result_94 : Logic_Equation;
If_Result_95 : Logic_Equation;
If_Result_96 : Logic_Equation;
If_Result_97 : Logic_Equation;
If_Result_98 : Logic_Equation;
If_Result_99 : Logic_Equation;
If_Result_100 : Logic_Equation;
If_Result_101 : Logic_Equation;
If_Result_102 : Logic_Equation;
If_Result_103 : Logic_Equation;
If_Result_104 : Logic_Equation;
If_Result_105 : Logic_Equation;
If_Result_106 : Logic_Equation;
If_Result_107 : Logic_Equation;
If_Result_108 : Logic_Equation;
If_Result_109 : Logic_Equation;
If_Result_110 : Logic_Equation;
If_Result_111 : Logic_Equation;
If_Result_112 : Logic_Equation;
If_Result_113 : Logic_Equation;
If_Result_114 : Logic_Equation;
If_Result_115 : Logic_Equation;
If_Result_116 : Logic_Equation;
If_Result_117 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1307 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Fld_22);
                     Dec_Ref (Fld_24);
                     Dec_Ref (Fld_26);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_30);
                     Dec_Ref (Fld_32);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_35);
                     Dec_Ref (Fld_36);
                     Dec_Ref (Fld_37);
                     Dec_Ref (Fld_39);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_43);
                     Dec_Ref (Fld_45);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_47);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_50);
                     Dec_Ref (Fld_51);
                     Dec_Ref (Fld_52);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (If_Result_87);
                     Dec_Ref (If_Result_88);
                     Dec_Ref (If_Result_89);
                     Dec_Ref (If_Result_90);
                     Dec_Ref (If_Result_91);
                     Dec_Ref (If_Result_92);
                     Dec_Ref (If_Result_93);
                     Dec_Ref (If_Result_94);
                     Dec_Ref (If_Result_95);
                     Dec_Ref (If_Result_96);
                     Dec_Ref (If_Result_97);
                     Dec_Ref (If_Result_98);
                     Dec_Ref (If_Result_99);
                     Dec_Ref (If_Result_100);
                     Dec_Ref (If_Result_101);
                     Dec_Ref (If_Result_102);
                     Dec_Ref (If_Result_103);
                     Dec_Ref (If_Result_104);
                     Dec_Ref (If_Result_105);
                     Dec_Ref (If_Result_106);
                     Dec_Ref (If_Result_107);
                     Dec_Ref (If_Result_108);
                     Dec_Ref (If_Result_109);
                     Dec_Ref (If_Result_110);
                     Dec_Ref (If_Result_111);
                     Dec_Ref (If_Result_112);
                     Dec_Ref (If_Result_113);
                     Dec_Ref (If_Result_114);
                     Dec_Ref (If_Result_115);
                     Dec_Ref (If_Result_116);
                     Dec_Ref (If_Result_117);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1307;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8095 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 7785 '<FieldAccess for name_symbol at ast.py:18192>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18192
--# expr-start 7784 '<FieldAccess for attribute at ast.py:18192>' Fld /tmp/lal-23.0.0/ada/ast.py:18192
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Attribute_Ref_F_Attribute, Info => Ent.Info);
--# expr-done 7784
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 7785
Block_Var := Fld_1; 
--# bind rel_name Block_Var
--# expr-start 8094 '<Cond at ast.py:18193>' If_Result_117 /tmp/lal-23.0.0/ada/ast.py:18193
--# expr-start 7787 '<Eq at ast.py:18195>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18195
--# expr-start 7786 '<Symbol First at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_First); 
--# expr-done 7786
Is_Equal := Block_Var = Sym; 
--# expr-done 7787
if Is_Equal then
   If_Result := True;
else
   --# expr-start 7789 '<Eq at ast.py:18195>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:18195
--# expr-start 7788 '<Symbol Last at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Last); 
--# expr-done 7788
Is_Equal_1 := Block_Var = Sym_1; 
--# expr-done 7789
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 7791 '<Eq at ast.py:18195>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:18195
--# expr-start 7790 '<Symbol Range at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range); 
--# expr-done 7790
Is_Equal_2 := Block_Var = Sym_2; 
--# expr-done 7791
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 7793 '<Eq at ast.py:18195>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:18195
--# expr-start 7792 '<Symbol Length at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Length); 
--# expr-done 7792
Is_Equal_3 := Block_Var = Sym_3; 
--# expr-done 7793
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   --# expr-start 7794 '<FieldAccess for array_attr_equation at ast.py:18196>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18196
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.array_attr_equation
Fld_2 := Libadalang.Implementation.Attribute_Ref_P_Array_Attr_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7794
   If_Result_117 := Fld_2;
else
--# expr-start 7796 '<Eq at ast.py:18199>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7795 '<Symbol Succ at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Succ); 
--# expr-done 7795
Is_Equal_4 := Block_Var = Sym_4; 
--# expr-done 7796
if Is_Equal_4 then
   If_Result_3 := True;
else
   --# expr-start 7798 '<Eq at ast.py:18199>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7797 '<Symbol Pred at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pred); 
--# expr-done 7797
Is_Equal_5 := Block_Var = Sym_5; 
--# expr-done 7798
   If_Result_3 := Is_Equal_5;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 7800 '<Eq at ast.py:18199>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7799 '<Symbol Min at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Min); 
--# expr-done 7799
Is_Equal_6 := Block_Var = Sym_6; 
--# expr-done 7800
   If_Result_4 := Is_Equal_6;
end if;
if If_Result_4 then
   If_Result_5 := True;
else
   --# expr-start 7802 '<Eq at ast.py:18199>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7801 '<Symbol Max at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Max); 
--# expr-done 7801
Is_Equal_7 := Block_Var = Sym_7; 
--# expr-done 7802
   If_Result_5 := Is_Equal_7;
end if;
if If_Result_5 then
   If_Result_6 := True;
else
   --# expr-start 7804 '<Eq at ast.py:18199>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7803 '<Symbol Ceiling at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ceiling); 
--# expr-done 7803
Is_Equal_8 := Block_Var = Sym_8; 
--# expr-done 7804
   If_Result_6 := Is_Equal_8;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 7806 '<Eq at ast.py:18199>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7805 '<Symbol Floor at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Floor); 
--# expr-done 7805
Is_Equal_9 := Block_Var = Sym_9; 
--# expr-done 7806
   If_Result_7 := Is_Equal_9;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 7808 '<Eq at ast.py:18199>' Is_Equal_10 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7807 '<Symbol Rounding at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rounding); 
--# expr-done 7807
Is_Equal_10 := Block_Var = Sym_10; 
--# expr-done 7808
   If_Result_8 := Is_Equal_10;
end if;
if If_Result_8 then
   If_Result_9 := True;
else
   --# expr-start 7810 '<Eq at ast.py:18199>' Is_Equal_11 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7809 '<Symbol Truncation at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Truncation); 
--# expr-done 7809
Is_Equal_11 := Block_Var = Sym_11; 
--# expr-done 7810
   If_Result_9 := Is_Equal_11;
end if;
if If_Result_9 then
   If_Result_10 := True;
else
   --# expr-start 7812 '<Eq at ast.py:18199>' Is_Equal_12 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7811 '<Symbol Exponent at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exponent); 
--# expr-done 7811
Is_Equal_12 := Block_Var = Sym_12; 
--# expr-done 7812
   If_Result_10 := Is_Equal_12;
end if;
if If_Result_10 then
   If_Result_11 := True;
else
   --# expr-start 7814 '<Eq at ast.py:18199>' Is_Equal_13 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7813 '<Symbol Fraction at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fraction); 
--# expr-done 7813
Is_Equal_13 := Block_Var = Sym_13; 
--# expr-done 7814
   If_Result_11 := Is_Equal_13;
end if;
if If_Result_11 then
   If_Result_12 := True;
else
   --# expr-start 7816 '<Eq at ast.py:18199>' Is_Equal_14 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7815 '<Symbol Copy_Sign at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Copy_Sign); 
--# expr-done 7815
Is_Equal_14 := Block_Var = Sym_14; 
--# expr-done 7816
   If_Result_12 := Is_Equal_14;
end if;
if If_Result_12 then
   If_Result_13 := True;
else
   --# expr-start 7818 '<Eq at ast.py:18199>' Is_Equal_15 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7817 '<Symbol Remainder at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Remainder); 
--# expr-done 7817
Is_Equal_15 := Block_Var = Sym_15; 
--# expr-done 7818
   If_Result_13 := Is_Equal_15;
end if;
if If_Result_13 then
   If_Result_14 := True;
else
   --# expr-start 7820 '<Eq at ast.py:18199>' Is_Equal_16 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7819 '<Symbol Adjacent at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Adjacent); 
--# expr-done 7819
Is_Equal_16 := Block_Var = Sym_16; 
--# expr-done 7820
   If_Result_14 := Is_Equal_16;
end if;
if If_Result_14 then
   If_Result_15 := True;
else
   --# expr-start 7822 '<Eq at ast.py:18199>' Is_Equal_17 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7821 '<Symbol Machine at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine); 
--# expr-done 7821
Is_Equal_17 := Block_Var = Sym_17; 
--# expr-done 7822
   If_Result_15 := Is_Equal_17;
end if;
if If_Result_15 then
   If_Result_16 := True;
else
   --# expr-start 7824 '<Eq at ast.py:18199>' Is_Equal_18 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7823 '<Symbol Machine_Rounding at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Rounding); 
--# expr-done 7823
Is_Equal_18 := Block_Var = Sym_18; 
--# expr-done 7824
   If_Result_16 := Is_Equal_18;
end if;
if If_Result_16 then
   If_Result_17 := True;
else
   --# expr-start 7826 '<Eq at ast.py:18199>' Is_Equal_19 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7825 '<Symbol Scaling at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Scaling); 
--# expr-done 7825
Is_Equal_19 := Block_Var = Sym_19; 
--# expr-done 7826
   If_Result_17 := Is_Equal_19;
end if;
if If_Result_17 then
   If_Result_18 := True;
else
   --# expr-start 7828 '<Eq at ast.py:18199>' Is_Equal_20 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7827 '<Symbol Compose at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Compose); 
--# expr-done 7827
Is_Equal_20 := Block_Var = Sym_20; 
--# expr-done 7828
   If_Result_18 := Is_Equal_20;
end if;
if If_Result_18 then
   If_Result_19 := True;
else
   --# expr-start 7830 '<Eq at ast.py:18199>' Is_Equal_21 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7829 '<Symbol Mod at ???>' Sym_21 None
Sym_21 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod_142); 
--# expr-done 7829
Is_Equal_21 := Block_Var = Sym_21; 
--# expr-done 7830
   If_Result_19 := Is_Equal_21;
end if;
if If_Result_19 then
   If_Result_20 := True;
else
   --# expr-start 7832 '<Eq at ast.py:18199>' Is_Equal_22 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7831 '<Symbol Value at ???>' Sym_22 None
Sym_22 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value); 
--# expr-done 7831
Is_Equal_22 := Block_Var = Sym_22; 
--# expr-done 7832
   If_Result_20 := Is_Equal_22;
end if;
if If_Result_20 then
   If_Result_21 := True;
else
   --# expr-start 7834 '<Eq at ast.py:18199>' Is_Equal_23 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7833 '<Symbol Wide_Value at ???>' Sym_23 None
Sym_23 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Value); 
--# expr-done 7833
Is_Equal_23 := Block_Var = Sym_23; 
--# expr-done 7834
   If_Result_21 := Is_Equal_23;
end if;
if If_Result_21 then
   If_Result_22 := True;
else
   --# expr-start 7836 '<Eq at ast.py:18199>' Is_Equal_24 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7835 '<Symbol Wide_Wide_Value at ???>' Sym_24 None
Sym_24 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Value); 
--# expr-done 7835
Is_Equal_24 := Block_Var = Sym_24; 
--# expr-done 7836
   If_Result_22 := Is_Equal_24;
end if;
if If_Result_22 then
   If_Result_23 := True;
else
   --# expr-start 7838 '<Eq at ast.py:18199>' Is_Equal_25 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7837 '<Symbol Fixed_Value at ???>' Sym_25 None
Sym_25 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fixed_Value); 
--# expr-done 7837
Is_Equal_25 := Block_Var = Sym_25; 
--# expr-done 7838
   If_Result_23 := Is_Equal_25;
end if;
if If_Result_23 then
   If_Result_24 := True;
else
   --# expr-start 7840 '<Eq at ast.py:18199>' Is_Equal_26 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7839 '<Symbol Integer_Value at ???>' Sym_26 None
Sym_26 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Integer_Value); 
--# expr-done 7839
Is_Equal_26 := Block_Var = Sym_26; 
--# expr-done 7840
   If_Result_24 := Is_Equal_26;
end if;
if If_Result_24 then
   If_Result_25 := True;
else
   --# expr-start 7842 '<Eq at ast.py:18199>' Is_Equal_27 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7841 '<Symbol Pos at ???>' Sym_27 None
Sym_27 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pos); 
--# expr-done 7841
Is_Equal_27 := Block_Var = Sym_27; 
--# expr-done 7842
   If_Result_25 := Is_Equal_27;
end if;
if If_Result_25 then
   If_Result_26 := True;
else
   --# expr-start 7844 '<Eq at ast.py:18199>' Is_Equal_28 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7843 '<Symbol Val at ???>' Sym_28 None
Sym_28 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val); 
--# expr-done 7843
Is_Equal_28 := Block_Var = Sym_28; 
--# expr-done 7844
   If_Result_26 := Is_Equal_28;
end if;
if If_Result_26 then
   If_Result_27 := True;
else
   --# expr-start 7846 '<Eq at ast.py:18199>' Is_Equal_29 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7845 '<Symbol Enum_Val at ???>' Sym_29 None
Sym_29 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Enum_Val); 
--# expr-done 7845
Is_Equal_29 := Block_Var = Sym_29; 
--# expr-done 7846
   If_Result_27 := Is_Equal_29;
end if;
if If_Result_27 then
   If_Result_28 := True;
else
   --# expr-start 7848 '<Eq at ast.py:18199>' Is_Equal_30 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7847 '<Symbol Write at ???>' Sym_30 None
Sym_30 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Write); 
--# expr-done 7847
Is_Equal_30 := Block_Var = Sym_30; 
--# expr-done 7848
   If_Result_28 := Is_Equal_30;
end if;
if If_Result_28 then
   If_Result_29 := True;
else
   --# expr-start 7850 '<Eq at ast.py:18199>' Is_Equal_31 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7849 '<Symbol Read at ???>' Sym_31 None
Sym_31 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Read); 
--# expr-done 7849
Is_Equal_31 := Block_Var = Sym_31; 
--# expr-done 7850
   If_Result_29 := Is_Equal_31;
end if;
if If_Result_29 then
   If_Result_30 := True;
else
   --# expr-start 7852 '<Eq at ast.py:18199>' Is_Equal_32 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7851 '<Symbol Output at ???>' Sym_32 None
Sym_32 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Output); 
--# expr-done 7851
Is_Equal_32 := Block_Var = Sym_32; 
--# expr-done 7852
   If_Result_30 := Is_Equal_32;
end if;
if If_Result_30 then
   If_Result_31 := True;
else
   --# expr-start 7854 '<Eq at ast.py:18199>' Is_Equal_33 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7853 '<Symbol Input at ???>' Sym_33 None
Sym_33 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Input); 
--# expr-done 7853
Is_Equal_33 := Block_Var = Sym_33; 
--# expr-done 7854
   If_Result_31 := Is_Equal_33;
end if;
if If_Result_31 then
   If_Result_32 := True;
else
   --# expr-start 7856 '<Eq at ast.py:18199>' Is_Equal_34 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7855 '<Symbol Put_Image at ???>' Sym_34 None
Sym_34 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image); 
--# expr-done 7855
Is_Equal_34 := Block_Var = Sym_34; 
--# expr-done 7856
   If_Result_32 := Is_Equal_34;
end if;
if If_Result_32 then
   If_Result_33 := True;
else
   --# expr-start 7858 '<Eq at ast.py:18199>' Is_Equal_35 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7857 '<Symbol Asm_Input at ???>' Sym_35 None
Sym_35 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Input); 
--# expr-done 7857
Is_Equal_35 := Block_Var = Sym_35; 
--# expr-done 7858
   If_Result_33 := Is_Equal_35;
end if;
if If_Result_33 then
   If_Result_34 := True;
else
   --# expr-start 7860 '<Eq at ast.py:18199>' Is_Equal_36 /tmp/lal-23.0.0/ada/ast.py:18199
--# expr-start 7859 '<Symbol Asm_Output at ???>' Sym_36 None
Sym_36 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Output); 
--# expr-done 7859
Is_Equal_36 := Block_Var = Sym_36; 
--# expr-done 7860
   If_Result_34 := Is_Equal_36;
end if;
if If_Result_34 then
   --# expr-start 7861 '<FieldAccess for attribute_subprogram_equation at ast.py:18208>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18208
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.attribute_subprogram_equation
Fld_3 := Libadalang.Implementation.Attribute_Ref_P_Attribute_Subprogram_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7861
   If_Result_116 := Fld_3;
else
--# expr-start 7863 '<Eq at ast.py:18210>' Is_Equal_37 /tmp/lal-23.0.0/ada/ast.py:18210
--# expr-start 7862 '<Symbol Size at ???>' Sym_37 None
Sym_37 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Size); 
--# expr-done 7862
Is_Equal_37 := Block_Var = Sym_37; 
--# expr-done 7863
if Is_Equal_37 then
   If_Result_35 := True;
else
   --# expr-start 7865 '<Eq at ast.py:18210>' Is_Equal_38 /tmp/lal-23.0.0/ada/ast.py:18210
--# expr-start 7864 '<Symbol VADS_Size at ???>' Sym_38 None
Sym_38 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Vads_Size); 
--# expr-done 7864
Is_Equal_38 := Block_Var = Sym_38; 
--# expr-done 7865
   If_Result_35 := Is_Equal_38;
end if;
if If_Result_35 then
   --# expr-start 7866 '<FieldAccess for size_equation at ast.py:18210>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18210
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.size_equation
Fld_4 := Libadalang.Implementation.Attribute_Ref_P_Size_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7866
   If_Result_115 := Fld_4;
else
--# expr-start 7868 '<Eq at ast.py:18212>' Is_Equal_39 /tmp/lal-23.0.0/ada/ast.py:18212
--# expr-start 7867 '<Symbol Max_Size_In_Storage_Elements at ???>' Sym_39 None
Sym_39 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Max_Size_In_Storage_Elements); 
--# expr-done 7867
Is_Equal_39 := Block_Var = Sym_39; 
--# expr-done 7868
if Is_Equal_39 then
   If_Result_36 := True;
else
   --# expr-start 7870 '<Eq at ast.py:18212>' Is_Equal_40 /tmp/lal-23.0.0/ada/ast.py:18212
--# expr-start 7869 '<Symbol Aft at ???>' Sym_40 None
Sym_40 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Aft); 
--# expr-done 7869
Is_Equal_40 := Block_Var = Sym_40; 
--# expr-done 7870
   If_Result_36 := Is_Equal_40;
end if;
if If_Result_36 then
   If_Result_37 := True;
else
   --# expr-start 7872 '<Eq at ast.py:18212>' Is_Equal_41 /tmp/lal-23.0.0/ada/ast.py:18212
--# expr-start 7871 '<Symbol Object_Size at ???>' Sym_41 None
Sym_41 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Object_Size); 
--# expr-done 7871
Is_Equal_41 := Block_Var = Sym_41; 
--# expr-done 7872
   If_Result_37 := Is_Equal_41;
end if;
if If_Result_37 then
   If_Result_38 := True;
else
   --# expr-start 7874 '<Eq at ast.py:18212>' Is_Equal_42 /tmp/lal-23.0.0/ada/ast.py:18212
--# expr-start 7873 '<Symbol Value_Size at ???>' Sym_42 None
Sym_42 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value_Size); 
--# expr-done 7873
Is_Equal_42 := Block_Var = Sym_42; 
--# expr-done 7874
   If_Result_38 := Is_Equal_42;
end if;
if If_Result_38 then
   If_Result_39 := True;
else
   --# expr-start 7876 '<Eq at ast.py:18212>' Is_Equal_43 /tmp/lal-23.0.0/ada/ast.py:18212
--# expr-start 7875 '<Symbol Storage_Size at ???>' Sym_43 None
Sym_43 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Storage_Size); 
--# expr-done 7875
Is_Equal_43 := Block_Var = Sym_43; 
--# expr-done 7876
   If_Result_39 := Is_Equal_43;
end if;
if If_Result_39 then
   --# expr-start 7877 '<FieldAccess for subtype_attr_equation at ast.py:18214>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18214
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.subtype_attr_equation
Fld_5 := Libadalang.Implementation.Attribute_Ref_P_Subtype_Attr_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7877
   If_Result_114 := Fld_5;
else
--# expr-start 7879 '<Eq at ast.py:18216>' Is_Equal_44 /tmp/lal-23.0.0/ada/ast.py:18216
--# expr-start 7878 '<Symbol Access at ???>' Sym_44 None
Sym_44 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Access); 
--# expr-done 7878
Is_Equal_44 := Block_Var = Sym_44; 
--# expr-done 7879
if Is_Equal_44 then
   If_Result_40 := True;
else
   --# expr-start 7881 '<Eq at ast.py:18216>' Is_Equal_45 /tmp/lal-23.0.0/ada/ast.py:18216
--# expr-start 7880 '<Symbol Unchecked_Access at ???>' Sym_45 None
Sym_45 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unchecked_Access); 
--# expr-done 7880
Is_Equal_45 := Block_Var = Sym_45; 
--# expr-done 7881
   If_Result_40 := Is_Equal_45;
end if;
if If_Result_40 then
   If_Result_41 := True;
else
   --# expr-start 7883 '<Eq at ast.py:18216>' Is_Equal_46 /tmp/lal-23.0.0/ada/ast.py:18216
--# expr-start 7882 '<Symbol Unrestricted_Access at ???>' Sym_46 None
Sym_46 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unrestricted_Access); 
--# expr-done 7882
Is_Equal_46 := Block_Var = Sym_46; 
--# expr-done 7883
   If_Result_41 := Is_Equal_46;
end if;
if If_Result_41 then
   --# expr-start 7884 '<FieldAccess for access_equation at ast.py:18218>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18218
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.access_equation
Fld_6 := Libadalang.Implementation.Attribute_Ref_P_Access_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7884
   If_Result_113 := Fld_6;
else
--# expr-start 7886 '<Eq at ast.py:18220>' Is_Equal_47 /tmp/lal-23.0.0/ada/ast.py:18220
--# expr-start 7885 '<Symbol Image at ???>' Sym_47 None
Sym_47 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Image); 
--# expr-done 7885
Is_Equal_47 := Block_Var = Sym_47; 
--# expr-done 7886
if Is_Equal_47 then
   --# expr-start 7889 '<FieldAccess for image_equation at ast.py:18221>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18221
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7888 '<FieldAccess for std_entity at ast.py:18221>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18221
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7887 '<Symbol String at ???>' Sym_48 None
Sym_48 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 7887
--# property-call-start AdaNode.std_entity
Fld_7 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_48);
--# end
--# expr-done 7888
--# property-call-start AttributeRef.image_equation
Fld_8 := Libadalang.Implementation.Attribute_Ref_P_Image_Equation (Node => Ent.Node, Str_Type => Fld_7, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7889
   If_Result_112 := Fld_8;
else
--# expr-start 7891 '<Eq at ast.py:18223>' Is_Equal_48 /tmp/lal-23.0.0/ada/ast.py:18223
--# expr-start 7890 '<Symbol Wide_Image at ???>' Sym_49 None
Sym_49 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Image); 
--# expr-done 7890
Is_Equal_48 := Block_Var = Sym_49; 
--# expr-done 7891
if Is_Equal_48 then
   --# expr-start 7894 '<FieldAccess for image_equation at ast.py:18224>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18224
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7893 '<FieldAccess for std_entity at ast.py:18224>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18224
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7892 '<Symbol Wide_String at ???>' Sym_50 None
Sym_50 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_String); 
--# expr-done 7892
--# property-call-start AdaNode.std_entity
Fld_9 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_50);
--# end
--# expr-done 7893
--# property-call-start AttributeRef.image_equation
Fld_10 := Libadalang.Implementation.Attribute_Ref_P_Image_Equation (Node => Ent.Node, Str_Type => Fld_9, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7894
   If_Result_111 := Fld_10;
else
--# expr-start 7896 '<Eq at ast.py:18226>' Is_Equal_49 /tmp/lal-23.0.0/ada/ast.py:18226
--# expr-start 7895 '<Symbol Wide_Wide_Image at ???>' Sym_51 None
Sym_51 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Image); 
--# expr-done 7895
Is_Equal_49 := Block_Var = Sym_51; 
--# expr-done 7896
if Is_Equal_49 then
   --# expr-start 7899 '<FieldAccess for image_equation at ast.py:18227>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18227
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7898 '<FieldAccess for std_entity at ast.py:18227>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18227
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7897 '<Symbol Wide_Wide_String at ???>' Sym_52 None
Sym_52 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_String); 
--# expr-done 7897
--# property-call-start AdaNode.std_entity
Fld_11 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_52);
--# end
--# expr-done 7898
--# property-call-start AttributeRef.image_equation
Fld_12 := Libadalang.Implementation.Attribute_Ref_P_Image_Equation (Node => Ent.Node, Str_Type => Fld_11, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7899
   If_Result_110 := Fld_12;
else
--# expr-start 7901 '<Eq at ast.py:18229>' Is_Equal_50 /tmp/lal-23.0.0/ada/ast.py:18229
--# expr-start 7900 '<Symbol Enum_Rep at ???>' Sym_53 None
Sym_53 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Enum_Rep); 
--# expr-done 7900
Is_Equal_50 := Block_Var = Sym_53; 
--# expr-done 7901
if Is_Equal_50 then
   --# expr-start 7902 '<FieldAccess for enum_rep_equation at ast.py:18230>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18230
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.enum_rep_equation
Fld_13 := Libadalang.Implementation.Attribute_Ref_P_Enum_Rep_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7902
   If_Result_109 := Fld_13;
else
--# expr-start 7904 '<Eq at ast.py:18232>' Is_Equal_51 /tmp/lal-23.0.0/ada/ast.py:18232
--# expr-start 7903 '<Symbol Invalid_Value at ???>' Sym_54 None
Sym_54 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Invalid_Value); 
--# expr-done 7903
Is_Equal_51 := Block_Var = Sym_54; 
--# expr-done 7904
if Is_Equal_51 then
   --# expr-start 7905 '<FieldAccess for invalid_value_equation at ast.py:18233>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18233
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.invalid_value_equation
Fld_14 := Libadalang.Implementation.Attribute_Ref_P_Invalid_Value_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7905
   If_Result_108 := Fld_14;
else
--# expr-start 7907 '<Eq at ast.py:18235>' Is_Equal_52 /tmp/lal-23.0.0/ada/ast.py:18235
--# expr-start 7906 '<Symbol Identity at ???>' Sym_55 None
Sym_55 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Identity); 
--# expr-done 7906
Is_Equal_52 := Block_Var = Sym_55; 
--# expr-done 7907
if Is_Equal_52 then
   --# expr-start 7908 '<FieldAccess for identity_equation at ast.py:18235>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:18235
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.identity_equation
Fld_15 := Libadalang.Implementation.Attribute_Ref_P_Identity_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7908
   If_Result_107 := Fld_15;
else
--# expr-start 7910 '<Eq at ast.py:18236>' Is_Equal_53 /tmp/lal-23.0.0/ada/ast.py:18236
--# expr-start 7909 '<Symbol Address at ???>' Sym_56 None
Sym_56 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Address); 
--# expr-done 7909
Is_Equal_53 := Block_Var = Sym_56; 
--# expr-done 7910
if Is_Equal_53 then
   --# expr-start 7911 '<FieldAccess for address_equation at ast.py:18236>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:18236
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.address_equation
Fld_16 := Libadalang.Implementation.Attribute_Ref_P_Address_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7911
   If_Result_106 := Fld_16;
else
--# expr-start 7913 '<Eq at ast.py:18238>' Is_Equal_54 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7912 '<Symbol Small at ???>' Sym_57 None
Sym_57 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Small); 
--# expr-done 7912
Is_Equal_54 := Block_Var = Sym_57; 
--# expr-done 7913
if Is_Equal_54 then
   If_Result_42 := True;
else
   --# expr-start 7915 '<Eq at ast.py:18238>' Is_Equal_55 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7914 '<Symbol Model_Small at ???>' Sym_58 None
Sym_58 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Model_Small); 
--# expr-done 7914
Is_Equal_55 := Block_Var = Sym_58; 
--# expr-done 7915
   If_Result_42 := Is_Equal_55;
end if;
if If_Result_42 then
   If_Result_43 := True;
else
   --# expr-start 7917 '<Eq at ast.py:18238>' Is_Equal_56 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7916 '<Symbol Safe_Small at ???>' Sym_59 None
Sym_59 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Safe_Small); 
--# expr-done 7916
Is_Equal_56 := Block_Var = Sym_59; 
--# expr-done 7917
   If_Result_43 := Is_Equal_56;
end if;
if If_Result_43 then
   If_Result_44 := True;
else
   --# expr-start 7919 '<Eq at ast.py:18238>' Is_Equal_57 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7918 '<Symbol Epsilon at ???>' Sym_60 None
Sym_60 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Epsilon); 
--# expr-done 7918
Is_Equal_57 := Block_Var = Sym_60; 
--# expr-done 7919
   If_Result_44 := Is_Equal_57;
end if;
if If_Result_44 then
   If_Result_45 := True;
else
   --# expr-start 7921 '<Eq at ast.py:18238>' Is_Equal_58 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7920 '<Symbol Model_Epsilon at ???>' Sym_61 None
Sym_61 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Model_Epsilon); 
--# expr-done 7920
Is_Equal_58 := Block_Var = Sym_61; 
--# expr-done 7921
   If_Result_45 := Is_Equal_58;
end if;
if If_Result_45 then
   If_Result_46 := True;
else
   --# expr-start 7923 '<Eq at ast.py:18238>' Is_Equal_59 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7922 '<Symbol Large at ???>' Sym_62 None
Sym_62 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Large); 
--# expr-done 7922
Is_Equal_59 := Block_Var = Sym_62; 
--# expr-done 7923
   If_Result_46 := Is_Equal_59;
end if;
if If_Result_46 then
   If_Result_47 := True;
else
   --# expr-start 7925 '<Eq at ast.py:18238>' Is_Equal_60 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7924 '<Symbol Safe_Large at ???>' Sym_63 None
Sym_63 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Safe_Large); 
--# expr-done 7924
Is_Equal_60 := Block_Var = Sym_63; 
--# expr-done 7925
   If_Result_47 := Is_Equal_60;
end if;
if If_Result_47 then
   If_Result_48 := True;
else
   --# expr-start 7927 '<Eq at ast.py:18238>' Is_Equal_61 /tmp/lal-23.0.0/ada/ast.py:18238
--# expr-start 7926 '<Symbol Delta at ???>' Sym_64 None
Sym_64 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Delta); 
--# expr-done 7926
Is_Equal_61 := Block_Var = Sym_64; 
--# expr-done 7927
   If_Result_48 := Is_Equal_61;
end if;
if If_Result_48 then
   --# expr-start 7928 '<FieldAccess for universal_real_equation at ast.py:18242>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:18242
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.universal_real_equation
Fld_17 := Libadalang.Implementation.Attribute_Ref_P_Universal_Real_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7928
   If_Result_105 := Fld_17;
else
--# expr-start 7930 '<Eq at ast.py:18244>' Is_Equal_62 /tmp/lal-23.0.0/ada/ast.py:18244
--# expr-start 7929 '<Symbol Img at ???>' Sym_65 None
Sym_65 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Img); 
--# expr-done 7929
Is_Equal_62 := Block_Var = Sym_65; 
--# expr-done 7930
if Is_Equal_62 then
   --# expr-start 7933 '<FieldAccess for img_equation at ast.py:18245>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:18245
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7932 '<FieldAccess for std_entity at ast.py:18245>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:18245
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 7931 '<Symbol String at ???>' Sym_66 None
Sym_66 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 7931
--# property-call-start AdaNode.std_entity
Fld_18 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_66);
--# end
--# expr-done 7932
--# property-call-start AttributeRef.img_equation
Fld_19 := Libadalang.Implementation.Attribute_Ref_P_Img_Equation (Node => Ent.Node, Str_Type => Fld_18, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7933
   If_Result_104 := Fld_19;
else
--# expr-start 7935 '<Eq at ast.py:18247>' Is_Equal_63 /tmp/lal-23.0.0/ada/ast.py:18247
--# expr-start 7934 '<Symbol Tag at ???>' Sym_67 None
Sym_67 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Tag); 
--# expr-done 7934
Is_Equal_63 := Block_Var = Sym_67; 
--# expr-done 7935
if Is_Equal_63 then
   --# expr-start 7936 '<FieldAccess for tag_attr_equation at ast.py:18247>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:18247
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.tag_attr_equation
Fld_20 := Libadalang.Implementation.Attribute_Ref_P_Tag_Attr_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7936
   If_Result_103 := Fld_20;
else
--# expr-start 7938 '<Eq at ast.py:18249>' Is_Equal_64 /tmp/lal-23.0.0/ada/ast.py:18249
--# expr-start 7937 '<Symbol Result at ???>' Sym_68 None
Sym_68 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Result); 
--# expr-done 7937
Is_Equal_64 := Block_Var = Sym_68; 
--# expr-done 7938
if Is_Equal_64 then
   --# expr-start 7939 '<FieldAccess for result_attr_equation at ast.py:18249>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:18249
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.result_attr_equation
Fld_21 := Libadalang.Implementation.Attribute_Ref_P_Result_Attr_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7939
   If_Result_102 := Fld_21;
else
--# expr-start 7941 '<Eq at ast.py:18251>' Is_Equal_65 /tmp/lal-23.0.0/ada/ast.py:18251
--# expr-start 7940 '<Symbol Old at ???>' Sym_69 None
Sym_69 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Old); 
--# expr-done 7940
Is_Equal_65 := Block_Var = Sym_69; 
--# expr-done 7941
if Is_Equal_65 then
   If_Result_49 := True;
else
   --# expr-start 7943 '<Eq at ast.py:18251>' Is_Equal_66 /tmp/lal-23.0.0/ada/ast.py:18251
--# expr-start 7942 '<Symbol Loop_Entry at ???>' Sym_70 None
Sym_70 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Loop_Entry); 
--# expr-done 7942
Is_Equal_66 := Block_Var = Sym_70; 
--# expr-done 7943
   If_Result_49 := Is_Equal_66;
end if;
if If_Result_49 then
   --# expr-start 7944 '<FieldAccess for bind_to_prefix_eq at ast.py:18252>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:18252
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.bind_to_prefix_eq
Fld_22 := Libadalang.Implementation.Attribute_Ref_P_Bind_To_Prefix_Eq (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 7944
   If_Result_101 := Fld_22;
else
--# expr-start 7946 '<Eq at ast.py:18254>' Is_Equal_67 /tmp/lal-23.0.0/ada/ast.py:18254
--# expr-start 7945 '<Symbol Class at ???>' Sym_71 None
Sym_71 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Class); 
--# expr-done 7945
Is_Equal_67 := Block_Var = Sym_71; 
--# expr-done 7946
if Is_Equal_67 then
   If_Result_50 := True;
else
   --# expr-start 7948 '<Eq at ast.py:18254>' Is_Equal_68 /tmp/lal-23.0.0/ada/ast.py:18254
--# expr-start 7947 '<Symbol Base at ???>' Sym_72 None
Sym_72 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Base); 
--# expr-done 7947
Is_Equal_68 := Block_Var = Sym_72; 
--# expr-done 7948
   If_Result_50 := Is_Equal_68;
end if;
if If_Result_50 then
   --# expr-start 7950 '<FieldAccess for sub_equation at ast.py:18255>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:18255
--# expr-start 7949 '<FieldAccess for prefix at ast.py:18255>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:18255
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7949
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_24 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_23.Node, Env => Env, Origin => Origin, E_Info => Fld_23.Info);
--# end
--# expr-done 7950
   If_Result_100 := Fld_24;
else
--# expr-start 7952 '<Eq at ast.py:18257>' Is_Equal_69 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7951 '<Symbol Valid at ???>' Sym_73 None
Sym_73 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Valid); 
--# expr-done 7951
Is_Equal_69 := Block_Var = Sym_73; 
--# expr-done 7952
if Is_Equal_69 then
   If_Result_51 := True;
else
   --# expr-start 7954 '<Eq at ast.py:18257>' Is_Equal_70 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7953 '<Symbol Machine_Overflows at ???>' Sym_74 None
Sym_74 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Overflows); 
--# expr-done 7953
Is_Equal_70 := Block_Var = Sym_74; 
--# expr-done 7954
   If_Result_51 := Is_Equal_70;
end if;
if If_Result_51 then
   If_Result_52 := True;
else
   --# expr-start 7956 '<Eq at ast.py:18257>' Is_Equal_71 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7955 '<Symbol Machine_Rounds at ???>' Sym_75 None
Sym_75 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Rounds); 
--# expr-done 7955
Is_Equal_71 := Block_Var = Sym_75; 
--# expr-done 7956
   If_Result_52 := Is_Equal_71;
end if;
if If_Result_52 then
   If_Result_53 := True;
else
   --# expr-start 7958 '<Eq at ast.py:18257>' Is_Equal_72 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7957 '<Symbol Has_Access_Values at ???>' Sym_76 None
Sym_76 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Has_Access_Values); 
--# expr-done 7957
Is_Equal_72 := Block_Var = Sym_76; 
--# expr-done 7958
   If_Result_53 := Is_Equal_72;
end if;
if If_Result_53 then
   If_Result_54 := True;
else
   --# expr-start 7960 '<Eq at ast.py:18257>' Is_Equal_73 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7959 '<Symbol Has_Discriminants at ???>' Sym_77 None
Sym_77 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Has_Discriminants); 
--# expr-done 7959
Is_Equal_73 := Block_Var = Sym_77; 
--# expr-done 7960
   If_Result_54 := Is_Equal_73;
end if;
if If_Result_54 then
   If_Result_55 := True;
else
   --# expr-start 7962 '<Eq at ast.py:18257>' Is_Equal_74 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7961 '<Symbol Has_Tagged_Values at ???>' Sym_78 None
Sym_78 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Has_Tagged_Values); 
--# expr-done 7961
Is_Equal_74 := Block_Var = Sym_78; 
--# expr-done 7962
   If_Result_55 := Is_Equal_74;
end if;
if If_Result_55 then
   If_Result_56 := True;
else
   --# expr-start 7964 '<Eq at ast.py:18257>' Is_Equal_75 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7963 '<Symbol Definite at ???>' Sym_79 None
Sym_79 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Definite); 
--# expr-done 7963
Is_Equal_75 := Block_Var = Sym_79; 
--# expr-done 7964
   If_Result_56 := Is_Equal_75;
end if;
if If_Result_56 then
   If_Result_57 := True;
else
   --# expr-start 7966 '<Eq at ast.py:18257>' Is_Equal_76 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7965 '<Symbol Constrained at ???>' Sym_80 None
Sym_80 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Constrained); 
--# expr-done 7965
Is_Equal_76 := Block_Var = Sym_80; 
--# expr-done 7966
   If_Result_57 := Is_Equal_76;
end if;
if If_Result_57 then
   If_Result_58 := True;
else
   --# expr-start 7968 '<Eq at ast.py:18257>' Is_Equal_77 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7967 '<Symbol Initialized at ???>' Sym_81 None
Sym_81 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Initialized); 
--# expr-done 7967
Is_Equal_77 := Block_Var = Sym_81; 
--# expr-done 7968
   If_Result_58 := Is_Equal_77;
end if;
if If_Result_58 then
   If_Result_59 := True;
else
   --# expr-start 7970 '<Eq at ast.py:18257>' Is_Equal_78 /tmp/lal-23.0.0/ada/ast.py:18257
--# expr-start 7969 '<Symbol Valid_Scalars at ???>' Sym_82 None
Sym_82 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Valid_Scalars); 
--# expr-done 7969
Is_Equal_78 := Block_Var = Sym_82; 
--# expr-done 7970
   If_Result_59 := Is_Equal_78;
end if;
if If_Result_59 then
   --# expr-start 7976 '<And at ast.py:18261>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18261
--# expr-start 7972 '<FieldAccess for sub_equation at ast.py:18261>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:18261
--# expr-start 7971 '<FieldAccess for prefix at ast.py:18261>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:18261
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 7971
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_26 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_25.Node, Env => Env, Origin => Origin, E_Info => Fld_25.Info);
--# end
--# expr-done 7972
--# expr-start 7975 '<Bind at ast.py:18262>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18262
--# expr-start 7973 '<FieldAccess for type_var at ast.py:18262>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:18262
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 7973
Fld_27.Value := No_Entity;
Entity_Vars.Reset (Fld_27);
--# expr-start 7974 '<FieldAccess for bool_type at ast.py:18262>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:18262
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_28 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 7974
      Cast_Result := Create_Internal_Entity
        (Node => Fld_28.Node,
         Info => Fld_28.Info);
Bind_Result := Solver.Create_Assign (Fld_27, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18262") else null)); 
--# expr-done 7975
And_Pred := Create_And (Fld_26, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18261") else null)); 
--# expr-done 7976
   If_Result_99 := And_Pred;
else
--# expr-start 7978 '<Eq at ast.py:18264>' Is_Equal_79 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7977 '<Symbol Width at ???>' Sym_83 None
Sym_83 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Width); 
--# expr-done 7977
Is_Equal_79 := Block_Var = Sym_83; 
--# expr-done 7978
if Is_Equal_79 then
   If_Result_60 := True;
else
   --# expr-start 7980 '<Eq at ast.py:18264>' Is_Equal_80 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7979 '<Symbol Component_Size at ???>' Sym_84 None
Sym_84 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Component_Size); 
--# expr-done 7979
Is_Equal_80 := Block_Var = Sym_84; 
--# expr-done 7980
   If_Result_60 := Is_Equal_80;
end if;
if If_Result_60 then
   If_Result_61 := True;
else
   --# expr-start 7982 '<Eq at ast.py:18264>' Is_Equal_81 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7981 '<Symbol Position at ???>' Sym_85 None
Sym_85 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Position); 
--# expr-done 7981
Is_Equal_81 := Block_Var = Sym_85; 
--# expr-done 7982
   If_Result_61 := Is_Equal_81;
end if;
if If_Result_61 then
   If_Result_62 := True;
else
   --# expr-start 7984 '<Eq at ast.py:18264>' Is_Equal_82 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7983 '<Symbol Mantissa at ???>' Sym_86 None
Sym_86 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mantissa); 
--# expr-done 7983
Is_Equal_82 := Block_Var = Sym_86; 
--# expr-done 7984
   If_Result_62 := Is_Equal_82;
end if;
if If_Result_62 then
   If_Result_63 := True;
else
   --# expr-start 7986 '<Eq at ast.py:18264>' Is_Equal_83 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7985 '<Symbol Model_Mantissa at ???>' Sym_87 None
Sym_87 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Model_Mantissa); 
--# expr-done 7985
Is_Equal_83 := Block_Var = Sym_87; 
--# expr-done 7986
   If_Result_63 := Is_Equal_83;
end if;
if If_Result_63 then
   If_Result_64 := True;
else
   --# expr-start 7988 '<Eq at ast.py:18264>' Is_Equal_84 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7987 '<Symbol Machine_Mantissa at ???>' Sym_88 None
Sym_88 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Mantissa); 
--# expr-done 7987
Is_Equal_84 := Block_Var = Sym_88; 
--# expr-done 7988
   If_Result_64 := Is_Equal_84;
end if;
if If_Result_64 then
   If_Result_65 := True;
else
   --# expr-start 7990 '<Eq at ast.py:18264>' Is_Equal_85 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7989 '<Symbol Fore at ???>' Sym_89 None
Sym_89 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fore); 
--# expr-done 7989
Is_Equal_85 := Block_Var = Sym_89; 
--# expr-done 7990
   If_Result_65 := Is_Equal_85;
end if;
if If_Result_65 then
   If_Result_66 := True;
else
   --# expr-start 7992 '<Eq at ast.py:18264>' Is_Equal_86 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7991 '<Symbol Aft at ???>' Sym_90 None
Sym_90 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Aft); 
--# expr-done 7991
Is_Equal_86 := Block_Var = Sym_90; 
--# expr-done 7992
   If_Result_66 := Is_Equal_86;
end if;
if If_Result_66 then
   If_Result_67 := True;
else
   --# expr-start 7994 '<Eq at ast.py:18264>' Is_Equal_87 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7993 '<Symbol Digits at ???>' Sym_91 None
Sym_91 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Digits); 
--# expr-done 7993
Is_Equal_87 := Block_Var = Sym_91; 
--# expr-done 7994
   If_Result_67 := Is_Equal_87;
end if;
if If_Result_67 then
   If_Result_68 := True;
else
   --# expr-start 7996 '<Eq at ast.py:18264>' Is_Equal_88 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7995 '<Symbol Modulus at ???>' Sym_92 None
Sym_92 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Modulus); 
--# expr-done 7995
Is_Equal_88 := Block_Var = Sym_92; 
--# expr-done 7996
   If_Result_68 := Is_Equal_88;
end if;
if If_Result_68 then
   If_Result_69 := True;
else
   --# expr-start 7998 '<Eq at ast.py:18264>' Is_Equal_89 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7997 '<Symbol Word_Size at ???>' Sym_93 None
Sym_93 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Word_Size); 
--# expr-done 7997
Is_Equal_89 := Block_Var = Sym_93; 
--# expr-done 7998
   If_Result_69 := Is_Equal_89;
end if;
if If_Result_69 then
   If_Result_70 := True;
else
   --# expr-start 8000 '<Eq at ast.py:18264>' Is_Equal_90 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 7999 '<Symbol Max_Integer_Size at ???>' Sym_94 None
Sym_94 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Max_Integer_Size); 
--# expr-done 7999
Is_Equal_90 := Block_Var = Sym_94; 
--# expr-done 8000
   If_Result_70 := Is_Equal_90;
end if;
if If_Result_70 then
   If_Result_71 := True;
else
   --# expr-start 8002 '<Eq at ast.py:18264>' Is_Equal_91 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8001 '<Symbol Address_Size at ???>' Sym_95 None
Sym_95 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Address_Size); 
--# expr-done 8001
Is_Equal_91 := Block_Var = Sym_95; 
--# expr-done 8002
   If_Result_71 := Is_Equal_91;
end if;
if If_Result_71 then
   If_Result_72 := True;
else
   --# expr-start 8004 '<Eq at ast.py:18264>' Is_Equal_92 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8003 '<Symbol Maximum_Alignment at ???>' Sym_96 None
Sym_96 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Maximum_Alignment); 
--# expr-done 8003
Is_Equal_92 := Block_Var = Sym_96; 
--# expr-done 8004
   If_Result_72 := Is_Equal_92;
end if;
if If_Result_72 then
   If_Result_73 := True;
else
   --# expr-start 8006 '<Eq at ast.py:18264>' Is_Equal_93 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8005 '<Symbol System_Allocator_Alignment at ???>' Sym_97 None
Sym_97 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System_Allocator_Alignment); 
--# expr-done 8005
Is_Equal_93 := Block_Var = Sym_97; 
--# expr-done 8006
   If_Result_73 := Is_Equal_93;
end if;
if If_Result_73 then
   If_Result_74 := True;
else
   --# expr-start 8008 '<Eq at ast.py:18264>' Is_Equal_94 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8007 '<Symbol Finalization_Size at ???>' Sym_98 None
Sym_98 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Finalization_Size); 
--# expr-done 8007
Is_Equal_94 := Block_Var = Sym_98; 
--# expr-done 8008
   If_Result_74 := Is_Equal_94;
end if;
if If_Result_74 then
   If_Result_75 := True;
else
   --# expr-start 8010 '<Eq at ast.py:18264>' Is_Equal_95 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8009 '<Symbol Descriptor_Size at ???>' Sym_99 None
Sym_99 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Descriptor_Size); 
--# expr-done 8009
Is_Equal_95 := Block_Var = Sym_99; 
--# expr-done 8010
   If_Result_75 := Is_Equal_95;
end if;
if If_Result_75 then
   If_Result_76 := True;
else
   --# expr-start 8012 '<Eq at ast.py:18264>' Is_Equal_96 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8011 '<Symbol Alignment at ???>' Sym_100 None
Sym_100 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Alignment); 
--# expr-done 8011
Is_Equal_96 := Block_Var = Sym_100; 
--# expr-done 8012
   If_Result_76 := Is_Equal_96;
end if;
if If_Result_76 then
   If_Result_77 := True;
else
   --# expr-start 8014 '<Eq at ast.py:18264>' Is_Equal_97 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8013 '<Symbol First_Bit at ???>' Sym_101 None
Sym_101 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_First_Bit); 
--# expr-done 8013
Is_Equal_97 := Block_Var = Sym_101; 
--# expr-done 8014
   If_Result_77 := Is_Equal_97;
end if;
if If_Result_77 then
   If_Result_78 := True;
else
   --# expr-start 8016 '<Eq at ast.py:18264>' Is_Equal_98 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8015 '<Symbol Last_Bit at ???>' Sym_102 None
Sym_102 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Last_Bit); 
--# expr-done 8015
Is_Equal_98 := Block_Var = Sym_102; 
--# expr-done 8016
   If_Result_78 := Is_Equal_98;
end if;
if If_Result_78 then
   If_Result_79 := True;
else
   --# expr-start 8018 '<Eq at ast.py:18264>' Is_Equal_99 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8017 '<Symbol Default_Bit_Order at ???>' Sym_103 None
Sym_103 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Default_Bit_Order); 
--# expr-done 8017
Is_Equal_99 := Block_Var = Sym_103; 
--# expr-done 8018
   If_Result_79 := Is_Equal_99;
end if;
if If_Result_79 then
   If_Result_80 := True;
else
   --# expr-start 8020 '<Eq at ast.py:18264>' Is_Equal_100 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8019 '<Symbol Range_Length at ???>' Sym_104 None
Sym_104 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range_Length); 
--# expr-done 8019
Is_Equal_100 := Block_Var = Sym_104; 
--# expr-done 8020
   If_Result_80 := Is_Equal_100;
end if;
if If_Result_80 then
   If_Result_81 := True;
else
   --# expr-start 8022 '<Eq at ast.py:18264>' Is_Equal_101 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8021 '<Symbol Storage_Unit at ???>' Sym_105 None
Sym_105 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Storage_Unit); 
--# expr-done 8021
Is_Equal_101 := Block_Var = Sym_105; 
--# expr-done 8022
   If_Result_81 := Is_Equal_101;
end if;
if If_Result_81 then
   If_Result_82 := True;
else
   --# expr-start 8024 '<Eq at ast.py:18264>' Is_Equal_102 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8023 '<Symbol Small_Numerator at ???>' Sym_106 None
Sym_106 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Small_Numerator); 
--# expr-done 8023
Is_Equal_102 := Block_Var = Sym_106; 
--# expr-done 8024
   If_Result_82 := Is_Equal_102;
end if;
if If_Result_82 then
   If_Result_83 := True;
else
   --# expr-start 8026 '<Eq at ast.py:18264>' Is_Equal_103 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8025 '<Symbol Small_Denominator at ???>' Sym_107 None
Sym_107 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Small_Denominator); 
--# expr-done 8025
Is_Equal_103 := Block_Var = Sym_107; 
--# expr-done 8026
   If_Result_83 := Is_Equal_103;
end if;
if If_Result_83 then
   If_Result_84 := True;
else
   --# expr-start 8028 '<Eq at ast.py:18264>' Is_Equal_104 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8027 '<Symbol Machine_Emin at ???>' Sym_108 None
Sym_108 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Emin); 
--# expr-done 8027
Is_Equal_104 := Block_Var = Sym_108; 
--# expr-done 8028
   If_Result_84 := Is_Equal_104;
end if;
if If_Result_84 then
   If_Result_85 := True;
else
   --# expr-start 8030 '<Eq at ast.py:18264>' Is_Equal_105 /tmp/lal-23.0.0/ada/ast.py:18264
--# expr-start 8029 '<Symbol Machine_Emax at ???>' Sym_109 None
Sym_109 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Emax); 
--# expr-done 8029
Is_Equal_105 := Block_Var = Sym_109; 
--# expr-done 8030
   If_Result_85 := Is_Equal_105;
end if;
if If_Result_85 then
   --# expr-start 8035 '<And at ast.py:18275>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18275
--# expr-start 8032 '<FieldAccess for sub_equation at ast.py:18275>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:18275
--# expr-start 8031 '<FieldAccess for prefix at ast.py:18275>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:18275
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8031
      if Fld_29.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_30 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_29.Node, Env => Env, Origin => Origin, E_Info => Fld_29.Info);
--# end
--# expr-done 8032
--# expr-start 8034 '<FieldAccess for universal_int_bind at ast.py:18276>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:18276
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8033 '<FieldAccess for type_var at ast.py:18276>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:18276
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8033
--# property-call-start AdaNode.universal_int_bind
Fld_32 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_31, Origin => Origin);
--# end
--# expr-done 8034
And_Pred_1 := Create_And (Fld_30, Fld_32, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18275") else null)); 
--# expr-done 8035
   If_Result_98 := And_Pred_1;
else
--# expr-start 8037 '<Eq at ast.py:18278>' Is_Equal_106 /tmp/lal-23.0.0/ada/ast.py:18278
--# expr-start 8036 '<Symbol Target_Name at ???>' Sym_110 None
Sym_110 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Target_Name); 
--# expr-done 8036
Is_Equal_106 := Block_Var = Sym_110; 
--# expr-done 8037
if Is_Equal_106 then
   --# expr-start 8041 '<Bind at ast.py:18279>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18279
--# expr-start 8038 '<FieldAccess for type_var at ast.py:18279>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:18279
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_33 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8038
Fld_33.Value := No_Entity;
Entity_Vars.Reset (Fld_33);
--# expr-start 8040 '<FieldAccess for std_entity at ast.py:18279>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:18279
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8039 '<Symbol String at ???>' Sym_111 None
Sym_111 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 8039
--# property-call-start AdaNode.std_entity
Fld_34 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_111);
--# end
--# expr-done 8040
Bind_Result_1 := Solver.Create_Assign (Fld_33, Fld_34, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18279") else null)); 
--# expr-done 8041
   If_Result_97 := Bind_Result_1;
else
--# expr-start 8043 '<Eq at ast.py:18281>' Is_Equal_107 /tmp/lal-23.0.0/ada/ast.py:18281
--# expr-start 8042 '<Symbol Storage_Pool at ???>' Sym_112 None
Sym_112 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Storage_Pool); 
--# expr-done 8042
Is_Equal_107 := Block_Var = Sym_112; 
--# expr-done 8043
if Is_Equal_107 then
   --# expr-start 8044 '<FieldAccess for storage_pool_equation at ast.py:18281>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:18281
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.storage_pool_equation
Fld_35 := Libadalang.Implementation.Attribute_Ref_P_Storage_Pool_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8044
   If_Result_96 := Fld_35;
else
--# expr-start 8046 '<Eq at ast.py:18283>' Is_Equal_108 /tmp/lal-23.0.0/ada/ast.py:18283
--# expr-start 8045 '<Symbol Scalar_Storage_Order at ???>' Sym_113 None
Sym_113 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Scalar_Storage_Order); 
--# expr-done 8045
Is_Equal_108 := Block_Var = Sym_113; 
--# expr-done 8046
if Is_Equal_108 then
   --# expr-start 8047 '<FieldAccess for scalar_storage_order_equation at ast.py:18284>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:18284
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.scalar_storage_order_equation
Fld_36 := Libadalang.Implementation.Attribute_Ref_P_Scalar_Storage_Order_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8047
   If_Result_95 := Fld_36;
else
--# expr-start 8049 '<Eq at ast.py:18286>' Is_Equal_109 /tmp/lal-23.0.0/ada/ast.py:18286
--# expr-start 8048 '<Symbol Type_Class at ???>' Sym_114 None
Sym_114 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Type_Class); 
--# expr-done 8048
Is_Equal_109 := Block_Var = Sym_114; 
--# expr-done 8049
if Is_Equal_109 then
   --# expr-start 8050 '<FieldAccess for type_class_equation at ast.py:18286>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:18286
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.type_class_equation
Fld_37 := Libadalang.Implementation.Attribute_Ref_P_Type_Class_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8050
   If_Result_94 := Fld_37;
else
--# expr-start 8052 '<Eq at ast.py:18289>' Is_Equal_110 /tmp/lal-23.0.0/ada/ast.py:18289
--# expr-start 8051 '<Symbol Callable at ???>' Sym_115 None
Sym_115 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Callable); 
--# expr-done 8051
Is_Equal_110 := Block_Var = Sym_115; 
--# expr-done 8052
if Is_Equal_110 then
   If_Result_86 := True;
else
   --# expr-start 8054 '<Eq at ast.py:18289>' Is_Equal_111 /tmp/lal-23.0.0/ada/ast.py:18289
--# expr-start 8053 '<Symbol Terminated at ???>' Sym_116 None
Sym_116 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Terminated); 
--# expr-done 8053
Is_Equal_111 := Block_Var = Sym_116; 
--# expr-done 8054
   If_Result_86 := Is_Equal_111;
end if;
if If_Result_86 then
   --# expr-start 8060 '<And at ast.py:18290>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18290
--# expr-start 8056 '<FieldAccess for sub_equation at ast.py:18290>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:18290
--# expr-start 8055 '<FieldAccess for prefix at ast.py:18290>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:18290
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_38 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8055
      if Fld_38.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_39 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_38.Node, Env => Env, Origin => Origin, E_Info => Fld_38.Info);
--# end
--# expr-done 8056
--# expr-start 8059 '<Bind at ast.py:18290>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18290
--# expr-start 8057 '<FieldAccess for type_var at ast.py:18290>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:18290
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_40 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8057
Fld_40.Value := No_Entity;
Entity_Vars.Reset (Fld_40);
--# expr-start 8058 '<FieldAccess for bool_type at ast.py:18290>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:18290
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_41 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 8058
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_41.Node,
         Info => Fld_41.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_40, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18290") else null)); 
--# expr-done 8059
And_Pred_2 := Create_And (Fld_39, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18290") else null)); 
--# expr-done 8060
   If_Result_93 := And_Pred_2;
else
--# expr-start 8062 '<Eq at ast.py:18293>' Is_Equal_112 /tmp/lal-23.0.0/ada/ast.py:18293
--# expr-start 8061 '<Symbol Count at ???>' Sym_117 None
Sym_117 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Count); 
--# expr-done 8061
Is_Equal_112 := Block_Var = Sym_117; 
--# expr-done 8062
if Is_Equal_112 then
   --# expr-start 8067 '<And at ast.py:18294>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:18294
--# expr-start 8064 '<FieldAccess for xref_no_overloading at ast.py:18294>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:18294
--# expr-start 8063 '<FieldAccess for prefix at ast.py:18294>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:18294
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_42 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8063
      if Fld_42.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_43 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_42.Node, Env => Env, Origin => Origin, E_Info => Fld_42.Info);
--# end
--# expr-done 8064
--# expr-start 8066 '<FieldAccess for universal_int_bind at ast.py:18295>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:18295
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8065 '<FieldAccess for type_var at ast.py:18295>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:18295
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_44 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8065
--# property-call-start AdaNode.universal_int_bind
Fld_45 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_44, Origin => Origin);
--# end
--# expr-done 8066
And_Pred_3 := Create_And (Fld_43, Fld_45, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18294") else null)); 
--# expr-done 8067
   If_Result_92 := And_Pred_3;
else
--# expr-start 8069 '<Eq at ast.py:18297>' Is_Equal_113 /tmp/lal-23.0.0/ada/ast.py:18297
--# expr-start 8068 '<Symbol Caller at ???>' Sym_118 None
Sym_118 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Caller); 
--# expr-done 8068
Is_Equal_113 := Block_Var = Sym_118; 
--# expr-done 8069
if Is_Equal_113 then
   --# expr-start 8075 '<And at ast.py:18298>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:18298
--# expr-start 8071 '<FieldAccess for xref_no_overloading at ast.py:18298>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:18298
--# expr-start 8070 '<FieldAccess for prefix at ast.py:18298>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:18298
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_46 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8070
      if Fld_46.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_47 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_46.Node, Env => Env, Origin => Origin, E_Info => Fld_46.Info);
--# end
--# expr-done 8071
--# expr-start 8074 '<Bind at ast.py:18299>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:18299
--# expr-start 8072 '<FieldAccess for type_var at ast.py:18299>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:18299
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_48 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8072
Fld_48.Value := No_Entity;
Entity_Vars.Reset (Fld_48);
--# expr-start 8073 '<FieldAccess for task_id_type at ast.py:18299>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:18299
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.task_id_type
Fld_49 := Libadalang.Implementation.Ada_Node_P_Task_Id_Type (Node => Self);
--# end
--# expr-done 8073
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_49.Node,
         Info => Fld_49.Info);
Bind_Result_3 := Solver.Create_Assign (Fld_48, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18299") else null)); 
--# expr-done 8074
And_Pred_4 := Create_And (Fld_47, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18298") else null)); 
--# expr-done 8075
   If_Result_91 := And_Pred_4;
else
--# expr-start 8077 '<Eq at ast.py:18301>' Is_Equal_114 /tmp/lal-23.0.0/ada/ast.py:18301
--# expr-start 8076 '<Symbol Machine_Radix at ???>' Sym_119 None
Sym_119 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Radix); 
--# expr-done 8076
Is_Equal_114 := Block_Var = Sym_119; 
--# expr-done 8077
if Is_Equal_114 then
   --# expr-start 8078 '<FieldAccess for universal_int_equation at ast.py:18302>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:18302
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.universal_int_equation
Fld_50 := Libadalang.Implementation.Attribute_Ref_P_Universal_Int_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8078
   If_Result_90 := Fld_50;
else
--# expr-start 8080 '<Eq at ast.py:18304>' Is_Equal_115 /tmp/lal-23.0.0/ada/ast.py:18304
--# expr-start 8079 '<Symbol To_Address at ???>' Sym_120 None
Sym_120 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_To_Address); 
--# expr-done 8079
Is_Equal_115 := Block_Var = Sym_120; 
--# expr-done 8080
if Is_Equal_115 then
   --# expr-start 8081 '<FieldAccess for to_address_equation at ast.py:18305>' Fld_51 /tmp/lal-23.0.0/ada/ast.py:18305
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.to_address_equation
Fld_51 := Libadalang.Implementation.Attribute_Ref_P_To_Address_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8081
   If_Result_89 := Fld_51;
else
--# expr-start 8083 '<Eq at ast.py:18307>' Is_Equal_116 /tmp/lal-23.0.0/ada/ast.py:18307
--# expr-start 8082 '<Symbol Index at ???>' Sym_121 None
Sym_121 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Index); 
--# expr-done 8082
Is_Equal_116 := Block_Var = Sym_121; 
--# expr-done 8083
if Is_Equal_116 then
   --# expr-start 8084 '<FieldAccess for index_equation at ast.py:18308>' Fld_52 /tmp/lal-23.0.0/ada/ast.py:18308
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.index_equation
Fld_52 := Libadalang.Implementation.Attribute_Ref_P_Index_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8084
   If_Result_88 := Fld_52;
else
--# expr-start 8086 '<Eq at ast.py:18310>' Is_Equal_117 /tmp/lal-23.0.0/ada/ast.py:18310
--# expr-start 8085 '<Symbol Abort_Signal at ???>' Sym_122 None
Sym_122 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abort_Signal); 
--# expr-done 8085
Is_Equal_117 := Block_Var = Sym_122; 
--# expr-done 8086
if Is_Equal_117 then
   --# expr-start 8093 '<And at ast.py:18311>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:18311
--# expr-start 8090 '<Bind at ast.py:18311>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:18311
--# expr-start 8087 '<FieldAccess for ref_var at ast.py:18311>' Fld_53 /tmp/lal-23.0.0/ada/ast.py:18311
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_53 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 8087
Fld_53.Value := No_Entity;
Entity_Vars.Reset (Fld_53);
--# expr-start 8089 '<FieldAccess for std_entity at ast.py:18311>' Fld_54 /tmp/lal-23.0.0/ada/ast.py:18311
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8088 '<Symbol abort_signal_ at ???>' Sym_123 None
Sym_123 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abort_Signal_259); 
--# expr-done 8088
--# property-call-start AdaNode.std_entity
Fld_54 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_123);
--# end
--# expr-done 8089
Bind_Result_4 := Solver.Create_Assign (Fld_53, Fld_54, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18311") else null)); 
--# expr-done 8090
--# expr-start 8092 '<Bind at ast.py:18312>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:18312
--# expr-start 8091 '<FieldAccess for type_var at ast.py:18312>' Fld_55 /tmp/lal-23.0.0/ada/ast.py:18312
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_55 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8091
Fld_55.Value := No_Entity;
Entity_Vars.Reset (Fld_55);
Cast_Expr := No_Entity_Base_Type_Decl; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result_5 := Solver.Create_Assign (Fld_55, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18312") else null)); 
--# expr-done 8092
And_Pred_5 := Create_And (Bind_Result_4, Bind_Result_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18311") else null)); 
--# expr-done 8093
   If_Result_87 := And_Pred_5;
else
   If_Result_87 := raise Property_Error with "Unhandled attribute";
end if;
      Inc_Ref (If_Result_87);
   If_Result_88 := If_Result_87;
end if;
      Inc_Ref (If_Result_88);
   If_Result_89 := If_Result_88;
end if;
      Inc_Ref (If_Result_89);
   If_Result_90 := If_Result_89;
end if;
      Inc_Ref (If_Result_90);
   If_Result_91 := If_Result_90;
end if;
      Inc_Ref (If_Result_91);
   If_Result_92 := If_Result_91;
end if;
      Inc_Ref (If_Result_92);
   If_Result_93 := If_Result_92;
end if;
      Inc_Ref (If_Result_93);
   If_Result_94 := If_Result_93;
end if;
      Inc_Ref (If_Result_94);
   If_Result_95 := If_Result_94;
end if;
      Inc_Ref (If_Result_95);
   If_Result_96 := If_Result_95;
end if;
      Inc_Ref (If_Result_96);
   If_Result_97 := If_Result_96;
end if;
      Inc_Ref (If_Result_97);
   If_Result_98 := If_Result_97;
end if;
      Inc_Ref (If_Result_98);
   If_Result_99 := If_Result_98;
end if;
      Inc_Ref (If_Result_99);
   If_Result_100 := If_Result_99;
end if;
      Inc_Ref (If_Result_100);
   If_Result_101 := If_Result_100;
end if;
      Inc_Ref (If_Result_101);
   If_Result_102 := If_Result_101;
end if;
      Inc_Ref (If_Result_102);
   If_Result_103 := If_Result_102;
end if;
      Inc_Ref (If_Result_103);
   If_Result_104 := If_Result_103;
end if;
      Inc_Ref (If_Result_104);
   If_Result_105 := If_Result_104;
end if;
      Inc_Ref (If_Result_105);
   If_Result_106 := If_Result_105;
end if;
      Inc_Ref (If_Result_106);
   If_Result_107 := If_Result_106;
end if;
      Inc_Ref (If_Result_107);
   If_Result_108 := If_Result_107;
end if;
      Inc_Ref (If_Result_108);
   If_Result_109 := If_Result_108;
end if;
      Inc_Ref (If_Result_109);
   If_Result_110 := If_Result_109;
end if;
      Inc_Ref (If_Result_110);
   If_Result_111 := If_Result_110;
end if;
      Inc_Ref (If_Result_111);
   If_Result_112 := If_Result_111;
end if;
      Inc_Ref (If_Result_112);
   If_Result_113 := If_Result_112;
end if;
      Inc_Ref (If_Result_113);
   If_Result_114 := If_Result_113;
end if;
      Inc_Ref (If_Result_114);
   If_Result_115 := If_Result_114;
end if;
      Inc_Ref (If_Result_115);
   If_Result_116 := If_Result_115;
end if;
      Inc_Ref (If_Result_116);
   If_Result_117 := If_Result_116;
end if;
      Inc_Ref (If_Result_117);
--# expr-done 8094
Let_Result := If_Result_117; Inc_Ref (Let_Result);
--# end
--# expr-done 8095
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1307;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1307;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Xref_Equation;
--# end
--# property-start AttributeRef.attribute_subprogram_equation /tmp/lal-23.0.0/ada/ast.py:18318
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Attribute_Subprogram_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1308 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1308 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1308;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8102 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8101 '<And at ast.py:18323>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18323
--# expr-start 8097 '<FieldAccess for xref_no_overloading at ast.py:18323>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18323
--# expr-start 8096 '<FieldAccess for prefix at ast.py:18323>' Fld /tmp/lal-23.0.0/ada/ast.py:18323
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8096
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8097
--# expr-start 8100 '<Bind at ast.py:18324>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18324
--# expr-start 8098 '<FieldAccess for ref_var at ast.py:18324>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18324
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 8098
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 8099 '<FieldAccess for attribute_subprogram at ast.py:18324>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18324
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.attribute_subprogram
Fld_3 := Libadalang.Implementation.Attribute_Ref_P_Attribute_Subprogram (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8099
      Cast_Result := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Bind_Result := Solver.Create_Assign (Fld_2, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18324") else null)); 
--# expr-done 8100
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18323") else null)); 
--# expr-done 8101
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8102
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1308;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1308;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Attribute_Subprogram_Equation;
--# end
--# property-start AttributeRef.type_class_equation /tmp/lal-23.0.0/ada/ast.py:18328
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Type_Class_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1309 with Inline_Always;
            procedure Finalizer_Scope_2849 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1309 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1309;
            procedure Finalizer_Scope_2849 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2849;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8116 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8110 '<Cast to BaseTypeDecl at ast.py:18337>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18337
--# expr-start 8109 '<EnvGet at ast.py:18334>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18334
--# expr-start 8106 '<FieldAccess for get_unit_root_decl at ast.py:18335>' Fld /tmp/lal-23.0.0/ada/ast.py:18335
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8105 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 8103 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 8103
--# expr-start 8104 '<Symbol Aux_DEC at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Aux_Dec); 
--# expr-done 8104
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 8105
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 8106
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 8107 '<FieldAccess for children_env at ast.py:18336>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18336
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 8107
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2849;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8108 '<Symbol Type_Class at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Type_Class); 
--# expr-done 8108
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8109
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8110
Block_Var := Cast_Result; 
--# bind typ Block_Var
--# expr-start 8115 '<And at ast.py:18340>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18340
--# expr-start 8112 '<FieldAccess for xref_equation at ast.py:18340>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18340
--# expr-start 8111 '<FieldAccess for prefix at ast.py:18340>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18340
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8111
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8112
--# expr-start 8114 '<Bind at ast.py:18340>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18340
--# expr-start 8113 '<FieldAccess for type_var at ast.py:18340>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18340
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8113
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18340") else null)); 
--# expr-done 8114
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18340") else null)); 
--# expr-done 8115
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8116
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1309;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1309;
               Finalizer_Scope_2849;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Type_Class_Equation;
--# end
--# property-start AttributeRef.storage_pool_equation /tmp/lal-23.0.0/ada/ast.py:18343
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Storage_Pool_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1310 with Inline_Always;
            procedure Finalizer_Scope_2850 with Inline_Always;
      Block_Var : Internal_Entity_Classwide_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Classwide_Type_Decl;
Fld_3 : Internal_Entity_Name;
Fld_4 : Logic_Equation;
Fld_5 : Logic_Var;
Cast_Expr : Internal_Entity_Classwide_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1310 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1310;
            procedure Finalizer_Scope_2850 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2850;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8131 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8125 '<FieldAccess for classwide_type at ast.py:18351>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18351
--# expr-start 8124 '<Cast to BaseTypeDecl at ast.py:18351>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18351
--# expr-start 8123 '<EnvGet at ast.py:18348>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18348
--# expr-start 8120 '<FieldAccess for get_unit_root_decl at ast.py:18349>' Fld /tmp/lal-23.0.0/ada/ast.py:18349
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8119 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 8117 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 8117
--# expr-start 8118 '<Symbol Storage_Pools at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Storage_Pools); 
--# expr-done 8118
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 8119
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 8120
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 8121 '<FieldAccess for children_env at ast.py:18350>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18350
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 8121
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2850;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8122 '<Symbol Root_Storage_Pool at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Root_Storage_Pool); 
--# expr-done 8122
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8123
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8124
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 8125
Block_Var := Fld_2; 
--# bind typ Block_Var
--# expr-start 8130 '<And at ast.py:18354>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18354
--# expr-start 8127 '<FieldAccess for xref_equation at ast.py:18354>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18354
--# expr-start 8126 '<FieldAccess for prefix at ast.py:18354>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18354
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8126
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_4 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 8127
--# expr-start 8129 '<Bind at ast.py:18354>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18354
--# expr-start 8128 '<FieldAccess for type_var at ast.py:18354>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18354
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8128
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18354") else null)); 
--# expr-done 8129
And_Pred := Create_And (Fld_4, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18354") else null)); 
--# expr-done 8130
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8131
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1310;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1310;
               Finalizer_Scope_2850;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Storage_Pool_Equation;
--# end
--# property-start AttributeRef.scalar_storage_order_equation /tmp/lal-23.0.0/ada/ast.py:18357
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Scalar_Storage_Order_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1311 with Inline_Always;
            procedure Finalizer_Scope_2851 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_1 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1311 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1311;
            procedure Finalizer_Scope_2851 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2851;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8144 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8138 '<Cast to BaseTypeDecl at ast.py:18365>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18365
--# expr-start 8137 '<EnvGet at ast.py:18362>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18362
--# expr-start 8134 '<FieldAccess for get_unit_root_decl at ast.py:18363>' Fld /tmp/lal-23.0.0/ada/ast.py:18363
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8133 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 8132 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 8132
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym)); 
--# expr-done 8133
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 8134
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 8135 '<FieldAccess for children_env at ast.py:18364>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18364
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 8135
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2851;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8136 '<Symbol Bit_Order at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Bit_Order); 
--# expr-done 8136
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_1, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8137
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8138
Block_Var := Cast_Result; 
--# bind typ Block_Var
--# expr-start 8143 '<And at ast.py:18368>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18368
--# expr-start 8140 '<FieldAccess for xref_equation at ast.py:18368>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18368
--# expr-start 8139 '<FieldAccess for prefix at ast.py:18368>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18368
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8139
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8140
--# expr-start 8142 '<Bind at ast.py:18368>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18368
--# expr-start 8141 '<FieldAccess for type_var at ast.py:18368>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18368
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8141
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18368") else null)); 
--# expr-done 8142
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18368") else null)); 
--# expr-done 8143
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8144
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1311;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1311;
               Finalizer_Scope_2851;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Scalar_Storage_Order_Equation;
--# end
--# property-start AttributeRef.bind_to_prefix_eq /tmp/lal-23.0.0/ada/ast.py:18371
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Bind_To_Prefix_Eq
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1312 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
Fld_2 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Name;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Bare_Name;
Fld_7 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1312 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1312;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8157 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8156 '<And at ast.py:18372>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18372
--# expr-start 8151 '<And at ast.py:18372>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18372
--# expr-start 8148 '<Bind at ast.py:18373>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18373
--# expr-start 8146 '<FieldAccess for expected_type_var at ast.py:18373>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18373
--# expr-start 8145 '<FieldAccess for prefix at ast.py:18373>' Fld /tmp/lal-23.0.0/ada/ast.py:18373
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Attribute_Ref_F_Prefix;
--# expr-done 8145
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 8146
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 8147 '<FieldAccess for expected_type_var at ast.py:18373>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18373
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 8147
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Bind_Result := Solver.Create_Unify (Fld_1, Fld_2, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18373") else null)); 
--# expr-done 8148
--# expr-start 8150 '<FieldAccess for sub_equation at ast.py:18374>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18374
--# expr-start 8149 '<FieldAccess for prefix at ast.py:18374>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18374
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8149
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 8150
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18372") else null)); 
--# expr-done 8151
--# expr-start 8155 '<Bind at ast.py:18375>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18375
--# expr-start 8152 '<FieldAccess for type_var at ast.py:18375>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18375
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8152
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 8154 '<FieldAccess for type_var at ast.py:18375>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18375
--# expr-start 8153 '<FieldAccess for prefix at ast.py:18375>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18375
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8153
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_6);
--# expr-done 8154
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result_1 := Solver.Create_Unify (Fld_5, Fld_7, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18375") else null)); 
--# expr-done 8155
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18372") else null)); 
--# expr-done 8156
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8157
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1312;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1312;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Bind_To_Prefix_Eq;
--# end
--# property-start AttributeRef.result_attr_equation /tmp/lal-23.0.0/ada/ast.py:18379
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Result_Attr_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1313 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Subp_Spec;
Env_Node : Bare_Ada_Node;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_2 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Name;
Fld_4 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1313 is
            begin
                     Dec_Ref (Node_Parents);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1313;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8172 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8163 '<Cast to BasicDecl at ast.py:18385>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18385
--# expr-start 8162 '<as_entity at ast.py:18385>' If_Result /tmp/lal-23.0.0/ada/ast.py:18385
--# expr-start 8161 '<Find at ast.py:18383>' Find_Result /tmp/lal-23.0.0/ada/ast.py:18383
   --# expr-start 8159 '<FieldAccess for parents at ast.py:18383>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:18383
--# expr-start 8158 '<env_node at ast.py:18383>' Env_Node /tmp/lal-23.0.0/ada/ast.py:18383
Env_Node := AST_Envs.Env_Node (Env); 
--# expr-done 8158
      if Env_Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Env_Node, True); 
--# expr-done 8159
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_254 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_254
      --# expr-start 8160 '<IsA BasicSubpDecl, BaseSubpBody at ast.py:18384>' Is_A /tmp/lal-23.0.0/ada/ast.py:18384
Is_A := Item_254 /= null 
and then Item_254.Kind in Ada_Basic_Subp_Decl | Ada_Base_Subp_Body; 
--# expr-done 8160
      if Is_A then
         Find_Result := Item_254;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 8161
Is_Null := Find_Result = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => E_Info, Node => Find_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 8162
   if If_Result.Node = null
      or else If_Result.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => If_Result.Node,
         Info => If_Result.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 8163
Block_Var := Cast_Result; 
--# bind containing_subp Block_Var
--# expr-start 8164 '<FieldAccess for subp_spec_or_null at ast.py:18387>' Fld /tmp/lal-23.0.0/ada/ast.py:18387
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 8164
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr
--# expr-start 8165 '<FieldAccess for return_type at ast.py:18388>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18388
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8165
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Block_Var_1 := Result_Var; 
--# bind returns Block_Var_1
--# expr-start 8171 '<And at ast.py:18391>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18391
--# expr-start 8167 '<Bind at ast.py:18392>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18392
--# expr-start 8166 '<FieldAccess for type_var at ast.py:18392>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18392
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8166
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Cast_Expr := Block_Var_1; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_2, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18392") else null)); 
--# expr-done 8167
--# expr-start 8170 '<Bind at ast.py:18393>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18393
--# expr-start 8169 '<FieldAccess for ref_var at ast.py:18393>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18393
--# expr-start 8168 '<FieldAccess for prefix at ast.py:18393>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18393
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8168
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_3.Node);
--# end
--# expr-done 8169
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_4, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18393") else null)); 
--# expr-done 8170
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18391") else null)); 
--# expr-done 8171
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8172
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1313;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1313;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Result_Attr_Equation;
--# end
--# property-start AttributeRef.tag_attr_equation /tmp/lal-23.0.0/ada/ast.py:18397
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Tag_Attr_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1314 with Inline_Always;
            procedure Finalizer_Scope_2854 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1314 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1314;
            procedure Finalizer_Scope_2854 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2854;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8186 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8180 '<Cast to BaseTypeDecl at ast.py:18402>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18402
--# expr-start 8179 '<EnvGet at ast.py:18399>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18399
--# expr-start 8176 '<FieldAccess for get_unit_root_decl at ast.py:18400>' Fld /tmp/lal-23.0.0/ada/ast.py:18400
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8175 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 8173 '<Symbol Ada at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ada); 
--# expr-done 8173
--# expr-start 8174 '<Symbol Tags at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Tags); 
--# expr-done 8174
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 8175
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 8176
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 8177 '<FieldAccess for children_env at ast.py:18401>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18401
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 8177
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2854;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8178 '<Symbol Tag at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Tag); 
--# expr-done 8178
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8179
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8180
Block_Var := Cast_Result; 
--# bind tag_type Block_Var
--# expr-start 8185 '<And at ast.py:18407>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18407
--# expr-start 8182 '<FieldAccess for xref_equation at ast.py:18407>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18407
--# expr-start 8181 '<FieldAccess for prefix at ast.py:18407>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18407
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8181
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8182
--# expr-start 8184 '<Bind at ast.py:18410>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18410
--# expr-start 8183 '<FieldAccess for type_var at ast.py:18410>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18410
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8183
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18410") else null)); 
--# expr-done 8184
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18407") else null)); 
--# expr-done 8185
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8186
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1314;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1314;
               Finalizer_Scope_2854;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Tag_Attr_Equation;
--# end
--# property-start AttributeRef.address_equation /tmp/lal-23.0.0/ada/ast.py:18414
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Address_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1315 with Inline_Always;
            procedure Finalizer_Scope_2855 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_1 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Bare_Name;
Fld_5 : Logic_Var;
Pred : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Internal_Entity_Name;
Fld_7 : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_8 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1315 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1315;
            procedure Finalizer_Scope_2855 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2855;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8206 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8193 '<Cast to BaseTypeDecl at ast.py:18419>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18419
--# expr-start 8192 '<EnvGet at ast.py:18416>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18416
--# expr-start 8189 '<FieldAccess for get_unit_root_decl at ast.py:18417>' Fld /tmp/lal-23.0.0/ada/ast.py:18417
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8188 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 8187 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 8187
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym)); 
--# expr-done 8188
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 8189
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 8190 '<FieldAccess for children_env at ast.py:18418>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18418
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 8190
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2855;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8191 '<Symbol Address at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Address); 
--# expr-done 8191
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_1, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8192
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8193
Block_Var := Cast_Result; 
--# bind address_type Block_Var
--# expr-start 8205 '<And at ast.py:18424>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18424
--# expr-start 8202 '<Or at ast.py:18424>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:18424
--# expr-start 8199 '<And at ast.py:18425>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18425
--# expr-start 8195 '<FieldAccess for xref_no_overloading at ast.py:18425>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18425
--# expr-start 8194 '<FieldAccess for prefix at ast.py:18425>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18425
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8194
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_3 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8195
--# expr-start 8198 '<Predicate on BasicDecl.is_subprogram at ast.py:18426>' Pred /tmp/lal-23.0.0/ada/ast.py:18426
--# expr-start 8197 '<FieldAccess for ref_var at ast.py:18426>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18426
--# expr-start 8196 '<FieldAccess for prefix at ast.py:18426>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18426
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8196
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_4);
--# end
--# expr-done 8197
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Pred := Solver.Create_Predicate (Fld_5, Create_Basic_Decl_P_Is_Subprogram_0_Predicate); 
--# expr-done 8198
And_Pred := Create_And (Fld_3, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18425") else null)); 
--# expr-done 8199
--# expr-start 8201 '<FieldAccess for sub_equation at ast.py:18428>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18428
--# expr-start 8200 '<FieldAccess for prefix at ast.py:18428>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18428
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8200
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_7 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_6.Node, Env => Env, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 8201
Or_Pred := Create_Or (And_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18424") else null)); 
--# expr-done 8202
--# expr-start 8204 '<Bind at ast.py:18429>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18429
--# expr-start 8203 '<FieldAccess for type_var at ast.py:18429>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18429
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8203
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_8, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18429") else null)); 
--# expr-done 8204
And_Pred_1 := Create_And (Or_Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18424") else null)); 
--# expr-done 8205
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8206
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1315;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1315;
               Finalizer_Scope_2855;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Address_Equation;
--# end
--# property-start AttributeRef.identity_equation /tmp/lal-23.0.0/ada/ast.py:18432
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Identity_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1316 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Fld_4 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1316 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1316;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8214 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8213 '<And at ast.py:18435>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18435
--# expr-start 8208 '<FieldAccess for sub_equation at ast.py:18436>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18436
--# expr-start 8207 '<FieldAccess for prefix at ast.py:18436>' Fld /tmp/lal-23.0.0/ada/ast.py:18436
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8207
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8208
--# expr-start 8212 '<Bind at ast.py:18437>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18437
--# expr-start 8210 '<FieldAccess for ref_var at ast.py:18437>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18437
--# expr-start 8209 '<FieldAccess for prefix at ast.py:18437>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18437
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8209
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_2);
--# end
--# expr-done 8210
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 8211 '<FieldAccess for type_var at ast.py:18437>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18437
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8211
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Bind_Result := Solver.Create_Propagate (Fld_3, Fld_4, Logic_Functor_208'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18437") else null)); 
--# expr-done 8212
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18435") else null)); 
--# expr-done 8213
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8214
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1316;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1316;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Identity_Equation;
--# end
--# property-start AttributeRef.universal_real_equation /tmp/lal-23.0.0/ada/ast.py:18442
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Universal_Real_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1317 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1317 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1317;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8220 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8219 '<And at ast.py:18444>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18444
--# expr-start 8216 '<FieldAccess for universal_real_bind at ast.py:18444>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18444
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8215 '<FieldAccess for type_var at ast.py:18444>' Fld /tmp/lal-23.0.0/ada/ast.py:18444
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8215
--# property-call-start AdaNode.universal_real_bind
Fld_1 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Self, Type_Var => Fld, Origin => Origin);
--# end
--# expr-done 8216
--# expr-start 8218 '<FieldAccess for sub_equation at ast.py:18445>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18445
--# expr-start 8217 '<FieldAccess for prefix at ast.py:18445>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18445
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8217
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8218
And_Pred := Create_And (Fld_1, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18444") else null)); 
--# expr-done 8219
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8220
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1317;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1317;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Universal_Real_Equation;
--# end
--# property-start AttributeRef.universal_int_equation /tmp/lal-23.0.0/ada/ast.py:18449
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Universal_Int_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1318 with Inline_Always;
            procedure Finalizer_Scope_2856 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Internal_Entity_Assoc_List;
Fld_7 : Bare_Assoc_List;
Fld_8 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_9 : Internal_Entity_Expr;
Fld_10 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_13 : Internal_Entity_Expr;
Fld_14 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Item_255 : Internal_Entity_Basic_Assoc;
Bare_Item_255 : Bare_Basic_Assoc;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1318 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1318;
            procedure Finalizer_Scope_2856 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_12);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_14);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_2856;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8241 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8222 '<FieldAccess for name_designated_type at ast.py:18450>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18450
--# expr-start 8221 '<FieldAccess for prefix at ast.py:18450>' Fld /tmp/lal-23.0.0/ada/ast.py:18450
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8221
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_1 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8222
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 8240 '<And at ast.py:18453>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:18453
--# expr-start 8227 '<And at ast.py:18453>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18453
--# expr-start 8224 '<FieldAccess for sub_equation at ast.py:18453>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18453
--# expr-start 8223 '<FieldAccess for prefix at ast.py:18453>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18453
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8223
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8224
--# expr-start 8226 '<FieldAccess for universal_int_bind at ast.py:18454>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18454
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8225 '<FieldAccess for type_var at ast.py:18454>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18454
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8225
--# property-call-start AdaNode.universal_int_bind
Fld_5 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_4, Origin => Origin);
--# end
--# expr-done 8226
And_Pred := Create_And (Fld_3, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18453") else null)); 
--# expr-done 8227
--# expr-start 8239 '<LogicAll at ast.py:18455>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:18455
--# expr-start 8238 '<Map at ast.py:18455>' Map_Result /tmp/lal-23.0.0/ada/ast.py:18455
   --# expr-start 8228 '<FieldAccess for args at ast.py:18455>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18455
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Attribute_Ref_F_Args, Info => Ent.Info);
--# expr-done 8228
Fld_7 := Fld_6.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_7 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_7;
      begin
         for Untyped_Item_255 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_255 := Untyped_Item_255; 
Is_Null := Bare_Item_255 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_8 := Fld_6.Info;
As_Entity := (Info => Fld_8, Node => Bare_Item_255); 
   If_Result := As_Entity;
end if;
                  Item_255 := If_Result; 
   --# scope-start
               --# bind arg Item_255
      --# expr-start 8237 '<And at ast.py:18457>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18457
--# expr-start 8234 '<And at ast.py:18457>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18457
--# expr-start 8231 '<Bind at ast.py:18457>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18457
--# expr-start 8230 '<FieldAccess for expected_type_var at ast.py:18457>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18457
--# expr-start 8229 '<FieldAccess for expr at ast.py:18457>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18457
      if Item_255.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_9 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_255.Node, E_Info => Item_255.Info);
--# end
--# expr-done 8229
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_9.Node);
--# expr-done 8230
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_10, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18457") else null)); 
--# expr-done 8231
--# expr-start 8233 '<FieldAccess for sub_equation at ast.py:18458>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18458
--# expr-start 8232 '<FieldAccess for expr at ast.py:18458>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18458
      if Item_255.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_11 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_255.Node, E_Info => Item_255.Info);
--# end
--# expr-done 8232
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_12 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_11.Node, Env => Env, Origin => Origin, E_Info => Fld_11.Info);
--# end
--# expr-done 8233
And_Pred_1 := Create_And (Bind_Result, Fld_12, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18457") else null)); 
--# expr-done 8234
--# expr-start 8236 '<FieldAccess for matches_expected_type at ast.py:18459>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18459
--# expr-start 8235 '<FieldAccess for expr at ast.py:18459>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18459
      if Item_255.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_13 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_255.Node, E_Info => Item_255.Info);
--# end
--# expr-done 8235
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_14 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_13.Node, Origin => Origin);
--# end
--# expr-done 8236
And_Pred_2 := Create_And (And_Pred_1, Fld_14, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18457") else null)); 
--# expr-done 8237
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_2;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2856;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8238
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18455") else null)); 
--# expr-done 8239
And_Pred_3 := Create_And (And_Pred, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18453") else null)); 
--# expr-done 8240
Let_Result := And_Pred_3; Inc_Ref (Let_Result);
--# end
--# expr-done 8241
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1318;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1318;
               Finalizer_Scope_2856;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Universal_Int_Equation;
--# end
--# property-start AttributeRef.image_equation /tmp/lal-23.0.0/ada/ast.py:18464
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Image_Equation
  (Node : Bare_Attribute_Ref
      ; Str_Type : Internal_Entity
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind str_type Str_Type
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1319 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Name;
Fld_6 : Logic_Equation;
Fld_7 : Logic_Var;
Fld_8 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Is_Null : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1319 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1319;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8257 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8243 '<FieldAccess for name_designated_type at ast.py:18465>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18465
--# expr-start 8242 '<FieldAccess for prefix at ast.py:18465>' Fld /tmp/lal-23.0.0/ada/ast.py:18465
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8242
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_1 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8243
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 8256 '<If at ast.py:18466>' If_Result /tmp/lal-23.0.0/ada/ast.py:18466
--# expr-start 8244 '<IsNull at ast.py:18467>' Is_Null /tmp/lal-23.0.0/ada/ast.py:18467
Is_Null := Block_Var.Node = null; 
--# expr-done 8244
if Is_Null then
   --# expr-start 8249 '<And at ast.py:18470>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18470
--# expr-start 8246 '<FieldAccess for sub_equation at ast.py:18470>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18470
--# expr-start 8245 '<FieldAccess for prefix at ast.py:18470>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18470
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8245
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8246
--# expr-start 8248 '<Bind at ast.py:18471>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18471
--# expr-start 8247 '<FieldAccess for type_var at ast.py:18471>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18471
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8247
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Bind_Result := Solver.Create_Assign (Fld_4, Str_Type, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18471") else null)); 
--# expr-done 8248
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18470") else null)); 
--# expr-done 8249
   If_Result := And_Pred;
else
   --# expr-start 8255 '<And at ast.py:18473>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18473
--# expr-start 8251 '<FieldAccess for xref_no_overloading at ast.py:18473>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18473
--# expr-start 8250 '<FieldAccess for prefix at ast.py:18473>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18473
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8250
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_6 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_5.Node, Env => Env, Origin => Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 8251
--# expr-start 8254 '<Bind at ast.py:18474>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18474
--# expr-start 8252 '<FieldAccess for ref_var at ast.py:18474>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18474
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 8252
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
--# expr-start 8253 '<FieldAccess for attribute_subprogram at ast.py:18474>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18474
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.attribute_subprogram
Fld_8 := Libadalang.Implementation.Attribute_Ref_P_Attribute_Subprogram (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8253
      Cast_Result := Create_Internal_Entity
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_7, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18474") else null)); 
--# expr-done 8254
And_Pred_1 := Create_And (Fld_6, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18473") else null)); 
--# expr-done 8255
   If_Result := And_Pred_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 8256
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8257
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1319;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1319;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Image_Equation;
--# end
--# property-start AttributeRef.img_equation /tmp/lal-23.0.0/ada/ast.py:18478
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Img_Equation
  (Node : Bare_Attribute_Ref
      ; Str_Type : Internal_Entity
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind str_type Str_Type
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1320 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1320 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1320;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8263 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8262 '<And at ast.py:18481>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18481
--# expr-start 8259 '<FieldAccess for xref_equation at ast.py:18481>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18481
--# expr-start 8258 '<FieldAccess for prefix at ast.py:18481>' Fld /tmp/lal-23.0.0/ada/ast.py:18481
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8258
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8259
--# expr-start 8261 '<Bind at ast.py:18484>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18484
--# expr-start 8260 '<FieldAccess for type_var at ast.py:18484>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18484
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8260
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Bind_Result := Solver.Create_Assign (Fld_2, Str_Type, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18484") else null)); 
--# expr-done 8261
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18481") else null)); 
--# expr-done 8262
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8263
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1320;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1320;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Img_Equation;
--# end
--# property-start AttributeRef.enum_rep_equation /tmp/lal-23.0.0/ada/ast.py:18488
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Enum_Rep_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1321 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Internal_Entity_Name;
Fld_7 : Logic_Equation;
Fld_8 : Logic_Var;
Fld_9 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Is_Null : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1321 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1321;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8280 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8265 '<FieldAccess for name_designated_type at ast.py:18489>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18489
--# expr-start 8264 '<FieldAccess for prefix at ast.py:18489>' Fld /tmp/lal-23.0.0/ada/ast.py:18489
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8264
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_1 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8265
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 8279 '<If at ast.py:18491>' If_Result /tmp/lal-23.0.0/ada/ast.py:18491
--# expr-start 8266 '<IsNull at ast.py:18492>' Is_Null /tmp/lal-23.0.0/ada/ast.py:18492
Is_Null := Block_Var.Node = null; 
--# expr-done 8266
if Is_Null then
   --# expr-start 8272 '<And at ast.py:18495>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18495
--# expr-start 8268 '<FieldAccess for sub_equation at ast.py:18495>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18495
--# expr-start 8267 '<FieldAccess for prefix at ast.py:18495>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18495
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8267
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8268
--# expr-start 8271 '<Bind at ast.py:18496>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18496
--# expr-start 8269 '<FieldAccess for type_var at ast.py:18496>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18496
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8269
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 8270 '<FieldAccess for universal_int_type at ast.py:18496>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18496
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld_5 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 8270
Bind_Result := Solver.Create_Assign (Fld_4, Fld_5, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18496") else null)); 
--# expr-done 8271
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18495") else null)); 
--# expr-done 8272
   If_Result := And_Pred;
else
   --# expr-start 8278 '<And at ast.py:18498>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18498
--# expr-start 8274 '<FieldAccess for xref_no_overloading at ast.py:18498>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18498
--# expr-start 8273 '<FieldAccess for prefix at ast.py:18498>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18498
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8273
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_7 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_6.Node, Env => Env, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 8274
--# expr-start 8277 '<Bind at ast.py:18499>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18499
--# expr-start 8275 '<FieldAccess for ref_var at ast.py:18499>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18499
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 8275
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
--# expr-start 8276 '<FieldAccess for attribute_subprogram at ast.py:18499>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18499
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.attribute_subprogram
Fld_9 := Libadalang.Implementation.Attribute_Ref_P_Attribute_Subprogram (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8276
      Cast_Result := Create_Internal_Entity
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_8, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18499") else null)); 
--# expr-done 8277
And_Pred_1 := Create_And (Fld_7, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18498") else null)); 
--# expr-done 8278
   If_Result := And_Pred_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 8279
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8280
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1321;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1321;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Enum_Rep_Equation;
--# end
--# property-start AttributeRef.invalid_value_equation /tmp/lal-23.0.0/ada/ast.py:18503
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Invalid_Value_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1322 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_4 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1322 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1322;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8289 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8282 '<FieldAccess for name_designated_type at ast.py:18504>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18504
--# expr-start 8281 '<FieldAccess for prefix at ast.py:18504>' Fld /tmp/lal-23.0.0/ada/ast.py:18504
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8281
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_1 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8282
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 8288 '<And at ast.py:18505>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18505
--# expr-start 8285 '<Bind at ast.py:18506>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18506
--# expr-start 8284 '<FieldAccess for ref_var at ast.py:18506>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18506
--# expr-start 8283 '<FieldAccess for prefix at ast.py:18506>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18506
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8283
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_2);
--# end
--# expr-done 8284
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_3, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18506") else null)); 
--# expr-done 8285
--# expr-start 8287 '<Bind at ast.py:18507>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18507
--# expr-start 8286 '<FieldAccess for type_var at ast.py:18507>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18507
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8286
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr_1 := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18507") else null)); 
--# expr-done 8287
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18505") else null)); 
--# expr-done 8288
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8289
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1322;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1322;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Invalid_Value_Equation;
--# end
--# property-start AttributeRef.access_equation /tmp/lal-23.0.0/ada/ast.py:18511
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Access_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1323 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Bare_Name;
Fld_4 : Logic_Var;
Pred : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_7 : Internal_Entity_Name;
Fld_8 : Logic_Equation;
Fld_9 : Logic_Var;
Fld_10 : Logic_Var;
Bind_Result_1 : Logic_Equation;
Fld_11 : Logic_Var;
Fld_12 : Bare_Name;
Fld_13 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_14 : Bare_Name;
Fld_15 : Logic_Var;
Fld_16 : Bare_Name;
Fld_17 : Logic_Var;
Bind_Result_3 : Logic_Equation;
Fld_18 : Bare_Name;
Fld_19 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result_4 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_20 : Internal_Entity_Name;
Fld_21 : Logic_Equation;
Or_Pred : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_22 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_5 : Logic_Equation;
Fld_23 : Bare_Name;
Fld_24 : Logic_Var;
Fld_25 : Logic_Var;
Bind_Result_6 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Or_Pred_1 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Or_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1323 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (Bind_Result_6);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Or_Pred_1);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Or_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1323;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8334 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8333 '<Or at ast.py:18512>' Or_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18512
--# expr-start 8300 '<And at ast.py:18514>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18514
--# expr-start 8296 '<And at ast.py:18514>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18514
--# expr-start 8291 '<FieldAccess for xref_no_overloading at ast.py:18514>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18514
--# expr-start 8290 '<FieldAccess for prefix at ast.py:18514>' Fld /tmp/lal-23.0.0/ada/ast.py:18514
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8290
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, All_Els => True, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8291
--# expr-start 8295 '<Predicate on BaseTypeDecl.is_subp_access_of at ast.py:18515>' Pred /tmp/lal-23.0.0/ada/ast.py:18515
--# expr-start 8292 '<FieldAccess for type_var at ast.py:18516>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18516
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8292
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 8294 '<FieldAccess for ref_var at ast.py:18517>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18517
--# expr-start 8293 '<FieldAccess for prefix at ast.py:18517>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18517
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8293
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_3);
--# end
--# expr-done 8294
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Pred := Solver.Create_N_Predicate ((Fld_2, Fld_4), Create_Base_Type_Decl_P_Is_Subp_Access_Of_0_Predicate (Origin)); 
--# expr-done 8295
And_Pred := Create_And (Fld_1, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18514") else null)); 
--# expr-done 8296
--# expr-start 8299 '<Bind at ast.py:18518>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18518
--# expr-start 8297 '<FieldAccess for type_var at ast.py:18518>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18518
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8297
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 8298 '<FieldAccess for expected_type_var at ast.py:18518>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18518
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 8298
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
Bind_Result := Solver.Create_Unify (Fld_5, Fld_6, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18518") else null)); 
--# expr-done 8299
And_Pred_1 := Create_And (And_Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18514") else null)); 
--# expr-done 8300
--# expr-start 8332 '<And at ast.py:18521>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:18521
--# expr-start 8302 '<FieldAccess for sub_equation at ast.py:18521>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18521
--# expr-start 8301 '<FieldAccess for prefix at ast.py:18521>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18521
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8301
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_8 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_7.Node, Env => Env, Origin => Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 8302
--# expr-start 8331 '<Or at ast.py:18522>' Or_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18522
--# expr-start 8323 '<And at ast.py:18532>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:18532
--# expr-start 8310 '<And at ast.py:18532>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18532
--# expr-start 8305 '<Bind at ast.py:18532>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18532
--# expr-start 8303 '<FieldAccess for expected_type_var at ast.py:18532>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18532
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 8303
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 8304 '<FieldAccess for type_var at ast.py:18532>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18532
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8304
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Bind_Result_1 := Solver.Create_Unify (Fld_9, Fld_10, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18532") else null)); 
--# expr-done 8305
--# expr-start 8309 '<Bind at ast.py:18533>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18533
--# expr-start 8306 '<FieldAccess for expected_type_var at ast.py:18533>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18533
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 8306
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
--# expr-start 8308 '<FieldAccess for expected_type_var at ast.py:18533>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18533
--# expr-start 8307 '<FieldAccess for prefix at ast.py:18533>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18533
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8307
      if Fld_12 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_12);
--# expr-done 8308
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
Bind_Result_2 := Solver.Create_Propagate (Fld_11, Fld_13, Logic_Functor_656'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18533") else null)); 
--# expr-done 8309
And_Pred_2 := Create_And (Bind_Result_1, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18532") else null)); 
--# expr-done 8310
--# expr-start 8322 '<Or at ast.py:18535>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:18535
--# expr-start 8319 '<And at ast.py:18540>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:18540
--# expr-start 8315 '<Bind at ast.py:18540>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:18540
--# expr-start 8312 '<FieldAccess for expected_type_var at ast.py:18540>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:18540
--# expr-start 8311 '<FieldAccess for prefix at ast.py:18540>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18540
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8311
      if Fld_14 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_14);
--# expr-done 8312
Fld_15.Value := No_Entity;
Entity_Vars.Reset (Fld_15);
--# expr-start 8314 '<FieldAccess for type_var at ast.py:18540>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:18540
--# expr-start 8313 '<FieldAccess for prefix at ast.py:18540>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:18540
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8313
      if Fld_16 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_16);
--# expr-done 8314
Fld_17.Value := No_Entity;
Entity_Vars.Reset (Fld_17);
Bind_Result_3 := Solver.Create_Unify (Fld_15, Fld_17, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18540") else null)); 
--# expr-done 8315
--# expr-start 8318 '<Bind at ast.py:18541>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:18541
--# expr-start 8317 '<FieldAccess for type_var at ast.py:18541>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:18541
--# expr-start 8316 '<FieldAccess for prefix at ast.py:18541>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:18541
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8316
      if Fld_18 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_18);
--# expr-done 8317
Fld_19.Value := No_Entity;
Entity_Vars.Reset (Fld_19);
Cast_Expr := No_Entity_Base_Type_Decl; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result_4 := Solver.Create_Assign (Fld_19, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18541") else null)); 
--# expr-done 8318
And_Pred_3 := Create_And (Bind_Result_3, Bind_Result_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18540") else null)); 
--# expr-done 8319
--# expr-start 8321 '<FieldAccess for matches_expected_formal_type at ast.py:18545>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:18545
--# expr-start 8320 '<FieldAccess for prefix at ast.py:18545>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:18545
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8320
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_21 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Fld_20.Node, Origin => Origin);
--# end
--# expr-done 8321
Or_Pred := Create_Or (And_Pred_3, Fld_21, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18535") else null)); 
--# expr-done 8322
And_Pred_4 := Create_And (And_Pred_2, Or_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18532") else null)); 
--# expr-done 8323
--# expr-start 8330 '<And at ast.py:18550>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:18550
--# expr-start 8325 '<Bind at ast.py:18550>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:18550
--# expr-start 8324 '<FieldAccess for expected_type_var at ast.py:18550>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:18550
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 8324
Fld_22.Value := No_Entity;
Entity_Vars.Reset (Fld_22);
Cast_Expr_1 := No_Entity_Base_Type_Decl; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_5 := Solver.Create_Assign (Fld_22, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18550") else null)); 
--# expr-done 8325
--# expr-start 8329 '<Bind at ast.py:18551>' Bind_Result_6 /tmp/lal-23.0.0/ada/ast.py:18551
--# expr-start 8327 '<FieldAccess for type_var at ast.py:18551>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:18551
--# expr-start 8326 '<FieldAccess for prefix at ast.py:18551>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:18551
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8326
      if Fld_23 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_23);
--# expr-done 8327
Fld_24.Value := No_Entity;
Entity_Vars.Reset (Fld_24);
--# expr-start 8328 '<FieldAccess for type_var at ast.py:18552>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:18552
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8328
Fld_25.Value := No_Entity;
Entity_Vars.Reset (Fld_25);
Bind_Result_6 := Solver.Create_Propagate (Fld_24, Fld_25, Logic_Functor_604'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18551") else null)); 
--# expr-done 8329
And_Pred_5 := Create_And (Bind_Result_5, Bind_Result_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18550") else null)); 
--# expr-done 8330
Or_Pred_1 := Create_Or (And_Pred_4, And_Pred_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18522") else null)); 
--# expr-done 8331
And_Pred_6 := Create_And (Fld_8, Or_Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18521") else null)); 
--# expr-done 8332
Or_Pred_2 := Create_Or (And_Pred_1, And_Pred_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18512") else null)); 
--# expr-done 8333
Let_Result := Or_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 8334
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1323;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1323;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Access_Equation;
--# end
--# property-start AttributeRef.size_equation /tmp/lal-23.0.0/ada/ast.py:18558
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Size_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1324 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Internal_Entity_Name;
Fld_7 : Logic_Equation;
Fld_8 : Logic_Var;
Fld_9 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1324 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1324;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8351 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8336 '<FieldAccess for name_designated_type at ast.py:18559>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18559
--# expr-start 8335 '<FieldAccess for prefix at ast.py:18559>' Fld /tmp/lal-23.0.0/ada/ast.py:18559
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8335
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_1 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8336
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 8350 '<If at ast.py:18560>' If_Result /tmp/lal-23.0.0/ada/ast.py:18560
--# expr-start 8338 '<Not at ast.py:18561>' Not_Val /tmp/lal-23.0.0/ada/ast.py:18561
--# expr-start 8337 '<IsNull at ast.py:18561>' Is_Null /tmp/lal-23.0.0/ada/ast.py:18561
Is_Null := Block_Var.Node = null; 
--# expr-done 8337
Not_Val := not (Is_Null); 
--# expr-done 8338
if Not_Val then
   --# expr-start 8344 '<And at ast.py:18563>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18563
--# expr-start 8341 '<Bind at ast.py:18563>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18563
--# expr-start 8340 '<FieldAccess for ref_var at ast.py:18563>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18563
--# expr-start 8339 '<FieldAccess for prefix at ast.py:18563>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18563
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Attribute_Ref_F_Prefix;
--# expr-done 8339
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_2);
--# end
--# expr-done 8340
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_3, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18563") else null)); 
--# expr-done 8341
--# expr-start 8343 '<FieldAccess for universal_int_bind at ast.py:18564>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18564
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8342 '<FieldAccess for type_var at ast.py:18564>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18564
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8342
--# property-call-start AdaNode.universal_int_bind
Fld_5 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_4, Origin => Origin);
--# end
--# expr-done 8343
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18563") else null)); 
--# expr-done 8344
   If_Result := And_Pred;
else
   --# expr-start 8349 '<And at ast.py:18566>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18566
--# expr-start 8346 '<FieldAccess for sub_equation at ast.py:18566>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18566
--# expr-start 8345 '<FieldAccess for prefix at ast.py:18566>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18566
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8345
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_7 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_6.Node, Env => Env, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 8346
--# expr-start 8348 '<FieldAccess for universal_int_bind at ast.py:18567>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18567
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8347 '<FieldAccess for type_var at ast.py:18567>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18567
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8347
--# property-call-start AdaNode.universal_int_bind
Fld_9 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_8, Origin => Origin);
--# end
--# expr-done 8348
And_Pred_1 := Create_And (Fld_7, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18566") else null)); 
--# expr-done 8349
   If_Result := And_Pred_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 8350
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8351
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1324;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1324;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Size_Equation;
--# end
--# property-start AttributeRef.array_attr_equation /tmp/lal-23.0.0/ada/ast.py:18571
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Array_Attr_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1325 with Inline_Always;
            procedure Finalizer_Scope_2858 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Block_Var_2 : Integer;
Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Basic_Assoc;
Unused_2 : Boolean;
Res : Boolean;
Pfx_Typ : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Identifier;
Sym : Symbol_Type;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Assoc_List;
Fld_5 : Bare_Assoc_List;
Fld_6 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_7 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Fld_8 : Boolean;
Fld_9 : Big_Integer_Type;
Small_Int : Integer;
Let_Result : Integer;
Scope_Result_1 : Integer;
Result_Var_1 : Integer;
Arith_Result : Integer;
Fld_10 : Internal_Entity_Name;
Fld_11 : Logic_Equation;
Fld_12 : Boolean;
If_Result_1 : Boolean;
Fld_13 : Logic_Var;
Fld_14 : Logic_Equation;
Fld_15 : Boolean;
Fld_16 : Logic_Var;
Fld_17 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_18 : Boolean;
Fld_19 : Boolean;
Not_Val : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Fld_20 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
False_Rel : Logic_Equation;
If_Result_4 : Logic_Equation;
If_Result_5 : Logic_Equation;
If_Result_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_21 : Internal_Entity_Name;
Fld_22 : Internal_Entity_Name;
Fld_23 : Logic_Var;
Pred : Logic_Equation;
Fld_24 : Boolean;
Fld_25 : Internal_Entity_Name;
Fld_26 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Fld_27 : Logic_Var;
Fld_28 : Logic_Equation;
Fld_29 : Logic_Var;
Fld_30 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
If_Result_7 : Logic_Equation;
False_Rel_1 : Logic_Equation;
If_Result_8 : Logic_Equation;
Let_Result_1 : Logic_Equation;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
If_Result_9 : Logic_Equation;
Let_Result_2 : Logic_Equation;
            procedure Finalizer_Scope_1325 is
            begin
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Pred);
                     Dec_Ref (Fld_28);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (False_Rel_1);
                     Dec_Ref (If_Result_8);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_1325;
            procedure Finalizer_Scope_2858 is
            begin
                     Dec_Ref (Fld_9);
            end Finalizer_Scope_2858;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8399 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 8354 '<FieldAccess for name_is at ast.py:18572>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18572
--# expr-start 8352 '<FieldAccess for attribute at ast.py:18572>' Fld /tmp/lal-23.0.0/ada/ast.py:18572
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Attribute_Ref_F_Attribute, Info => Ent.Info);
--# expr-done 8352
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8353 '<Symbol Length at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Length); 
--# expr-done 8353
--# property-call-start Name.name_is
Fld_1 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld.Node, Sym => Sym);
--# end
--# expr-done 8354
Block_Var := Fld_1; 
--# bind is_length Block_Var
--# expr-start 8356 '<FieldAccess for name_designated_type at ast.py:18573>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18573
--# expr-start 8355 '<FieldAccess for prefix at ast.py:18573>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18573
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8355
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 8356
Block_Var_1 := Fld_3; 
--# bind typ Block_Var_1
--# expr-start 8363 '<Arithmetic - at ast.py:18577>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:18577
--# expr-start 8357 '<FieldAccess for args at ast.py:18577>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18577
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Attribute_Ref_F_Args, Info => Ent.Info);
--# expr-done 8357
Fld_5 := Fld_4.Node;
Get_Result := Get (Self, Fld_5, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_6 := Fld_4.Info;
As_Entity := (Info => Fld_6, Node => Get_Result); 
   If_Result := As_Entity;
end if;
Var_Expr_1 := If_Result;
if Var_Expr_1 /= No_Entity_Basic_Assoc then
   --# scope-start
--# expr-start 8358 '<FieldAccess for expr at ast.py:18577>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18577
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8358
Scope_Result := Fld_7;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Expr;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind expr Var_Expr
--# expr-start 8362 '<Let at ast.py:18578>' Let_Result /tmp/lal-23.0.0/ada/ast.py:18578
--# scope-start
--# expr-start 8359 '<FieldAccess for resolve_names_internal at ast.py:18579>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18579
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_internal
Fld_8 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8359
Unused_2 := Fld_8; 
--# bind _ Unused_2
--# expr-start 8361 '<as_int at ast.py:18580>' Small_Int /tmp/lal-23.0.0/ada/ast.py:18580
--# expr-start 8360 '<FieldAccess for eval_as_int at ast.py:18580>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18580
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_9 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 8360
Small_Int := To_Integer (Self, Fld_9); 
--# expr-done 8361
Let_Result := Small_Int; 
--# end
--# expr-done 8362
Scope_Result_1 := Let_Result;
   --# end
      Finalizer_Scope_2858;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := 1;
end if;
Arith_Result := (Result_Var_1 - 1); 
--# expr-done 8363
Block_Var_2 := Arith_Result; 
--# bind dim Block_Var_2
--# expr-start 8398 '<If at ast.py:18583>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:18583
--# expr-start 8365 '<Not at ast.py:18584>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:18584
--# expr-start 8364 '<IsNull at ast.py:18584>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:18584
Is_Null_1 := Block_Var_1.Node = null; 
--# expr-done 8364
Not_Val_1 := not (Is_Null_1); 
--# expr-done 8365
if Not_Val_1 then
   --# expr-start 8381 '<And at ast.py:18587>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18587
--# expr-start 8367 '<FieldAccess for xref_no_overloading at ast.py:18587>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18587
--# expr-start 8366 '<FieldAccess for prefix at ast.py:18587>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18587
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8366
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_11 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_10.Node, Env => Env, Origin => Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 8367
--# expr-start 8380 '<Cond at ast.py:18587>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:18587
--# expr-start 8368 '<FieldAccess for is_array_def_with_deref at ast.py:18588>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18588
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_array_def_with_deref
Fld_12 := Libadalang.Implementation.Base_Type_Decl_P_Is_Array_Def_With_Deref (Node => Block_Var_1.Node, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 8368
if Fld_12 then
   If_Result_1 := Block_Var;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 8370 '<FieldAccess for universal_int_bind at ast.py:18589>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18589
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8369 '<FieldAccess for type_var at ast.py:18589>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18589
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8369
--# property-call-start AdaNode.universal_int_bind
Fld_14 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_13, Origin => Origin);
--# end
--# expr-done 8370
   If_Result_6 := Fld_14;
else
--# expr-start 8371 '<FieldAccess for is_array_def_with_deref at ast.py:18592>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:18592
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_array_def_with_deref
Fld_15 := Libadalang.Implementation.Base_Type_Decl_P_Is_Array_Def_With_Deref (Node => Block_Var_1.Node, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 8371
if Fld_15 then
   --# expr-start 8374 '<Bind at ast.py:18593>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18593
--# expr-start 8372 '<FieldAccess for type_var at ast.py:18593>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:18593
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8372
Fld_16.Value := No_Entity;
Entity_Vars.Reset (Fld_16);
--# expr-start 8373 '<FieldAccess for index_type at ast.py:18593>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:18593
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.index_type
Fld_17 := Libadalang.Implementation.Base_Type_Decl_P_Index_Type (Node => Block_Var_1.Node, Dim => Block_Var_2, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 8373
      Cast_Result := Create_Internal_Entity
        (Node => Fld_17.Node,
         Info => Fld_17.Info);
Bind_Result := Solver.Create_Assign (Fld_16, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18593") else null)); 
--# expr-done 8374
   If_Result_5 := Bind_Result;
else
--# expr-start 8375 '<FieldAccess for is_discrete_type at ast.py:18596>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:18596
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_discrete_type'
Fld_18 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Discrete_Type (Node => Block_Var_1.Node, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 8375
if Fld_18 then
   If_Result_3 := True;
else
--# expr-start 8376 '<FieldAccess for is_real_type at ast.py:18596>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:18596
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_real_type'
Fld_19 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Real_Type (Node => Block_Var_1.Node, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 8376
if Fld_19 then
   --# expr-start 8377 '<Not at ast.py:18596>' Not_Val /tmp/lal-23.0.0/ada/ast.py:18596
Not_Val := not (Block_Var); 
--# expr-done 8377
   If_Result_2 := Not_Val;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
if If_Result_3 then
   --# expr-start 8379 '<Bind at ast.py:18597>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18597
--# expr-start 8378 '<FieldAccess for type_var at ast.py:18597>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:18597
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8378
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
Cast_Expr := Block_Var_1; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_20, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18597") else null)); 
--# expr-done 8379
   If_Result_4 := Bind_Result_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18599") else null)); 
   If_Result_4 := False_Rel;
end if;
      Inc_Ref (If_Result_4);
   If_Result_5 := If_Result_4;
end if;
      Inc_Ref (If_Result_5);
   If_Result_6 := If_Result_5;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 8380
And_Pred := Create_And (Fld_11, If_Result_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18587") else null)); 
--# expr-done 8381
   If_Result_9 := And_Pred;
else
   --# expr-start 8397 '<Let at ast.py:18604>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:18604
--# scope-start
--# expr-start 8386 '<FieldAccess for resolve_names_internal_with_eq at ast.py:18606>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:18606
--# expr-start 8382 '<FieldAccess for prefix at ast.py:18606>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:18606
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8382
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8385 '<Predicate on BaseTypeDecl.is_array_def_with_deref at ast.py:18607>' Pred /tmp/lal-23.0.0/ada/ast.py:18607
--# expr-start 8384 '<FieldAccess for type_var at ast.py:18608>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:18608
--# expr-start 8383 '<FieldAccess for prefix at ast.py:18608>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:18608
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8383
      if Fld_22.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_22.Node);
--# expr-done 8384
Fld_23.Value := No_Entity;
Entity_Vars.Reset (Fld_23);
Pred := Solver.Create_Predicate (Fld_23, Create_Base_Type_Decl_P_Is_Array_Def_With_Deref_0_Predicate (Origin)); 
--# expr-done 8385
--# property-call-start AdaNode.resolve_names_internal_with_eq
Fld_24 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal_With_Eq (Node => Fld_21.Node, Additional_Equation => Pred, Env => Env, Origin => Origin, E_Info => Fld_21.Info);
--# end
--# expr-done 8386
Res := Fld_24; 
--# bind res Res
--# expr-start 8389 '<Cast to BaseTypeDecl at ast.py:18610>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:18610
--# expr-start 8388 '<FieldAccess for type_val at ast.py:18610>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:18610
--# expr-start 8387 '<FieldAccess for prefix at ast.py:18610>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:18610
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8387
      if Fld_25.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_26 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld_25.Node);
--# end
--# expr-done 8388
   if Fld_26.Node = null
      or else Fld_26.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_26.Node,
         Info => Fld_26.Info);
   else
         Cast_Result_2 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8389
Pfx_Typ := Cast_Result_2; 
--# bind pfx_typ Pfx_Typ
--# expr-start 8396 '<If at ast.py:18612>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:18612
if Res then
   --# expr-start 8395 '<If at ast.py:18614>' If_Result_7 /tmp/lal-23.0.0/ada/ast.py:18614
if Block_Var then
   --# expr-start 8391 '<FieldAccess for universal_int_bind at ast.py:18616>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:18616
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8390 '<FieldAccess for type_var at ast.py:18616>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:18616
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8390
--# property-call-start AdaNode.universal_int_bind
Fld_28 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_27, Origin => Origin);
--# end
--# expr-done 8391
   If_Result_7 := Fld_28;
else
   --# expr-start 8394 '<Bind at ast.py:18617>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18617
--# expr-start 8392 '<FieldAccess for type_var at ast.py:18617>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:18617
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8392
Fld_29.Value := No_Entity;
Entity_Vars.Reset (Fld_29);
--# expr-start 8393 '<FieldAccess for index_type at ast.py:18617>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:18617
      if Pfx_Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.index_type
Fld_30 := Libadalang.Implementation.Base_Type_Decl_P_Index_Type (Node => Pfx_Typ.Node, Dim => Block_Var_2, Origin => Origin, E_Info => Pfx_Typ.Info);
--# end
--# expr-done 8393
      Cast_Result_3 := Create_Internal_Entity
        (Node => Fld_30.Node,
         Info => Fld_30.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_29, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18617") else null)); 
--# expr-done 8394
   If_Result_7 := Bind_Result_2;
end if;
      Inc_Ref (If_Result_7);
--# expr-done 8395
   If_Result_8 := If_Result_7;
else
   False_Rel_1 := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18619") else null)); 
   If_Result_8 := False_Rel_1;
end if;
      Inc_Ref (If_Result_8);
--# expr-done 8396
Let_Result_1 := If_Result_8; Inc_Ref (Let_Result_1);
--# end
--# expr-done 8397
   If_Result_9 := Let_Result_1;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 8398
Let_Result_2 := If_Result_9; Inc_Ref (Let_Result_2);
--# end
--# expr-done 8399
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1325;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1325;
               Finalizer_Scope_2858;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Array_Attr_Equation;
--# end
--# property-start AttributeRef.subtype_attr_equation /tmp/lal-23.0.0/ada/ast.py:18625
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Subtype_Attr_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1326 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1326 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1326;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8408 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8407 '<And at ast.py:18631>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18631
--# expr-start 8404 '<Bind at ast.py:18631>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18631
--# expr-start 8401 '<FieldAccess for ref_var at ast.py:18631>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18631
--# expr-start 8400 '<FieldAccess for prefix at ast.py:18631>' Fld /tmp/lal-23.0.0/ada/ast.py:18631
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Attribute_Ref_F_Prefix;
--# expr-done 8400
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 8401
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 8403 '<FieldAccess for name_designated_type at ast.py:18631>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18631
--# expr-start 8402 '<FieldAccess for prefix at ast.py:18631>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18631
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8402
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 8403
      Cast_Result := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18631") else null)); 
--# expr-done 8404
--# expr-start 8406 '<FieldAccess for universal_int_bind at ast.py:18632>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18632
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8405 '<FieldAccess for type_var at ast.py:18632>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18632
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8405
--# property-call-start AdaNode.universal_int_bind
Fld_5 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_4, Origin => Origin);
--# end
--# expr-done 8406
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18631") else null)); 
--# expr-done 8407
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8408
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1326;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1326;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Subtype_Attr_Equation;
--# end
--# property-start AttributeRef.to_address_equation /tmp/lal-23.0.0/ada/ast.py:18636
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_To_Address_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1327 with Inline_Always;
            procedure Finalizer_Scope_2859 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Subp_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Subp_Decl;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Cast_Expr : Internal_Entity_Basic_Subp_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1327 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1327;
            procedure Finalizer_Scope_2859 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2859;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8422 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8416 '<Cast to BasicSubpDecl at ast.py:18647>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18647
--# expr-start 8415 '<EnvGet at ast.py:18643>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18643
--# expr-start 8412 '<FieldAccess for get_unit_root_decl at ast.py:18643>' Fld /tmp/lal-23.0.0/ada/ast.py:18643
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8411 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 8409 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 8409
--# expr-start 8410 '<Symbol Storage_Elements at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Storage_Elements); 
--# expr-done 8410
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 8411
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Ent.Node, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 8412
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 8413 '<FieldAccess for children_env at ast.py:18645>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18645
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 8413
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2859;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8414 '<Symbol To_Address at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_To_Address); 
--# expr-done 8414
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Minimal), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8415
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Basic_Subp_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Subp_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Cast_Result := No_Entity_Basic_Subp_Decl;
   end if;
--# expr-done 8416
Block_Var := Cast_Result; 
--# bind to_address_subp Block_Var
--# expr-start 8421 '<And at ast.py:18649>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18649
--# expr-start 8418 '<FieldAccess for sub_equation at ast.py:18650>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18650
--# expr-start 8417 '<FieldAccess for prefix at ast.py:18650>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18650
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8417
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 8418
--# expr-start 8420 '<Bind at ast.py:18651>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18651
--# expr-start 8419 '<FieldAccess for ref_var at ast.py:18651>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18651
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 8419
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18651") else null)); 
--# expr-done 8420
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18649") else null)); 
--# expr-done 8421
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8422
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1327;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1327;
               Finalizer_Scope_2859;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_To_Address_Equation;
--# end
--# property-start AttributeRef.index_equation /tmp/lal-23.0.0/ada/ast.py:18655
pragma Warnings (Off, "is not referenced");
 function Attribute_Ref_P_Index_Equation
  (Node : Bare_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Attribute_Ref := Bare_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Attribute_Ref :=
     Internal_Entity_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1328 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result : Internal_Entity_Entry_Decl;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Name;
Fld_4 : Logic_Equation;
Fld_5 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1328 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1328;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8433 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8427 '<FieldAccess for family_type at ast.py:18661>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18661
--# expr-start 8426 '<Cast to EntryDecl at ast.py:18661>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18661
--# expr-start 8425 '<EnvGet at ast.py:18660>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:18660
--# expr-start 8424 '<FieldAccess for name_symbol at ast.py:18660>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18660
--# expr-start 8423 '<FieldAccess for prefix at ast.py:18660>' Fld /tmp/lal-23.0.0/ada/ast.py:18660
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8423
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 8424
Env_Get_Result := AST_Envs.Get_First (Self => Env, Key => Fld_1, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 8425
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Entry_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8426
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EntryDecl.family_type
Fld_2 := Libadalang.Implementation.Entry_Decl_P_Family_Type (Node => Cast_Result.Node, Origin => Origin, E_Info => Cast_Result.Info);
--# end
--# expr-done 8427
Block_Var := Fld_2; 
--# bind typ Block_Var
--# expr-start 8432 '<And at ast.py:18663>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18663
--# expr-start 8429 '<FieldAccess for sub_equation at ast.py:18663>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18663
--# expr-start 8428 '<FieldAccess for prefix at ast.py:18663>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18663
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 8428
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 8429
--# expr-start 8431 '<Bind at ast.py:18663>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18663
--# expr-start 8430 '<FieldAccess for type_var at ast.py:18663>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18663
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8430
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18663") else null)); 
--# expr-done 8431
And_Pred := Create_And (Fld_4, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18663") else null)); 
--# expr-done 8432
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 8433
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1328;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1328;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Attribute_Ref_P_Index_Equation;
--# end
   --
   --  Primitives for Bare_Call_Expr
   --
      procedure Initialize_Fields_For_Call_Expr
        (Self : Bare_Call_Expr
         ; Call_Expr_F_Name : Bare_Name
         ; Call_Expr_F_Suffix : Bare_Ada_Node
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Call_Expr_F_Name := Call_Expr_F_Name;
            Self.Call_Expr_F_Suffix := Call_Expr_F_Suffix;
      Self.Call_Expr_R_Called_Spec := Null_Var_Record;
      end Initialize_Fields_For_Call_Expr;
   function Call_Expr_F_Name
     (Node : Bare_Call_Expr) return Bare_Name
   is
   begin
         return Node.Call_Expr_F_Name;
   end;
   function Call_Expr_F_Suffix
     (Node : Bare_Call_Expr) return Bare_Ada_Node
   is
   begin
         return Node.Call_Expr_F_Suffix;
   end;
--# property-start CallExpr.ref_var /tmp/lal-23.0.0/ada/ast.py:14184
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Ref_Var
  (Node : Bare_Call_Expr
  )
   return Logic_Var
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8435 '<FieldAccess for ref_var at ast.py:14184>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14184
--# expr-start 8434 '<FieldAccess for name at ast.py:14184>' Fld /tmp/lal-23.0.0/ada/ast.py:14184
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Call_Expr_F_Name;
--# expr-done 8434
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 8435
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Ref_Var;
--# end
--# property-start CallExpr.subp_spec_var /tmp/lal-23.0.0/ada/ast.py:14188
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Subp_Spec_Var
  (Node : Bare_Call_Expr
  )
   return Logic_Var
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8436 '<FieldAccess for r_called_spec at ast.py:14188>' Fld /tmp/lal-23.0.0/ada/ast.py:14188
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Call_Expr_R_Called_Spec'Unrestricted_Access;
--# expr-done 8436
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Subp_Spec_Var;
--# end
--# property-start CallExpr.defines_subp_spec_var /tmp/lal-23.0.0/ada/ast.py:14189
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Defines_Subp_Spec_Var
  (Node : Bare_Call_Expr
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Defines_Subp_Spec_Var;
--# end
--# property-start CallExpr.relative_name /tmp/lal-23.0.0/ada/ast.py:14191
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Relative_Name
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8438 '<FieldAccess for relative_name at ast.py:14191>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14191
--# expr-start 8437 '<FieldAccess for name at ast.py:14191>' Fld /tmp/lal-23.0.0/ada/ast.py:14191
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8437
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8438
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Relative_Name;
--# end
--# property-start CallExpr.kind /tmp/lal-23.0.0/ada/ast.py:14194
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Kind
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Call_Expr_Kind
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Call_Expr_Kind;
      Fld : Boolean;
Fld_1 : Boolean;
Fld_2 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_3 : Internal_Entity_Name;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Array_Type_Def;
Is_Null : Boolean;
Not_Val : Boolean;
Dyn_Var_Bind_Result : Boolean;
Fld_6 : Internal_Entity_Assoc_List;
Fld_7 : Bare_Assoc_List;
Len : Integer;
Is_Equal : Boolean;
Fld_8 : Internal_Entity_Name;
Fld_9 : Internal_Entity_Basic_Decl;
Is_A : Boolean;
If_Result : Boolean;
If_Result_1 : Call_Expr_Kind;
If_Result_2 : Call_Expr_Kind;
If_Result_3 : Call_Expr_Kind;
If_Result_4 : Call_Expr_Kind;
Let_Result : Call_Expr_Kind;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8455 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8454 '<Cond at ast.py:14199>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:14199
--# expr-start 8439 '<FieldAccess for is_call at ast.py:14200>' Fld /tmp/lal-23.0.0/ada/ast.py:14200
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_call
Fld := Libadalang.Implementation.Name_P_Is_Call (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8439
if Fld then
   If_Result_4 := Call;
else
--# expr-start 8440 '<FieldAccess for is_array_slice at ast.py:14203>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14203
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.is_array_slice
Fld_1 := Libadalang.Implementation.Call_Expr_P_Is_Array_Slice (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8440
if Fld_1 then
   If_Result_3 := Array_Slice;
else
--# expr-start 8447 '<bind at ast.py:14206>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:14206
--# expr-start 8441 '<FieldAccess for origin_node at ast.py:14207>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14207
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_2 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 8441
Bound_Origin := Fld_2; 
--# expr-start 8446 '<Not at ast.py:14208>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14208
--# expr-start 8445 '<IsNull at ast.py:14208>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14208
--# expr-start 8444 '<FieldAccess for array_def_with_deref at ast.py:14208>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14208
--# expr-start 8443 '<FieldAccess for expression_type at ast.py:14208>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14208
--# expr-start 8442 '<FieldAccess for name at ast.py:14208>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14208
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8442
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_4 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# end
--# expr-done 8443
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld_5 := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Fld_4.Node, Origin => Bound_Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 8444
Is_Null := Fld_5.Node = null; 
--# expr-done 8445
Not_Val := not (Is_Null); 
--# expr-done 8446
Dyn_Var_Bind_Result := Not_Val; 
--# expr-done 8447
if Dyn_Var_Bind_Result then
   If_Result_2 := Array_Index;
else
--# expr-start 8450 '<Eq at ast.py:14215>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14215
--# expr-start 8449 '<length at ast.py:14215>' Len /tmp/lal-23.0.0/ada/ast.py:14215
--# expr-start 8448 '<FieldAccess for params at ast.py:14215>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14215
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_6 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8448
Fld_7 := Fld_6.Node; 
Len := Length (Fld_7); 
--# expr-done 8449
Is_Equal := Len = 1; 
--# expr-done 8450
if Is_Equal then
   --# expr-start 8453 '<IsA TypeDecl at ast.py:14216>' Is_A /tmp/lal-23.0.0/ada/ast.py:14216
--# expr-start 8452 '<FieldAccess for referenced_decl at ast.py:14216>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14216
--# expr-start 8451 '<FieldAccess for name at ast.py:14216>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14216
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8451
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_9 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld_8.Node, Imprecise_Fallback => False, E_Info => Fld_8.Info);
--# end
--# expr-done 8452
Is_A := Fld_9.Node /= null 
and then Fld_9.Node.Kind in Ada_Type_Decl; 
--# expr-done 8453
   If_Result := Is_A;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_1 := Type_Conversion;
else
   If_Result_1 := raise Property_Error with "undetermined CallExpr kind";
end if;
   If_Result_2 := If_Result_1;
end if;
   If_Result_3 := If_Result_2;
end if;
   If_Result_4 := If_Result_3;
end if;
--# expr-done 8454
Let_Result := If_Result_4; 
--# end
--# expr-done 8455
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Kind;
--# end
--# property-start CallExpr.is_constant /tmp/lal-23.0.0/ada/ast.py:14225
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Is_Constant
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Match_0 : Internal_Entity_Name;
Match_1 : Internal_Entity_Expr;
Fld : Call_Expr_Kind;
Is_Equal : Boolean;
Fld_1 : Internal_Entity_Assoc_List;
Fld_2 : Bare_Assoc_List;
Fld_3 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Boolean;
Match_Prefix : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_1 : Internal_Entity_Expr;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Match_Result : Boolean;
Fld_6 : Internal_Entity_Basic_Decl;
Fld_7 : Boolean;
If_Result_1 : Boolean;
Let_Result_2 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8465 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 8464 '<Cond at ast.py:14226>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14226
--# expr-start 8457 '<Eq at ast.py:14227>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14227
--# expr-start 8456 '<FieldAccess for kind at ast.py:14227>' Fld /tmp/lal-23.0.0/ada/ast.py:14227
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.kind
Fld := Libadalang.Implementation.Call_Expr_P_Kind (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8456
Is_Equal := Fld = Type_Conversion; 
--# expr-done 8457
if Is_Equal then
   --# expr-start 8461 '<Match at ast.py:14228>' Match_Result /tmp/lal-23.0.0/ada/ast.py:14228
--# expr-start 8459 '<FieldAccess for expr at ast.py:14228>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14228
--# expr-start 8458 '<FieldAccess for params at ast.py:14228>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14228
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_1 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8458
Fld_2 := Fld_1.Node;
Get_Result := Get (Self, Fld_2, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Get_Result); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 8459
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_4; 
case Ada_Expr (Match_Prefix.Node.Kind) is
         when Ada_Attribute_Ref .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind n Match_0
--# expr-start 8460 '<FieldAccess for is_constant at ast.py:14231>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14231
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.is_constant'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Is_Constant (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 8460
Let_Result := Fld_5; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Abstract_State_Decl_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
Let_Result_1 := True; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
end case;
--# expr-done 8461
   If_Result_1 := Match_Result;
else
   --# expr-start 8463 '<FieldAccess for is_constant_object at ast.py:14237>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14237
--# expr-start 8462 '<FieldAccess for referenced_decl at ast.py:14237>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14237
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_6 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 8462
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_constant_object'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Constant_Object (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 8463
   If_Result_1 := Fld_7;
end if;
--# expr-done 8464
Let_Result_2 := If_Result_1; 
--# end
--# expr-done 8465
      Property_Result := Let_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Is_Constant;
--# end
--# property-start CallExpr.designated_env /tmp/lal-23.0.0/ada/ast.py:14241
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Designated_Env
  (Node : Bare_Call_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1054 with Inline_Always;
            procedure Finalizer_Scope_2862 with Inline_Always;
            procedure Finalizer_Scope_2863 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Match_0 : Internal_Entity_Basic_Decl;
Match_1 : Internal_Entity;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Lexical_Env := Empty_Env;
Bound_Include_Ud_Indexing : Boolean;
Fld_3 : Internal_Entity_Array_Access;
Fld_4 : Lexical_Env := Empty_Env;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Let_Result : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Cast_Result_1 : Internal_Entity;
Let_Result_1 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Match_Result : Lexical_Env := Empty_Env;
Map_Result : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Lexical_Env := Empty_Env;
Let_Result_2 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1054 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_1054;
            procedure Finalizer_Scope_2862 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_2862;
            procedure Finalizer_Scope_2863 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2863;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8478 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 8467 '<FieldAccess for name_designated_type at ast.py:14242>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14242
--# expr-start 8466 '<FieldAccess for name at ast.py:14242>' Fld /tmp/lal-23.0.0/ada/ast.py:14242
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8466
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_1 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8467
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 8477 '<If at ast.py:14244>' If_Result /tmp/lal-23.0.0/ada/ast.py:14244
--# expr-start 8469 '<Not at ast.py:14245>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14245
--# expr-start 8468 '<IsNull at ast.py:14245>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14245
Is_Null := Block_Var.Node = null; 
--# expr-done 8468
Not_Val := not (Is_Null); 
--# expr-done 8469
if Not_Val then
   --# expr-start 8470 '<FieldAccess for defining_env at ast.py:14247>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14247
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Block_Var.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Block_Var.Info);
--# end
--# expr-done 8470
   If_Result := Fld_2;
else
   --# expr-start 8476 '<bind at ast.py:14252>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:14252
Bound_Include_Ud_Indexing := True; 
--# expr-start 8475 '<env_group at ast.py:14257>' Group_Env /tmp/lal-23.0.0/ada/ast.py:14257
--# expr-start 8474 '<Map at ast.py:14254>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14254
   --# expr-start 8471 '<FieldAccess for env_elements at ast.py:14254>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14254
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_3 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Ent.Node, Env => Env, No_Visibility => No_Visibility, E_Info => Ent.Info);
--# end
--# expr-done 8471
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_3;
      begin
         for Item_256 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_256
      --# expr-start 8473 '<Match at ast.py:14254>' Match_Result /tmp/lal-23.0.0/ada/ast.py:14254
      if Item_256.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_256; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Abstract_State_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind bd Match_0
--# expr-start 8472 '<FieldAccess for defining_env at ast.py:14255>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14255
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Match_0.Node, Origin => Origin, Include_Ud_Indexing => Bound_Include_Ud_Indexing, Dottable_Type => No_Bare_Ada_Node, E_Info => Match_0.Info);
--# end
--# expr-done 8472
Let_Result := Fld_4; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2863;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind _ Match_1
Let_Result_1 := Empty_Env; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
end case;
--# expr-done 8473
         declare
            Item_To_Append : constant Lexical_Env := Match_Result;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2862;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8474
Group_Env := Group (Map_Result, No_Metadata); 
--# expr-done 8475
Dyn_Var_Bind_Result := Group_Env; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 8476
   If_Result := Dyn_Var_Bind_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 8477
Let_Result_2 := If_Result; Inc_Ref (Let_Result_2);
--# end
--# expr-done 8478
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1054;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1054;
               Finalizer_Scope_2862;
               Finalizer_Scope_2863;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Designated_Env;
--# end
--# property-start CallExpr.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:14262
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Env_Elements_Impl
  (Node : Bare_Call_Expr
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1055 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1055 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1055;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8481 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8480 '<FieldAccess for env_elements_impl at ast.py:14263>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14263
--# expr-start 8479 '<FieldAccess for name at ast.py:14263>' Fld /tmp/lal-23.0.0/ada/ast.py:14263
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8479
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Fld.Node, Env => Env, E_Info => Fld.Info);
--# end
--# expr-done 8480
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8481
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1055;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1055;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Env_Elements_Impl;
--# end
--# property-start CallExpr.designated_type_impl /tmp/lal-23.0.0/ada/ast.py:14268
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Designated_Type_Impl
  (Node : Bare_Call_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_2865 with Inline_Always;
            procedure Finalizer_Scope_2866 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Boolean;
Var_Expr : Internal_Entity_Assoc_List;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Name;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Assoc_List;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Fld_4 : Internal_Param_Match_Array_Access;
Fld_5 : Boolean;
Fld_6 : Internal_Entity_Defining_Name;
Fld_7 : Internal_Entity_Base_Formal_Param_Decl;
Fld_8 : Internal_Entity_Base_Type_Decl;
Fld_9 : Internal_Single_Actual;
Fld_10 : Internal_Entity_Basic_Assoc;
Fld_11 : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_12 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Fld_13 : Boolean;
If_Result : Boolean;
Quantifier_Result : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_2865 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2865;
            procedure Finalizer_Scope_2866 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_2866;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8499 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8483 '<FieldAccess for designated_type_impl at ast.py:14270>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14270
--# expr-start 8482 '<FieldAccess for name at ast.py:14270>' Fld /tmp/lal-23.0.0/ada/ast.py:14270
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8482
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8483
Block_Var := Fld_1; 
--# bind prefix_tpe Block_Var
--# expr-start 8484 '<FieldAccess for params at ast.py:14275>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14275
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_2 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8484
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Assoc_List then
   --# scope-start
   --# bind ps Var_Expr
--# expr-start 8497 '<AllQuantifier at ast.py:14278>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:14278
   --# expr-start 8486 '<FieldAccess for match_formals at ast.py:14276>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14276
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 8485 '<FieldAccess for discriminants_list at ast.py:14277>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14277
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8485
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2866;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# property-call-start AdaNode.match_formals
Fld_4 := Libadalang.Implementation.Ada_Node_P_Match_Formals (Node => Self, Formal_Params => Result_Var, Params => Var_Expr, Is_Dottable_Subp => False);
--# end
--# expr-done 8486
      Quantifier_Result := True;
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_4;
      begin
         for Item_257 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_257
--# expr-start 8487 '<FieldAccess for has_matched at ast.py:14280>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14280
Fld_5 := Item_257.Has_Matched;
--# expr-done 8487
if Fld_5 then
   --# expr-start 8496 '<FieldAccess for matching_type at ast.py:14281>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14281
--# expr-start 8490 '<FieldAccess for formal_type at ast.py:14281>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14281
--# expr-start 8489 '<FieldAccess for formal_decl at ast.py:14281>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14281
--# expr-start 8488 '<FieldAccess for formal at ast.py:14281>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14281
Fld_6 := Item_257.Formal;
--# expr-done 8488
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_7 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_6.Node, E_Info => Fld_6.Info);
--# end
--# expr-done 8489
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_8 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_7.Node, Origin => Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 8490
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8494 '<Cast to Name at ast.py:14282>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14282
--# expr-start 8493 '<FieldAccess for expr at ast.py:14282>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14282
--# expr-start 8492 '<FieldAccess for assoc at ast.py:14282>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14282
--# expr-start 8491 '<FieldAccess for actual at ast.py:14282>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14282
Fld_9 := Item_257.Actual;
--# expr-done 8491
Fld_10 := Fld_9.Assoc;
--# expr-done 8492
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_11 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_10.Node, E_Info => Fld_10.Info);
--# end
--# expr-done 8493
   if Fld_11.Node = null
      or else Fld_11.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld_11.Node,
         Info => Fld_11.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 8494
Var_Expr_2 := Cast_Result;
if Var_Expr_2 /= No_Entity_Name then
   --# scope-start
--# expr-start 8495 '<FieldAccess for name_designated_type at ast.py:14282>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14282
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_12 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 8495
Scope_Result_1 := Fld_12;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
--# property-call-start BaseTypeDecl.matching_type
Fld_13 := Libadalang.Implementation.Base_Type_Decl_P_Matching_Type (Node => Fld_8.Node, Expected_Type => Result_Var_1, Origin => Origin, E_Info => Fld_8.Info);
--# end
--# expr-done 8496
   If_Result := Fld_13;
else
   If_Result := False;
end if;
      Quantifier_Result := If_Result;
   --# end
               exit when not Quantifier_Result;
         end loop;
      end;
--# expr-done 8497
Scope_Result_2 := Quantifier_Result;
   --# end
      Finalizer_Scope_2865;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := True;
end if;
Block_Var_1 := Result_Var_2; 
--# bind matches_formals Block_Var_1
--# expr-start 8498 '<If at ast.py:14291>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14291
if Block_Var_1 then
   If_Result_1 := Block_Var;
else
   If_Result_1 := No_Entity_Base_Type_Decl;
end if;
--# expr-done 8498
Let_Result := If_Result_1; 
--# end
--# expr-done 8499
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2865;
               Finalizer_Scope_2866;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Designated_Type_Impl;
--# end
--# property-start CallExpr.params /tmp/lal-23.0.0/ada/ast.py:14293
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Params
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Assoc_List
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Assoc_List;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Assoc_List;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8501 '<Cast to AssocList at ast.py:14293>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14293
--# expr-start 8500 '<FieldAccess for suffix at ast.py:14293>' Fld /tmp/lal-23.0.0/ada/ast.py:14293
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.Call_Expr_F_Suffix, Info => Ent.Info);
--# expr-done 8500
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Assoc_List_Range
   then
      Cast_Result := Create_Internal_Entity_Assoc_List
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Assoc_List;
   end if;
--# expr-done 8501
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Params;
--# end
--# property-start CallExpr.check_array_slice /tmp/lal-23.0.0/ada/ast.py:14296
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Check_Array_Slice
  (Node : Bare_Call_Expr
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Array_Type_Def;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity;
Var_Expr_2 : Internal_Entity_Assoc_List;
Var_Expr_3 : Internal_Entity_Name;
Fld : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Result_Var : Internal_Entity_Array_Type_Def;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity;
Is_A : Boolean;
Is_A_1 : Boolean;
If_Result : Boolean;
Is_A_2 : Boolean;
If_Result_1 : Boolean;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Assoc_List;
Fld_2 : Bare_Assoc_List;
Len : Integer;
Is_Equal : Boolean;
Saved : Internal_Entity_Assoc_List;
Fld_3 : Bare_Assoc_List;
Fld_4 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_2 : Internal_Entity_Basic_Assoc;
Fld_5 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_6 : Internal_Entity_Base_Type_Decl;
Is_Null_2 : Boolean;
Not_Val_1 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_3 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_4 : Boolean;
Scope_Result_3 : Boolean;
Result_Var_3 : Boolean;
If_Result_5 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8517 '<Block at ???>' Let_Result None
--# scope-start
Var_Expr := Typ;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 8502 '<FieldAccess for array_def_with_deref at ast.py:14301>' Fld /tmp/lal-23.0.0/ada/ast.py:14301
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8502
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Array_Type_Def;
end if;
Block_Var := Result_Var; 
--# bind atd Block_Var
--# expr-start 8504 '<Not at ast.py:14303>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14303
--# expr-start 8503 '<IsNull at ast.py:14303>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14303
Is_Null := Block_Var.Node = null; 
--# expr-done 8503
Not_Val := not (Is_Null); 
--# expr-done 8504
if Not_Val then
--# expr-start 8505 '<FieldAccess for suffix at ast.py:14304>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14304
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity (Node => Ent.Node.Call_Expr_F_Suffix, Info => Ent.Info);
--# expr-done 8505
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity then
   --# scope-start
   --# bind sfx Var_Expr_1
--# expr-start 8506 '<IsA BinOp at ast.py:14307>' Is_A /tmp/lal-23.0.0/ada/ast.py:14307
Is_A := Var_Expr_1.Node /= null 
and then Var_Expr_1.Node.Kind in Ada_Bin_Op_Range; 
--# expr-done 8506
if Is_A then
   If_Result := True;
else
   --# expr-start 8507 '<IsA AttributeRef at ast.py:14309>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:14309
Is_A_1 := Var_Expr_1.Node /= null 
and then Var_Expr_1.Node.Kind in Ada_Attribute_Ref_Range; 
--# expr-done 8507
   If_Result := Is_A_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 8508 '<IsA SubtypeIndication at ast.py:14311>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:14311
Is_A_2 := Var_Expr_1.Node /= null 
and then Var_Expr_1.Node.Kind in Ada_Subtype_Indication_Range; 
--# expr-done 8508
   If_Result_1 := Is_A_2;
end if;
if If_Result_1 then
   If_Result_4 := True;
else
--# expr-start 8509 '<Cast to AssocList at ast.py:14313>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14313
Cast_Expr := Var_Expr_1; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Assoc_List_Range
   then
      Cast_Result := Create_Internal_Entity_Assoc_List
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Assoc_List;
   end if;
--# expr-done 8509
Var_Expr_2 := Cast_Result;
if Var_Expr_2 /= No_Entity_Assoc_List then
   --# scope-start
   --# bind al Var_Expr_2
--# expr-start 8511 '<Eq at ast.py:14315>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14315
--# expr-start 8510 '<length at ast.py:14315>' Len /tmp/lal-23.0.0/ada/ast.py:14315
Fld_2 := Var_Expr_2.Node; 
Len := Length (Fld_2); 
--# expr-done 8510
Is_Equal := Len = 1; 
--# expr-done 8511
if Is_Equal then
--# expr-start 8513 '<Cast to Name at ast.py:14316>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:14316
--# expr-start 8512 '<FieldAccess for expr at ast.py:14316>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14316
Saved := Var_Expr_2; 
Fld_3 := Saved.Node;
Get_Result := Get (Self, Fld_3, 0, True); 
Is_Null_1 := Get_Result = null; 
if Is_Null_1 then
   If_Result_2 := No_Entity_Basic_Assoc;
else
Fld_4 := Saved.Info;
As_Entity := (Info => Fld_4, Node => Get_Result); 
   If_Result_2 := As_Entity;
end if;
      if If_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_5 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result_2.Node, E_Info => If_Result_2.Info);
--# end
--# expr-done 8512
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 8513
Var_Expr_3 := Cast_Result_1;
if Var_Expr_3 /= No_Entity_Name then
   --# scope-start
   --# bind n Var_Expr_3
--# expr-start 8516 '<Not at ast.py:14317>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:14317
--# expr-start 8515 '<IsNull at ast.py:14317>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:14317
--# expr-start 8514 '<FieldAccess for name_designated_type at ast.py:14317>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14317
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_6 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 8514
Is_Null_2 := Fld_6.Node = null; 
--# expr-done 8515
Not_Val_1 := not (Is_Null_2); 
--# expr-done 8516
Scope_Result_1 := Not_Val_1;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_3 := Result_Var_1;
else
   If_Result_3 := False;
end if;
Scope_Result_2 := If_Result_3;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
   If_Result_4 := Result_Var_2;
end if;
Scope_Result_3 := If_Result_4;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := False;
end if;
   If_Result_5 := Result_Var_3;
else
   If_Result_5 := False;
end if;
Let_Result := If_Result_5; 
--# end
--# expr-done 8517
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Check_Array_Slice;
--# end
--# property-start CallExpr.is_array_slice /tmp/lal-23.0.0/ada/ast.py:14326
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Is_Array_Slice
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Name;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8523 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8522 '<bind at ast.py:14331>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:14331
--# expr-start 8518 '<FieldAccess for origin_node at ast.py:14332>' Fld /tmp/lal-23.0.0/ada/ast.py:14332
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 8518
Bound_Origin := Fld; 
--# expr-start 8521 '<FieldAccess for check_array_slice at ast.py:14333>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14333
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8520 '<FieldAccess for expression_type at ast.py:14333>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14333
--# expr-start 8519 '<FieldAccess for name at ast.py:14333>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14333
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8519
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_2 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 8520
--# property-call-start CallExpr.check_array_slice
Fld_3 := Libadalang.Implementation.Call_Expr_P_Check_Array_Slice (Node => Ent.Node, Typ => Fld_2, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 8521
Dyn_Var_Bind_Result := Fld_3; 
--# expr-done 8522
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 8523
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Is_Array_Slice;
--# end
--# property-start CallExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:14337
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Xref_Equation
  (Node : Bare_Call_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1060 with Inline_Always;
      Fld : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1060 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1060;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8525 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8524 '<FieldAccess for bottom_up_name_equation at ast.py:14338>' Fld /tmp/lal-23.0.0/ada/ast.py:14338
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.bottom_up_name_equation
Fld := Libadalang.Implementation.Name_P_Bottom_Up_Name_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8524
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 8525
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1060;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1060;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Xref_Equation;
--# end
--# property-start CallExpr.type_conv_self_xref_equation /tmp/lal-23.0.0/ada/ast.py:14341
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Type_Conv_Self_Xref_Equation
  (Node : Bare_Call_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1061 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Fld_4 : Bare_Name;
Fld_5 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Var;
Fld_7 : Bare_Name;
Fld_8 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1061 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1061;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8539 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8538 '<And at ast.py:14347>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14347
--# expr-start 8533 '<And at ast.py:14347>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14347
--# expr-start 8527 '<FieldAccess for subtype_indication_equation at ast.py:14348>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14348
--# expr-start 8526 '<FieldAccess for name at ast.py:14348>' Fld /tmp/lal-23.0.0/ada/ast.py:14348
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8526
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.subtype_indication_equation
Fld_1 := Libadalang.Implementation.Name_P_Subtype_Indication_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8527
--# expr-start 8532 '<Bind at ast.py:14349>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14349
--# expr-start 8529 '<FieldAccess for ref_var at ast.py:14349>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14349
--# expr-start 8528 '<FieldAccess for name at ast.py:14349>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14349
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Call_Expr_F_Name;
--# expr-done 8528
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_2);
--# end
--# expr-done 8529
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 8531 '<FieldAccess for type_var at ast.py:14349>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14349
--# expr-start 8530 '<FieldAccess for name at ast.py:14349>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14349
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Call_Expr_F_Name;
--# expr-done 8530
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_4);
--# expr-done 8531
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result := Solver.Create_Unify (Fld_3, Fld_5, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14349") else null)); 
--# expr-done 8532
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14347") else null)); 
--# expr-done 8533
--# expr-start 8537 '<Bind at ast.py:14350>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14350
--# expr-start 8534 '<FieldAccess for type_var at ast.py:14350>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14350
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8534
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 8536 '<FieldAccess for ref_var at ast.py:14350>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14350
--# expr-start 8535 '<FieldAccess for name at ast.py:14350>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14350
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Call_Expr_F_Name;
--# expr-done 8535
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_7);
--# end
--# expr-done 8536
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Bind_Result_1 := Solver.Create_Unify (Fld_6, Fld_8, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14350") else null)); 
--# expr-done 8537
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14347") else null)); 
--# expr-done 8538
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8539
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1061;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1061;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Type_Conv_Self_Xref_Equation;
--# end
--# property-start CallExpr.entry_equation /tmp/lal-23.0.0/ada/ast.py:14354
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Entry_Equation
  (Node : Bare_Call_Expr
      ; E : Internal_Entity_Entry_Decl
      ; Root : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind e E
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1062 with Inline_Always;
            procedure Finalizer_Scope_2873 with Inline_Always;
            procedure Finalizer_Scope_2874 with Inline_Always;
            procedure Finalizer_Scope_2875 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Call_Expr;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Assoc_List;
Fld_2 : Bare_Assoc_List;
Fld_3 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_6 : Internal_Entity_Assoc_List;
Fld_7 : Bare_Assoc_List;
Fld_8 : Internal_Entity_Info;
Get_Result_1 : Bare_Basic_Assoc;
As_Entity_1 : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Assoc;
Fld_9 : Internal_Entity_Expr;
Fld_10 : Logic_Equation;
And_Pred : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Fld_11 : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Call_Expr;
Fld_12 : Internal_Entity_Assoc_List;
Fld_13 : Bare_Assoc_List;
Fld_14 : Internal_Entity_Info;
As_Entity_2 : Internal_Entity_Basic_Assoc;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity_Basic_Assoc;
Fld_15 : Internal_Entity_Expr;
Fld_16 : Logic_Equation;
Item_258 : Internal_Entity_Basic_Assoc;
Bare_Item_258 : Bare_Basic_Assoc;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Cast_Expr_1 : Internal_Entity_Entry_Decl;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_17 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Cast_Expr_2 : Internal_Entity_Entry_Decl;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Fld_18 : Logic_Equation;
Fld_19 : Boolean;
If_Result_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1062 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_18);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1062;
            procedure Finalizer_Scope_2873 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_10);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_2873;
            procedure Finalizer_Scope_2874 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Fld_17);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_2874;
            procedure Finalizer_Scope_2875 is
            begin
                     Dec_Ref (Fld_16);
            end Finalizer_Scope_2875;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8562 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8561 '<If at ast.py:14359>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:14359
--# expr-start 8540 '<FieldAccess for has_family at ast.py:14360>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14360
      if E.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EntryDecl.has_family
Fld_19 := Libadalang.Implementation.Entry_Decl_P_Has_Family (Node => E.Node);
--# end
--# expr-done 8540
if Fld_19 then
   --# expr-start 8559 '<And at ast.py:14363>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14363
--# expr-start 8541 '<FieldAccess for family_type at ast.py:14363>' Fld /tmp/lal-23.0.0/ada/ast.py:14363
      if E.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EntryDecl.family_type
Fld := Libadalang.Implementation.Entry_Decl_P_Family_Type (Node => E.Node, Origin => Origin, E_Info => E.Info);
--# end
--# expr-done 8541
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind ft Var_Expr
--# expr-start 8549 '<And at ast.py:14365>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14365
--# expr-start 8545 '<Bind at ast.py:14365>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14365
--# expr-start 8544 '<FieldAccess for expected_type_var at ast.py:14365>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14365
--# expr-start 8543 '<FieldAccess for expr at ast.py:14365>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14365
--# expr-start 8542 '<FieldAccess for params at ast.py:14365>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14365
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_1 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8542
Fld_2 := Fld_1.Node;
Get_Result := Get (Self, Fld_2, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Get_Result); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 8543
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_4.Node);
--# expr-done 8544
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr := Var_Expr; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14365") else null)); 
--# expr-done 8545
--# expr-start 8548 '<FieldAccess for matches_expected_type at ast.py:14366>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14366
--# expr-start 8547 '<FieldAccess for expr at ast.py:14366>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14366
--# expr-start 8546 '<FieldAccess for params at ast.py:14366>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14366
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_6 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8546
Fld_7 := Fld_6.Node;
Get_Result_1 := Get (Self, Fld_7, 0, True); 
Is_Null_1 := Get_Result_1 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Assoc;
else
Fld_8 := Fld_6.Info;
As_Entity_1 := (Info => Fld_8, Node => Get_Result_1); 
   If_Result_1 := As_Entity_1;
end if;
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_9 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result_1.Node, E_Info => If_Result_1.Info);
--# end
--# expr-done 8547
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_10 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_9.Node, Origin => Origin);
--# end
--# expr-done 8548
And_Pred := Create_And (Bind_Result, Fld_10, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14365") else null)); 
--# expr-done 8549
Scope_Result := And_Pred;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2873;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14370") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8551 '<Cast to CallExpr at ast.py:14372>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:14372
--# expr-start 8550 '<FieldAccess for parent_name at ast.py:14372>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14372
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_11 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 8550
   if Fld_11.Node = null
      or else Fld_11.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Call_Expr
        (Node => Fld_11.Node,
         Info => Fld_11.Info);
   else
         Cast_Result_1 := No_Entity_Call_Expr;
   end if;
--# expr-done 8551
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Call_Expr then
   --# scope-start
   --# bind c Var_Expr_1
--# expr-start 8558 '<And at ast.py:14374>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14374
--# expr-start 8556 '<LogicAll at ast.py:14374>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14374
--# expr-start 8555 '<Map at ast.py:14374>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14374
   --# expr-start 8552 '<FieldAccess for params at ast.py:14374>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14374
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_12 := Libadalang.Implementation.Call_Expr_P_Params (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8552
Fld_13 := Fld_12.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_13 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_13;
      begin
         for Untyped_Item_258 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_258 := Untyped_Item_258; 
Is_Null_2 := Bare_Item_258 = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity_Basic_Assoc;
else
Fld_14 := Fld_12.Info;
As_Entity_2 := (Info => Fld_14, Node => Bare_Item_258); 
   If_Result_2 := As_Entity_2;
end if;
                  Item_258 := If_Result_2; 
   --# scope-start
               --# bind pa Item_258
      --# expr-start 8554 '<FieldAccess for sub_equation at ast.py:14374>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14374
--# expr-start 8553 '<FieldAccess for expr at ast.py:14374>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14374
      if Item_258.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_15 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_258.Node, E_Info => Item_258.Info);
--# end
--# expr-done 8553
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_16 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_15.Node, Env => Env, Origin => Origin, E_Info => Fld_15.Info);
--# end
--# expr-done 8554
         declare
            Item_To_Append : constant Logic_Equation := Fld_16;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2875;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8555
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14374") else null)); 
--# expr-done 8556
--# expr-start 8557 '<FieldAccess for entity_equation at ast.py:14375>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14375
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_1 := E; 
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
--# property-call-start CallExpr.entity_equation
Fld_17 := Libadalang.Implementation.Call_Expr_P_Entity_Equation (Node => Var_Expr_1.Node, S => Cast_Result_2, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8557
And_Pred_1 := Create_And (Logic_Boolean_Op, Fld_17, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14374") else null)); 
--# expr-done 8558
Scope_Result_1 := And_Pred_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2874;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14379") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_2 := Create_And (Result_Var, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14363") else null)); 
--# expr-done 8559
   If_Result_3 := And_Pred_2;
else
   --# expr-start 8560 '<FieldAccess for entity_equation at ast.py:14384>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14384
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_2 := E; 
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
--# property-call-start CallExpr.entity_equation
Fld_18 := Libadalang.Implementation.Call_Expr_P_Entity_Equation (Node => Ent.Node, S => Cast_Result_3, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8560
   If_Result_3 := Fld_18;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 8561
Let_Result := If_Result_3; Inc_Ref (Let_Result);
--# end
--# expr-done 8562
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1062;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1062;
               Finalizer_Scope_2873;
               Finalizer_Scope_2874;
               Finalizer_Scope_2875;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Entry_Equation;
--# end
--# property-start CallExpr.entity_equation /tmp/lal-23.0.0/ada/ast.py:14388
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Entity_Equation
  (Node : Bare_Call_Expr
      ; S : Internal_Entity_Basic_Decl
      ; Root : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind s S
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1063 with Inline_Always;
            procedure Finalizer_Scope_2876 with Inline_Always;
            procedure Finalizer_Scope_2877 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Var_Expr_1 : Internal_Entity_Name;
Fld : Bare_Name;
Fld_1 : Logic_Var;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Logic_Equation;
Fld_5 : Boolean;
Fld_6 : Internal_Entity_Base_Type_Decl;
Fld_7 : Logic_Equation;
Fld_8 : Internal_Entity_Base_Subp_Spec;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_9 : Internal_Entity_Info;
Fld_10 : Internal_Metadata;
Fld_11 : Boolean;
Fld_12 : Logic_Equation;
Fld_13 : Internal_Entity_Name;
Fld_14 : Internal_Entity_Base_Type_Decl;
Fld_15 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_16 : Internal_Entity_Base_Subp_Spec;
Cast_Result_2 : Internal_Entity_Base_Formal_Param_Holder;
Fld_17 : Internal_Entity_Info;
Fld_18 : Internal_Metadata;
Fld_19 : Boolean;
Fld_20 : Logic_Equation;
Fld_21 : Internal_Entity_Name;
Fld_22 : Internal_Entity_Base_Type_Decl;
Fld_23 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
If_Result : Logic_Equation;
If_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1063 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1063;
            procedure Finalizer_Scope_2876 is
            begin
                     Dec_Ref (Fld_15);
            end Finalizer_Scope_2876;
            procedure Finalizer_Scope_2877 is
            begin
                     Dec_Ref (Fld_23);
            end Finalizer_Scope_2877;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8593 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8592 '<And at ast.py:14390>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14390
--# expr-start 8565 '<Bind at ast.py:14390>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14390
--# expr-start 8564 '<FieldAccess for ref_var at ast.py:14390>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14390
--# expr-start 8563 '<FieldAccess for name at ast.py:14390>' Fld /tmp/lal-23.0.0/ada/ast.py:14390
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Call_Expr_F_Name;
--# expr-done 8563
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 8564
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Cast_Expr := S; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14390") else null)); 
--# expr-done 8565
--# expr-start 8591 '<Cond at ast.py:14390>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14390
--# expr-start 8566 '<FieldAccess for is_paramless at ast.py:14395>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14395
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_paramless
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Is_Paramless (Node => S.Node, E_Info => S.Info);
--# end
--# expr-done 8566
if Fld_2 then
   --# expr-start 8568 '<FieldAccess for parent_name_equation at ast.py:14395>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14395
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8567 '<FieldAccess for expr_type at ast.py:14396>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14396
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => S.Node, Origin => Origin, E_Info => S.Info);
--# end
--# expr-done 8567
--# property-call-start Name.parent_name_equation
Fld_4 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Ent.Node, Typ => Fld_3, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8568
   If_Result_1 := Fld_4;
else
--# expr-start 8569 '<FieldAccess for can_be_paramless at ast.py:14401>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14401
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.can_be_paramless
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Can_Be_Paramless (Node => S.Node, E_Info => S.Info);
--# end
--# expr-done 8569
if Fld_5 then
   --# expr-start 8581 '<Or at ast.py:14401>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:14401
--# expr-start 8571 '<FieldAccess for parent_name_equation at ast.py:14402>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14402
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8570 '<FieldAccess for expr_type at ast.py:14403>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14403
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => S.Node, Origin => Origin, E_Info => S.Info);
--# end
--# expr-done 8570
--# property-call-start Name.parent_name_equation
Fld_7 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Ent.Node, Typ => Fld_6, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8571
--# expr-start 8580 '<And at ast.py:14406>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14406
--# expr-start 8576 '<FieldAccess for subprogram_equation at ast.py:14407>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14407
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8572 '<FieldAccess for subp_spec_or_null at ast.py:14408>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14408
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => S.Node, E_Info => S.Info);
--# end
--# expr-done 8572
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
--# expr-start 8575 '<FieldAccess for dottable_subp at ast.py:14409>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14409
--# expr-start 8574 '<FieldAccess for md at ast.py:14409>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14409
--# expr-start 8573 '<FieldAccess for info at ast.py:14409>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14409
Fld_9 := S.Info;
--# expr-done 8573
Fld_10 := Fld_9.Md;
--# expr-done 8574
Fld_11 := Fld_10.Dottable_Subp;
--# expr-done 8575
--# property-call-start CallExpr.subprogram_equation
Fld_12 := Libadalang.Implementation.Call_Expr_P_Subprogram_Equation (Node => Ent.Node, Subp_Spec => Cast_Result_1, Dottable_Subp => Fld_11, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8576
--# expr-start 8577 '<FieldAccess for parent_name at ast.py:14411>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14411
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_13 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 8577
Var_Expr := Fld_13;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind pn Var_Expr
--# expr-start 8579 '<FieldAccess for parent_name_equation at ast.py:14413>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14413
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8578 '<FieldAccess for expr_type at ast.py:14413>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14413
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_14 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => S.Node, Origin => Origin, E_Info => S.Info);
--# end
--# expr-done 8578
--# property-call-start Name.parent_name_equation
Fld_15 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr.Node, Typ => Fld_14, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8579
Scope_Result := Fld_15;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2876;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14414") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld_12, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14406") else null)); 
--# expr-done 8580
Or_Pred := Create_Or (Fld_7, And_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14401") else null)); 
--# expr-done 8581
   If_Result := Or_Pred;
else
   --# expr-start 8590 '<And at ast.py:14419>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14419
--# expr-start 8586 '<FieldAccess for subprogram_equation at ast.py:14420>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:14420
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8582 '<FieldAccess for subp_spec_or_null at ast.py:14421>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14421
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_16 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => S.Node, E_Info => S.Info);
--# end
--# expr-done 8582
      Cast_Result_2 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_16.Node,
         Info => Fld_16.Info);
--# expr-start 8585 '<FieldAccess for dottable_subp at ast.py:14422>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14422
--# expr-start 8584 '<FieldAccess for md at ast.py:14422>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14422
--# expr-start 8583 '<FieldAccess for info at ast.py:14422>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14422
Fld_17 := S.Info;
--# expr-done 8583
Fld_18 := Fld_17.Md;
--# expr-done 8584
Fld_19 := Fld_18.Dottable_Subp;
--# expr-done 8585
--# property-call-start CallExpr.subprogram_equation
Fld_20 := Libadalang.Implementation.Call_Expr_P_Subprogram_Equation (Node => Ent.Node, Subp_Spec => Cast_Result_2, Dottable_Subp => Fld_19, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8586
--# expr-start 8587 '<FieldAccess for parent_name at ast.py:14424>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:14424
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_21 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 8587
Var_Expr_1 := Fld_21;
if Var_Expr_1 /= No_Entity_Name then
   --# scope-start
   --# bind pn Var_Expr_1
--# expr-start 8589 '<FieldAccess for parent_name_equation at ast.py:14426>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:14426
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8588 '<FieldAccess for expr_type at ast.py:14426>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:14426
      if S.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_22 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => S.Node, Origin => Origin, E_Info => S.Info);
--# end
--# expr-done 8588
--# property-call-start Name.parent_name_equation
Fld_23 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr_1.Node, Typ => Fld_22, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8589
Scope_Result_1 := Fld_23;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2877;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14427") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_1 := Create_And (Fld_20, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14419") else null)); 
--# expr-done 8590
   If_Result := And_Pred_1;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 8591
And_Pred_2 := Create_And (Bind_Result, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14390") else null)); 
--# expr-done 8592
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 8593
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1063;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1063;
               Finalizer_Scope_2876;
               Finalizer_Scope_2877;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Entity_Equation;
--# end
--# property-start CallExpr.is_type_conversion /tmp/lal-23.0.0/ada/ast.py:14433
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Is_Type_Conversion
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Name;
Is_A : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity_Name;
Fld_2 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8601 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8596 '<Not at ast.py:14438>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14438
--# expr-start 8595 '<IsA QualExpr at ast.py:14438>' Is_A /tmp/lal-23.0.0/ada/ast.py:14438
--# expr-start 8594 '<FieldAccess for name at ast.py:14438>' Fld /tmp/lal-23.0.0/ada/ast.py:14438
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8594
Is_A := Fld.Node /= null 
and then Fld.Node.Kind in Ada_Qual_Expr_Range; 
--# expr-done 8595
Not_Val := not (Is_A); 
--# expr-done 8596
if Not_Val then
   --# expr-start 8600 '<Not at ast.py:14439>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:14439
--# expr-start 8599 '<IsNull at ast.py:14439>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14439
--# expr-start 8598 '<FieldAccess for name_designated_type at ast.py:14439>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14439
--# expr-start 8597 '<FieldAccess for name at ast.py:14439>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14439
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8597
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_2 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 8598
Is_Null := Fld_2.Node = null; 
--# expr-done 8599
Not_Val_1 := not (Is_Null); 
--# expr-done 8600
   If_Result := Not_Val_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 8601
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Is_Type_Conversion;
--# end
--# property-start CallExpr.xref_stop_resolution /tmp/lal-23.0.0/ada/ast.py:14442
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Xref_Stop_Resolution
  (Node : Bare_Call_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 8602 '<Super at ast.py:14443>' Fld /tmp/lal-23.0.0/ada/ast.py:14443
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.xref_stop_resolution
Fld := Libadalang.Implementation.Expr_P_Xref_Stop_Resolution (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8602
if Fld then
   If_Result := True;
else
   --# expr-start 8603 '<FieldAccess for is_type_conversion at ast.py:14443>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14443
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.is_type_conversion
Fld_1 := Libadalang.Implementation.Call_Expr_P_Is_Type_Conversion (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8603
   If_Result := Fld_1;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Xref_Stop_Resolution;
--# end
--# property-start CallExpr.stop_resolution_equation /tmp/lal-23.0.0/ada/ast.py:14446
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Stop_Resolution_Equation
  (Node : Bare_Call_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1066 with Inline_Always;
      Fld : Logic_Equation;
Fld_1 : Logic_Equation;
Fld_2 : Boolean;
If_Result : Logic_Equation;
            procedure Finalizer_Scope_1066 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_1066;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8607 '<If at ast.py:14446>' If_Result /tmp/lal-23.0.0/ada/ast.py:14446
--# expr-start 8604 '<FieldAccess for is_type_conversion at ast.py:14447>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14447
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.is_type_conversion
Fld_2 := Libadalang.Implementation.Call_Expr_P_Is_Type_Conversion (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8604
if Fld_2 then
   --# expr-start 8605 '<FieldAccess for type_conv_self_xref_equation at ast.py:14448>' Fld /tmp/lal-23.0.0/ada/ast.py:14448
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.type_conv_self_xref_equation
Fld := Libadalang.Implementation.Call_Expr_P_Type_Conv_Self_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8605
   If_Result := Fld;
else
   --# expr-start 8606 '<Super at ast.py:14449>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14449
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.stop_resolution_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Stop_Resolution_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8606
   If_Result := Fld_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 8607
      Property_Result := If_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1066;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1066;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Stop_Resolution_Equation;
--# end
--# property-start CallExpr.general_xref_equation /tmp/lal-23.0.0/ada/ast.py:14453
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_General_Xref_Equation
  (Node : Bare_Call_Expr
      ; Root : Bare_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1067 with Inline_Always;
            procedure Finalizer_Scope_2878 with Inline_Always;
            procedure Finalizer_Scope_2879 with Inline_Always;
            procedure Finalizer_Scope_2880 with Inline_Always;
            procedure Finalizer_Scope_2881 with Inline_Always;
            procedure Finalizer_Scope_2882 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Var_Expr_1 : Boolean;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Subps : Internal_Entity_Array_Access;
Var_Expr_3 : Internal_Entity_Entry_Decl;
Fld : Boolean;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Assoc_List;
Fld_3 : Bare_Assoc_List;
Fld_4 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Internal_Entity_Assoc_List;
Fld_8 : Bare_Assoc_List;
Fld_9 : Internal_Entity_Info;
Get_Result_1 : Bare_Basic_Assoc;
As_Entity_1 : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Assoc;
Fld_10 : Internal_Entity_Expr;
Fld_11 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_12 : Internal_Entity_Name;
Fld_13 : Internal_Entity_Name;
Fld_14 : Internal_Entity_Base_Type_Decl;
Fld_15 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_16 : Internal_Entity_Name;
Is_A : Boolean;
Fld_17 : Internal_Entity_Name;
Fld_18 : Boolean;
Fld_19 : Logic_Equation;
Fld_20 : Internal_Entity_Name;
Fld_21 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_22 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Fld_23 : Internal_Entity_Name;
Fld_24 : Logic_Var;
Is_Logic_Var_Defined : Boolean;
Eq_Solution : Internal_Entity;
If_Result_2 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_25 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
False_Rel : Logic_Equation;
Result_Var_2 : Logic_Equation;
Fld_26 : Logic_Equation;
Fld_27 : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Entry_Decl;
Fld_28 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Cast_Expr_2 : Internal_Entity;
Cast_Result_4 : Internal_Entity_Basic_Decl;
Fld_29 : Logic_Equation;
Result_Var_3 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_30 : Internal_Entity_Name;
Fld_31 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Let_Result : Logic_Equation;
And_Pred_5 : Logic_Equation;
If_Result_3 : Logic_Equation;
If_Result_4 : Logic_Equation;
Let_Result_1 : Logic_Equation;
            procedure Finalizer_Scope_1067 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_11);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (False_Rel);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Fld_26);
                     Dec_Ref (Fld_27);
                     Dec_Ref (Subps);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Fld_31);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Let_Result);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_1067;
            procedure Finalizer_Scope_2878 is
            begin
                     Dec_Ref (Fld_15);
            end Finalizer_Scope_2878;
            procedure Finalizer_Scope_2879 is
            begin
                     Dec_Ref (Fld_19);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Fld_25);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_2879;
            procedure Finalizer_Scope_2880 is
            begin
                     Dec_Ref (Fld_22);
            end Finalizer_Scope_2880;
            procedure Finalizer_Scope_2881 is
            begin
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Fld_29);
                     Dec_Ref (Result_Var_3);
            end Finalizer_Scope_2881;
            procedure Finalizer_Scope_2882 is
            begin
                     Dec_Ref (Fld_28);
            end Finalizer_Scope_2882;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8653 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 8652 '<Cond at ast.py:14458>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:14458
--# expr-start 8608 '<FieldAccess for is_type_conversion at ast.py:14459>' Fld /tmp/lal-23.0.0/ada/ast.py:14459
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.is_type_conversion
Fld := Libadalang.Implementation.Call_Expr_P_Is_Type_Conversion (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8608
if Fld then
   --# expr-start 8623 '<And at ast.py:14462>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14462
--# expr-start 8618 '<And at ast.py:14462>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14462
--# expr-start 8614 '<And at ast.py:14462>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14462
--# expr-start 8609 '<FieldAccess for type_conv_self_xref_equation at ast.py:14462>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14462
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.type_conv_self_xref_equation
Fld_1 := Libadalang.Implementation.Call_Expr_P_Type_Conv_Self_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8609
--# expr-start 8613 '<Bind at ast.py:14463>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14463
--# expr-start 8612 '<FieldAccess for expected_type_var at ast.py:14463>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14463
--# expr-start 8611 '<FieldAccess for expr at ast.py:14463>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14463
--# expr-start 8610 '<FieldAccess for params at ast.py:14463>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14463
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_2 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8610
Fld_3 := Fld_2.Node;
Get_Result := Get (Self, Fld_3, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_4 := Fld_2.Info;
As_Entity := (Info => Fld_4, Node => Get_Result); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_5 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 8611
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_5.Node);
--# expr-done 8612
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
Cast_Expr := No_Entity_Base_Type_Decl; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_6, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14463") else null)); 
--# expr-done 8613
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14462") else null)); 
--# expr-done 8614
--# expr-start 8617 '<FieldAccess for sub_equation at ast.py:14465>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14465
--# expr-start 8616 '<FieldAccess for expr at ast.py:14465>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14465
--# expr-start 8615 '<FieldAccess for params at ast.py:14465>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14465
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_7 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8615
Fld_8 := Fld_7.Node;
Get_Result_1 := Get (Self, Fld_8, 0, True); 
Is_Null_1 := Get_Result_1 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Assoc;
else
Fld_9 := Fld_7.Info;
As_Entity_1 := (Info => Fld_9, Node => Get_Result_1); 
   If_Result_1 := As_Entity_1;
end if;
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result_1.Node, E_Info => If_Result_1.Info);
--# end
--# expr-done 8616
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_11 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_10.Node, Env => Env, Origin => Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 8617
And_Pred_1 := Create_And (And_Pred, Fld_11, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14462") else null)); 
--# expr-done 8618
--# expr-start 8619 '<FieldAccess for parent_name at ast.py:14466>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14466
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_12 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 8619
Var_Expr := Fld_12;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind pn Var_Expr
--# expr-start 8622 '<FieldAccess for parent_name_equation at ast.py:14467>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14467
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8621 '<FieldAccess for name_designated_type at ast.py:14468>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14468
--# expr-start 8620 '<FieldAccess for name at ast.py:14468>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14468
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8620
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_14 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Fld_13.Node, E_Info => Fld_13.Info);
--# end
--# expr-done 8621
--# property-call-start Name.parent_name_equation
Fld_15 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr.Node, Typ => Fld_14, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8622
Scope_Result := Fld_15;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2878;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14471") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (And_Pred_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14462") else null)); 
--# expr-done 8623
   If_Result_4 := And_Pred_2;
else
--# expr-start 8625 '<IsA AttributeRef at ast.py:14477>' Is_A /tmp/lal-23.0.0/ada/ast.py:14477
--# expr-start 8624 '<FieldAccess for name at ast.py:14477>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14477
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8624
Is_A := Fld_16.Node /= null 
and then Fld_16.Node.Kind in Ada_Attribute_Ref_Range; 
--# expr-done 8625
if Is_A then
--# expr-start 8627 '<FieldAccess for resolve_names_internal at ast.py:14478>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14478
--# expr-start 8626 '<FieldAccess for name at ast.py:14478>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14478
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8626
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_internal
Fld_18 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal (Node => Fld_17.Node, Env => Env, Origin => Origin, E_Info => Fld_17.Info);
--# end
--# expr-done 8627
Var_Expr_1 := Fld_18;
if Var_Expr_1 /= False then
   --# scope-start
   --# bind _ Var_Expr_1
--# expr-start 8638 '<And at ast.py:14478>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:14478
--# expr-start 8628 '<FieldAccess for all_args_xref_equation at ast.py:14479>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14479
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_args_xref_equation
Fld_19 := Libadalang.Implementation.Name_P_All_Args_Xref_Equation (Node => Ent.Node, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8628
--# expr-start 8631 '<Cast to BaseTypeDecl at ast.py:14480>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:14480
--# expr-start 8630 '<FieldAccess for type_val at ast.py:14480>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:14480
--# expr-start 8629 '<FieldAccess for name at ast.py:14480>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:14480
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8629
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_21 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld_20.Node);
--# end
--# expr-done 8630
   if Fld_21.Node = null
      or else Fld_21.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_21.Node,
         Info => Fld_21.Info);
   else
         Cast_Result_1 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 8631
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr_2
--# expr-start 8632 '<FieldAccess for parent_name_equation at ast.py:14481>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:14481
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name_equation
Fld_22 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Ent.Node, Typ => Var_Expr_2, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8632
Scope_Result_1 := Fld_22;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2880;
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 8637 '<FieldAccess for entity_equation at ast.py:14486>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:14486
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8636 '<Cast to BasicDecl at ast.py:14487>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:14487
--# expr-start 8635 '<get_value at ast.py:14487>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:14487
--# expr-start 8634 '<FieldAccess for ref_var at ast.py:14487>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:14487
--# expr-start 8633 '<FieldAccess for name at ast.py:14487>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:14487
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8633
      if Fld_23.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_24 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_23.Node);
--# end
--# expr-done 8634
Is_Logic_Var_Defined := Entity_Vars.Is_Defined (Fld_24); 
if Is_Logic_Var_Defined then
Eq_Solution := Entity_Vars.Get_Value (Fld_24); 
   If_Result_2 := Eq_Solution;
else
   If_Result_2 := No_Entity;
end if;
--# expr-done 8635
   if If_Result_2.Node = null
      or else If_Result_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => If_Result_2.Node,
         Info => If_Result_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8636
--# property-call-start CallExpr.entity_equation
Fld_25 := Libadalang.Implementation.Call_Expr_P_Entity_Equation (Node => Ent.Node, S => Cast_Result_2, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8637
   Result_Var_1 := Fld_25;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_3 := Create_And (Fld_19, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14478") else null)); 
--# expr-done 8638
Scope_Result_2 := And_Pred_3;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2879;
   Result_Var_2 := Scope_Result_2;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14491") else null)); 
   Result_Var_2 := False_Rel;
end if;
      Inc_Ref (Result_Var_2);
   If_Result_3 := Result_Var_2;
else
   --# expr-start 8651 '<And at ast.py:14494>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:14494
--# expr-start 8639 '<FieldAccess for all_args_xref_equation at ast.py:14495>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:14495
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_args_xref_equation
Fld_26 := Libadalang.Implementation.Name_P_All_Args_Xref_Equation (Node => Ent.Node, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8639
--# expr-start 8650 '<Let at ast.py:14499>' Let_Result /tmp/lal-23.0.0/ada/ast.py:14499
--# scope-start
--# expr-start 8640 '<FieldAccess for env_elements at ast.py:14499>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:14499
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_27 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Ent.Node, Env => Env, No_Visibility => False, E_Info => Ent.Info);
--# end
--# expr-done 8640
Subps := Fld_27; Inc_Ref (Subps);
--# bind subps Subps
--# expr-start 8649 '<And at ast.py:14499>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:14499
--# expr-start 8646 '<LogicAny at ast.py:14500>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14500
--# expr-start 8645 '<Map at ast.py:14500>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14500
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Subps;
      begin
         for Item_259 of
               Collection.Items
         loop
   --# scope-start
               --# bind s Item_259
--# expr-start 8641 '<Cast to EntryDecl at ast.py:14501>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:14501
Cast_Expr_1 := Item_259; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Entry_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_3 := No_Entity_Entry_Decl;
   end if;
--# expr-done 8641
Var_Expr_3 := Cast_Result_3;
if Var_Expr_3 /= No_Entity_Entry_Decl then
   --# scope-start
   --# bind e Var_Expr_3
--# expr-start 8642 '<FieldAccess for entry_equation at ast.py:14502>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:14502
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.entry_equation
Fld_28 := Libadalang.Implementation.Call_Expr_P_Entry_Equation (Node => Ent.Node, E => Var_Expr_3, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8642
Scope_Result_3 := Fld_28;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2882;
   Result_Var_3 := Scope_Result_3;
else
   --# expr-start 8644 '<FieldAccess for entity_equation at ast.py:14503>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:14503
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8643 '<Cast to BasicDecl at ast.py:14504>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:14504
Cast_Expr_2 := Item_259; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8643
--# property-call-start CallExpr.entity_equation
Fld_29 := Libadalang.Implementation.Call_Expr_P_Entity_Equation (Node => Ent.Node, S => Cast_Result_4, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8644
   Result_Var_3 := Fld_29;
end if;
      Inc_Ref (Result_Var_3);
         declare
            Item_To_Append : constant Logic_Equation := Result_Var_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2881;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8645
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14500") else null)); 
--# expr-done 8646
--# expr-start 8648 '<FieldAccess for sub_equation at ast.py:14509>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:14509
--# expr-start 8647 '<FieldAccess for name at ast.py:14509>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:14509
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_30 := Create_Internal_Entity_Name (Node => Ent.Node.Call_Expr_F_Name, Info => Ent.Info);
--# expr-done 8647
      if Fld_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_31 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_30.Node, Env => Env, Origin => Origin, E_Info => Fld_30.Info);
--# end
--# expr-done 8648
And_Pred_4 := Create_And (Logic_Boolean_Op, Fld_31, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14499") else null)); 
--# expr-done 8649
Let_Result := And_Pred_4; Inc_Ref (Let_Result);
--# end
--# expr-done 8650
And_Pred_5 := Create_And (Fld_26, Let_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14494") else null)); 
--# expr-done 8651
   If_Result_3 := And_Pred_5;
end if;
      Inc_Ref (If_Result_3);
   If_Result_4 := If_Result_3;
end if;
      Inc_Ref (If_Result_4);
--# expr-done 8652
Let_Result_1 := If_Result_4; Inc_Ref (Let_Result_1);
--# end
--# expr-done 8653
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1067;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1067;
               Finalizer_Scope_2878;
               Finalizer_Scope_2879;
               Finalizer_Scope_2880;
               Finalizer_Scope_2881;
               Finalizer_Scope_2882;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_General_Xref_Equation;
--# end
--# property-start CallExpr.subscriptable_type_equation /tmp/lal-23.0.0/ada/ast.py:14517
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Subscriptable_Type_Equation
  (Node : Bare_Call_Expr
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1068 with Inline_Always;
            procedure Finalizer_Scope_2885 with Inline_Always;
            procedure Finalizer_Scope_2887 with Inline_Always;
            procedure Finalizer_Scope_2889 with Inline_Always;
            procedure Finalizer_Scope_2890 with Inline_Always;
            procedure Finalizer_Scope_2891 with Inline_Always;
            procedure Finalizer_Scope_2892 with Inline_Always;
            procedure Finalizer_Scope_2893 with Inline_Always;
            procedure Finalizer_Scope_2894 with Inline_Always;
            procedure Finalizer_Scope_2895 with Inline_Always;
            procedure Finalizer_Scope_2896 with Inline_Always;
      Block_Var : Internal_Entity_Array_Type_Def;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Access_To_Subp_Def;
Var_Expr_3 : Internal_Entity_Array_Type_Def;
Match_0 : Internal_Entity_Assoc_List;
Match_1 : Internal_Entity_Bin_Op;
Match_2 : Internal_Entity_Attribute_Ref;
Match_3 : Internal_Entity_Subtype_Indication;
Match_4 : Internal_Entity;
Var_Expr_4 : Internal_Entity_Name;
Var_Expr_5 : Internal_Entity_Basic_Assoc;
Var_Expr_6 : Internal_Entity_Assoc_List;
Formal : Internal_Entity_Defining_Name;
Ret_Type : Internal_Entity_Base_Type_Decl;
Param : Internal_Entity_Expr;
Fld : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Result_Var : Internal_Entity_Array_Type_Def;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Access_Def;
Is_A : Boolean;
Fld_4 : Internal_Entity_Access_Def;
Cast_Result : Internal_Entity_Access_To_Subp_Def;
Fld_5 : Internal_Entity_Subp_Spec;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_6 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
False_Rel : Logic_Equation;
Result_Var_2 : Logic_Equation;
Fld_7 : Internal_Entity_Array_Indices;
Scope_Result_3 : Internal_Entity_Array_Indices;
Result_Var_3 : Internal_Entity_Array_Indices;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_8 : Internal_Entity;
Fld_9 : Internal_Entity_Assoc_List;
Fld_10 : Bare_Assoc_List;
Fld_11 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Assoc;
Fld_12 : Internal_Entity_Expr;
Scope_Result_4 : Internal_Entity_Expr;
Result_Var_4 : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity_Name;
False_Rel_1 : Logic_Equation;
Fld_13 : Logic_Equation;
Fld_14 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_15 : Internal_Entity_Base_Type_Decl;
Is_Null_2 : Boolean;
If_Result_2 : Logic_Equation;
Scope_Result_5 : Logic_Equation;
False_Rel_2 : Logic_Equation;
Result_Var_5 : Logic_Equation;
Fld_16 : Internal_Entity_Assoc_List;
Saved : Internal_Entity_Assoc_List;
Fld_17 : Bare_Assoc_List;
Fld_18 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Basic_Assoc;
Is_Null_3 : Boolean;
If_Result_3 : Internal_Entity_Basic_Assoc;
Fld_19 : Internal_Entity_Array_Indices;
Fld_20 : Internal_Entity_Expr;
Fld_21 : Logic_Equation;
Item_260 : Internal_Entity_Basic_Assoc;
Bare_Item_260 : Bare_Basic_Assoc;
Index_261 : Integer;
Map_Result : Logic_Equation_Array_Access;
Scope_Result_6 : Logic_Equation_Array_Access;
Result_Var_6 : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_22 : Logic_Var;
Fld_23 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Or_Pred : Logic_Equation;
Fld_24 : Internal_Entity_Array_Indices;
Fld_25 : Internal_Entity_Expr;
Fld_26 : Logic_Equation;
Fld_27 : Internal_Entity_Array_Indices;
Fld_28 : Internal_Entity_Expr;
Fld_29 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_30 : Logic_Var;
Fld_31 : Internal_Entity_Expr;
Fld_32 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_33 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_5 : Internal_Entity;
Bind_Result_3 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_34 : Internal_Entity_Expr;
Fld_35 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Fld_36 : Internal_Entity_Expr;
Fld_37 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Fld_38 : Logic_Equation;
Fld_39 : Internal_Entity_Array_Indices;
Cast_Expr_2 : Internal_Entity_Attribute_Ref;
Cast_Result_6 : Internal_Entity_Expr;
Fld_40 : Logic_Equation;
And_Pred_7 : Logic_Equation;
Fld_41 : Logic_Var;
Cast_Expr_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_7 : Internal_Entity;
Bind_Result_4 : Logic_Equation;
And_Pred_8 : Logic_Equation;
Fld_42 : Logic_Equation;
Fld_43 : Logic_Var;
Cast_Expr_4 : Internal_Entity_Base_Type_Decl;
Cast_Result_8 : Internal_Entity;
Bind_Result_5 : Logic_Equation;
And_Pred_9 : Logic_Equation;
False_Rel_3 : Logic_Equation;
Match_Prefix : Internal_Entity;
Cast_Result_9 : Internal_Entity_Assoc_List;
Let_Result : Logic_Equation;
Scope_Result_7 : Logic_Equation;
Cast_Result_10 : Internal_Entity_Bin_Op;
Let_Result_1 : Logic_Equation;
Scope_Result_8 : Logic_Equation;
Cast_Result_11 : Internal_Entity_Attribute_Ref;
Let_Result_2 : Logic_Equation;
Scope_Result_9 : Logic_Equation;
Cast_Result_12 : Internal_Entity_Subtype_Indication;
Let_Result_3 : Logic_Equation;
Scope_Result_10 : Logic_Equation;
Cast_Result_13 : Internal_Entity;
Let_Result_4 : Logic_Equation;
Scope_Result_11 : Logic_Equation;
Match_Result : Logic_Equation;
Is_Null_4 : Boolean;
Not_Val_1 : Boolean;
Fld_44 : Boolean;
If_Result_4 : Boolean;
Fld_45 : Internal_Entity_Basic_Decl_Array_Access;
Fld_46 : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Fld_47 : Internal_Entity_Base_Subp_Spec;
Fld_48 : Internal_Entity_Defining_Name_Array_Access;
Get_Result_1 : Internal_Entity_Defining_Name;
Fld_49 : Internal_Entity_Base_Subp_Spec;
Fld_50 : Internal_Entity_Base_Type_Decl;
Fld_51 : Internal_Entity_Assoc_List;
Fld_52 : Bare_Assoc_List;
Fld_53 : Internal_Entity_Info;
Get_Result_2 : Bare_Basic_Assoc;
As_Entity_2 : Internal_Entity_Basic_Assoc;
Is_Null_5 : Boolean;
If_Result_5 : Internal_Entity_Basic_Assoc;
Fld_54 : Internal_Entity_Expr;
Fld_55 : Logic_Var;
Cast_Expr_5 : Internal_Entity_Base_Type_Decl;
Cast_Result_14 : Internal_Entity;
Bind_Result_6 : Logic_Equation;
Fld_56 : Logic_Var;
Fld_57 : Internal_Entity_Base_Formal_Param_Decl;
Fld_58 : Internal_Entity_Base_Type_Decl;
Cast_Result_15 : Internal_Entity;
Bind_Result_7 : Logic_Equation;
And_Pred_10 : Logic_Equation;
Fld_59 : Logic_Equation;
And_Pred_11 : Logic_Equation;
Let_Result_5 : Logic_Equation;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
False_Rel_4 : Logic_Equation;
If_Result_6 : Logic_Equation;
If_Result_7 : Logic_Equation;
If_Result_8 : Logic_Equation;
Let_Result_6 : Logic_Equation;
            procedure Finalizer_Scope_1068 is
            begin
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (False_Rel);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_8);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_9);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_10);
                     Dec_Ref (Let_Result_4);
                     Dec_Ref (Scope_Result_11);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Fld_45);
                     Dec_Ref (Fld_46);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (False_Rel_4);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (If_Result_8);
                     Dec_Ref (Let_Result_6);
            end Finalizer_Scope_1068;
            procedure Finalizer_Scope_2885 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2885;
            procedure Finalizer_Scope_2887 is
            begin
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (False_Rel_2);
                     Dec_Ref (Result_Var_5);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Result_Var_6);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Or_Pred);
            end Finalizer_Scope_2887;
            procedure Finalizer_Scope_2889 is
            begin
                     Dec_Ref (False_Rel_1);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (If_Result_2);
            end Finalizer_Scope_2889;
            procedure Finalizer_Scope_2890 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2890;
            procedure Finalizer_Scope_2891 is
            begin
                     Dec_Ref (Fld_21);
            end Finalizer_Scope_2891;
            procedure Finalizer_Scope_2892 is
            begin
                     Dec_Ref (Fld_26);
                     Dec_Ref (Fld_29);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_35);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Fld_37);
                     Dec_Ref (And_Pred_6);
            end Finalizer_Scope_2892;
            procedure Finalizer_Scope_2893 is
            begin
                     Dec_Ref (Fld_38);
                     Dec_Ref (Fld_40);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (And_Pred_8);
            end Finalizer_Scope_2893;
            procedure Finalizer_Scope_2894 is
            begin
                     Dec_Ref (Fld_42);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (And_Pred_9);
            end Finalizer_Scope_2894;
            procedure Finalizer_Scope_2895 is
            begin
                     Dec_Ref (False_Rel_3);
            end Finalizer_Scope_2895;
            procedure Finalizer_Scope_2896 is
            begin
                     Dec_Ref (Fld_48);
                     Dec_Ref (Bind_Result_6);
                     Dec_Ref (Bind_Result_7);
                     Dec_Ref (And_Pred_10);
                     Dec_Ref (Fld_59);
                     Dec_Ref (And_Pred_11);
                     Dec_Ref (Let_Result_5);
            end Finalizer_Scope_2896;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8748 '<Block at ???>' Let_Result_6 None
--# scope-start
Var_Expr := Typ;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 8654 '<FieldAccess for array_def_with_deref at ast.py:14522>' Fld /tmp/lal-23.0.0/ada/ast.py:14522
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8654
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Array_Type_Def;
end if;
Block_Var := Result_Var; 
--# bind atd Block_Var
Var_Expr_1 := Typ;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr_1
--# expr-start 8657 '<If at ast.py:14524>' If_Result /tmp/lal-23.0.0/ada/ast.py:14524
--# expr-start 8655 '<FieldAccess for is_implicit_deref at ast.py:14524>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14524
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_implicit_deref
Fld_2 := Libadalang.Implementation.Base_Type_Decl_P_Is_Implicit_Deref (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8655
if Fld_2 then
   --# expr-start 8656 '<FieldAccess for accessed_type at ast.py:14524>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14524
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8656
   If_Result := Fld_1;
else
   If_Result := Var_Expr_1;
end if;
--# expr-done 8657
Scope_Result_1 := If_Result;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Block_Var_1 := Result_Var_1; 
--# bind real_typ Block_Var_1
--# expr-start 8747 '<Cond at ast.py:14527>' If_Result_8 /tmp/lal-23.0.0/ada/ast.py:14527
--# expr-start 8659 '<IsA AccessToSubpDef at ast.py:14529>' Is_A /tmp/lal-23.0.0/ada/ast.py:14529
--# expr-start 8658 '<FieldAccess for access_def at ast.py:14529>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14529
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Typ.Node, Origin => Origin, E_Info => Typ.Info);
--# end
--# expr-done 8658
Is_A := Fld_3.Node /= null 
and then Fld_3.Node.Kind in Ada_Access_To_Subp_Def_Range; 
--# expr-done 8659
if Is_A then
--# expr-start 8661 '<Cast to AccessToSubpDef at ast.py:14530>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14530
--# expr-start 8660 '<FieldAccess for access_def at ast.py:14530>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14530
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Typ.Node, Origin => Origin, E_Info => Typ.Info);
--# end
--# expr-done 8660
   if Fld_4.Node = null
      or else Fld_4.Node.Kind in Ada_Access_To_Subp_Def_Range
   then
      Cast_Result := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
   else
         Cast_Result := No_Entity_Access_To_Subp_Def;
   end if;
--# expr-done 8661
Var_Expr_2 := Cast_Result;
if Var_Expr_2 /= No_Entity_Access_To_Subp_Def then
   --# scope-start
   --# bind asd Var_Expr_2
--# expr-start 8663 '<FieldAccess for subprogram_equation at ast.py:14532>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14532
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8662 '<FieldAccess for subp_spec at ast.py:14532>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14532
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr_2.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Var_Expr_2.Info);
--# expr-done 8662
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
--# property-call-start CallExpr.subprogram_equation
Fld_6 := Libadalang.Implementation.Call_Expr_P_Subprogram_Equation (Node => Ent.Node, Subp_Spec => Cast_Result_1, Dottable_Subp => False, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 8663
Scope_Result_2 := Fld_6;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2885;
   Result_Var_2 := Scope_Result_2;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14533") else null)); 
   Result_Var_2 := False_Rel;
end if;
      Inc_Ref (Result_Var_2);
   If_Result_8 := Result_Var_2;
else
--# expr-start 8666 '<Not at ast.py:14536>' Not_Val /tmp/lal-23.0.0/ada/ast.py:14536
--# expr-start 8665 '<IsNull at ast.py:14536>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14536
Var_Expr_3 := Block_Var;
if Var_Expr_3 /= No_Entity_Array_Type_Def then
   --# scope-start
--# expr-start 8664 '<FieldAccess for indices at ast.py:14536>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14536
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Array_Indices (Node => Var_Expr_3.Node.Array_Type_Def_F_Indices, Info => Var_Expr_3.Info);
--# expr-done 8664
Scope_Result_3 := Fld_7;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Entity_Array_Indices;
end if;
Is_Null := Result_Var_3.Node = null; 
--# expr-done 8665
Not_Val := not (Is_Null); 
--# expr-done 8666
if Not_Val then
   --# expr-start 8721 '<Match at ast.py:14536>' Match_Result /tmp/lal-23.0.0/ada/ast.py:14536
--# expr-start 8667 '<FieldAccess for suffix at ast.py:14536>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14536
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity (Node => Ent.Node.Call_Expr_F_Suffix, Info => Ent.Info);
--# expr-done 8667
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_8; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Assoc_List =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Create_Internal_Entity_Assoc_List
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_9; 
--# bind _ Match_0
--# expr-start 8688 '<Or at ast.py:14537>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:14537
--# expr-start 8670 '<Cast to Name at ast.py:14539>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:14539
--# expr-start 8668 '<FieldAccess for params at ast.py:14539>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14539
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_9 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8668
Fld_10 := Fld_9.Node;
Get_Result := Get (Self, Fld_10, 0, True); 
Is_Null_1 := Get_Result = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Assoc;
else
Fld_11 := Fld_9.Info;
As_Entity := (Info => Fld_11, Node => Get_Result); 
   If_Result_1 := As_Entity;
end if;
Var_Expr_5 := If_Result_1;
if Var_Expr_5 /= No_Entity_Basic_Assoc then
   --# scope-start
--# expr-start 8669 '<FieldAccess for expr at ast.py:14539>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14539
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_12 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 8669
Scope_Result_4 := Fld_12;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Expr;
end if;
   if Result_Var_4.Node = null
      or else Result_Var_4.Node.Kind in Ada_Name
   then
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Result_Var_4.Node,
         Info => Result_Var_4.Info);
   else
         Cast_Result_2 := No_Entity_Name;
   end if;
--# expr-done 8670
Var_Expr_4 := Cast_Result_2;
if Var_Expr_4 /= No_Entity_Name then
   --# scope-start
   --# bind name Var_Expr_4
--# expr-start 8677 '<If at ast.py:14540>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:14540
--# expr-start 8672 '<IsNull at ast.py:14541>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:14541
--# expr-start 8671 '<FieldAccess for name_designated_type at ast.py:14541>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14541
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_15 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr_4.Node, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 8671
Is_Null_2 := Fld_15.Node = null; 
--# expr-done 8672
if Is_Null_2 then
   False_Rel_1 := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14542") else null)); 
   If_Result_2 := False_Rel_1;
else
   --# expr-start 8676 '<And at ast.py:14543>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14543
--# expr-start 8673 '<FieldAccess for xref_no_overloading at ast.py:14543>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14543
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_13 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Var_Expr_4.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 8673
--# expr-start 8675 '<Bind at ast.py:14544>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14544
--# expr-start 8674 '<FieldAccess for type_var at ast.py:14544>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14544
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8674
Fld_14.Value := No_Entity;
Entity_Vars.Reset (Fld_14);
Cast_Expr := Block_Var_1; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_14, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14544") else null)); 
--# expr-done 8675
And_Pred := Create_And (Fld_13, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14543") else null)); 
--# expr-done 8676
   If_Result_2 := And_Pred;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 8677
Scope_Result_5 := If_Result_2;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2889;
   Result_Var_5 := Scope_Result_5;
else
   False_Rel_2 := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14546") else null)); 
   Result_Var_5 := False_Rel_2;
end if;
      Inc_Ref (Result_Var_5);
--# expr-start 8687 '<And at ast.py:14550>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14550
--# expr-start 8683 '<LogicAll at ast.py:14550>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14550
--# expr-start 8678 '<FieldAccess for params at ast.py:14550>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14550
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_16 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8678
Var_Expr_6 := Fld_16;
if Var_Expr_6 /= No_Entity_Assoc_List then
   --# scope-start
--# expr-start 8682 '<Map at ast.py:14550>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14550
Saved := Var_Expr_6; 
Fld_17 := Saved.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_17 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
         Index_261 := 0;
      declare
         Collection : constant Bare_Assoc_List := Fld_17;
      begin
         for Untyped_Item_260 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_260 := Untyped_Item_260; 
Is_Null_3 := Bare_Item_260 = null; 
if Is_Null_3 then
   If_Result_3 := No_Entity_Basic_Assoc;
else
Fld_18 := Saved.Info;
As_Entity_1 := (Info => Fld_18, Node => Bare_Item_260); 
   If_Result_3 := As_Entity_1;
end if;
                  Item_260 := If_Result_3; 
   --# scope-start
               --# bind pa Item_260
               --# bind i Index_261
      --# expr-start 8681 '<FieldAccess for constrain_index_expr at ast.py:14552>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:14552
--# expr-start 8679 '<FieldAccess for indices at ast.py:14552>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14552
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Array_Indices (Node => Block_Var.Node.Array_Type_Def_F_Indices, Info => Block_Var.Info);
--# expr-done 8679
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8680 '<FieldAccess for expr at ast.py:14552>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:14552
      if Item_260.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_20 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Item_260.Node, E_Info => Item_260.Info);
--# end
--# expr-done 8680
--# property-call-start '[dispatcher]ArrayIndices.constrain_index_expr'
Fld_21 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Constrain_Index_Expr (Node => Fld_19.Node, Index_Expr => Fld_20, Dim => Index_261, Origin => Origin, E_Info => Fld_19.Info);
--# end
--# expr-done 8681
         declare
            Item_To_Append : constant Logic_Equation := Fld_21;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2891;
               Index_261 := Index_261 + 1;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8682
Scope_Result_6 := Map_Result;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_2890;
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Logic_Equation_Array_Type;
end if;
      Inc_Ref (Result_Var_6);
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Result_Var_6.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14550") else null)); 
--# expr-done 8683
--# expr-start 8686 '<Bind at ast.py:14554>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14554
--# expr-start 8684 '<FieldAccess for type_var at ast.py:14554>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:14554
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8684
Fld_22.Value := No_Entity;
Entity_Vars.Reset (Fld_22);
--# expr-start 8685 '<FieldAccess for comp_type at ast.py:14554>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:14554
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ArrayTypeDef.comp_type
Fld_23 := Libadalang.Implementation.Array_Type_Def_P_Comp_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 8685
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_23.Node,
         Info => Fld_23.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_22, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14554") else null)); 
--# expr-done 8686
And_Pred_1 := Create_And (Logic_Boolean_Op, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14550") else null)); 
--# expr-done 8687
Or_Pred := Create_Or (Result_Var_5, And_Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14537") else null)); 
--# expr-done 8688
Let_Result := Or_Pred; Inc_Ref (Let_Result);
--# end
Scope_Result_7 := Let_Result;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_2887;
            Match_Result := Scope_Result_7; Inc_Ref (Match_Result);
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_10; 
--# bind bo Match_1
--# expr-start 8709 '<And at ast.py:14559>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:14559
--# expr-start 8706 '<And at ast.py:14559>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:14559
--# expr-start 8703 '<And at ast.py:14559>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:14559
--# expr-start 8700 '<And at ast.py:14559>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:14559
--# expr-start 8695 '<And at ast.py:14559>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14559
--# expr-start 8691 '<FieldAccess for constrain_index_expr at ast.py:14559>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:14559
--# expr-start 8689 '<FieldAccess for indices at ast.py:14559>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:14559
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Create_Internal_Entity_Array_Indices (Node => Block_Var.Node.Array_Type_Def_F_Indices, Info => Block_Var.Info);
--# expr-done 8689
      if Fld_24.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8690 '<FieldAccess for left at ast.py:14559>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:14559
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Left, Info => Match_1.Info);
--# expr-done 8690
--# property-call-start '[dispatcher]ArrayIndices.constrain_index_expr'
Fld_26 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Constrain_Index_Expr (Node => Fld_24.Node, Index_Expr => Fld_25, Dim => 0, Origin => Origin, E_Info => Fld_24.Info);
--# end
--# expr-done 8691
--# expr-start 8694 '<FieldAccess for constrain_index_expr at ast.py:14560>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:14560
--# expr-start 8692 '<FieldAccess for indices at ast.py:14560>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:14560
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_27 := Create_Internal_Entity_Array_Indices (Node => Block_Var.Node.Array_Type_Def_F_Indices, Info => Block_Var.Info);
--# expr-done 8692
      if Fld_27.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8693 '<FieldAccess for right at ast.py:14560>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:14560
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Right, Info => Match_1.Info);
--# expr-done 8693
--# property-call-start '[dispatcher]ArrayIndices.constrain_index_expr'
Fld_29 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Constrain_Index_Expr (Node => Fld_27.Node, Index_Expr => Fld_28, Dim => 0, Origin => Origin, E_Info => Fld_27.Info);
--# end
--# expr-done 8694
And_Pred_2 := Create_And (Fld_26, Fld_29, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14559") else null)); 
--# expr-done 8695
--# expr-start 8699 '<Bind at ast.py:14561>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:14561
--# expr-start 8696 '<FieldAccess for expected_type_var at ast.py:14561>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:14561
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_30 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Match_1.Node);
--# expr-done 8696
Fld_30.Value := No_Entity;
Entity_Vars.Reset (Fld_30);
--# expr-start 8698 '<FieldAccess for expected_type_var at ast.py:14561>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:14561
--# expr-start 8697 '<FieldAccess for right at ast.py:14561>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:14561
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Right, Info => Match_1.Info);
--# expr-done 8697
      if Fld_31.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_32 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_31.Node);
--# expr-done 8698
Fld_32.Value := No_Entity;
Entity_Vars.Reset (Fld_32);
Bind_Result_2 := Solver.Create_Unify (Fld_30, Fld_32, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14561") else null)); 
--# expr-done 8699
And_Pred_3 := Create_And (And_Pred_2, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14559") else null)); 
--# expr-done 8700
--# expr-start 8702 '<Bind at ast.py:14562>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:14562
--# expr-start 8701 '<FieldAccess for type_var at ast.py:14562>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:14562
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_33 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8701
Fld_33.Value := No_Entity;
Entity_Vars.Reset (Fld_33);
Cast_Expr_1 := Block_Var_1; 
      Cast_Result_5 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_3 := Solver.Create_Assign (Fld_33, Cast_Result_5, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14562") else null)); 
--# expr-done 8702
And_Pred_4 := Create_And (And_Pred_3, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14559") else null)); 
--# expr-done 8703
--# expr-start 8705 '<FieldAccess for sub_equation at ast.py:14563>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:14563
--# expr-start 8704 '<FieldAccess for left at ast.py:14563>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:14563
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_34 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Left, Info => Match_1.Info);
--# expr-done 8704
      if Fld_34.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_35 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_34.Node, Env => Env, Origin => Origin, E_Info => Fld_34.Info);
--# end
--# expr-done 8705
And_Pred_5 := Create_And (And_Pred_4, Fld_35, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14559") else null)); 
--# expr-done 8706
--# expr-start 8708 '<FieldAccess for sub_equation at ast.py:14564>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:14564
--# expr-start 8707 '<FieldAccess for right at ast.py:14564>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:14564
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_36 := Create_Internal_Entity_Expr (Node => Match_1.Node.Bin_Op_F_Right, Info => Match_1.Info);
--# expr-done 8707
      if Fld_36.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_37 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_36.Node, Env => Env, Origin => Origin, E_Info => Fld_36.Info);
--# end
--# expr-done 8708
And_Pred_6 := Create_And (And_Pred_5, Fld_37, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14559") else null)); 
--# expr-done 8709
Let_Result_1 := And_Pred_6; Inc_Ref (Let_Result_1);
--# end
Scope_Result_8 := Let_Result_1;
   Inc_Ref (Scope_Result_8);
   --# end
      Finalizer_Scope_2892;
            Match_Result := Scope_Result_8; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_11; 
--# bind ar Match_2
--# expr-start 8716 '<And at ast.py:14568>' And_Pred_8 /tmp/lal-23.0.0/ada/ast.py:14568
--# expr-start 8713 '<And at ast.py:14568>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:14568
--# expr-start 8710 '<FieldAccess for sub_equation at ast.py:14568>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:14568
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_38 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_2.Node, Env => Env, Origin => Origin, E_Info => Match_2.Info);
--# end
--# expr-done 8710
--# expr-start 8712 '<FieldAccess for constrain_index_expr at ast.py:14569>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:14569
--# expr-start 8711 '<FieldAccess for indices at ast.py:14569>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:14569
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_39 := Create_Internal_Entity_Array_Indices (Node => Block_Var.Node.Array_Type_Def_F_Indices, Info => Block_Var.Info);
--# expr-done 8711
      if Fld_39.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Cast_Expr_2 := Match_2; 
      Cast_Result_6 := Create_Internal_Entity_Expr
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
--# property-call-start '[dispatcher]ArrayIndices.constrain_index_expr'
Fld_40 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Constrain_Index_Expr (Node => Fld_39.Node, Index_Expr => Cast_Result_6, Dim => 0, Origin => Origin, E_Info => Fld_39.Info);
--# end
--# expr-done 8712
And_Pred_7 := Create_And (Fld_38, Fld_40, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14568") else null)); 
--# expr-done 8713
--# expr-start 8715 '<Bind at ast.py:14570>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:14570
--# expr-start 8714 '<FieldAccess for type_var at ast.py:14570>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:14570
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_41 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8714
Fld_41.Value := No_Entity;
Entity_Vars.Reset (Fld_41);
Cast_Expr_3 := Block_Var_1; 
      Cast_Result_7 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
Bind_Result_4 := Solver.Create_Assign (Fld_41, Cast_Result_7, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14570") else null)); 
--# expr-done 8715
And_Pred_8 := Create_And (And_Pred_7, Bind_Result_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14568") else null)); 
--# expr-done 8716
Let_Result_2 := And_Pred_8; Inc_Ref (Let_Result_2);
--# end
Scope_Result_9 := Let_Result_2;
   Inc_Ref (Scope_Result_9);
   --# end
      Finalizer_Scope_2893;
            Match_Result := Scope_Result_9; Inc_Ref (Match_Result);
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_12 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_12; 
--# bind st Match_3
--# expr-start 8720 '<And at ast.py:14574>' And_Pred_9 /tmp/lal-23.0.0/ada/ast.py:14574
--# expr-start 8717 '<FieldAccess for sub_equation at ast.py:14574>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:14574
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_42 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_3.Node, Env => Env, Origin => Origin, E_Info => Match_3.Info);
--# end
--# expr-done 8717
--# expr-start 8719 '<Bind at ast.py:14575>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:14575
--# expr-start 8718 '<FieldAccess for type_var at ast.py:14575>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:14575
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_43 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8718
Fld_43.Value := No_Entity;
Entity_Vars.Reset (Fld_43);
Cast_Expr_4 := Block_Var_1; 
      Cast_Result_8 := Create_Internal_Entity
        (Node => Cast_Expr_4.Node,
         Info => Cast_Expr_4.Info);
Bind_Result_5 := Solver.Create_Assign (Fld_43, Cast_Result_8, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14575") else null)); 
--# expr-done 8719
And_Pred_9 := Create_And (Fld_42, Bind_Result_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14574") else null)); 
--# expr-done 8720
Let_Result_3 := And_Pred_9; Inc_Ref (Let_Result_3);
--# end
Scope_Result_10 := Let_Result_3;
   Inc_Ref (Scope_Result_10);
   --# end
      Finalizer_Scope_2894;
            Match_Result := Scope_Result_10; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Base_Assoc_List | Ada_Basic_Decl_List .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Call_Expr .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_13 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_13; 
--# bind _ Match_4
False_Rel_3 := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14577") else null)); 
Let_Result_4 := False_Rel_3; Inc_Ref (Let_Result_4);
--# end
Scope_Result_11 := Let_Result_4;
   Inc_Ref (Scope_Result_11);
   --# end
      Finalizer_Scope_2895;
            Match_Result := Scope_Result_11; Inc_Ref (Match_Result);
end case;
--# expr-done 8721
   If_Result_7 := Match_Result;
else
--# expr-start 8723 '<Not at ast.py:14581>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:14581
--# expr-start 8722 '<IsNull at ast.py:14581>' Is_Null_4 /tmp/lal-23.0.0/ada/ast.py:14581
Is_Null_4 := Typ.Node = null; 
--# expr-done 8722
Not_Val_1 := not (Is_Null_4); 
--# expr-done 8723
if Not_Val_1 then
   --# expr-start 8724 '<FieldAccess for has_ud_indexing at ast.py:14581>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:14581
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.has_ud_indexing'
Fld_44 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Has_Ud_Indexing (Node => Typ.Node, E_Info => Typ.Info);
--# end
--# expr-done 8724
   If_Result_4 := Fld_44;
else
   If_Result_4 := False;
end if;
if If_Result_4 then
   --# expr-start 8746 '<LogicAny at ast.py:14583>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:14583
--# expr-start 8745 '<Map at ast.py:14583>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:14583
   --# expr-start 8727 '<Concat at ast.py:14582>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:14582
--# expr-start 8725 '<FieldAccess for constant_indexing_fns at ast.py:14582>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:14582
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.constant_indexing_fns'
Fld_45 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Constant_Indexing_Fns (Node => Typ.Node, E_Info => Typ.Info);
--# end
--# expr-done 8725
--# expr-start 8726 '<FieldAccess for variable_indexing_fns at ast.py:14582>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:14582
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.variable_indexing_fns'
Fld_46 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Variable_Indexing_Fns (Node => Typ.Node, E_Info => Typ.Info);
--# end
--# expr-done 8726
Concat_Result := Concat (Fld_45, Fld_46); 
--# expr-done 8727
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Concat_Result;
      begin
         for Item_262 of
               Collection.Items
         loop
   --# scope-start
               --# bind fn Item_262
      --# expr-start 8744 '<Let at ast.py:14583>' Let_Result_5 /tmp/lal-23.0.0/ada/ast.py:14583
--# scope-start
--# expr-start 8730 '<at at ast.py:14585>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:14585
--# expr-start 8729 '<FieldAccess for unpacked_formal_params at ast.py:14585>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:14585
--# expr-start 8728 '<FieldAccess for subp_spec_or_null at ast.py:14585>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:14585
      if Item_262.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_47 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Item_262.Node, E_Info => Item_262.Info);
--# end
--# expr-done 8728
      if Fld_47.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_48 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Fld_47.Node, E_Info => Fld_47.Info);
--# end
--# expr-done 8729
Get_Result_1 := Get (Self, Fld_48, 1, True); 
--# expr-done 8730
Formal := Get_Result_1; 
--# bind formal Formal
--# expr-start 8732 '<FieldAccess for return_type at ast.py:14586>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:14586
--# expr-start 8731 '<FieldAccess for subp_spec_or_null at ast.py:14586>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:14586
      if Item_262.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_49 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Item_262.Node, E_Info => Item_262.Info);
--# end
--# expr-done 8731
      if Fld_49.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_50 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld_49.Node, Origin => Origin, E_Info => Fld_49.Info);
--# end
--# expr-done 8732
Ret_Type := Fld_50; 
--# bind ret_type Ret_Type
--# expr-start 8734 '<FieldAccess for expr at ast.py:14587>' Fld_54 /tmp/lal-23.0.0/ada/ast.py:14587
--# expr-start 8733 '<FieldAccess for params at ast.py:14587>' Fld_51 /tmp/lal-23.0.0/ada/ast.py:14587
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_51 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8733
Fld_52 := Fld_51.Node;
Get_Result_2 := Get (Self, Fld_52, 0, True); 
Is_Null_5 := Get_Result_2 = null; 
if Is_Null_5 then
   If_Result_5 := No_Entity_Basic_Assoc;
else
Fld_53 := Fld_51.Info;
As_Entity_2 := (Info => Fld_53, Node => Get_Result_2); 
   If_Result_5 := As_Entity_2;
end if;
      if If_Result_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_54 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result_5.Node, E_Info => If_Result_5.Info);
--# end
--# expr-done 8734
Param := Fld_54; 
--# bind param Param
--# expr-start 8743 '<And at ast.py:14589>' And_Pred_11 /tmp/lal-23.0.0/ada/ast.py:14589
--# expr-start 8741 '<And at ast.py:14589>' And_Pred_10 /tmp/lal-23.0.0/ada/ast.py:14589
--# expr-start 8736 '<Bind at ast.py:14589>' Bind_Result_6 /tmp/lal-23.0.0/ada/ast.py:14589
--# expr-start 8735 '<FieldAccess for type_var at ast.py:14589>' Fld_55 /tmp/lal-23.0.0/ada/ast.py:14589
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_55 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8735
Fld_55.Value := No_Entity;
Entity_Vars.Reset (Fld_55);
Cast_Expr_5 := Ret_Type; 
      Cast_Result_14 := Create_Internal_Entity
        (Node => Cast_Expr_5.Node,
         Info => Cast_Expr_5.Info);
Bind_Result_6 := Solver.Create_Assign (Fld_55, Cast_Result_14, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14589") else null)); 
--# expr-done 8736
--# expr-start 8740 '<Bind at ast.py:14590>' Bind_Result_7 /tmp/lal-23.0.0/ada/ast.py:14590
--# expr-start 8737 '<FieldAccess for expected_type_var at ast.py:14590>' Fld_56 /tmp/lal-23.0.0/ada/ast.py:14590
      if Param.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_56 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Param.Node);
--# expr-done 8737
Fld_56.Value := No_Entity;
Entity_Vars.Reset (Fld_56);
--# expr-start 8739 '<FieldAccess for formal_type at ast.py:14590>' Fld_58 /tmp/lal-23.0.0/ada/ast.py:14590
--# expr-start 8738 '<FieldAccess for formal_decl at ast.py:14590>' Fld_57 /tmp/lal-23.0.0/ada/ast.py:14590
      if Formal.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_57 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Formal.Node, E_Info => Formal.Info);
--# end
--# expr-done 8738
      if Fld_57.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamDecl.formal_type
Fld_58 := Libadalang.Implementation.Base_Formal_Param_Decl_P_Formal_Type (Node => Fld_57.Node, Origin => Origin, E_Info => Fld_57.Info);
--# end
--# expr-done 8739
      Cast_Result_15 := Create_Internal_Entity
        (Node => Fld_58.Node,
         Info => Fld_58.Info);
Bind_Result_7 := Solver.Create_Assign (Fld_56, Cast_Result_15, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14590") else null)); 
--# expr-done 8740
And_Pred_10 := Create_And (Bind_Result_6, Bind_Result_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14589") else null)); 
--# expr-done 8741
--# expr-start 8742 '<FieldAccess for matches_expected_type at ast.py:14591>' Fld_59 /tmp/lal-23.0.0/ada/ast.py:14591
      if Param.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_59 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Param.Node, Origin => Origin);
--# end
--# expr-done 8742
And_Pred_11 := Create_And (And_Pred_10, Fld_59, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14589") else null)); 
--# expr-done 8743
Let_Result_5 := And_Pred_11; Inc_Ref (Let_Result_5);
--# end
--# expr-done 8744
         declare
            Item_To_Append : constant Logic_Equation := Let_Result_5;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2896;
         end loop;
      end;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 8745
Logic_Boolean_Op_1 := Solver.Create_Any (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14583") else null)); 
--# expr-done 8746
   If_Result_6 := Logic_Boolean_Op_1;
else
   False_Rel_4 := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14594") else null)); 
   If_Result_6 := False_Rel_4;
end if;
      Inc_Ref (If_Result_6);
   If_Result_7 := If_Result_6;
end if;
      Inc_Ref (If_Result_7);
   If_Result_8 := If_Result_7;
end if;
      Inc_Ref (If_Result_8);
--# expr-done 8747
Let_Result_6 := If_Result_8; Inc_Ref (Let_Result_6);
--# end
--# expr-done 8748
      Property_Result := Let_Result_6;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1068;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1068;
               Finalizer_Scope_2885;
               Finalizer_Scope_2887;
               Finalizer_Scope_2889;
               Finalizer_Scope_2890;
               Finalizer_Scope_2891;
               Finalizer_Scope_2892;
               Finalizer_Scope_2893;
               Finalizer_Scope_2894;
               Finalizer_Scope_2895;
               Finalizer_Scope_2896;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Subscriptable_Type_Equation;
--# end
--# property-start CallExpr.subprogram_equation /tmp/lal-23.0.0/ada/ast.py:14598
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Subprogram_Equation
  (Node : Bare_Call_Expr
      ; Subp_Spec : Internal_Entity_Base_Formal_Param_Holder
      ; Dottable_Subp : Boolean
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind subp_spec Subp_Spec
   --# bind dottable_subp Dottable_Subp
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1069 with Inline_Always;
            procedure Finalizer_Scope_2897 with Inline_Always;
            procedure Finalizer_Scope_2899 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Formal_Param_Holder;
Var_Expr_1 : Internal_Entity_Base_Subp_Spec;
N : Internal_Entity_Base_Formal_Param_Decl;
Fld : Logic_Var;
Cast_Expr : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Formal_Param_Holder;
Cast_Result_2 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_3 : Internal_Entity_Assoc_List;
Fld_4 : Internal_Param_Match_Array_Access;
Fld_5 : Internal_Entity_Defining_Name;
Fld_6 : Internal_Entity_Base_Formal_Param_Decl;
Fld_7 : Internal_Single_Actual;
Fld_8 : Internal_Entity_Basic_Assoc;
Fld_9 : Internal_Entity_Expr;
Fld_10 : Logic_Equation;
True_Rel : Logic_Equation;
Fld_11 : Internal_Single_Actual;
Fld_12 : Bare_Base_Id;
Fld_13 : Logic_Var;
Fld_14 : Internal_Entity_Defining_Name;
Fld_15 : Internal_Entity_Base_Formal_Param_Decl;
Fld_16 : Bare_Base_Formal_Param_Decl;
Cast_Result_3 : Bare_Ada_Node;
Fld_17 : Internal_Entity_Info;
Fld_18 : Env_Rebindings;
Fld_19 : Internal_Entity_Info;
Fld_20 : Boolean;
Fld_21 : Internal_Entity;
Let_Result : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Fld_22 : Internal_Single_Actual;
Fld_23 : Bare_Base_Id;
Is_Null : Boolean;
If_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
False_Rel : Logic_Equation;
Fld_24 : Boolean;
If_Result_1 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_2 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
False_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
Let_Result_1 : Logic_Equation;
            procedure Finalizer_Scope_1069 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (False_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_1069;
            procedure Finalizer_Scope_2897 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_2897;
            procedure Finalizer_Scope_2899 is
            begin
                     Dec_Ref (Fld_10);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result_1);
            end Finalizer_Scope_2899;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8787 '<Block at ???>' Let_Result_1 None
--# scope-start
Var_Expr := Subp_Spec;
if Var_Expr /= No_Entity_Base_Formal_Param_Holder then
   --# scope-start
   --# bind subp_spec Var_Expr
--# expr-start 8786 '<And at ast.py:14604>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:14604
--# expr-start 8755 '<And at ast.py:14604>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14604
--# expr-start 8752 '<Bind at ast.py:14604>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14604
--# expr-start 8749 '<FieldAccess for type_var at ast.py:14604>' Fld /tmp/lal-23.0.0/ada/ast.py:14604
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 8749
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 8750 '<Cast to BaseSubpSpec at ast.py:14604>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14604
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Subp_Spec
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Spec
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Subp_Spec;
   end if;
--# expr-done 8750
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Base_Subp_Spec then
   --# scope-start
--# expr-start 8751 '<FieldAccess for return_type at ast.py:14604>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14604
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Var_Expr_1.Node, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8751
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
      Cast_Result_1 := Create_Internal_Entity
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14604") else null)); 
--# expr-done 8752
--# expr-start 8754 '<Bind at ast.py:14608>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14608
--# expr-start 8753 '<FieldAccess for subp_spec_var at ast.py:14608>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14608
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Self);
--# end
--# expr-done 8753
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Cast_Expr_1 := Var_Expr; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_2, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14608") else null)); 
--# expr-done 8754
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14604") else null)); 
--# expr-done 8755
--# expr-start 8785 '<LogicAll at ast.py:14614>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:14614
--# expr-start 8784 '<Map at ast.py:14614>' Map_Result /tmp/lal-23.0.0/ada/ast.py:14614
   --# expr-start 8757 '<FieldAccess for match_param_list at ast.py:14612>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14612
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8756 '<FieldAccess for params at ast.py:14613>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14613
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_3 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8756
--# property-call-start BaseFormalParamHolder.match_param_list
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Param_List (Node => Var_Expr.Node, Params => Fld_3, Is_Dottable_Subp => Dottable_Subp, Env => Env, E_Info => Var_Expr.Info);
--# end
--# expr-done 8757
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Param_Match_Array_Access := Fld_4;
      begin
         for Item_263 of
               Collection.Items
         loop
   --# scope-start
               --# bind pm Item_263
      --# expr-start 8783 '<If at ast.py:14615>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:14615
--# expr-start 8758 '<FieldAccess for has_matched at ast.py:14616>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:14616
Fld_24 := Item_263.Has_Matched;
--# expr-done 8758
if Fld_24 then
   --# expr-start 8782 '<And at ast.py:14617>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:14617
--# expr-start 8764 '<FieldAccess for call_argument_equation at ast.py:14617>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14617
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8760 '<FieldAccess for formal_decl at ast.py:14618>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14618
--# expr-start 8759 '<FieldAccess for formal at ast.py:14618>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14618
Fld_5 := Item_263.Formal;
--# expr-done 8759
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_6 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_5.Node, E_Info => Fld_5.Info);
--# end
--# expr-done 8760
--# expr-start 8763 '<FieldAccess for expr at ast.py:14619>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14619
--# expr-start 8762 '<FieldAccess for assoc at ast.py:14619>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14619
--# expr-start 8761 '<FieldAccess for actual at ast.py:14619>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14619
Fld_7 := Item_263.Actual;
--# expr-done 8761
Fld_8 := Fld_7.Assoc;
--# expr-done 8762
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_9 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_8.Node, E_Info => Fld_8.Info);
--# end
--# expr-done 8763
--# property-call-start BaseFormalParamHolder.call_argument_equation
Fld_10 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Call_Argument_Equation (Node => Var_Expr.Node, Param => Fld_6, Arg => Fld_9, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8764
--# expr-start 8781 '<If at ast.py:14620>' If_Result /tmp/lal-23.0.0/ada/ast.py:14620
--# expr-start 8767 '<IsNull at ast.py:14623>' Is_Null /tmp/lal-23.0.0/ada/ast.py:14623
--# expr-start 8766 '<FieldAccess for name at ast.py:14623>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:14623
--# expr-start 8765 '<FieldAccess for actual at ast.py:14623>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:14623
Fld_22 := Item_263.Actual;
--# expr-done 8765
Fld_23 := Fld_22.Name;
--# expr-done 8766
Is_Null := Fld_23 = null; 
--# expr-done 8767
if Is_Null then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14624") else null)); 
   If_Result := True_Rel;
else
   --# expr-start 8780 '<Bind at ast.py:14625>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:14625
--# expr-start 8770 '<FieldAccess for ref_var at ast.py:14626>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14626
--# expr-start 8769 '<FieldAccess for name at ast.py:14626>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14626
--# expr-start 8768 '<FieldAccess for actual at ast.py:14626>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14626
Fld_11 := Item_263.Actual;
--# expr-done 8768
Fld_12 := Fld_11.Name;
--# expr-done 8769
      if Fld_12 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_13 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_12);
--# end
--# expr-done 8770
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
--# expr-start 8779 '<Let at ast.py:14627>' Let_Result /tmp/lal-23.0.0/ada/ast.py:14627
--# scope-start
--# expr-start 8772 '<FieldAccess for formal_decl at ast.py:14627>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14627
--# expr-start 8771 '<FieldAccess for formal at ast.py:14627>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14627
Fld_14 := Item_263.Formal;
--# expr-done 8771
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_15 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Fld_14.Node, E_Info => Fld_14.Info);
--# end
--# expr-done 8772
N := Fld_15; 
--# bind n N
--# expr-start 8778 '<FieldAccess for entity_no_md at ast.py:14628>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:14628
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8773 '<FieldAccess for node at ast.py:14629>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14629
Fld_16 := N.Node;
--# expr-done 8773
      Cast_Result_3 := Fld_16;
--# expr-start 8775 '<FieldAccess for rebindings at ast.py:14630>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14630
--# expr-start 8774 '<FieldAccess for info at ast.py:14630>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14630
Fld_17 := N.Info;
--# expr-done 8774
Fld_18 := Fld_17.Rebindings;
--# expr-done 8775
--# expr-start 8777 '<FieldAccess for from_rebound at ast.py:14631>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:14631
--# expr-start 8776 '<FieldAccess for info at ast.py:14631>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:14631
Fld_19 := N.Info;
--# expr-done 8776
Fld_20 := Fld_19.From_Rebound;
--# expr-done 8777
--# property-call-start AdaNode.entity_no_md
Fld_21 := Libadalang.Implementation.Ada_Node_P_Entity_No_Md (Node => Ent.Node, N => Cast_Result_3, Rebindings => Fld_18, From_Rebound => Fld_20);
--# end
--# expr-done 8778
Let_Result := Fld_21; 
--# end
--# expr-done 8779
Bind_Result_2 := Solver.Create_Assign (Fld_13, Let_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14625") else null)); 
--# expr-done 8780
   If_Result := Bind_Result_2;
end if;
      Inc_Ref (If_Result);
--# expr-done 8781
And_Pred_1 := Create_And (Fld_10, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14617") else null)); 
--# expr-done 8782
   If_Result_1 := And_Pred_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14635") else null)); 
   If_Result_1 := False_Rel;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 8783
         declare
            Item_To_Append : constant Logic_Equation := If_Result_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2899;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8784
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14614") else null)); 
--# expr-done 8785
And_Pred_2 := Create_And (And_Pred, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14604") else null)); 
--# expr-done 8786
Scope_Result_1 := And_Pred_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2897;
   Result_Var_1 := Scope_Result_1;
else
   False_Rel_1 := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14638") else null)); 
   Result_Var_1 := False_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
Let_Result_1 := Result_Var_1; Inc_Ref (Let_Result_1);
--# end
--# expr-done 8787
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1069;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1069;
               Finalizer_Scope_2897;
               Finalizer_Scope_2899;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Subprogram_Equation;
--# end
--# property-start CallExpr.check_for_type /tmp/lal-23.0.0/ada/ast.py:14642
pragma Warnings (Off, "is not referenced");
 function Call_Expr_P_Check_For_Type
  (Node : Bare_Call_Expr
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Call_Expr := Bare_Call_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Expr :=
     Internal_Entity_Call_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind env Env
   --# bind origin Origin
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Array_Type_Def;
Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Array_Type_Def;
Match_0 : Bare_Assoc_List;
Match_1 : Bare_Bin_Op;
Match_2 : Bare_Subtype_Indication;
Match_3 : Bare_Attribute_Ref;
Match_4 : Bare_Ada_Node;
Var_Expr_3 : Internal_Entity_Access_To_Subp_Def;
Var_Expr_4 : Bare_Assoc_List;
Var_Expr_5 : Internal_Entity_Call_Expr;
Fld : Internal_Entity_Array_Type_Def;
Scope_Result : Internal_Entity_Array_Type_Def;
Result_Var : Internal_Entity_Array_Type_Def;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Bare_Ada_Node;
Fld_3 : Integer;
Len : Integer;
Is_Equal : Boolean;
Fld_4 : Integer;
Is_Equal_1 : Boolean;
Fld_5 : Integer;
Is_Equal_2 : Boolean;
Fld_6 : Integer;
Is_Equal_3 : Boolean;
Match_Prefix : Bare_Ada_Node;
Cast_Result : Bare_Assoc_List;
Let_Result : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_1 : Bare_Bin_Op;
Let_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Cast_Result_2 : Bare_Subtype_Indication;
Let_Result_2 : Boolean;
Scope_Result_3 : Boolean;
Cast_Result_3 : Bare_Attribute_Ref;
Let_Result_3 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_4 : Bare_Ada_Node;
Let_Result_4 : Boolean;
Scope_Result_5 : Boolean;
Match_Result : Boolean;
Scope_Result_6 : Boolean;
Result_Var_1 : Boolean;
Fld_7 : Internal_Entity_Access_Def;
Cast_Result_5 : Internal_Entity_Access_To_Subp_Def;
Fld_8 : Internal_Entity_Subp_Spec;
Fld_9 : Internal_Entity_Assoc_List;
Fld_10 : Boolean;
Scope_Result_7 : Boolean;
Result_Var_2 : Boolean;
If_Result : Boolean;
Fld_11 : Boolean;
Fld_12 : Bare_Ada_Node;
Cast_Result_6 : Bare_Assoc_List;
Len_1 : Integer;
Is_Equal_4 : Boolean;
Scope_Result_8 : Boolean;
Result_Var_3 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Fld_13 : Internal_Entity;
Cast_Result_7 : Internal_Entity_Call_Expr;
Fld_14 : Internal_Entity_Base_Type_Decl;
Fld_15 : Internal_Entity_Base_Type_Decl;
Fld_16 : Boolean;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Fld_17 : Boolean;
If_Result_4 : Internal_Entity_Base_Type_Decl;
Fld_18 : Boolean;
Scope_Result_9 : Boolean;
Result_Var_4 : Boolean;
If_Result_5 : Boolean;
Scope_Result_10 : Boolean;
Result_Var_5 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result_5 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8821 '<Block at ???>' Let_Result_5 None
--# scope-start
Var_Expr := Typ;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 8788 '<FieldAccess for array_def_with_deref at ast.py:14653>' Fld /tmp/lal-23.0.0/ada/ast.py:14653
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.array_def_with_deref
Fld := Libadalang.Implementation.Base_Type_Decl_P_Array_Def_With_Deref (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 8788
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Array_Type_Def;
end if;
Block_Var := Result_Var; 
--# bind atd Block_Var
--# expr-start 8820 '<bind at ast.py:14655>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:14655
--# expr-start 8789 '<FieldAccess for origin_node at ast.py:14655>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14655
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 8789
Bound_Origin := Fld_1; 
Var_Expr_1 := Typ;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr_1
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Entity_Array_Type_Def then
   --# scope-start
   --# bind _ Var_Expr_2
--# expr-start 8800 '<Match at ast.py:14658>' Match_Result /tmp/lal-23.0.0/ada/ast.py:14658
--# expr-start 8790 '<FieldAccess for suffix at ast.py:14658>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14658
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Call_Expr_F_Suffix;
--# expr-done 8790
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_2; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Assoc_List =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind al Match_0
--# expr-start 8793 '<Eq at ast.py:14660>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:14660
--# expr-start 8791 '<FieldAccess for array_ndims at ast.py:14660>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14660
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_3 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Block_Var.Node, Origin => Bound_Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 8791
--# expr-start 8792 '<length at ast.py:14660>' Len /tmp/lal-23.0.0/ada/ast.py:14660
Len := Length (Match_0); 
--# expr-done 8792
Is_Equal := Fld_3 = Len; 
--# expr-done 8793
Let_Result := Is_Equal; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind _ Match_1
--# expr-start 8795 '<Eq at ast.py:14663>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:14663
--# expr-start 8794 '<FieldAccess for array_ndims at ast.py:14663>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14663
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_4 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Block_Var.Node, Origin => Bound_Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 8794
Is_Equal_1 := Fld_4 = 1; 
--# expr-done 8795
Let_Result_1 := Is_Equal_1; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
--# expr-start 8797 '<Eq at ast.py:14664>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:14664
--# expr-start 8796 '<FieldAccess for array_ndims at ast.py:14664>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14664
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_5 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Block_Var.Node, Origin => Bound_Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 8796
Is_Equal_2 := Fld_5 = 1; 
--# expr-done 8797
Let_Result_2 := Is_Equal_2; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_3 := Cast_Result_3; 
--# bind _ Match_3
--# expr-start 8799 '<Eq at ast.py:14665>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:14665
--# expr-start 8798 '<FieldAccess for array_ndims at ast.py:14665>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14665
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.array_ndims'
Fld_6 := Libadalang.Implementation.Dispatcher_Type_Def_P_Array_Ndims (Node => Block_Var.Node, Origin => Bound_Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 8798
Is_Equal_3 := Fld_6 = 1; 
--# expr-done 8799
Let_Result_3 := Is_Equal_3; 
--# end
Scope_Result_4 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Abort_Absent .. Ada_Base_Assoc_List | Ada_Basic_Decl_List .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Call_Expr .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix;
Match_4 := Cast_Result_4; 
--# bind _ Match_4
Let_Result_4 := False; 
--# end
Scope_Result_5 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_5; 
end case;
--# expr-done 8800
Scope_Result_6 := Match_Result;
   --# end
   Result_Var_1 := Scope_Result_6;
else
   Result_Var_1 := False;
end if;
if Result_Var_1 then
   If_Result := True;
else
--# expr-start 8802 '<Cast to AccessToSubpDef at ast.py:14671>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:14671
--# expr-start 8801 '<FieldAccess for access_def at ast.py:14671>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14671
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8801
   if Fld_7.Node = null
      or else Fld_7.Node.Kind in Ada_Access_To_Subp_Def_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Access_To_Subp_Def
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
   else
         Cast_Result_5 := No_Entity_Access_To_Subp_Def;
   end if;
--# expr-done 8802
Var_Expr_3 := Cast_Result_5;
if Var_Expr_3 /= No_Entity_Access_To_Subp_Def then
   --# scope-start
   --# bind sa Var_Expr_3
--# expr-start 8805 '<FieldAccess for is_matching_param_list at ast.py:14673>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:14673
--# expr-start 8803 '<FieldAccess for subp_spec at ast.py:14673>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:14673
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr_3.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Var_Expr_3.Info);
--# expr-done 8803
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8804 '<FieldAccess for params at ast.py:14673>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:14673
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_9 := Libadalang.Implementation.Call_Expr_P_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8804
--# property-call-start BaseFormalParamHolder.is_matching_param_list
Fld_10 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Is_Matching_Param_List (Node => Fld_8.Node, Params => Fld_9, Is_Dottable_Subp => False, Env => Env);
--# end
--# expr-done 8805
Scope_Result_7 := Fld_10;
   --# end
   Result_Var_2 := Scope_Result_7;
else
   Result_Var_2 := False;
end if;
   If_Result := Result_Var_2;
end if;
if If_Result then
   If_Result_2 := True;
else
--# expr-start 8806 '<FieldAccess for has_ud_indexing at ast.py:14677>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:14677
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.has_ud_indexing'
Fld_11 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Has_Ud_Indexing (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8806
if Fld_11 then
--# expr-start 8808 '<Cast to AssocList at ast.py:14678>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:14678
--# expr-start 8807 '<FieldAccess for suffix at ast.py:14678>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:14678
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Self.Call_Expr_F_Suffix;
--# expr-done 8807
   if Fld_12 = null
      or else Fld_12.Kind in Ada_Assoc_List_Range
   then
      Cast_Result_6 := Fld_12;
   else
         Cast_Result_6 := No_Bare_Ada_Node;
   end if;
--# expr-done 8808
Var_Expr_4 := Cast_Result_6;
if Var_Expr_4 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind al Var_Expr_4
--# expr-start 8810 '<Eq at ast.py:14678>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:14678
--# expr-start 8809 '<length at ast.py:14678>' Len_1 /tmp/lal-23.0.0/ada/ast.py:14678
Len_1 := Length (Var_Expr_4); 
--# expr-done 8809
Is_Equal_4 := Len_1 = 1; 
--# expr-done 8810
Scope_Result_8 := Is_Equal_4;
   --# end
   Result_Var_3 := Scope_Result_8;
else
   Result_Var_3 := False;
end if;
   If_Result_1 := Result_Var_3;
else
   If_Result_1 := False;
end if;
   If_Result_2 := If_Result_1;
end if;
if If_Result_2 then
--# expr-start 8812 '<Cast to CallExpr at ast.py:14681>' Cast_Result_7 /tmp/lal-23.0.0/ada/ast.py:14681
--# expr-start 8811 '<parent at ast.py:14681>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:14681
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 8811
   if Fld_13.Node = null
      or else Fld_13.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_7 := Create_Internal_Entity_Call_Expr
        (Node => Fld_13.Node,
         Info => Fld_13.Info);
   else
         Cast_Result_7 := No_Entity_Call_Expr;
   end if;
--# expr-done 8812
Var_Expr_5 := Cast_Result_7;
if Var_Expr_5 /= No_Entity_Call_Expr then
   --# scope-start
   --# bind ce Var_Expr_5
--# expr-start 8819 '<FieldAccess for check_for_type at ast.py:14687>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:14687
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8818 '<If at ast.py:14687>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:14687
--# expr-start 8813 '<FieldAccess for check_array_slice at ast.py:14688>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:14688
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.check_array_slice
Fld_17 := Libadalang.Implementation.Call_Expr_P_Check_Array_Slice (Node => Ent.Node, Typ => Var_Expr_1, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 8813
if Fld_17 then
   If_Result_4 := Var_Expr_1;
else
   --# expr-start 8817 '<If at ast.py:14690>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:14690
--# expr-start 8814 '<FieldAccess for is_iterable_type at ast.py:14692>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:14692
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_16 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8814
if Fld_16 then
   --# expr-start 8815 '<FieldAccess for iterable_comp_type at ast.py:14693>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:14693
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_14 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8815
   If_Result_3 := Fld_14;
else
   --# expr-start 8816 '<FieldAccess for comp_type at ast.py:14694>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:14694
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.comp_type
Fld_15 := Libadalang.Implementation.Base_Type_Decl_P_Comp_Type (Node => Var_Expr_1.Node, Is_Subscript => True, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8816
   If_Result_3 := Fld_15;
end if;
--# expr-done 8817
   If_Result_4 := If_Result_3;
end if;
--# expr-done 8818
--# property-call-start CallExpr.check_for_type
Fld_18 := Libadalang.Implementation.Call_Expr_P_Check_For_Type (Node => Var_Expr_5.Node, Typ => If_Result_4, Env => Env, Origin => Bound_Origin, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 8819
Scope_Result_9 := Fld_18;
   --# end
   Result_Var_4 := Scope_Result_9;
else
   Result_Var_4 := True;
end if;
   If_Result_5 := Result_Var_4;
else
   If_Result_5 := False;
end if;
Scope_Result_10 := If_Result_5;
   --# end
   Result_Var_5 := Scope_Result_10;
else
   Result_Var_5 := False;
end if;
Dyn_Var_Bind_Result := Result_Var_5; 
--# expr-done 8820
Let_Result_5 := Dyn_Var_Bind_Result; 
--# end
--# expr-done 8821
      Property_Result := Let_Result_5;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Expr_P_Check_For_Type;
--# end
   --
   --  Primitives for Bare_Defining_Name
   --
      procedure Initialize_Fields_For_Defining_Name
        (Self : Bare_Defining_Name
         ; Defining_Name_F_Name : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Defining_Name_F_Name := Defining_Name_F_Name;
      end Initialize_Fields_For_Defining_Name;
   function Defining_Name_F_Name
     (Node : Bare_Defining_Name) return Bare_Name
   is
   begin
         return Node.Defining_Name_F_Name;
   end;
--# property-start DefiningName.parent_scope /tmp/lal-23.0.0/ada/ast.py:15615
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Parent_Scope
  (Node : Bare_Defining_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1125 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1125 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1125;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8823 '<FieldAccess for parent_scope at ast.py:15615>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15615
--# expr-start 8822 '<FieldAccess for name at ast.py:15615>' Fld /tmp/lal-23.0.0/ada/ast.py:15615
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Defining_Name_F_Name;
--# expr-done 8822
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.parent_scope'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Parent_Scope (Node => Fld, Env => Env);
--# end
--# expr-done 8823
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1125;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1125;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Parent_Scope;
--# end
--# property-start DefiningName.scope /tmp/lal-23.0.0/ada/ast.py:15616
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Scope
  (Node : Bare_Defining_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1126 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1126 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1126;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8825 '<FieldAccess for scope at ast.py:15616>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15616
--# expr-start 8824 '<FieldAccess for name at ast.py:15616>' Fld /tmp/lal-23.0.0/ada/ast.py:15616
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Defining_Name_F_Name;
--# expr-done 8824
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.scope'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Scope (Node => Fld, Env => Env);
--# end
--# expr-done 8825
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1126;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1126;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Scope;
--# end
--# property-start DefiningName.relative_name /tmp/lal-23.0.0/ada/ast.py:15617
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Relative_Name
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8827 '<FieldAccess for relative_name at ast.py:15617>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15617
--# expr-start 8826 '<FieldAccess for name at ast.py:15617>' Fld /tmp/lal-23.0.0/ada/ast.py:15617
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Defining_Name_F_Name, Info => Ent.Info);
--# expr-done 8826
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 8827
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Relative_Name;
--# end
--# property-start DefiningName.ref_var /tmp/lal-23.0.0/ada/ast.py:15618
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Ref_Var
  (Node : Bare_Defining_Name
  )
   return Logic_Var
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8829 '<FieldAccess for ref_var at ast.py:15618>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15618
--# expr-start 8828 '<FieldAccess for name at ast.py:15618>' Fld /tmp/lal-23.0.0/ada/ast.py:15618
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Defining_Name_F_Name;
--# expr-done 8828
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 8829
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Ref_Var;
--# end
--# property-start DefiningName.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:15619
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Env_Elements_Impl
  (Node : Bare_Defining_Name
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1129 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1129 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1129;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8831 '<FieldAccess for env_elements_impl at ast.py:15619>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15619
--# expr-start 8830 '<FieldAccess for name at ast.py:15619>' Fld /tmp/lal-23.0.0/ada/ast.py:15619
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Defining_Name_F_Name, Info => Ent.Info);
--# expr-done 8830
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Fld.Node, Env => Env, E_Info => Fld.Info);
--# end
--# expr-done 8831
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1129;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1129;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Env_Elements_Impl;
--# end
--# property-start DefiningName.formal_decl /tmp/lal-23.0.0/ada/ast.py:15622
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Formal_Decl
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Decl;
            procedure Finalizer_Scope_1130 with Inline_Always;
      Fld : Internal_Entity_Array_Access;
Is_A : Boolean;
Find_Result : Internal_Entity;
Cast_Result : Internal_Entity_Base_Formal_Param_Decl;
Let_Result : Internal_Entity_Base_Formal_Param_Decl;
            procedure Finalizer_Scope_1130 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1130;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 8836 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8835 '<Cast to BaseFormalParamDecl at ast.py:15629>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15629
--# expr-start 8834 '<Find at ast.py:15627>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15627
   --# expr-start 8832 '<FieldAccess for parents at ast.py:15627>' Fld /tmp/lal-23.0.0/ada/ast.py:15627
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parents (Node => Ent.Node, With_Self => True, E_Info => Ent.Info);
--# expr-done 8832
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_264 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_264
      --# expr-start 8833 '<IsA BaseFormalParamDecl at ast.py:15628>' Is_A /tmp/lal-23.0.0/ada/ast.py:15628
Is_A := Item_264.Node /= null 
and then Item_264.Node.Kind in Ada_Base_Formal_Param_Decl; 
--# expr-done 8833
      if Is_A then
         Find_Result := Item_264;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 8834
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Base_Formal_Param_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Formal_Param_Decl
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8835
Let_Result := Cast_Result; 
--# end
--# expr-done 8836
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1130;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1130;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Formal_Decl;
--# end
--# property-start DefiningName.canonical_fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:15632
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Canonical_Fully_Qualified_Name
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_1131 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_1131 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1131;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8839 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8838 '<FieldAccess for canonical_fully_qualified_name_impl at ast.py:15637>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15637
--# expr-start 8837 '<FieldAccess for basic_decl at ast.py:15637>' Fld /tmp/lal-23.0.0/ada/ast.py:15637
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8837
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_fully_qualified_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Fully_Qualified_Name_Impl (Node => Fld.Node, Dn => Ent, E_Info => Fld.Info);
--# end
--# expr-done 8838
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8839
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1131;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1131;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Canonical_Fully_Qualified_Name;
--# end
--# property-start DefiningName.unique_identifying_name /tmp/lal-23.0.0/ada/ast.py:15640
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Unique_Identifying_Name
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_1132 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_1132 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1132;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8842 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8841 '<FieldAccess for unique_identifying_name_impl at ast.py:15651>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15651
--# expr-start 8840 '<FieldAccess for basic_decl at ast.py:15651>' Fld /tmp/lal-23.0.0/ada/ast.py:15651
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8840
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.unique_identifying_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Unique_Identifying_Name_Impl (Node => Fld.Node, Dn => Ent, E_Info => Fld.Info);
--# end
--# expr-done 8841
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8842
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1132;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1132;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Unique_Identifying_Name;
--# end
--# property-start DefiningName.fully_qualified_name_array /tmp/lal-23.0.0/ada/ast.py:15654
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Fully_Qualified_Name_Array
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1133 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : String_Type_Array_Access;
Sym : Symbol_Type;
Map_Result : Symbol_Type_Array_Access;
Let_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1133 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1133;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8847 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8846 '<Map at ast.py:15661>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15661
   --# expr-start 8844 '<FieldAccess for fully_qualified_name_impl at ast.py:15659>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15659
--# expr-start 8843 '<FieldAccess for basic_decl at ast.py:15659>' Fld /tmp/lal-23.0.0/ada/ast.py:15659
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8843
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Impl (Node => Fld.Node, Dn => Ent, E_Info => Fld.Info);
--# end
--# expr-done 8844
      declare
         Map_Result_Vec : Symbol_Type_Vectors.Vector;
      begin
      declare
         Collection : constant String_Type_Array_Access := Fld_1;
      begin
         for Item_265 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_265
      --# expr-start 8845 '<to_symbol at ast.py:15661>' Sym /tmp/lal-23.0.0/ada/ast.py:15661
Sym := String_To_Symbol (Self, Self.Unit.Context, Item_265); 
--# expr-done 8845
         declare
            Item_To_Append : constant Symbol_Type := Sym;
         begin
            Symbol_Type_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Symbol_Type_Array
           (Items_Count => Natural (Symbol_Type_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Symbol_Type_Vectors.Get
              (Map_Result_Vec,
               I + Symbol_Type_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Symbol_Type_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8846
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8847
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1133;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1133;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Fully_Qualified_Name_Array;
--# end
--# property-start DefiningName.fully_qualified_name /tmp/lal-23.0.0/ada/ast.py:15664
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Fully_Qualified_Name
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_1134 with Inline_Always;
      Str : String_Type;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : String_Type_Array_Access;
Join_Result : String_Type;
Let_Result : String_Type;
            procedure Finalizer_Scope_1134 is
            begin
                     Dec_Ref (Str);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Join_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1134;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8852 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8851 '<Join at ast.py:15668>' Join_Result /tmp/lal-23.0.0/ada/ast.py:15668
--# expr-start 8848 '<String at ast.py:15668>' Str /tmp/lal-23.0.0/ada/ast.py:15668
Str := Create_String ("."); 
--# expr-done 8848
--# expr-start 8850 '<FieldAccess for fully_qualified_name_impl at ast.py:15669>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15669
--# expr-start 8849 '<FieldAccess for basic_decl at ast.py:15669>' Fld /tmp/lal-23.0.0/ada/ast.py:15669
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8849
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.fully_qualified_name_impl
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Fully_Qualified_Name_Impl (Node => Fld.Node, Dn => Ent, E_Info => Fld.Info);
--# end
--# expr-done 8850
Join_Result := Join_Strings (Str, Fld_1); 
--# expr-done 8851
Let_Result := Join_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8852
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1134;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1134;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Fully_Qualified_Name;
--# end
--# property-start DefiningName.all_env_els_impl /tmp/lal-23.0.0/ada/ast.py:15673
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_All_Env_Els_Impl
  (Node : Bare_Defining_Name
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind seq Seq
   --# bind seq_from Seq_From
   --# bind categories Categories
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1135 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1135 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1135;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8855 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8854 '<FieldAccess for all_env_els_impl at ast.py:15678>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15678
--# expr-start 8853 '<FieldAccess for name at ast.py:15678>' Fld /tmp/lal-23.0.0/ada/ast.py:15678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Defining_Name_F_Name, Info => Ent.Info);
--# expr-done 8853
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.all_env_els_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_All_Env_Els_Impl (Node => Fld.Node, Seq => Seq, Seq_From => Seq_From, Categories => Categories, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 8854
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8855
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1135;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1135;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_All_Env_Els_Impl;
--# end
--# property-start DefiningName.basic_decl /tmp/lal-23.0.0/ada/ast.py:15680
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Basic_Decl
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_1136 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_1136 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_1136;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Defining_Name_Defining_Name_P_Basic_Decl,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Defining_Name,
                                As_Bare_Defining_Name => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 8860 '<as_entity at ast.py:15682>' If_Result /tmp/lal-23.0.0/ada/ast.py:15682
--# expr-start 8859 '<Cast to BasicDecl at ast.py:15682>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15682
--# expr-start 8858 '<Find at ast.py:15681>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15681
   --# expr-start 8856 '<FieldAccess for parents at ast.py:15681>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:15681
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 8856
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_266 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_266
      --# expr-start 8857 '<IsA BasicDecl at ast.py:15681>' Is_A /tmp/lal-23.0.0/ada/ast.py:15681
Is_A := Item_266 /= null 
and then Item_266.Kind in Ada_Basic_Decl; 
--# expr-done 8857
      if Is_A then
         Find_Result := Item_266;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 8858
   if Find_Result = null
      or else Find_Result.Kind in Ada_Basic_Decl
   then
      Cast_Result := Find_Result;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8859
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 8860
      Property_Result := If_Result;
   --# end
      Finalizer_Scope_1136;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl,
                        As_Internal_Entity_Basic_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1136;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Basic_Decl;
--# end
--# property-start DefiningName.basic_decl_no_internal /tmp/lal-23.0.0/ada/ast.py:15687
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Basic_Decl_No_Internal
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Is_A : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 8861 '<FieldAccess for basic_decl at ast.py:15688>' Fld /tmp/lal-23.0.0/ada/ast.py:15688
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8861
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr
--# expr-start 8865 '<If at ast.py:15689>' If_Result /tmp/lal-23.0.0/ada/ast.py:15689
--# expr-start 8862 '<IsA GenericPackageInternal, GenericSubpInternal, SingleTaskTypeDecl at ast.py:15690>' Is_A /tmp/lal-23.0.0/ada/ast.py:15690
Is_A := Var_Expr.Node /= null 
and then Var_Expr.Node.Kind in Ada_Generic_Package_Internal_Range | Ada_Generic_Subp_Internal_Range | Ada_Single_Task_Type_Decl_Range; 
--# expr-done 8862
if Is_A then
   --# expr-start 8864 '<Cast to BasicDecl at ast.py:15692>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15692
--# expr-start 8863 '<parent at ast.py:15692>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15692
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Parent (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# expr-done 8863
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8864
   If_Result := Cast_Result;
else
   If_Result := Var_Expr;
end if;
--# expr-done 8865
Scope_Result := If_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
      Property_Result := Result_Var;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Basic_Decl_No_Internal;
--# end
--# property-start DefiningName.find_refs /tmp/lal-23.0.0/ada/ast.py:15702
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Find_Refs
  (Node : Bare_Defining_Name
      ; Root : Internal_Entity
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Ref_Result_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1139 with Inline_Always;
      Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Ref_Result_Array_Access;
Let_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1139 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1139;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8868 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8867 '<FieldAccess for find_refs_impl at ast.py:15707>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15707
--# expr-start 8866 '<FieldAccess for canonical_part at ast.py:15707>' Fld /tmp/lal-23.0.0/ada/ast.py:15707
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.canonical_part
Fld := Libadalang.Implementation.Defining_Name_P_Canonical_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8866
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.find_refs_impl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Find_Refs_Impl (Node => Fld.Node, Root => Root, Skip_Name => Self, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 8867
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8868
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1139;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1139;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Find_Refs;
--# end
--# property-start DefiningName.find_refs_impl /tmp/lal-23.0.0/ada/ast.py:15711
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Find_Refs_Impl
  (Node : Bare_Defining_Name
      ; Root : Internal_Entity
      ; Skip_Name : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Ref_Result_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind skip_name Skip_Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1140 with Inline_Always;
            procedure Finalizer_Scope_2916 with Inline_Always;
            procedure Finalizer_Scope_2918 with Inline_Always;
            procedure Finalizer_Scope_2919 with Inline_Always;
            procedure Finalizer_Scope_2920 with Inline_Always;
      Var_Expr : Internal_Entity_Array_Access;
Var_Expr_1 : Internal_Entity_Base_Id;
Var_Expr_2 : Ref_Result_Kind;
Fld : Internal_Entity_Array_Access;
Is_Null : Boolean;
Fld_1 : Bare_Ada_Node;
Cast_Expr : Bare_Defining_Name;
Cast_Result : Bare_Ada_Node;
Is_Equal : Boolean;
If_Result : Boolean;
Not_Val : Boolean;
Map_Result : Internal_Entity_Array_Access;
Fld_2 : Internal_Ref_Result_Array_Access;
Map_Result_1 : Internal_Ref_Result_Array_Access;
Scope_Result : Internal_Ref_Result_Array_Access;
Result_Var : Internal_Ref_Result_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Id;
Fld_3 : Ref_Result_Kind;
New_Struct : Internal_Ref_Result;
Singleton : Internal_Ref_Result_Array_Access;
Is_Equal_1 : Boolean;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Internal_Ref_Result_Array_Access;
Scope_Result_1 : Internal_Ref_Result_Array_Access;
Result_Var_1 : Internal_Ref_Result_Array_Access;
Scope_Result_2 : Internal_Ref_Result_Array_Access;
Result_Var_2 : Internal_Ref_Result_Array_Access;
Concat_Result : Internal_Ref_Result_Array_Access;
Let_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1140 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1140;
            procedure Finalizer_Scope_2916 is
            begin
                     Dec_Ref (Var_Expr);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_2916;
            procedure Finalizer_Scope_2918 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2918;
            procedure Finalizer_Scope_2919 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_2919;
            procedure Finalizer_Scope_2920 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (If_Result_2);
            end Finalizer_Scope_2920;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8884 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8883 '<Concat at ast.py:15723>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15723
--# expr-start 8869 '<children at ast.py:15719>' Fld /tmp/lal-23.0.0/ada/ast.py:15719
      if Root.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children (Node => Root.Node, E_Info => Root.Info);
--# expr-done 8869
Var_Expr := Fld;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Array_Type then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 8876 '<Mapcat at ast.py:15722>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:15722
   --# expr-start 8874 '<Filter at ast.py:15720>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15720
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Var_Expr;
      begin
         for Item_268 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_268
         --# expr-start 8873 '<Not at ast.py:15721>' Not_Val /tmp/lal-23.0.0/ada/ast.py:15721
--# expr-start 8870 '<IsNull at ast.py:15721>' Is_Null /tmp/lal-23.0.0/ada/ast.py:15721
Is_Null := Item_268.Node = null; 
--# expr-done 8870
if Is_Null then
   If_Result := True;
else
   --# expr-start 8872 '<Eq at ast.py:15721>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15721
--# expr-start 8871 '<FieldAccess for node at ast.py:15721>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15721
Fld_1 := Item_268.Node;
--# expr-done 8871
Cast_Expr := Skip_Name; 
      Cast_Result := Cast_Expr;
Is_Equal := Fld_1 = Cast_Result; 
--# expr-done 8872
   If_Result := Is_Equal;
end if;
Not_Val := not (If_Result); 
--# expr-done 8873
         if Not_Val then
         declare
            Item_To_Append : constant Internal_Entity := Item_268;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8874
      declare
         Map_Result_1_Vec : Internal_Ref_Result_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Map_Result;
      begin
         for Item_267 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_267
      --# expr-start 8875 '<FieldAccess for find_refs_impl at ast.py:15722>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15722
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.find_refs_impl
Fld_2 := Libadalang.Implementation.Defining_Name_P_Find_Refs_Impl (Node => Ent.Node, Root => Item_267, Skip_Name => Skip_Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8875
         for Item_To_Append of
               Fld_2.Items
         loop
            Internal_Ref_Result_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2918;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Ref_Result_Array
           (Items_Count => Natural (Internal_Ref_Result_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Ref_Result_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Ref_Result_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Ref_Result_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 8876
Scope_Result := Map_Result_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2916;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Ref_Result_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# expr-start 8877 '<Cast to BaseId at ast.py:15724>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15724
Cast_Expr_1 := Root; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Base_Id
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Id
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Base_Id;
   end if;
--# expr-done 8877
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Base_Id then
   --# scope-start
   --# bind id Var_Expr_1
--# expr-start 8878 '<FieldAccess for is_referenced_by at ast.py:15725>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15725
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_referenced_by
Fld_3 := Libadalang.Implementation.Defining_Name_P_Is_Referenced_By (Node => Ent.Node, Id => Var_Expr_1, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8878
Var_Expr_2 := Fld_3;
if Var_Expr_2 /= No_Ref then
   --# scope-start
   --# bind ref_kind Var_Expr_2
--# expr-start 8882 '<If at ast.py:15726>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:15726
--# expr-start 8879 '<Eq at ast.py:15727>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:15727
Is_Equal_1 := Var_Expr_2 = Precise; 
--# expr-done 8879
if Is_Equal_1 then
   If_Result_1 := True;
else
   --# expr-start 8880 '<Eq at ast.py:15727>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:15727
Is_Equal_2 := Var_Expr_2 = Imprecise; 
--# expr-done 8880
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   --# expr-start 8881 '<New RefResult at ast.py:15730>' New_Struct /tmp/lal-23.0.0/ada/ast.py:15730
New_Struct := (Kind => Var_Expr_2, Ref => Var_Expr_1); 
--# expr-done 8881
                Singleton := Create_Internal_Ref_Result_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
   If_Result_2 := Singleton;
else
   If_Result_2 := No_Internal_Ref_Result_Array_Type;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 8882
Scope_Result_1 := If_Result_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2920;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Ref_Result_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
Scope_Result_2 := Result_Var_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2919;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Internal_Ref_Result_Array_Type;
end if;
      Inc_Ref (Result_Var_2);
Concat_Result := Concat (Result_Var, Result_Var_2); 
--# expr-done 8883
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8884
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1140;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1140;
               Finalizer_Scope_2916;
               Finalizer_Scope_2918;
               Finalizer_Scope_2919;
               Finalizer_Scope_2920;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Find_Refs_Impl;
--# end
--# property-start DefiningName.is_derivable_equal /tmp/lal-23.0.0/ada/ast.py:15737
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Is_Derivable_Equal
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Subp_Spec;
Var_Expr_1 : Internal_Entity_Type_Expr;
Sym : Symbol_Type;
Fld : Boolean;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Base_Subp_Spec;
Fld_3 : Internal_Entity_Type_Expr;
Fld_4 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Defining_Name_Defining_Name_P_Is_Derivable_Equal,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Defining_Name,
                                As_Bare_Defining_Name => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 8893 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8886 '<FieldAccess for name_is at ast.py:15745>' Fld /tmp/lal-23.0.0/ada/ast.py:15745
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8885 '<Symbol "=" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 8885
--# property-call-start Name.name_is
Fld := Libadalang.Implementation.Name_P_Name_Is (Node => Self, Sym => Sym);
--# end
--# expr-done 8886
if Fld then
--# expr-start 8888 '<FieldAccess for subp_spec_or_null at ast.py:15746>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15746
--# expr-start 8887 '<FieldAccess for basic_decl at ast.py:15746>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15746
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8887
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 8888
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind s Var_Expr
--# expr-start 8892 '<Eq at ast.py:15747>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:15747
--# expr-start 8889 '<FieldAccess for returns at ast.py:15747>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15747
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 8889
Var_Expr_1 := Fld_3;
if Var_Expr_1 /= No_Entity_Type_Expr then
   --# scope-start
--# expr-start 8890 '<FieldAccess for designated_type_decl at ast.py:15747>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15747
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.designated_type_decl
Fld_4 := Libadalang.Implementation.Type_Expr_P_Designated_Type_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 8890
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
      Cast_Result := Create_Internal_Entity
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
--# expr-start 8891 '<FieldAccess for bool_type at ast.py:15747>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15747
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_5 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Ent.Node);
--# end
--# expr-done 8891
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 8892
Scope_Result_1 := Is_Equiv;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result := Result_Var_1;
else
   If_Result := False;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 8893
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Is_Derivable_Equal;
--# end
--# property-start DefiningName.is_potential_reference /tmp/lal-23.0.0/ada/ast.py:15752
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Is_Potential_Reference
  (Node : Bare_Defining_Name
      ; Symbol : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind symbol Symbol
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
Sym : Symbol_Type;
Is_Equal : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Defining_Name_Defining_Name_P_Is_Potential_Reference,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Defining_Name,
                                As_Bare_Defining_Name => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Symbol_Type,
                                      As_Symbol_Type => Symbol);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 8898 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8894 '<FieldAccess for name_is at ast.py:15758>' Fld /tmp/lal-23.0.0/ada/ast.py:15758
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld := Libadalang.Implementation.Name_P_Name_Is (Node => Self, Sym => Symbol);
--# end
--# expr-done 8894
if Fld then
   If_Result_1 := True;
else
--# expr-start 8895 '<FieldAccess for is_derivable_equal at ast.py:15759>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15759
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_derivable_equal
Fld_1 := Libadalang.Implementation.Defining_Name_P_Is_Derivable_Equal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8895
if Fld_1 then
   --# expr-start 8897 '<Eq at ast.py:15759>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15759
--# expr-start 8896 '<Symbol "/=" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 8896
Is_Equal := Symbol = Sym; 
--# expr-done 8897
   If_Result := Is_Equal;
else
   If_Result := False;
end if;
   If_Result_1 := If_Result;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 8898
      Property_Result := Let_Result;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Is_Potential_Reference;
--# end
--# property-start DefiningName.is_referenced_by /tmp/lal-23.0.0/ada/ast.py:15764
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Is_Referenced_By
  (Node : Bare_Defining_Name
      ; Id : Internal_Entity_Base_Id
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Ref_Result_Kind
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind id Id
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Ref_Result_Kind;
            procedure Finalizer_Scope_2923 with Inline_Always;
            procedure Finalizer_Scope_2926 with Inline_Always;
      Var_Expr : Internal_Refd_Def;
Canon : Bare_Defining_Name;
Var_Expr_1 : Internal_Entity_Defining_Name;
Var_Expr_2 : Internal_Entity_Defining_Name;
Var_Expr_3 : Internal_Entity_Basic_Decl_Array_Access;
Fld : Internal_Entity_Defining_Name;
New_Struct : Internal_Refd_Def;
Fld_1 : Internal_Refd_Def;
Fld_2 : Boolean;
If_Result : Internal_Refd_Def;
Fld_3 : Internal_Entity_Defining_Name;
Fld_4 : Internal_Entity_Defining_Name;
Scope_Result : Internal_Entity_Defining_Name;
Result_Var : Internal_Entity_Defining_Name;
Fld_5 : Bare_Defining_Name;
Scope_Result_1 : Bare_Defining_Name;
Result_Var_1 : Bare_Defining_Name;
Fld_6 : Ref_Result_Kind;
Cast_Expr : Bare_Defining_Name;
Cast_Result : Bare_Defining_Name;
Is_Equal : Boolean;
Fld_7 : Internal_Entity_Basic_Decl;
Fld_8 : Internal_Entity_Basic_Decl_Array_Access;
Fld_9 : Internal_Entity_Defining_Name;
Fld_10 : Bare_Defining_Name;
Cast_Result_1 : Bare_Defining_Name;
Is_Equal_1 : Boolean;
Quantifier_Result : Boolean;
Fld_11 : Boolean;
If_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Ref_Result_Kind;
Let_Result : Ref_Result_Kind;
Scope_Result_3 : Ref_Result_Kind;
Result_Var_3 : Ref_Result_Kind;
Fld_12 : Symbol_Type;
Fld_13 : Boolean;
If_Result_4 : Ref_Result_Kind;
Let_Result_1 : Ref_Result_Kind;
            procedure Finalizer_Scope_2923 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_2923;
            procedure Finalizer_Scope_2926 is
            begin
                     Dec_Ref (Var_Expr_3);
            end Finalizer_Scope_2926;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8921 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 8920 '<If at ast.py:15776>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:15776
--# expr-start 8900 '<FieldAccess for is_potential_reference at ast.py:15777>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15777
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8899 '<FieldAccess for name_symbol at ast.py:15777>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15777
      if Id.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_12 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Id.Node);
--# end
--# expr-done 8899
--# property-call-start DefiningName.is_potential_reference
Fld_13 := Libadalang.Implementation.Defining_Name_P_Is_Potential_Reference (Node => Ent.Node, Symbol => Fld_12, E_Info => Ent.Info);
--# end
--# expr-done 8900
if Fld_13 then
--# expr-start 8905 '<If at ast.py:15779>' If_Result /tmp/lal-23.0.0/ada/ast.py:15779
--# expr-start 8901 '<FieldAccess for is_defining at ast.py:15779>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15779
      if Id.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_defining
Fld_2 := Libadalang.Implementation.Name_P_Is_Defining (Node => Id.Node);
--# end
--# expr-done 8901
if Fld_2 then
   --# expr-start 8903 '<New RefdDef at ast.py:15780>' New_Struct /tmp/lal-23.0.0/ada/ast.py:15780
--# expr-start 8902 '<FieldAccess for enclosing_defining_name at ast.py:15780>' Fld /tmp/lal-23.0.0/ada/ast.py:15780
      if Id.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.enclosing_defining_name
Fld := Libadalang.Implementation.Name_P_Enclosing_Defining_Name (Node => Id.Node, E_Info => Id.Info);
--# end
--# expr-done 8902
New_Struct := (Def_Name => Fld, Kind => Precise); 
--# expr-done 8903
   If_Result := New_Struct;
else
   --# expr-start 8904 '<FieldAccess for failsafe_referenced_def_name at ast.py:15782>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15782
      if Id.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.failsafe_referenced_def_name
Fld_1 := Libadalang.Implementation.Name_P_Failsafe_Referenced_Def_Name (Node => Id.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Id.Info);
--# end
--# expr-done 8904
   If_Result := Fld_1;
end if;
--# expr-done 8905
Var_Expr := If_Result;
if Var_Expr /= No_Refd_Def then
   --# scope-start
   --# bind def_res Var_Expr
--# expr-start 8919 '<Let at ast.py:15785>' Let_Result /tmp/lal-23.0.0/ada/ast.py:15785
--# scope-start
--# expr-start 8906 '<FieldAccess for def_name at ast.py:15786>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15786
Fld_3 := Var_Expr.Def_Name;
--# expr-done 8906
Var_Expr_2 := Fld_3;
if Var_Expr_2 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 8907 '<FieldAccess for canonical_part at ast.py:15786>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15786
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.canonical_part
Fld_4 := Libadalang.Implementation.Defining_Name_P_Canonical_Part (Node => Var_Expr_2.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 8907
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Defining_Name;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 8908 '<FieldAccess for node at ast.py:15786>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15786
Fld_5 := Var_Expr_1.Node;
--# expr-done 8908
Scope_Result_1 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Bare_Ada_Node;
end if;
Canon := Result_Var_1; 
--# bind canon Canon
--# expr-start 8918 '<If at ast.py:15788>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:15788
--# expr-start 8909 '<Eq at ast.py:15791>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15791
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Is_Equal := Cast_Result = Canon; 
--# expr-done 8909
if Is_Equal then
   If_Result_2 := True;
else
--# expr-start 8911 '<FieldAccess for base_subp_declarations at ast.py:15796>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15796
--# expr-start 8910 '<FieldAccess for basic_decl at ast.py:15796>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15796
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_7 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8910
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.base_subp_declarations
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Base_Subp_Declarations (Node => Fld_7.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_7.Info);
--# end
--# expr-done 8911
Var_Expr_3 := Fld_8;
      Inc_Ref (Var_Expr_3);
if Var_Expr_3 /= No_Internal_Entity_Basic_Decl_Array_Type then
   --# scope-start
   --# bind decls Var_Expr_3
--# expr-start 8915 '<AnyQuantifier at ast.py:15797>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:15797
      Quantifier_Result := False;
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Var_Expr_3;
      begin
         for Item_269 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_269
      --# expr-start 8914 '<Eq at ast.py:15798>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:15798
--# expr-start 8913 '<FieldAccess for node at ast.py:15798>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15798
--# expr-start 8912 '<FieldAccess for defining_name at ast.py:15798>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15798
      if Item_269.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_9 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Item_269.Node, E_Info => Item_269.Info);
--# end
--# expr-done 8912
Fld_10 := Fld_9.Node;
--# expr-done 8913
      Cast_Result_1 := Fld_10;
Is_Equal_1 := Cast_Result_1 = Canon; 
--# expr-done 8914
      Quantifier_Result := Is_Equal_1;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
--# expr-done 8915
if Quantifier_Result then
   --# expr-start 8916 '<FieldAccess for is_dispatching_call at ast.py:15800>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15800
      if Id.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.is_dispatching_call'
Fld_11 := Libadalang.Implementation.Dispatcher_Expr_P_Is_Dispatching_Call (Node => Id.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Id.Info);
--# end
--# expr-done 8916
   If_Result_1 := Fld_11;
else
   If_Result_1 := False;
end if;
Scope_Result_2 := If_Result_1;
   --# end
      Finalizer_Scope_2926;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
   If_Result_2 := Result_Var_2;
end if;
if If_Result_2 then
   --# expr-start 8917 '<FieldAccess for kind at ast.py:15803>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15803
Fld_6 := Var_Expr.Kind;
--# expr-done 8917
   If_Result_3 := Fld_6;
else
   If_Result_3 := No_Ref;
end if;
--# expr-done 8918
Let_Result := If_Result_3; 
--# end
--# expr-done 8919
Scope_Result_3 := Let_Result;
   --# end
      Finalizer_Scope_2923;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Ref;
end if;
   If_Result_4 := Result_Var_3;
else
   If_Result_4 := No_Ref;
end if;
--# expr-done 8920
Let_Result_1 := If_Result_4; 
--# end
--# expr-done 8921
      Property_Result := Let_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2923;
               Finalizer_Scope_2926;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Is_Referenced_By;
--# end
--# property-start DefiningName.find_all_references /tmp/lal-23.0.0/ada/ast.py:15814
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Find_All_References
  (Node : Bare_Defining_Name
      ; Units : Internal_Unit_Array_Access
      ; Follow_Renamings : Boolean
         := False
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Ref_Result_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind units Units
   --# bind follow_renamings Follow_Renamings
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1144 with Inline_Always;
            procedure Finalizer_Scope_2928 with Inline_Always;
            procedure Finalizer_Scope_2929 with Inline_Always;
            procedure Finalizer_Scope_2930 with Inline_Always;
            procedure Finalizer_Scope_2931 with Inline_Always;
            procedure Finalizer_Scope_2932 with Inline_Always;
            procedure Finalizer_Scope_2935 with Inline_Always;
            procedure Finalizer_Scope_2937 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name;
Block_Var_1 : Internal_Entity_Basic_Decl_Array_Access;
Block_Var_2 : Internal_Unit_Array_Access;
Block_Var_3 : Internal_Ref_Result_Array_Access;
Var_Expr : Internal_Entity_Basic_Decl_Array_Access;
Var_Expr_1 : Bare_Ada_Node;
Var_Expr_2 : Internal_Entity_Renaming_Clause;
Var_Expr_3 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Defining_Name;
Cast_Expr : Bare_Defining_Name;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result : Internal_Entity_Basic_Decl_Array_Access;
Fld_3 : Internal_Entity_Basic_Decl;
Singleton : Internal_Entity_Basic_Decl_Array_Access;
Result_Var : Internal_Entity_Basic_Decl_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Basic_Decl_Array_Access;
Fld_4 : Internal_Unit_Array_Access;
Map_Result : Internal_Unit_Array_Access;
Unique_Array : Internal_Unit_Array_Access;
Fld_5 : Bare_Ada_Node;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_6 : Internal_Ref_Result_Array_Access;
Scope_Result_1 : Internal_Ref_Result_Array_Access;
Result_Var_1 : Internal_Ref_Result_Array_Access;
Map_Result_1 : Internal_Ref_Result_Array_Access;
Fld_7 : Internal_Entity_Base_Id;
Fld_8 : Internal_Entity_Array_Access;
Is_A : Boolean;
Find_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Renaming_Clause;
Fld_9 : Internal_Entity_Name;
Fld_10 : Internal_Entity_Defining_Name;
Fld_11 : Bare_Defining_Name;
Fld_12 : Bare_Defining_Name;
Cast_Result_2 : Bare_Defining_Name;
Is_Equal : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Map_Result_2 : Internal_Ref_Result_Array_Access;
Fld_13 : Internal_Entity_Base_Id;
Fld_14 : Internal_Entity_Array_Access;
Is_A_1 : Boolean;
Find_Result_1 : Internal_Entity;
Fld_15 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Fld_16 : Internal_Entity_Defining_Name;
Fld_17 : Internal_Ref_Result_Array_Access;
Scope_Result_3 : Internal_Ref_Result_Array_Access;
Result_Var_3 : Internal_Ref_Result_Array_Access;
Map_Result_3 : Internal_Ref_Result_Array_Access;
Concat_Result : Internal_Ref_Result_Array_Access;
If_Result_1 : Internal_Ref_Result_Array_Access;
Let_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1144 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Singleton);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Unique_Array);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Map_Result_3);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1144;
            procedure Finalizer_Scope_2928 is
            begin
                     Dec_Ref (Var_Expr);
            end Finalizer_Scope_2928;
            procedure Finalizer_Scope_2929 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_2929;
            procedure Finalizer_Scope_2930 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_2930;
            procedure Finalizer_Scope_2931 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_2931;
            procedure Finalizer_Scope_2932 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_2932;
            procedure Finalizer_Scope_2935 is
            begin
                     Dec_Ref (Fld_14);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
            end Finalizer_Scope_2935;
            procedure Finalizer_Scope_2937 is
            begin
                     Dec_Ref (Fld_17);
            end Finalizer_Scope_2937;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8956 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8922 '<FieldAccess for canonical_part at ast.py:15824>' Fld /tmp/lal-23.0.0/ada/ast.py:15824
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.canonical_part
Fld := Libadalang.Implementation.Defining_Name_P_Canonical_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8922
Block_Var := Fld; 
--# bind dn Block_Var
--# expr-start 8926 '<bind at ast.py:15834>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:15834
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 8924 '<FieldAccess for root_subp_declarations at ast.py:15836>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15836
--# expr-start 8923 '<FieldAccess for basic_decl at ast.py:15836>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15836
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 8923
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.root_subp_declarations
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Root_Subp_Declarations (Node => Fld_1.Node, Origin => Bound_Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_1.Info);
--# end
--# expr-done 8924
Var_Expr := Fld_2;
      Inc_Ref (Var_Expr);
if Var_Expr /= No_Internal_Entity_Basic_Decl_Array_Type then
   --# scope-start
   --# bind e Var_Expr
Scope_Result := Var_Expr;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2928;
   Result_Var := Scope_Result;
else
   --# expr-start 8925 '<FieldAccess for basic_decl at ast.py:15836>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15836
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_3 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 8925
                Singleton := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_3;
   Result_Var := Singleton;
end if;
      Inc_Ref (Result_Var);
Dyn_Var_Bind_Result := Result_Var; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 8926
Block_Var_1 := Dyn_Var_Bind_Result; Inc_Ref (Block_Var_1);
--# bind bases Block_Var_1
--# expr-start 8929 '<unique at ast.py:15841>' Unique_Array /tmp/lal-23.0.0/ada/ast.py:15841
--# expr-start 8928 '<Mapcat at ast.py:15839>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15839
      declare
         Map_Result_Vec : Internal_Unit_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Block_Var_1;
      begin
         for Item_270 of
               Collection.Items
         loop
   --# scope-start
               --# bind base Item_270
      --# expr-start 8927 '<FieldAccess for filter_is_imported_by at ast.py:15840>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15840
      if Item_270.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Ada_Node_P_Filter_Is_Imported_By (Node => Item_270.Node, Units => Units, Transitive => True);
--# expr-done 8927
         for Item_To_Append of
               Fld_4.Items
         loop
            Internal_Unit_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2929;
         end loop;
      end;
         Map_Result := Create_Internal_Unit_Array
           (Items_Count => Natural (Internal_Unit_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Unit_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Unit_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Unit_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8928
Unique_Array := Make_Unique (Map_Result); 
--# expr-done 8929
Block_Var_2 := Unique_Array; Inc_Ref (Block_Var_2);
--# bind all_units Block_Var_2
--# expr-start 8933 '<Mapcat at ast.py:15843>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:15843
      declare
         Map_Result_1_Vec : Internal_Ref_Result_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Unit_Array_Access := Block_Var_2;
      begin
         for Item_271 of
               Collection.Items
         loop
   --# scope-start
               --# bind u Item_271
--# expr-start 8930 '<FieldAccess for root at ast.py:15843>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15843
      if Item_271 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Item_271.Ast_Root;
--# expr-done 8930
Var_Expr_1 := Fld_5;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind r Var_Expr_1
--# expr-start 8932 '<FieldAccess for find_refs_impl at ast.py:15844>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15844
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8931 '<as_bare_entity at ast.py:15844>' If_Result /tmp/lal-23.0.0/ada/ast.py:15844
Is_Null := Var_Expr_1 = null; 
if Is_Null then
   If_Result := No_Entity;
else
As_Entity := (Info => No_Entity_Info, Node => Var_Expr_1); 
   If_Result := As_Entity;
end if;
--# expr-done 8931
--# property-call-start DefiningName.find_refs_impl
Fld_6 := Libadalang.Implementation.Defining_Name_P_Find_Refs_Impl (Node => Block_Var.Node, Root => If_Result, Skip_Name => Self, Imprecise_Fallback => Imprecise_Fallback, E_Info => Block_Var.Info);
--# end
--# expr-done 8932
Scope_Result_1 := Fld_6;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2931;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Ref_Result_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
         for Item_To_Append of
               Result_Var_1.Items
         loop
            Internal_Ref_Result_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2930;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Ref_Result_Array
           (Items_Count => Natural (Internal_Ref_Result_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Ref_Result_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Ref_Result_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Ref_Result_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 8933
Block_Var_3 := Map_Result_1; Inc_Ref (Block_Var_3);
--# bind refs Block_Var_3
--# expr-start 8955 '<If at ast.py:15847>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:15847
if Follow_Renamings then
   --# expr-start 8954 '<Concat at ast.py:15849>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15849
--# expr-start 8953 '<Mapcat at ast.py:15863>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:15863
   --# expr-start 8944 '<Filter at ast.py:15850>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:15850
      declare
         Map_Result_2_Vec : Internal_Ref_Result_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Ref_Result_Array_Access := Block_Var_3;
      begin
         for Item_273 of
               Collection.Items
         loop
   --# scope-start
               --# bind f Item_273
--# expr-start 8938 '<Cast to RenamingClause at ast.py:15858>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15858
--# expr-start 8937 '<Find at ast.py:15856>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15856
   --# expr-start 8935 '<FieldAccess for parents at ast.py:15856>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15856
--# expr-start 8934 '<FieldAccess for ref at ast.py:15856>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15856
Fld_7 := Item_273.Ref;
--# expr-done 8934
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Parents (Node => Fld_7.Node, With_Self => True, E_Info => Fld_7.Info);
--# expr-done 8935
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_8;
      begin
         for Item_274 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_274
      --# expr-start 8936 '<IsA RenamingClause at ast.py:15857>' Is_A /tmp/lal-23.0.0/ada/ast.py:15857
Is_A := Item_274.Node /= null 
and then Item_274.Node.Kind in Ada_Renaming_Clause_Range; 
--# expr-done 8936
      if Is_A then
         Find_Result := Item_274;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 8937
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Renaming_Clause_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Renaming_Clause
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_1 := No_Entity_Renaming_Clause;
   end if;
--# expr-done 8938
Var_Expr_2 := Cast_Result_1;
if Var_Expr_2 /= No_Entity_Renaming_Clause then
   --# scope-start
   --# bind r Var_Expr_2
--# expr-start 8943 '<Eq at ast.py:15860>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:15860
--# expr-start 8941 '<FieldAccess for node at ast.py:15860>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15860
--# expr-start 8940 '<FieldAccess for referenced_defining_name at ast.py:15860>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15860
--# expr-start 8939 '<FieldAccess for renamed_object at ast.py:15860>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15860
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Name (Node => Var_Expr_2.Node.Renaming_Clause_F_Renamed_Object, Info => Var_Expr_2.Info);
--# expr-done 8939
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_defining_name
Fld_10 := Libadalang.Implementation.Name_P_Referenced_Defining_Name (Node => Fld_9.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_9.Info);
--# end
--# expr-done 8940
Fld_11 := Fld_10.Node;
--# expr-done 8941
      Cast_Result_2 := Fld_11;
--# expr-start 8942 '<FieldAccess for node at ast.py:15861>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15861
Fld_12 := Block_Var.Node;
--# expr-done 8942
Is_Equal := Cast_Result_2 = Fld_12; 
--# expr-done 8943
Scope_Result_2 := Is_Equal;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
         if Result_Var_2 then
         declare
            Item_To_Append : constant Internal_Ref_Result := Item_273;
         begin
            Internal_Ref_Result_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
      Finalizer_Scope_2932;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Ref_Result_Array
           (Items_Count => Natural (Internal_Ref_Result_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Ref_Result_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Ref_Result_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Ref_Result_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 8944
      declare
         Map_Result_3_Vec : Internal_Ref_Result_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Ref_Result_Array_Access := Map_Result_2;
      begin
         for Item_272 of
               Collection.Items
         loop
   --# scope-start
               --# bind f Item_272
--# expr-start 8950 '<Cast to BasicDecl at ast.py:15869>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:15869
--# expr-start 8949 '<parent at ast.py:15869>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:15869
--# expr-start 8948 '<Find at ast.py:15867>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:15867
   --# expr-start 8946 '<FieldAccess for parents at ast.py:15867>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:15867
--# expr-start 8945 '<FieldAccess for ref at ast.py:15867>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:15867
Fld_13 := Item_272.Ref;
--# expr-done 8945
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Parents (Node => Fld_13.Node, With_Self => True, E_Info => Fld_13.Info);
--# expr-done 8946
      Find_Result_1 := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_14;
      begin
         for Item_275 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_275
      --# expr-start 8947 '<IsA RenamingClause at ast.py:15868>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:15868
Is_A_1 := Item_275.Node /= null 
and then Item_275.Node.Kind in Ada_Renaming_Clause_Range; 
--# expr-done 8947
      if Is_A_1 then
         Find_Result_1 := Item_275;
      end if;
   --# end
               exit when Is_A_1;
         end loop;
      end;
--# expr-done 8948
      if Find_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Libadalang.Implementation.Parent (Node => Find_Result_1.Node, E_Info => Find_Result_1.Info);
--# expr-done 8949
   if Fld_15.Node = null
      or else Fld_15.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 8950
Var_Expr_3 := Cast_Result_3;
if Var_Expr_3 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr_3
--# expr-start 8952 '<FieldAccess for find_all_references at ast.py:15870>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:15870
--# expr-start 8951 '<FieldAccess for defining_name at ast.py:15870>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:15870
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_16 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 8951
      if Fld_16.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.find_all_references
Fld_17 := Libadalang.Implementation.Defining_Name_P_Find_All_References (Node => Fld_16.Node, Units => Units, Follow_Renamings => True, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_16.Info);
--# end
--# expr-done 8952
Scope_Result_3 := Fld_17;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2937;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Internal_Ref_Result_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
         for Item_To_Append of
               Result_Var_3.Items
         loop
            Internal_Ref_Result_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2935;
         end loop;
      end;
         Map_Result_3 := Create_Internal_Ref_Result_Array
           (Items_Count => Natural (Internal_Ref_Result_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Internal_Ref_Result_Vectors.Get
              (Map_Result_3_Vec,
               I + Internal_Ref_Result_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Internal_Ref_Result_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 8953
Concat_Result := Concat (Block_Var_3, Map_Result_3); 
--# expr-done 8954
   If_Result_1 := Concat_Result;
else
   If_Result_1 := Block_Var_3;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 8955
Let_Result := If_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 8956
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1144;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1144;
               Finalizer_Scope_2928;
               Finalizer_Scope_2929;
               Finalizer_Scope_2930;
               Finalizer_Scope_2931;
               Finalizer_Scope_2932;
               Finalizer_Scope_2935;
               Finalizer_Scope_2937;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Find_All_References;
--# end
--# property-start DefiningName.find_matching_name /tmp/lal-23.0.0/ada/ast.py:15881
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Find_Matching_Name
  (Node : Bare_Defining_Name
      ; Bd : Internal_Entity_Basic_Decl
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind bd Bd
   Property_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_1145 with Inline_Always;
            procedure Finalizer_Scope_2914 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Name;
Fld_2 : Symbol_Type;
Fld_3 : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
            procedure Finalizer_Scope_1145 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1145;
            procedure Finalizer_Scope_2914 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_2914;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8962 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8961 '<Find at ast.py:15886>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15886
Var_Expr := Bd;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 8957 '<FieldAccess for defining_names at ast.py:15886>' Fld /tmp/lal-23.0.0/ada/ast.py:15886
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 8957
Scope_Result := Fld;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2914;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Result_Var;
      begin
         for Item_276 of
               Collection.Items
         loop
   --# scope-start
               --# bind di Item_276
      --# expr-start 8960 '<FieldAccess for name_is at ast.py:15887>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15887
--# expr-start 8958 '<FieldAccess for name at ast.py:15887>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15887
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Defining_Name_F_Name, Info => Ent.Info);
--# expr-done 8958
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8959 '<FieldAccess for name_symbol at ast.py:15887>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15887
      if Item_276.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Item_276.Node);
--# end
--# expr-done 8959
--# property-call-start Name.name_is
Fld_3 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_1.Node, Sym => Fld_2);
--# end
--# expr-done 8960
      if Fld_3 then
         Find_Result := Item_276;
      end if;
   --# end
               exit when Fld_3;
         end loop;
      end;
--# expr-done 8961
Let_Result := Find_Result; 
--# end
--# expr-done 8962
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1145;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1145;
               Finalizer_Scope_2914;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Find_Matching_Name;
--# end
--# property-start DefiningName.find_all_calls /tmp/lal-23.0.0/ada/ast.py:15892
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Find_All_Calls
  (Node : Bare_Defining_Name
      ; Units : Internal_Unit_Array_Access
      ; Follow_Renamings : Boolean
         := False
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Ref_Result_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind units Units
   --# bind follow_renamings Follow_Renamings
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1146 with Inline_Always;
      Fld : Internal_Ref_Result_Array_Access;
Fld_1 : Internal_Entity_Base_Id;
Fld_2 : Boolean;
Map_Result : Internal_Ref_Result_Array_Access;
Let_Result : Internal_Ref_Result_Array_Access;
            procedure Finalizer_Scope_1146 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1146;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8967 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8966 '<Filter at ast.py:15904>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15904
   --# expr-start 8963 '<FieldAccess for find_all_references at ast.py:15904>' Fld /tmp/lal-23.0.0/ada/ast.py:15904
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.find_all_references
Fld := Libadalang.Implementation.Defining_Name_P_Find_All_References (Node => Ent.Node, Units => Units, Follow_Renamings => Follow_Renamings, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8963
      declare
         Map_Result_Vec : Internal_Ref_Result_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Ref_Result_Array_Access := Fld;
      begin
         for Item_277 of
               Collection.Items
         loop
   --# scope-start
               --# bind r Item_277
         --# expr-start 8965 '<FieldAccess for is_direct_call at ast.py:15905>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15905
--# expr-start 8964 '<FieldAccess for ref at ast.py:15905>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15905
Fld_1 := Item_277.Ref;
--# expr-done 8964
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_direct_call
Fld_2 := Libadalang.Implementation.Name_P_Is_Direct_Call (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 8965
         if Fld_2 then
         declare
            Item_To_Append : constant Internal_Ref_Result := Item_277;
         begin
            Internal_Ref_Result_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Ref_Result_Array
           (Items_Count => Natural (Internal_Ref_Result_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Ref_Result_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Ref_Result_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Ref_Result_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 8966
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 8967
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1146;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1146;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Find_All_Calls;
--# end
--# property-start DefiningName.next_part /tmp/lal-23.0.0/ada/ast.py:15908
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Next_Part
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8971 '<FieldAccess for find_matching_name at ast.py:15909>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15909
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8970 '<FieldAccess for next_part_for_name at ast.py:15910>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15910
--# expr-start 8968 '<FieldAccess for basic_decl at ast.py:15910>' Fld /tmp/lal-23.0.0/ada/ast.py:15910
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8968
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8969 '<FieldAccess for name_symbol at ast.py:15910>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15910
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 8969
--# property-call-start '[dispatcher]BasicDecl.next_part_for_name'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Next_Part_For_Name (Node => Fld.Node, Sym => Fld_1, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 8970
--# property-call-start DefiningName.find_matching_name
Fld_3 := Libadalang.Implementation.Defining_Name_P_Find_Matching_Name (Node => Ent.Node, Bd => Fld_2, E_Info => Ent.Info);
--# end
--# expr-done 8971
      Property_Result := Fld_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Next_Part;
--# end
--# property-start DefiningName.previous_part /tmp/lal-23.0.0/ada/ast.py:15917
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Previous_Part
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8975 '<FieldAccess for find_matching_name at ast.py:15918>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15918
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8974 '<FieldAccess for previous_part_for_name at ast.py:15919>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15919
--# expr-start 8972 '<FieldAccess for basic_decl at ast.py:15919>' Fld /tmp/lal-23.0.0/ada/ast.py:15919
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8972
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8973 '<FieldAccess for name_symbol at ast.py:15919>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15919
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 8973
--# property-call-start '[dispatcher]BasicDecl.previous_part_for_name'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Previous_Part_For_Name (Node => Fld.Node, Sym => Fld_1, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 8974
--# property-call-start DefiningName.find_matching_name
Fld_3 := Libadalang.Implementation.Defining_Name_P_Find_Matching_Name (Node => Ent.Node, Bd => Fld_2, E_Info => Ent.Info);
--# end
--# expr-done 8975
      Property_Result := Fld_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Previous_Part;
--# end
--# property-start DefiningName.canonical_part /tmp/lal-23.0.0/ada/ast.py:15926
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Canonical_Part
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8979 '<FieldAccess for find_matching_name at ast.py:15927>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15927
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8978 '<FieldAccess for canonical_part_for_name at ast.py:15928>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15928
--# expr-start 8976 '<FieldAccess for basic_decl at ast.py:15928>' Fld /tmp/lal-23.0.0/ada/ast.py:15928
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8976
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8977 '<FieldAccess for name_symbol at ast.py:15928>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15928
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 8977
--# property-call-start BasicDecl.canonical_part_for_name
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Canonical_Part_For_Name (Node => Fld.Node, Sym => Fld_1, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 8978
--# property-call-start DefiningName.find_matching_name
Fld_3 := Libadalang.Implementation.Defining_Name_P_Find_Matching_Name (Node => Ent.Node, Bd => Fld_2, E_Info => Ent.Info);
--# end
--# expr-done 8979
      Property_Result := Fld_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Canonical_Part;
--# end
--# property-start DefiningName.most_visible_part /tmp/lal-23.0.0/ada/ast.py:15937
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Most_Visible_Part
  (Node : Bare_Defining_Name
      ; Origin : Bare_Ada_Node
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name;
      Fld : Internal_Entity_Basic_Decl;
Fld_1 : Symbol_Type;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Defining_Name;
Let_Result : Internal_Entity_Defining_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8984 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8983 '<FieldAccess for find_matching_name at ast.py:15943>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15943
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8982 '<FieldAccess for most_visible_part_for_name at ast.py:15944>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15944
--# expr-start 8980 '<FieldAccess for basic_decl at ast.py:15944>' Fld /tmp/lal-23.0.0/ada/ast.py:15944
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 8980
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 8981 '<FieldAccess for name_symbol at ast.py:15944>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15944
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Ent.Node);
--# end
--# expr-done 8981
--# property-call-start BasicDecl.most_visible_part_for_name
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Most_Visible_Part_For_Name (Node => Fld.Node, Sym => Fld_1, Origin => Origin, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 8982
--# property-call-start DefiningName.find_matching_name
Fld_3 := Libadalang.Implementation.Defining_Name_P_Find_Matching_Name (Node => Ent.Node, Bd => Fld_2, E_Info => Ent.Info);
--# end
--# expr-done 8983
Let_Result := Fld_3; 
--# end
--# expr-done 8984
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Most_Visible_Part;
--# end
--# property-start DefiningName.all_previous_parts /tmp/lal-23.0.0/ada/ast.py:15949
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_All_Previous_Parts
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1151 with Inline_Always;
            procedure Finalizer_Scope_2939 with Inline_Always;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Concat_Result : Internal_Entity_Defining_Name_Array_Access;
Cast_Expr : Internal_Entity_Defining_Name;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Defining_Name;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1151 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1151;
            procedure Finalizer_Scope_2939 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2939;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8990 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8985 '<FieldAccess for previous_part at ast.py:15954>' Fld /tmp/lal-23.0.0/ada/ast.py:15954
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.previous_part
Fld := Libadalang.Implementation.Defining_Name_P_Previous_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8985
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind pp Var_Expr
--# expr-start 8989 '<If at ast.py:15955>' If_Result /tmp/lal-23.0.0/ada/ast.py:15955
--# expr-start 8986 '<Eq at ast.py:15956>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:15956
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Var_Expr; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 8986
if Is_Equiv then
   If_Result := No_Internal_Entity_Defining_Name_Array_Type;
else
   --# expr-start 8988 '<Concat at ast.py:15958>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15958
--# expr-start 8987 '<FieldAccess for all_previous_parts at ast.py:15958>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15958
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.all_previous_parts
Fld_1 := Libadalang.Implementation.Defining_Name_P_All_Previous_Parts (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 8987
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Concat_Result := Concat (Fld_1, Singleton); 
--# expr-done 8988
   If_Result := Concat_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 8989
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2939;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 8990
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1151;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1151;
               Finalizer_Scope_2939;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_All_Previous_Parts;
--# end
--# property-start DefiningName.all_next_parts /tmp/lal-23.0.0/ada/ast.py:15964
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_All_Next_Parts
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1152 with Inline_Always;
            procedure Finalizer_Scope_2940 with Inline_Always;
      Var_Expr : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Concat_Result : Internal_Entity_Defining_Name_Array_Access;
Cast_Expr : Internal_Entity_Defining_Name;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Defining_Name;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1152 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1152;
            procedure Finalizer_Scope_2940 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (If_Result);
            end Finalizer_Scope_2940;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 8996 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8991 '<FieldAccess for next_part at ast.py:15969>' Fld /tmp/lal-23.0.0/ada/ast.py:15969
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.next_part
Fld := Libadalang.Implementation.Defining_Name_P_Next_Part (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8991
Var_Expr := Fld;
if Var_Expr /= No_Entity_Defining_Name then
   --# scope-start
   --# bind np Var_Expr
--# expr-start 8995 '<If at ast.py:15970>' If_Result /tmp/lal-23.0.0/ada/ast.py:15970
--# expr-start 8992 '<Eq at ast.py:15971>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:15971
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Var_Expr; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 8992
if Is_Equiv then
   If_Result := No_Internal_Entity_Defining_Name_Array_Type;
else
   --# expr-start 8994 '<Concat at ast.py:15973>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15973
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
--# expr-start 8993 '<FieldAccess for all_next_parts at ast.py:15973>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15973
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.all_next_parts
Fld_1 := Libadalang.Implementation.Defining_Name_P_All_Next_Parts (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 8993
Concat_Result := Concat (Singleton, Fld_1); 
--# expr-done 8994
   If_Result := Concat_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 8995
Scope_Result := If_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2940;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 8996
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1152;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1152;
               Finalizer_Scope_2940;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_All_Next_Parts;
--# end
--# property-start DefiningName.all_parts /tmp/lal-23.0.0/ada/ast.py:15979
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_All_Parts
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1153 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Block_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Concat_Result : Internal_Entity_Defining_Name_Array_Access;
Concat_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_1153 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1153;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9001 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 8997 '<FieldAccess for all_previous_parts at ast.py:15984>' Fld /tmp/lal-23.0.0/ada/ast.py:15984
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.all_previous_parts
Fld := Libadalang.Implementation.Defining_Name_P_All_Previous_Parts (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8997
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind prevs Block_Var
--# expr-start 8998 '<FieldAccess for all_next_parts at ast.py:15985>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15985
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.all_next_parts
Fld_1 := Libadalang.Implementation.Defining_Name_P_All_Next_Parts (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 8998
Block_Var_1 := Fld_1; Inc_Ref (Block_Var_1);
--# bind nexts Block_Var_1
--# expr-start 9000 '<Concat at ast.py:15986>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:15986
--# expr-start 8999 '<Concat at ast.py:15986>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:15986
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Ent;
Concat_Result := Concat (Block_Var, Singleton); 
--# expr-done 8999
Concat_Result_1 := Concat (Concat_Result, Block_Var_1); 
--# expr-done 9000
Let_Result := Concat_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9001
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1153;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1153;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_All_Parts;
--# end
--# property-start DefiningName.get_aspect_impl /tmp/lal-23.0.0/ada/ast.py:15990
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Get_Aspect_Impl
  (Node : Bare_Defining_Name
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Aspect
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Aspect;
      Var_Expr : Internal_Aspect;
Var_Expr_1 : Internal_Aspect;
Var_Expr_2 : Internal_Aspect;
Var_Expr_3 : Internal_Entity_Pragma_Node;
Var_Expr_4 : Internal_Entity_Aspect_Assoc;
Var_Expr_5 : Internal_Entity_Attribute_Def_Clause;
Var_Expr_6 : Internal_Entity_At_Clause;
Fld : Internal_Entity_Pragma_Node;
Fld_1 : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Pragma_Node;
Cast_Result : Internal_Entity;
New_Struct : Internal_Aspect;
Scope_Result : Internal_Aspect;
Result_Var : Internal_Aspect;
Scope_Result_1 : Internal_Aspect;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Aspect_Assoc;
Fld_4 : Internal_Entity_Expr;
Cast_Expr_1 : Internal_Entity_Aspect_Assoc;
Cast_Result_1 : Internal_Entity;
New_Struct_1 : Internal_Aspect;
Scope_Result_2 : Internal_Aspect;
Result_Var_1 : Internal_Aspect;
Result_Var_2 : Internal_Aspect;
Scope_Result_3 : Internal_Aspect;
Fld_5 : Internal_Entity_Attribute_Def_Clause;
Fld_6 : Internal_Entity_Expr;
Cast_Expr_2 : Internal_Entity_Attribute_Def_Clause;
Cast_Result_2 : Internal_Entity;
New_Struct_2 : Internal_Aspect;
Scope_Result_4 : Internal_Aspect;
Result_Var_3 : Internal_Aspect;
Result_Var_4 : Internal_Aspect;
Scope_Result_5 : Internal_Aspect;
Fld_7 : Internal_Entity_At_Clause;
Fld_8 : Internal_Entity_Expr;
Cast_Expr_3 : Internal_Entity_At_Clause;
Cast_Result_3 : Internal_Entity;
New_Struct_3 : Internal_Aspect;
Scope_Result_6 : Internal_Aspect;
Result_Var_5 : Internal_Aspect;
Sym : Symbol_Type;
Is_Equal : Boolean;
If_Result : Internal_Aspect;
Result_Var_6 : Internal_Aspect;
Let_Result : Internal_Aspect;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9018 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9002 '<FieldAccess for get_pragma at ast.py:15995>' Fld /tmp/lal-23.0.0/ada/ast.py:15995
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_pragma
Fld := Libadalang.Implementation.Defining_Name_P_Get_Pragma (Node => Ent.Node, Name => Name, E_Info => Ent.Info);
--# end
--# expr-done 9002
Var_Expr_3 := Fld;
if Var_Expr_3 /= No_Entity_Pragma_Node then
   --# scope-start
   --# bind p Var_Expr_3
--# expr-start 9004 '<New Aspect at ast.py:15996>' New_Struct /tmp/lal-23.0.0/ada/ast.py:15996
Cast_Expr := Var_Expr_3; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# expr-start 9003 '<FieldAccess for value_expr at ast.py:15997>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15997
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.value_expr
Fld_1 := Libadalang.Implementation.Pragma_Node_P_Value_Expr (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 9003
New_Struct := (Exists => True, Node => Cast_Result, Value => Fld_1); 
--# expr-done 9004
Scope_Result := New_Struct;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Aspect;
end if;
Var_Expr_2 := Result_Var;
if Var_Expr_2 /= No_Aspect then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_1 := Var_Expr_2;
   --# end
   Result_Var_2 := Scope_Result_1;
else
--# expr-start 9006 '<FieldAccess for get_aspect_assoc at ast.py:15999>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15999
--# expr-start 9005 '<FieldAccess for basic_decl at ast.py:15999>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15999
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl
Fld_2 := Libadalang.Implementation.Defining_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9005
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.get_aspect_assoc'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Get_Aspect_Assoc (Node => Fld_2.Node, Name => Name, E_Info => Fld_2.Info);
--# end
--# expr-done 9006
Var_Expr_4 := Fld_3;
if Var_Expr_4 /= No_Entity_Aspect_Assoc then
   --# scope-start
   --# bind aa Var_Expr_4
--# expr-start 9008 '<New Aspect at ast.py:16000>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:16000
Cast_Expr_1 := Var_Expr_4; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
--# expr-start 9007 '<FieldAccess for expr at ast.py:16000>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16000
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Var_Expr_4.Node.Aspect_Assoc_F_Expr, Info => Var_Expr_4.Info);
--# expr-done 9007
New_Struct_1 := (Exists => True, Node => Cast_Result_1, Value => Fld_4); 
--# expr-done 9008
Scope_Result_2 := New_Struct_1;
   --# end
   Result_Var_1 := Scope_Result_2;
else
   Result_Var_1 := No_Aspect;
end if;
   Result_Var_2 := Result_Var_1;
end if;
Var_Expr_1 := Result_Var_2;
if Var_Expr_1 /= No_Aspect then
   --# scope-start
   --# bind e Var_Expr_1
Scope_Result_3 := Var_Expr_1;
   --# end
   Result_Var_4 := Scope_Result_3;
else
--# expr-start 9009 '<FieldAccess for get_representation_clause at ast.py:16001>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16001
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_representation_clause
Fld_5 := Libadalang.Implementation.Defining_Name_P_Get_Representation_Clause (Node => Ent.Node, Name => Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 9009
Var_Expr_5 := Fld_5;
if Var_Expr_5 /= No_Entity_Attribute_Def_Clause then
   --# scope-start
   --# bind rc Var_Expr_5
--# expr-start 9011 '<New Aspect at ast.py:16002>' New_Struct_2 /tmp/lal-23.0.0/ada/ast.py:16002
Cast_Expr_2 := Var_Expr_5; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
--# expr-start 9010 '<FieldAccess for expr at ast.py:16002>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16002
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Var_Expr_5.Node.Attribute_Def_Clause_F_Expr, Info => Var_Expr_5.Info);
--# expr-done 9010
New_Struct_2 := (Exists => True, Node => Cast_Result_2, Value => Fld_6); 
--# expr-done 9011
Scope_Result_4 := New_Struct_2;
   --# end
   Result_Var_3 := Scope_Result_4;
else
   Result_Var_3 := No_Aspect;
end if;
   Result_Var_4 := Result_Var_3;
end if;
Var_Expr := Result_Var_4;
if Var_Expr /= No_Aspect then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_5 := Var_Expr;
   --# end
   Result_Var_6 := Scope_Result_5;
else
   --# expr-start 9017 '<If at ast.py:16003>' If_Result /tmp/lal-23.0.0/ada/ast.py:16003
--# expr-start 9013 '<Eq at ast.py:16004>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16004
--# expr-start 9012 '<Symbol Address at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Address); 
--# expr-done 9012
Is_Equal := Name = Sym; 
--# expr-done 9013
if Is_Equal then
--# expr-start 9014 '<FieldAccess for get_at_clause at ast.py:16005>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16005
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_at_clause
Fld_7 := Libadalang.Implementation.Defining_Name_P_Get_At_Clause (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 9014
Var_Expr_6 := Fld_7;
if Var_Expr_6 /= No_Entity_At_Clause then
   --# scope-start
   --# bind atc Var_Expr_6
--# expr-start 9016 '<New Aspect at ast.py:16006>' New_Struct_3 /tmp/lal-23.0.0/ada/ast.py:16006
Cast_Expr_3 := Var_Expr_6; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
--# expr-start 9015 '<FieldAccess for expr at ast.py:16006>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16006
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Var_Expr_6.Node.At_Clause_F_Expr, Info => Var_Expr_6.Info);
--# expr-done 9015
New_Struct_3 := (Exists => True, Node => Cast_Result_3, Value => Fld_8); 
--# expr-done 9016
Scope_Result_6 := New_Struct_3;
   --# end
   Result_Var_5 := Scope_Result_6;
else
   Result_Var_5 := No_Aspect;
end if;
   If_Result := Result_Var_5;
else
   If_Result := No_Aspect;
end if;
--# expr-done 9017
   Result_Var_6 := If_Result;
end if;
Let_Result := Result_Var_6; 
--# end
--# expr-done 9018
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Get_Aspect_Impl;
--# end
--# property-start DefiningName.get_aspect /tmp/lal-23.0.0/ada/ast.py:16013
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Get_Aspect
  (Node : Bare_Defining_Name
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Aspect
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Aspect;
            procedure Finalizer_Scope_1155 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Defining_Name_Array_Access;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Sym : Symbol_Type;
Is_Equal : Boolean;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Internal_Entity_Defining_Name_Array_Access;
Fld_1 : Internal_Aspect;
Map_Result : Internal_Aspect_Array_Access;
Fld_2 : Boolean;
Find_Result : Internal_Aspect;
Let_Result : Internal_Aspect;
            procedure Finalizer_Scope_1155 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Singleton);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1155;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9031 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9026 '<If at ast.py:16027>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:16027
--# expr-start 9020 '<Eq at ast.py:16028>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16028
--# expr-start 9019 '<Symbol Inline at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Inline); 
--# expr-done 9019
Is_Equal := Name = Sym; 
--# expr-done 9020
if Is_Equal then
   If_Result := True;
else
   --# expr-start 9022 '<Eq at ast.py:16028>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:16028
--# expr-start 9021 '<Symbol Ghost at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ghost); 
--# expr-done 9021
Is_Equal_1 := Name = Sym_1; 
--# expr-done 9022
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 9024 '<Eq at ast.py:16028>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:16028
--# expr-start 9023 '<Symbol Default_Initial_Condition at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Default_Initial_Condition); 
--# expr-done 9023
Is_Equal_2 := Name = Sym_2; 
--# expr-done 9024
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   --# expr-start 9025 '<FieldAccess for all_parts at ast.py:16035>' Fld /tmp/lal-23.0.0/ada/ast.py:16035
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.all_parts
Fld := Libadalang.Implementation.Defining_Name_P_All_Parts (Node => Ent.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 9025
   If_Result_2 := Fld;
else
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Ent;
   If_Result_2 := Singleton;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 9026
Block_Var := If_Result_2; Inc_Ref (Block_Var);
--# bind parts_to_check Block_Var
--# expr-start 9030 '<Find at ast.py:16040>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16040
   --# expr-start 9028 '<Map at ast.py:16038>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16038
      declare
         Map_Result_Vec : Internal_Aspect_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Block_Var;
      begin
         for Item_279 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_279
      --# expr-start 9027 '<FieldAccess for get_aspect_impl at ast.py:16039>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16039
      if Item_279.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_aspect_impl
Fld_1 := Libadalang.Implementation.Defining_Name_P_Get_Aspect_Impl (Node => Item_279.Node, Name => Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Item_279.Info);
--# end
--# expr-done 9027
         declare
            Item_To_Append : constant Internal_Aspect := Fld_1;
         begin
            Internal_Aspect_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Aspect_Array
           (Items_Count => Natural (Internal_Aspect_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Aspect_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Aspect_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Aspect_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9028
      Find_Result := No_Aspect;
      declare
         Collection : constant Internal_Aspect_Array_Access := Map_Result;
      begin
         for Item_278 of
               Collection.Items
         loop
   --# scope-start
               --# bind a Item_278
      --# expr-start 9029 '<FieldAccess for exists at ast.py:16041>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16041
Fld_2 := Item_278.Exists;
--# expr-done 9029
      if Fld_2 then
         Find_Result := Item_278;
      end if;
   --# end
               exit when Fld_2;
         end loop;
      end;
--# expr-done 9030
Let_Result := Find_Result; 
--# end
--# expr-done 9031
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1155;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1155;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Get_Aspect;
--# end
--# property-start DefiningName.has_aspect /tmp/lal-23.0.0/ada/ast.py:16046
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Has_Aspect
  (Node : Bare_Defining_Name
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
            procedure Finalizer_Scope_2951 with Inline_Always;
      Block_Var : Internal_Aspect;
Var_Expr : Internal_Entity_Expr;
Fld : Internal_Aspect;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Not_Val : Boolean;
Fld_5 : Big_Integer_Type;
Big_Int : Big_Integer_Type;
Is_Equal : Boolean;
If_Result : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Fld_6 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_2951 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Big_Int);
            end Finalizer_Scope_2951;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9044 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9032 '<FieldAccess for get_aspect at ast.py:16053>' Fld /tmp/lal-23.0.0/ada/ast.py:16053
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.get_aspect
Fld := Libadalang.Implementation.Defining_Name_P_Get_Aspect (Node => Ent.Node, Name => Name, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 9032
Block_Var := Fld; 
--# bind a Block_Var
--# expr-start 9033 '<FieldAccess for exists at ast.py:16055>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16055
Fld_1 := Block_Var.Exists;
--# expr-done 9033
if Fld_1 then
   --# expr-start 9043 '<If at ast.py:16055>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16055
--# expr-start 9034 '<FieldAccess for is_contract_aspect at ast.py:16056>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16056
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.is_contract_aspect
Fld_6 := Libadalang.Implementation.Ada_Node_P_Is_Contract_Aspect (Node => Self, Name => Name);
--# end
--# expr-done 9034
if Fld_6 then
   If_Result_1 := True;
else
--# expr-start 9035 '<FieldAccess for value at ast.py:16062>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16062
Fld_2 := Block_Var.Value;
--# expr-done 9035
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind val Var_Expr
--# expr-start 9039 '<Not at ast.py:16066>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16066
--# expr-start 9038 '<Eq at ast.py:16066>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:16066
--# expr-start 9036 '<FieldAccess for expression_type at ast.py:16066>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16066
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_3 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9036
      Cast_Result := Create_Internal_Entity
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
--# expr-start 9037 '<FieldAccess for bool_type at ast.py:16066>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16066
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_4 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 9037
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 9038
Not_Val := not (Is_Equiv); 
--# expr-done 9039
if Not_Val then
   If_Result := True;
else
   --# expr-start 9042 '<Eq at ast.py:16067>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16067
--# expr-start 9040 '<FieldAccess for eval_as_int at ast.py:16067>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16067
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld_5 := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9040
--# expr-start 9041 '<BigInteger 1 at ast.py:16067>' Big_Int /tmp/lal-23.0.0/ada/ast.py:16067
Big_Int := Create_Big_Integer ("1"); 
--# expr-done 9041
Is_Equal := Equivalent (Fld_5, Big_Int); 
--# expr-done 9042
   If_Result := Is_Equal;
end if;
Scope_Result := If_Result;
   --# end
      Finalizer_Scope_2951;
   Result_Var := Scope_Result;
else
   Result_Var := True;
end if;
   If_Result_1 := Result_Var;
end if;
--# expr-done 9043
   If_Result_2 := If_Result_1;
else
   If_Result_2 := False;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 9044
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2951;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Has_Aspect;
--# end
--# property-start DefiningName.is_valid_pragma_for_name /tmp/lal-23.0.0/ada/ast.py:16072
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Is_Valid_Pragma_For_Name
  (Node : Bare_Defining_Name
      ; Name : Symbol_Type
      ; Decl : Internal_Entity
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind decl Decl
   Property_Result : Boolean;
            procedure Finalizer_Scope_2952 with Inline_Always;
      Var_Expr : Internal_Entity_Pragma_Node;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Pragma_Node;
Fld : Internal_Entity_Identifier;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Defining_Name_Array_Access;
Cast_Expr_1 : Internal_Entity_Defining_Name;
Cast_Result_1 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Defining_Name;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
Fld_3 : Bare_Pragma_Node;
Node_Comp : Boolean;
If_Result_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_2952 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2952;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9055 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9045 '<Cast to Pragma at ast.py:16078>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16078
Cast_Expr := Decl; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Pragma_Node_Range
   then
      Cast_Result := Create_Internal_Entity_Pragma_Node
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Pragma_Node;
   end if;
--# expr-done 9045
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Pragma_Node then
   --# scope-start
   --# bind p Var_Expr
--# expr-start 9047 '<FieldAccess for name_is at ast.py:16081>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16081
--# expr-start 9046 '<FieldAccess for id at ast.py:16081>' Fld /tmp/lal-23.0.0/ada/ast.py:16081
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Var_Expr.Node.Pragma_Node_F_Id, Info => Var_Expr.Info);
--# expr-done 9046
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_1 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld.Node, Sym => Name);
--# end
--# expr-done 9047
if Fld_1 then
   --# expr-start 9052 '<Not at ast.py:16083>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16083
--# expr-start 9051 '<IsNull at ast.py:16084>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16084
--# expr-start 9050 '<Find at ast.py:16083>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16083
   --# expr-start 9048 '<FieldAccess for associated_entities at ast.py:16083>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16083
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.associated_entities
Fld_2 := Libadalang.Implementation.Pragma_Node_P_Associated_Entities (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9048
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_2;
      begin
         for Item_280 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_280
      --# expr-start 9049 '<Eq at ast.py:16083>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:16083
Cast_Expr_1 := Ent; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Cast_Expr_2 := Item_280; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 9049
      if Is_Equiv then
         Find_Result := Item_280;
      end if;
   --# end
               exit when Is_Equiv;
         end loop;
      end;
--# expr-done 9050
Is_Null := Find_Result.Node = null; 
--# expr-done 9051
Not_Val := not (Is_Null); 
--# expr-done 9052
   If_Result := Not_Val;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 9054 '<OrderingTest '"'"'lt'"'"' at ast.py:16086>' Node_Comp /tmp/lal-23.0.0/ada/ast.py:16086
--# expr-start 9053 '<FieldAccess for node at ast.py:16086>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16086
Fld_3 := Var_Expr.Node;
--# expr-done 9053
Node_Comp := Compare (Self, Self, Fld_3, Less_Than); 
--# expr-done 9054
   If_Result_1 := Node_Comp;
else
   If_Result_1 := False;
end if;
Scope_Result := If_Result_1;
   --# end
      Finalizer_Scope_2952;
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 9055
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_2952;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Is_Valid_Pragma_For_Name;
--# end
--# property-start DefiningName.get_pragma /tmp/lal-23.0.0/ada/ast.py:16091
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Get_Pragma
  (Node : Bare_Defining_Name
      ; Name : Symbol_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Pragma_Node
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Internal_Entity_Pragma_Node;
            procedure Finalizer_Scope_1158 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Pragma_Node;
Var_Expr_1 : Internal_Entity_Pragma_Node_List;
Var_Expr_2 : Internal_Entity;
Var_Expr_3 : Internal_Entity;
Var_Expr_4 : Internal_Entity_Ada_Node_List;
Var_Expr_5 : Bare_Public_Part;
Var_Expr_6 : Bare_Private_Part;
Match_0 : Bare_Base_Package_Decl;
Match_1 : Bare_Protected_Def;
Match_2 : Bare_Ada_Node;
Var_Expr_7 : Internal_Entity_Declarative_Part;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Pragma_Node_List;
Saved : Internal_Entity_Pragma_Node_List;
Fld_2 : Bare_Pragma_Node_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Pragma_Node;
Is_Null : Boolean;
If_Result : Internal_Entity_Pragma_Node;
Fld_4 : Internal_Entity_Identifier;
Fld_5 : Boolean;
Item_281 : Internal_Entity_Pragma_Node;
Bare_Item_281 : Bare_Pragma_Node;
Find_Result : Internal_Entity_Pragma_Node;
Scope_Result : Internal_Entity_Pragma_Node;
Result_Var : Internal_Entity_Pragma_Node;
Scope_Result_1 : Internal_Entity_Pragma_Node;
Fld_6 : Internal_Entity;
Cast_Result : Internal_Entity_Ada_Node_List;
Saved_1 : Internal_Entity_Ada_Node_List;
Fld_7 : Bare_Ada_Node_List;
Fld_8 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Fld_9 : Boolean;
Item_282 : Internal_Entity;
Bare_Item_282 : Bare_Ada_Node;
Find_Result_1 : Internal_Entity;
Scope_Result_2 : Internal_Entity;
Result_Var_1 : Internal_Entity;
Scope_Result_3 : Internal_Entity;
Fld_10 : Bare_Declarative_Part;
Cast_Result_1 : Bare_Public_Part;
Fld_11 : Bare_Ada_Node;
Fld_12 : Bare_Private_Part;
Fld_13 : Bare_Private_Part;
Match_Prefix : Bare_Ada_Node;
Cast_Result_2 : Bare_Base_Package_Decl;
Let_Result : Bare_Private_Part;
Scope_Result_4 : Bare_Private_Part;
Cast_Result_3 : Bare_Protected_Def;
Let_Result_1 : Bare_Private_Part;
Scope_Result_5 : Bare_Private_Part;
Cast_Result_4 : Bare_Ada_Node;
Let_Result_2 : Bare_Private_Part;
Scope_Result_6 : Bare_Private_Part;
Match_Result : Bare_Private_Part;
Fld_14 : Bare_Ada_Node_List;
Scope_Result_7 : Bare_Ada_Node_List;
Result_Var_2 : Bare_Ada_Node_List;
As_Entity_2 : Internal_Entity_Ada_Node_List;
Is_Null_2 : Boolean;
If_Result_2 : Internal_Entity_Ada_Node_List;
Fld_15 : Bare_Ada_Node_List;
Fld_16 : Internal_Entity_Info;
As_Entity_3 : Internal_Entity;
Is_Null_3 : Boolean;
If_Result_3 : Internal_Entity;
Fld_17 : Boolean;
Item_283 : Internal_Entity;
Bare_Item_283 : Bare_Ada_Node;
Find_Result_2 : Internal_Entity;
Scope_Result_8 : Internal_Entity;
Result_Var_3 : Internal_Entity;
Result_Var_4 : Internal_Entity;
Scope_Result_9 : Internal_Entity;
Fld_18 : Internal_Entity_Declarative_Part_Array_Access;
Get_Result : Internal_Entity_Declarative_Part;
Fld_19 : Internal_Entity_Ada_Node_List;
Scope_Result_10 : Internal_Entity_Ada_Node_List;
Result_Var_5 : Internal_Entity_Ada_Node_List;
Fld_20 : Bare_Ada_Node_List;
Fld_21 : Internal_Entity_Info;
As_Entity_4 : Internal_Entity;
Is_Null_4 : Boolean;
If_Result_4 : Internal_Entity;
Fld_22 : Boolean;
Item_284 : Internal_Entity;
Bare_Item_284 : Bare_Ada_Node;
Find_Result_3 : Internal_Entity;
Result_Var_6 : Internal_Entity;
Cast_Result_5 : Internal_Entity_Pragma_Node;
Result_Var_7 : Internal_Entity_Pragma_Node;
Let_Result_3 : Internal_Entity_Pragma_Node;
            procedure Finalizer_Scope_1158 is
            begin
                     Dec_Ref (Fld_18);
            end Finalizer_Scope_1158;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9081 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 9056 '<FieldAccess for basic_decl_no_internal at ast.py:16099>' Fld /tmp/lal-23.0.0/ada/ast.py:16099
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl_no_internal
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl_No_Internal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9056
Block_Var := Fld; 
--# bind bd Block_Var
--# expr-start 9057 '<FieldAccess for library_item_pragmas at ast.py:16101>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16101
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.library_item_pragmas
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Library_Item_Pragmas (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 9057
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity_Pragma_Node_List then
   --# scope-start
   --# bind plist Var_Expr_1
--# expr-start 9060 '<Find at ast.py:16103>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16103
Saved := Var_Expr_1; 
Fld_2 := Saved.Node;
      Find_Result := No_Entity_Pragma_Node;
      if Fld_2 = null then
      Find_Result := No_Entity_Pragma_Node;
      else
      declare
         Collection : constant Bare_Pragma_Node_List := Fld_2;
      begin
         for Untyped_Item_281 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_281 := Untyped_Item_281; 
Is_Null := Bare_Item_281 = null; 
if Is_Null then
   If_Result := No_Entity_Pragma_Node;
else
Fld_3 := Saved.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_281); 
   If_Result := As_Entity;
end if;
                  Item_281 := If_Result; 
   --# scope-start
               --# bind p Item_281
      --# expr-start 9059 '<FieldAccess for name_is at ast.py:16103>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16103
--# expr-start 9058 '<FieldAccess for id at ast.py:16103>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16103
      if Item_281.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Item_281.Node.Pragma_Node_F_Id, Info => Item_281.Info);
--# expr-done 9058
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_5 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_4.Node, Sym => Name);
--# end
--# expr-done 9059
      if Fld_5 then
         Find_Result := Item_281;
      end if;
   --# end
               exit when Fld_5;
         end loop;
      end;
      end if;
--# expr-done 9060
Scope_Result := Find_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Pragma_Node;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Pragma_Node then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_1 := Var_Expr;
   --# end
   Result_Var_7 := Scope_Result_1;
else
   --# expr-start 9080 '<Cast to Pragma at ast.py:16130>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:16130
--# expr-start 9062 '<Cast to AdaNode.list at ast.py:16109>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16109
--# expr-start 9061 '<parent at ast.py:16109>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16109
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Parent (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 9061
   if Fld_6.Node = null
      or else Fld_6.Node.Kind in Ada_Ada_Node_List_Range
   then
      Cast_Result := Create_Internal_Entity_Ada_Node_List
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
   else
         Cast_Result := No_Entity_Ada_Node_List;
   end if;
--# expr-done 9062
Var_Expr_4 := Cast_Result;
if Var_Expr_4 /= No_Entity_Ada_Node_List then
   --# scope-start
--# expr-start 9064 '<Find at ast.py:16109>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:16109
Saved_1 := Var_Expr_4; 
Fld_7 := Saved_1.Node;
      Find_Result_1 := No_Entity;
      if Fld_7 = null then
      Find_Result_1 := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_7;
      begin
         for Untyped_Item_282 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_282 := Untyped_Item_282; 
Is_Null_1 := Bare_Item_282 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_8 := Saved_1.Info;
As_Entity_1 := (Info => Fld_8, Node => Bare_Item_282); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_282 := If_Result_1; 
   --# scope-start
               --# bind d Item_282
      --# expr-start 9063 '<FieldAccess for is_valid_pragma_for_name at ast.py:16110>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:16110
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_valid_pragma_for_name
Fld_9 := Libadalang.Implementation.Defining_Name_P_Is_Valid_Pragma_For_Name (Node => Ent.Node, Name => Name, Decl => Item_282, E_Info => Ent.Info);
--# end
--# expr-done 9063
      if Fld_9 then
         Find_Result_1 := Item_282;
      end if;
   --# end
               exit when Fld_9;
         end loop;
      end;
      end if;
--# expr-done 9064
Scope_Result_2 := Find_Result_1;
   --# end
   Result_Var_1 := Scope_Result_2;
else
   Result_Var_1 := No_Entity;
end if;
Var_Expr_3 := Result_Var_1;
if Var_Expr_3 /= No_Entity then
   --# scope-start
   --# bind e Var_Expr_3
Scope_Result_3 := Var_Expr_3;
   --# end
   Result_Var_4 := Scope_Result_3;
else
--# expr-start 9066 '<Cast to PublicPart at ast.py:16115>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16115
--# expr-start 9065 '<FieldAccess for declarative_scope at ast.py:16115>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:16115
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld_10 := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Block_Var.Node);
--# end
--# expr-done 9065
   if Fld_10 = null
      or else Fld_10.Kind in Ada_Public_Part_Range
   then
      Cast_Result_1 := Fld_10;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 9066
Var_Expr_5 := Cast_Result_1;
if Var_Expr_5 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind pp Var_Expr_5
--# expr-start 9074 '<Find at ast.py:16120>' Find_Result_2 /tmp/lal-23.0.0/ada/ast.py:16120
   --# expr-start 9072 '<as_entity at ast.py:16120>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:16120
--# expr-start 9070 '<Match at ast.py:16116>' Match_Result /tmp/lal-23.0.0/ada/ast.py:16116
--# expr-start 9067 '<parent at ast.py:16116>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:16116
      if Var_Expr_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Var_Expr_5.Parent; 
--# expr-done 9067
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_11; 
case Ada_Ada_Node (Match_Prefix.Kind) is
         when Ada_Generic_Package_Internal .. Ada_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_0 := Cast_Result_2; 
--# bind pkg Match_0
--# expr-start 9068 '<FieldAccess for private_part at ast.py:16117>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:16117
      if Match_0 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Match_0.Base_Package_Decl_F_Private_Part;
--# expr-done 9068
Let_Result := Fld_12; 
--# end
Scope_Result_4 := Let_Result;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Protected_Def =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_1 := Cast_Result_3; 
--# bind ptd Match_1
--# expr-start 9069 '<FieldAccess for private_part at ast.py:16118>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:16118
      if Match_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Match_1.Protected_Def_F_Private_Part;
--# expr-done 9069
Let_Result_1 := Fld_13; 
--# end
Scope_Result_5 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Abort_Absent .. Ada_Synthetic_Formal_Param_Decl | Ada_Discrete_Base_Subtype_Decl .. Ada_Private_Present | Ada_Protected_Absent .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix;
Match_2 := Cast_Result_4; 
--# bind _ Match_2
Let_Result_2 := No_Bare_Ada_Node; 
--# end
Scope_Result_6 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_6; 
end case;
--# expr-done 9070
Var_Expr_6 := Match_Result;
if Var_Expr_6 /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 9071 '<FieldAccess for decls at ast.py:16120>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:16120
      if Var_Expr_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Var_Expr_6.Declarative_Part_F_Decls;
--# expr-done 9071
Scope_Result_7 := Fld_14;
   --# end
   Result_Var_2 := Scope_Result_7;
else
   Result_Var_2 := No_Bare_Ada_Node;
end if;
Is_Null_2 := Result_Var_2 = null; 
if Is_Null_2 then
   If_Result_2 := No_Entity_Ada_Node_List;
else
As_Entity_2 := (Info => E_Info, Node => Result_Var_2); 
   If_Result_2 := As_Entity_2;
end if;
--# expr-done 9072
Fld_15 := If_Result_2.Node;
      Find_Result_2 := No_Entity;
      if Fld_15 = null then
      Find_Result_2 := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_15;
      begin
         for Untyped_Item_283 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_283 := Untyped_Item_283; 
Is_Null_3 := Bare_Item_283 = null; 
if Is_Null_3 then
   If_Result_3 := No_Entity;
else
Fld_16 := If_Result_2.Info;
As_Entity_3 := (Info => Fld_16, Node => Bare_Item_283); 
   If_Result_3 := As_Entity_3;
end if;
                  Item_283 := If_Result_3; 
   --# scope-start
               --# bind d Item_283
      --# expr-start 9073 '<FieldAccess for is_valid_pragma_for_name at ast.py:16121>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:16121
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_valid_pragma_for_name
Fld_17 := Libadalang.Implementation.Defining_Name_P_Is_Valid_Pragma_For_Name (Node => Ent.Node, Name => Name, Decl => Item_283, E_Info => Ent.Info);
--# end
--# expr-done 9073
      if Fld_17 then
         Find_Result_2 := Item_283;
      end if;
   --# end
               exit when Fld_17;
         end loop;
      end;
      end if;
--# expr-done 9074
Scope_Result_8 := Find_Result_2;
   --# end
   Result_Var_3 := Scope_Result_8;
else
   Result_Var_3 := No_Entity;
end if;
   Result_Var_4 := Result_Var_3;
end if;
Var_Expr_2 := Result_Var_4;
if Var_Expr_2 /= No_Entity then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_9 := Var_Expr_2;
   --# end
   Result_Var_6 := Scope_Result_9;
else
   --# expr-start 9079 '<Find at ast.py:16126>' Find_Result_3 /tmp/lal-23.0.0/ada/ast.py:16126
--# expr-start 9076 '<at at ast.py:16126>' Get_Result /tmp/lal-23.0.0/ada/ast.py:16126
--# expr-start 9075 '<FieldAccess for declarative_parts at ast.py:16126>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:16126
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.declarative_parts'
Fld_18 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Declarative_Parts (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 9075
Get_Result := Get (Self, Fld_18, 0, True); 
--# expr-done 9076
Var_Expr_7 := Get_Result;
if Var_Expr_7 /= No_Entity_Declarative_Part then
   --# scope-start
--# expr-start 9077 '<FieldAccess for decls at ast.py:16126>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:16126
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Ada_Node_List (Node => Var_Expr_7.Node.Declarative_Part_F_Decls, Info => Var_Expr_7.Info);
--# expr-done 9077
Scope_Result_10 := Fld_19;
   --# end
   Result_Var_5 := Scope_Result_10;
else
   Result_Var_5 := No_Entity_Ada_Node_List;
end if;
Fld_20 := Result_Var_5.Node;
      Find_Result_3 := No_Entity;
      if Fld_20 = null then
      Find_Result_3 := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_20;
      begin
         for Untyped_Item_284 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_284 := Untyped_Item_284; 
Is_Null_4 := Bare_Item_284 = null; 
if Is_Null_4 then
   If_Result_4 := No_Entity;
else
Fld_21 := Result_Var_5.Info;
As_Entity_4 := (Info => Fld_21, Node => Bare_Item_284); 
   If_Result_4 := As_Entity_4;
end if;
                  Item_284 := If_Result_4; 
   --# scope-start
               --# bind d Item_284
      --# expr-start 9078 '<FieldAccess for is_valid_pragma_for_name at ast.py:16127>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:16127
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_valid_pragma_for_name
Fld_22 := Libadalang.Implementation.Defining_Name_P_Is_Valid_Pragma_For_Name (Node => Ent.Node, Name => Name, Decl => Item_284, E_Info => Ent.Info);
--# end
--# expr-done 9078
      if Fld_22 then
         Find_Result_3 := Item_284;
      end if;
   --# end
               exit when Fld_22;
         end loop;
      end;
      end if;
--# expr-done 9079
   Result_Var_6 := Find_Result_3;
end if;
   if Result_Var_6.Node = null
      or else Result_Var_6.Node.Kind in Ada_Pragma_Node_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Pragma_Node
        (Node => Result_Var_6.Node,
         Info => Result_Var_6.Info);
   else
         Cast_Result_5 := No_Entity_Pragma_Node;
   end if;
--# expr-done 9080
   Result_Var_7 := Cast_Result_5;
end if;
Let_Result_3 := Result_Var_7; 
--# end
--# expr-done 9081
      Property_Result := Let_Result_3;
   --# end
      Finalizer_Scope_1158;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1158;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Get_Pragma;
--# end
--# property-start DefiningName.get_representation_clause /tmp/lal-23.0.0/ada/ast.py:16135
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Get_Representation_Clause
  (Node : Bare_Defining_Name
      ; Name : Symbol_Type
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Attribute_Def_Clause
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_Attribute_Def_Clause;
      Var_Expr : Bare_Declarative_Part;
Var_Expr_1 : Internal_Entity_Attribute_Def_Clause;
Attr : Internal_Entity_Attribute_Ref;
Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node_List;
Scope_Result : Bare_Ada_Node_List;
Result_Var : Bare_Ada_Node_List;
As_Entity : Internal_Entity_Ada_Node_List;
Is_Null : Boolean;
If_Result : Internal_Entity_Ada_Node_List;
Fld_2 : Bare_Ada_Node_List;
Fld_3 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Attribute_Def_Clause;
Fld_4 : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Attribute_Ref;
Fld_5 : Internal_Entity_Identifier;
Fld_6 : Boolean;
Fld_7 : Internal_Entity_Name;
Fld_8 : Internal_Entity_Defining_Name;
Cast_Result_2 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Defining_Name;
Cast_Result_3 : Internal_Entity;
Is_Equiv : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Item_285 : Internal_Entity;
Bare_Item_285 : Bare_Ada_Node;
Find_Result : Internal_Entity;
Cast_Result_4 : Internal_Entity_Attribute_Def_Clause;
Let_Result_1 : Internal_Entity_Attribute_Def_Clause;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9096 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 9095 '<Cast to AttributeDefClause.entity at ast.py:16148>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:16148
--# expr-start 9094 '<Find at ast.py:16140>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16140
   --# expr-start 9084 '<as_entity at ast.py:16140>' If_Result /tmp/lal-23.0.0/ada/ast.py:16140
--# expr-start 9082 '<FieldAccess for declarative_scope at ast.py:16140>' Fld /tmp/lal-23.0.0/ada/ast.py:16140
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 9082
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 9083 '<FieldAccess for decls at ast.py:16140>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16140
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr.Declarative_Part_F_Decls;
--# expr-done 9083
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_Null := Result_Var = null; 
if Is_Null then
   If_Result := No_Entity_Ada_Node_List;
else
As_Entity := (Info => E_Info, Node => Result_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 9084
Fld_2 := If_Result.Node;
      Find_Result := No_Entity;
      if Fld_2 = null then
      Find_Result := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_285 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_285 := Untyped_Item_285; 
Is_Null_1 := Bare_Item_285 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_3 := If_Result.Info;
As_Entity_1 := (Info => Fld_3, Node => Bare_Item_285); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_285 := If_Result_1; 
   --# scope-start
               --# bind d Item_285
--# expr-start 9085 '<Cast to AttributeDefClause at ast.py:16141>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16141
Cast_Expr := Item_285; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Attribute_Def_Clause_Range
   then
      Cast_Result := Create_Internal_Entity_Attribute_Def_Clause
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Attribute_Def_Clause;
   end if;
--# expr-done 9085
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Attribute_Def_Clause then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 9093 '<Let at ast.py:16142>' Let_Result /tmp/lal-23.0.0/ada/ast.py:16142
--# scope-start
--# expr-start 9087 '<Cast to AttributeRef at ast.py:16143>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16143
--# expr-start 9086 '<FieldAccess for attribute_expr at ast.py:16143>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16143
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Attribute_Def_Clause_F_Attribute_Expr, Info => Var_Expr_1.Info);
--# expr-done 9086
   if Fld_4.Node = null
      or else Fld_4.Node.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Attribute_Ref
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9087
Attr := Cast_Result_1; 
--# bind attr Attr
--# expr-start 9089 '<FieldAccess for name_is at ast.py:16144>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16144
--# expr-start 9088 '<FieldAccess for attribute at ast.py:16144>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16144
      if Attr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Identifier (Node => Attr.Node.Attribute_Ref_F_Attribute, Info => Attr.Info);
--# expr-done 9088
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_is
Fld_6 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_5.Node, Sym => Name);
--# end
--# expr-done 9089
if Fld_6 then
   --# expr-start 9092 '<Eq at ast.py:16145>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:16145
--# expr-start 9091 '<FieldAccess for referenced_defining_name at ast.py:16145>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16145
--# expr-start 9090 '<FieldAccess for prefix at ast.py:16145>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16145
      if Attr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Attr.Node.Attribute_Ref_F_Prefix, Info => Attr.Info);
--# expr-done 9090
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_defining_name
Fld_8 := Libadalang.Implementation.Name_P_Referenced_Defining_Name (Node => Fld_7.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_7.Info);
--# end
--# expr-done 9091
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 9092
   If_Result_2 := Is_Equiv;
else
   If_Result_2 := False;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 9093
Scope_Result_1 := Let_Result;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
      if Result_Var_1 then
         Find_Result := Item_285;
      end if;
   --# end
               exit when Result_Var_1;
         end loop;
      end;
      end if;
--# expr-done 9094
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Attribute_Def_Clause_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Attribute_Def_Clause
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_4 := No_Entity_Attribute_Def_Clause;
   end if;
--# expr-done 9095
Let_Result_1 := Cast_Result_4; 
--# end
--# expr-done 9096
      Property_Result := Let_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Get_Representation_Clause;
--# end
--# property-start DefiningName.get_at_clause /tmp/lal-23.0.0/ada/ast.py:16152
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Get_At_Clause
  (Node : Bare_Defining_Name
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_At_Clause
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Entity_At_Clause;
      Var_Expr : Bare_Declarative_Part;
Var_Expr_1 : Internal_Entity_At_Clause;
Fld : Bare_Declarative_Part;
Fld_1 : Bare_Ada_Node_List;
Scope_Result : Bare_Ada_Node_List;
Result_Var : Bare_Ada_Node_List;
As_Entity : Internal_Entity_Ada_Node_List;
Is_Null : Boolean;
If_Result : Internal_Entity_Ada_Node_List;
Fld_2 : Bare_Ada_Node_List;
Fld_3 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_At_Clause;
Fld_4 : Internal_Entity_Base_Id;
Fld_5 : Internal_Entity_Defining_Name;
Cast_Result_1 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Defining_Name;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Item_286 : Internal_Entity;
Bare_Item_286 : Bare_Ada_Node;
Find_Result : Internal_Entity;
Cast_Result_3 : Internal_Entity_At_Clause;
Let_Result : Internal_Entity_At_Clause;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9106 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9105 '<Cast to AtClause.entity at ast.py:16160>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:16160
--# expr-start 9104 '<Find at ast.py:16156>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16156
   --# expr-start 9099 '<as_entity at ast.py:16156>' If_Result /tmp/lal-23.0.0/ada/ast.py:16156
--# expr-start 9097 '<FieldAccess for declarative_scope at ast.py:16156>' Fld /tmp/lal-23.0.0/ada/ast.py:16156
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 9097
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 9098 '<FieldAccess for decls at ast.py:16156>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16156
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Var_Expr.Declarative_Part_F_Decls;
--# expr-done 9098
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_Null := Result_Var = null; 
if Is_Null then
   If_Result := No_Entity_Ada_Node_List;
else
As_Entity := (Info => E_Info, Node => Result_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 9099
Fld_2 := If_Result.Node;
      Find_Result := No_Entity;
      if Fld_2 = null then
      Find_Result := No_Entity;
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_2;
      begin
         for Untyped_Item_286 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_286 := Untyped_Item_286; 
Is_Null_1 := Bare_Item_286 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_3 := If_Result.Info;
As_Entity_1 := (Info => Fld_3, Node => Bare_Item_286); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_286 := If_Result_1; 
   --# scope-start
               --# bind d Item_286
--# expr-start 9100 '<Cast to AtClause at ast.py:16157>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16157
Cast_Expr := Item_286; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_At_Clause_Range
   then
      Cast_Result := Create_Internal_Entity_At_Clause
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_At_Clause;
   end if;
--# expr-done 9100
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_At_Clause then
   --# scope-start
   --# bind p Var_Expr_1
--# expr-start 9103 '<Eq at ast.py:16158>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:16158
--# expr-start 9102 '<FieldAccess for referenced_defining_name at ast.py:16158>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16158
--# expr-start 9101 '<FieldAccess for name at ast.py:16158>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16158
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Base_Id (Node => Var_Expr_1.Node.At_Clause_F_Name, Info => Var_Expr_1.Info);
--# expr-done 9101
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_defining_name
Fld_5 := Libadalang.Implementation.Name_P_Referenced_Defining_Name (Node => Fld_4.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_4.Info);
--# end
--# expr-done 9102
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Cast_Expr_1 := Ent; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 9103
Scope_Result_1 := Is_Equiv;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
      if Result_Var_1 then
         Find_Result := Item_286;
      end if;
   --# end
               exit when Result_Var_1;
         end loop;
      end;
      end if;
--# expr-done 9104
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_At_Clause_Range
   then
      Cast_Result_3 := Create_Internal_Entity_At_Clause
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_3 := No_Entity_At_Clause;
   end if;
--# expr-done 9105
Let_Result := Cast_Result_3; 
--# end
--# expr-done 9106
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Get_At_Clause;
--# end
--# property-start DefiningName.is_imported /tmp/lal-23.0.0/ada/ast.py:16163
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Is_Imported
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Sym : Symbol_Type;
Fld : Boolean;
Sym_1 : Symbol_Type;
Fld_1 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9111 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9108 '<FieldAccess for has_aspect at ast.py:16168>' Fld /tmp/lal-23.0.0/ada/ast.py:16168
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9107 '<Symbol Import at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import); 
--# expr-done 9107
--# property-call-start DefiningName.has_aspect
Fld := Libadalang.Implementation.Defining_Name_P_Has_Aspect (Node => Ent.Node, Name => Sym, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 9108
if Fld then
   If_Result := True;
else
   --# expr-start 9110 '<FieldAccess for has_aspect at ast.py:16168>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16168
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9109 '<Symbol Interface at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Interface); 
--# expr-done 9109
--# property-call-start DefiningName.has_aspect
Fld_1 := Libadalang.Implementation.Defining_Name_P_Has_Aspect (Node => Ent.Node, Name => Sym_1, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 9110
   If_Result := Fld_1;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 9111
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Is_Imported;
--# end
--# property-start DefiningName.is_ghost_code /tmp/lal-23.0.0/ada/ast.py:16171
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Is_Ghost_Code
  (Node : Bare_Defining_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Generic_Instantiation;
Var_Expr_2 : Internal_Entity_Name;
Match_0 : Internal_Entity_Subp_Renaming_Decl;
Match_1 : Internal_Entity_Package_Renaming_Decl;
Match_2 : Internal_Entity_Generic_Renaming_Decl;
Match_3 : Internal_Entity_Basic_Decl;
Var_Expr_3 : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Basic_Decl;
Sym : Symbol_Type;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Basic_Decl;
Fld_3 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Generic_Instantiation;
Fld_4 : Internal_Entity_Basic_Decl;
Fld_5 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_1 : Boolean;
Fld_6 : Internal_Entity_Renaming_Clause;
Fld_7 : Internal_Entity_Name;
Fld_8 : Internal_Entity_Renaming_Clause;
Fld_9 : Internal_Entity_Name;
Fld_10 : Internal_Entity_Name;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Subp_Renaming_Decl;
Let_Result : Internal_Entity_Name;
Scope_Result_2 : Internal_Entity_Name;
Cast_Result_2 : Internal_Entity_Package_Renaming_Decl;
Let_Result_1 : Internal_Entity_Name;
Scope_Result_3 : Internal_Entity_Name;
Cast_Result_3 : Internal_Entity_Generic_Renaming_Decl;
Let_Result_2 : Internal_Entity_Name;
Scope_Result_4 : Internal_Entity_Name;
Cast_Result_4 : Internal_Entity_Basic_Decl;
Let_Result_3 : Internal_Entity_Name;
Scope_Result_5 : Internal_Entity_Name;
Match_Result : Internal_Entity_Name;
Fld_11 : Internal_Entity_Defining_Name;
Fld_12 : Boolean;
Scope_Result_6 : Boolean;
Result_Var_2 : Boolean;
Scope_Result_7 : Boolean;
Result_Var_3 : Boolean;
If_Result_2 : Boolean;
Let_Result_4 : Boolean;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Defining_Name_Defining_Name_P_Is_Ghost_Code,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Defining_Name,
                                As_Bare_Defining_Name => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Boolean;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 9128 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 9112 '<FieldAccess for basic_decl_no_internal at ast.py:16176>' Fld /tmp/lal-23.0.0/ada/ast.py:16176
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.basic_decl_no_internal
Fld := Libadalang.Implementation.Defining_Name_P_Basic_Decl_No_Internal (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9112
Block_Var := Fld; 
--# bind bd Block_Var
--# expr-start 9114 '<FieldAccess for has_aspect at ast.py:16178>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16178
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9113 '<Symbol Ghost at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ghost); 
--# expr-done 9113
--# property-call-start DefiningName.has_aspect
Fld_1 := Libadalang.Implementation.Defining_Name_P_Has_Aspect (Node => Ent.Node, Name => Sym, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 9114
if Fld_1 then
   If_Result := True;
else
--# expr-start 9115 '<FieldAccess for parent_basic_decl at ast.py:16179>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16179
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_2 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 9115
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 9116 '<FieldAccess for is_ghost_code at ast.py:16179>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16179
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_ghost_code
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Is_Ghost_Code (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9116
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
end if;
if If_Result then
   If_Result_1 := True;
else
--# expr-start 9117 '<Cast to GenericInstantiation at ast.py:16182>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16182
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Generic_Instantiation
   then
      Cast_Result := Create_Internal_Entity_Generic_Instantiation
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Generic_Instantiation;
   end if;
--# expr-done 9117
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Generic_Instantiation then
   --# scope-start
   --# bind gi Var_Expr_1
--# expr-start 9119 '<FieldAccess for is_ghost_code at ast.py:16183>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16183
--# expr-start 9118 '<FieldAccess for designated_generic_decl at ast.py:16183>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16183
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericInstantiation.designated_generic_decl'
Fld_4 := Libadalang.Implementation.Dispatcher_Generic_Instantiation_P_Designated_Generic_Decl (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 9118
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_ghost_code
Fld_5 := Libadalang.Implementation.Basic_Decl_P_Is_Ghost_Code (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 9119
Scope_Result_1 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_1 := Result_Var_1;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
--# expr-start 9125 '<Match at ast.py:16187>' Match_Result /tmp/lal-23.0.0/ada/ast.py:16187
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Block_Var; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Subp_Renaming_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_1; 
--# bind sr Match_0
--# expr-start 9121 '<FieldAccess for renamed_object at ast.py:16188>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16188
--# expr-start 9120 '<FieldAccess for renames at ast.py:16188>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16188
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Renaming_Clause (Node => Match_0.Node.Subp_Renaming_Decl_F_Renames, Info => Match_0.Info);
--# expr-done 9120
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Fld_6.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_6.Info);
--# expr-done 9121
Let_Result := Fld_7; 
--# end
Scope_Result_2 := Let_Result;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Package_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Package_Renaming_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_2; 
--# bind pr Match_1
--# expr-start 9123 '<FieldAccess for renamed_object at ast.py:16189>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:16189
--# expr-start 9122 '<FieldAccess for renames at ast.py:16189>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16189
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Renaming_Clause (Node => Match_1.Node.Package_Renaming_Decl_F_Renames, Info => Match_1.Info);
--# expr-done 9122
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Name (Node => Fld_8.Node.Renaming_Clause_F_Renamed_Object, Info => Fld_8.Info);
--# expr-done 9123
Let_Result_1 := Fld_9; 
--# end
Scope_Result_3 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Generic_Package_Renaming_Decl .. Ada_Generic_Subp_Renaming_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Generic_Renaming_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind gr Match_2
--# expr-start 9124 '<FieldAccess for renaming_name at ast.py:16190>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:16190
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]GenericRenamingDecl.renaming_name'
Fld_10 := Libadalang.Implementation.Dispatcher_Generic_Renaming_Decl_P_Renaming_Name (Node => Match_2.Node, E_Info => Match_2.Info);
--# end
--# expr-done 9124
Let_Result_2 := Fld_10; 
--# end
Scope_Result_4 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Abstract_State_Decl .. Ada_Subp_Body | Ada_Package_Body_Stub .. Ada_Generic_Subp_Instantiation | Ada_Label_Decl .. Ada_No_Type_Object_Renaming_Decl | Ada_Single_Protected_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_4; 
--# bind _ Match_3
Let_Result_3 := No_Entity_Name; 
--# end
Scope_Result_5 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_5; 
end case;
--# expr-done 9125
Var_Expr_2 := Match_Result;
if Var_Expr_2 /= No_Entity_Name then
   --# scope-start
   --# bind c Var_Expr_2
--# expr-start 9126 '<FieldAccess for referenced_defining_name at ast.py:16192>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:16192
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_defining_name
Fld_11 := Libadalang.Implementation.Name_P_Referenced_Defining_Name (Node => Var_Expr_2.Node, Imprecise_Fallback => False, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 9126
Var_Expr_3 := Fld_11;
if Var_Expr_3 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 9127 '<FieldAccess for is_ghost_code at ast.py:16192>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:16192
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_ghost_code
Fld_12 := Libadalang.Implementation.Defining_Name_P_Is_Ghost_Code (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 9127
Scope_Result_6 := Fld_12;
   --# end
   Result_Var_2 := Scope_Result_6;
else
   Result_Var_2 := False;
end if;
Scope_Result_7 := Result_Var_2;
   --# end
   Result_Var_3 := Scope_Result_7;
else
   Result_Var_3 := False;
end if;
   If_Result_2 := Result_Var_3;
end if;
Let_Result_4 := If_Result_2; 
--# end
--# expr-done 9128
      Property_Result := Let_Result_4;
   --# end
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Boolean,
                        As_Boolean => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Is_Ghost_Code;
--# end
--# property-start DefiningName.xref_equation /tmp/lal-23.0.0/ada/ast.py:16196
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Xref_Equation
  (Node : Bare_Defining_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Defining_Name :=
     Internal_Entity_Defining_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1163 with Inline_Always;
            procedure Finalizer_Scope_2999 with Inline_Always;
      Var_Expr : Internal_Entity_Dotted_Name;
Fld : Internal_Entity_Name;
Cast_Result : Internal_Entity_Dotted_Name;
Fld_1 : Internal_Entity_Name;
Fld_2 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1163 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1163;
            procedure Finalizer_Scope_2999 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_2999;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9133 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9130 '<Cast to DottedName at ast.py:16200>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16200
--# expr-start 9129 '<FieldAccess for name at ast.py:16200>' Fld /tmp/lal-23.0.0/ada/ast.py:16200
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Defining_Name_F_Name, Info => Ent.Info);
--# expr-done 9129
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result := Create_Internal_Entity_Dotted_Name
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Dotted_Name;
   end if;
--# expr-done 9130
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Dotted_Name then
   --# scope-start
   --# bind dn Var_Expr
--# expr-start 9132 '<FieldAccess for xref_equation at ast.py:16201>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16201
--# expr-start 9131 '<FieldAccess for prefix at ast.py:16201>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16201
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Dotted_Name_F_Prefix, Info => Var_Expr.Info);
--# expr-done 9131
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_2 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 9132
Scope_Result := Fld_2;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2999;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16202") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 9133
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1163;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1163;
               Finalizer_Scope_2999;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Xref_Equation;
--# end
--# property-start DefiningName.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:16207
pragma Warnings (Off, "is not referenced");
 function Defining_Name_P_Xref_Entry_Point
  (Node : Bare_Defining_Name
  )
   return Boolean
is
   Self : Bare_Defining_Name := Bare_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Name;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9135 '<IsA DottedName at ast.py:16207>' Is_A /tmp/lal-23.0.0/ada/ast.py:16207
--# expr-start 9134 '<FieldAccess for name at ast.py:16207>' Fld /tmp/lal-23.0.0/ada/ast.py:16207
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Defining_Name_F_Name;
--# expr-done 9134
Is_A := Fld /= null 
and then Fld.Kind in Ada_Dotted_Name_Range; 
--# expr-done 9135
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Defining_Name_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_Synthetic_Defining_Name
   --
      procedure Initialize_Fields_For_Synthetic_Defining_Name
        (Self : Bare_Synthetic_Defining_Name
         ; Defining_Name_F_Name : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Defining_Name
              (Self, Defining_Name_F_Name);
      end Initialize_Fields_For_Synthetic_Defining_Name;
--# property-start SyntheticDefiningName.name_symbol /tmp/lal-23.0.0/ada/ast.py:17462
pragma Warnings (Off, "is not referenced");
 function Synthetic_Defining_Name_P_Name_Symbol
  (Node : Bare_Synthetic_Defining_Name
  )
   return Symbol_Type
is
   Self : Bare_Synthetic_Defining_Name := Bare_Synthetic_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Fld : Bare_Name;
Fld_1 : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9137 '<FieldAccess for name_symbol at ast.py:17462>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17462
--# expr-start 9136 '<FieldAccess for name at ast.py:17462>' Fld /tmp/lal-23.0.0/ada/ast.py:17462
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Defining_Name_F_Name;
--# expr-done 9136
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld);
--# end
--# expr-done 9137
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Defining_Name_P_Name_Symbol;
--# end
--# property-start SyntheticDefiningName.as_symbol_array /tmp/lal-23.0.0/ada/ast.py:17464
pragma Warnings (Off, "is not referenced");
 function Synthetic_Defining_Name_P_As_Symbol_Array
  (Node : Bare_Synthetic_Defining_Name
  )
   return Symbol_Type_Array_Access
is
   Self : Bare_Synthetic_Defining_Name := Bare_Synthetic_Defining_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1248 with Inline_Always;
      Fld : Symbol_Type;
Singleton : Symbol_Type_Array_Access;
            procedure Finalizer_Scope_1248 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_1248;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9138 '<FieldAccess for name_symbol at ast.py:17464>' Fld /tmp/lal-23.0.0/ada/ast.py:17464
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Self);
--# end
--# expr-done 9138
                Singleton := Create_Symbol_Type_Array (Items_Count => 1);
                Singleton.Items (1) := Fld;
      Property_Result := Singleton;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1248;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1248;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Defining_Name_P_As_Symbol_Array;
--# end
   --
   --  Primitives for Bare_Discrete_Subtype_Name
   --
      procedure Initialize_Fields_For_Discrete_Subtype_Name
        (Self : Bare_Discrete_Subtype_Name
         ; Discrete_Subtype_Name_F_Subtype : Bare_Discrete_Subtype_Indication
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Discrete_Subtype_Name_F_Subtype := Discrete_Subtype_Name_F_Subtype;
      end Initialize_Fields_For_Discrete_Subtype_Name;
   function Discrete_Subtype_Name_F_Subtype
     (Node : Bare_Discrete_Subtype_Name) return Bare_Discrete_Subtype_Indication
   is
   begin
         return Node.Discrete_Subtype_Name_F_Subtype;
   end;
   --
   --  Primitives for Bare_Dotted_Name
   --
      procedure Initialize_Fields_For_Dotted_Name
        (Self : Bare_Dotted_Name
         ; Dotted_Name_F_Prefix : Bare_Name
         ; Dotted_Name_F_Suffix : Bare_Base_Id
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Dotted_Name_F_Prefix := Dotted_Name_F_Prefix;
            Self.Dotted_Name_F_Suffix := Dotted_Name_F_Suffix;
      end Initialize_Fields_For_Dotted_Name;
   function Dotted_Name_F_Prefix
     (Node : Bare_Dotted_Name) return Bare_Name
   is
   begin
         return Node.Dotted_Name_F_Prefix;
   end;
   function Dotted_Name_F_Suffix
     (Node : Bare_Dotted_Name) return Bare_Base_Id
   is
   begin
         return Node.Dotted_Name_F_Suffix;
   end;
--# property-start DottedName.ref_var /tmp/lal-23.0.0/ada/ast.py:18815
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Ref_Var
  (Node : Bare_Dotted_Name
  )
   return Logic_Var
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Base_Id;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9140 '<FieldAccess for ref_var at ast.py:18815>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18815
--# expr-start 9139 '<FieldAccess for suffix at ast.py:18815>' Fld /tmp/lal-23.0.0/ada/ast.py:18815
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Dotted_Name_F_Suffix;
--# expr-done 9139
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 9140
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Ref_Var;
--# end
--# property-start DottedName.subp_spec_var /tmp/lal-23.0.0/ada/ast.py:18817
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Subp_Spec_Var
  (Node : Bare_Dotted_Name
  )
   return Logic_Var
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Base_Id;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9142 '<FieldAccess for subp_spec_var at ast.py:18817>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18817
--# expr-start 9141 '<FieldAccess for suffix at ast.py:18817>' Fld /tmp/lal-23.0.0/ada/ast.py:18817
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Dotted_Name_F_Suffix;
--# expr-done 9141
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Fld);
--# end
--# expr-done 9142
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Subp_Spec_Var;
--# end
--# property-start DottedName.defines_subp_spec_var /tmp/lal-23.0.0/ada/ast.py:18818
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Defines_Subp_Spec_Var
  (Node : Bare_Dotted_Name
  )
   return Boolean
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Defines_Subp_Spec_Var;
--# end
--# property-start DottedName.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:18820
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Has_Context_Free_Type
  (Node : Bare_Dotted_Name
  )
   return Boolean
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Base_Id;
Is_A : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9145 '<Not at ast.py:18820>' Not_Val /tmp/lal-23.0.0/ada/ast.py:18820
--# expr-start 9144 '<IsA CharLiteral at ast.py:18820>' Is_A /tmp/lal-23.0.0/ada/ast.py:18820
--# expr-start 9143 '<FieldAccess for suffix at ast.py:18820>' Fld /tmp/lal-23.0.0/ada/ast.py:18820
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Dotted_Name_F_Suffix;
--# expr-done 9143
Is_A := Fld /= null 
and then Fld.Kind in Ada_Char_Literal_Range; 
--# expr-done 9144
Not_Val := not (Is_A); 
--# expr-done 9145
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Has_Context_Free_Type;
--# end
--# property-start DottedName.complete_items /tmp/lal-23.0.0/ada/ast.py:18823
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Complete_Items
  (Node : Bare_Dotted_Name
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Array_Access
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_1341 with Inline_Always;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Bound_No_Visibility : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Info;
Fld_6 : Internal_Metadata;
Fld_7 : Boolean;
Fld_8 : Internal_Entity_Info;
Fld_9 : Internal_Metadata;
Fld_10 : Boolean;
Fld_11 : Internal_Unit;
Fld_12 : Boolean;
If_Result : Boolean;
New_Struct : Internal_Completion_Item;
Is_A : Boolean;
Not_Val : Boolean;
Fld_13 : Analysis_Unit_Kind;
Is_Equal : Boolean;
Fld_14 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Boolean;
Map_Result : Internal_Completion_Item_Array_Access;
Dyn_Var_Bind_Result : Internal_Completion_Item_Array_Access;
Dyn_Var_Bind_Result_1 : Internal_Completion_Item_Array_Access;
Dyn_Var_Bind_Result_2 : Internal_Completion_Item_Array_Access;
Let_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_1341 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1341;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9170 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9169 '<bind at ast.py:18824>' Dyn_Var_Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18824
--# expr-start 9146 '<FieldAccess for origin_node at ast.py:18824>' Fld /tmp/lal-23.0.0/ada/ast.py:18824
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9146
Bound_Origin := Fld; 
--# expr-start 9168 '<bind at ast.py:18824>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18824
--# expr-start 9147 '<FieldAccess for node_env at ast.py:18825>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18825
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Node_Env (Node => Self);
--# expr-done 9147
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 9167 '<bind at ast.py:18829>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18829
Bound_No_Visibility := True; 
--# expr-start 9166 '<FilterMap at ast.py:18835>' Map_Result /tmp/lal-23.0.0/ada/ast.py:18835
   --# expr-start 9150 '<FieldAccess for env_get_public at ast.py:18831>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18831
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9149 '<FieldAccess for designated_env at ast.py:18832>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18832
--# expr-start 9148 '<FieldAccess for prefix at ast.py:18832>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18832
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9148
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld_2.Node, Env => Bound_Env, Origin => Bound_Origin, No_Visibility => Bound_No_Visibility, E_Info => Fld_2.Info);
--# end
--# expr-done 9149
--# property-call-start AdaNode.env_get_public
Fld_4 := Libadalang.Implementation.Ada_Node_P_Env_Get_Public (Node => Self, Env => Fld_3, Symbol => null, Lookup => Flat);
--# end
--# expr-done 9150
      declare
         Map_Result_Vec : Internal_Completion_Item_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_4;
      begin
         for Item_287 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_287
--# expr-start 9152 '<Not at ast.py:18856>' Not_Val /tmp/lal-23.0.0/ada/ast.py:18856
--# expr-start 9151 '<IsA PrivatePart at ast.py:18856>' Is_A /tmp/lal-23.0.0/ada/ast.py:18856
Is_A := Item_287.Node /= null 
and then Item_287.Node.Kind in Ada_Private_Part_Range; 
--# expr-done 9151
Not_Val := not (Is_A); 
--# expr-done 9152
if Not_Val then
--# expr-start 9154 '<Eq at ast.py:18858>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:18858
--# expr-start 9153 '<FieldAccess for owning_unit_kind at ast.py:18858>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18858
      if Item_287.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.owning_unit_kind
Fld_13 := Libadalang.Implementation.Ada_Node_P_Owning_Unit_Kind (Node => Item_287.Node);
--# end
--# expr-done 9153
Is_Equal := Fld_13 = Unit_Specification; 
--# expr-done 9154
if Is_Equal then
   If_Result_1 := True;
else
   --# expr-start 9155 '<FieldAccess for has_visibility at ast.py:18859>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18859
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_visibility
Fld_14 := Libadalang.Implementation.Ada_Node_P_Has_Visibility (Node => Self, Other_Entity => Item_287);
--# end
--# expr-done 9155
   If_Result_1 := Fld_14;
end if;
   If_Result_2 := If_Result_1;
else
   If_Result_2 := False;
end if;
         if If_Result_2 then
      --# expr-start 9165 '<New CompletionItem at ast.py:18836>' New_Struct /tmp/lal-23.0.0/ada/ast.py:18836
--# expr-start 9156 '<Cast to BasicDecl at ast.py:18837>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18837
Cast_Expr := Item_287; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 9156
--# expr-start 9159 '<FieldAccess for dottable_subp at ast.py:18838>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18838
--# expr-start 9158 '<FieldAccess for md at ast.py:18838>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18838
--# expr-start 9157 '<FieldAccess for info at ast.py:18838>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18838
Fld_5 := Item_287.Info;
--# expr-done 9157
Fld_6 := Fld_5.Md;
--# expr-done 9158
Fld_7 := Fld_6.Dottable_Subp;
--# expr-done 9159
--# expr-start 9162 '<FieldAccess for dottable_subp at ast.py:18842>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18842
--# expr-start 9161 '<FieldAccess for md at ast.py:18842>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18842
--# expr-start 9160 '<FieldAccess for info at ast.py:18842>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18842
Fld_8 := Item_287.Info;
--# expr-done 9160
Fld_9 := Fld_8.Md;
--# expr-done 9161
Fld_10 := Fld_9.Dottable_Subp;
--# expr-done 9162
if Fld_10 then
   If_Result := True;
else
   --# expr-start 9164 '<FieldAccess for has_with_visibility at ast.py:18845>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18845
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9163 '<FieldAccess for unit at ast.py:18845>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18845
      if Item_287.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Unit (Node => Item_287.Node);
--# expr-done 9163
--# property-call-start AdaNode.has_with_visibility
Fld_12 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Self, Refd_Unit => Fld_11);
--# end
--# expr-done 9164
   If_Result := Fld_12;
end if;
New_Struct := (Decl => Cast_Result, Is_Dot_Call => Fld_7, Is_Visible => If_Result, Weight => 0); 
--# expr-done 9165
         declare
            Item_To_Append : constant Internal_Completion_Item := New_Struct;
         begin
            Internal_Completion_Item_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Completion_Item_Array
           (Items_Count => Natural (Internal_Completion_Item_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Completion_Item_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Completion_Item_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Completion_Item_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9166
Dyn_Var_Bind_Result := Map_Result; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9167
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 9168
Dyn_Var_Bind_Result_2 := Dyn_Var_Bind_Result_1; Inc_Ref (Dyn_Var_Bind_Result_2);
--# expr-done 9169
Let_Result := Dyn_Var_Bind_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 9170
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1341;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1341;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Complete_Items;
--# end
--# property-start DottedName.designated_env_no_overloading /tmp/lal-23.0.0/ada/ast.py:18867
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Designated_Env_No_Overloading
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1342 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Fld : Internal_Entity_Name;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Base_Id;
Fld_3 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1342 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1342;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9176 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9172 '<FieldAccess for designated_env_no_overloading at ast.py:18868>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18868
--# expr-start 9171 '<FieldAccess for prefix at ast.py:18868>' Fld /tmp/lal-23.0.0/ada/ast.py:18868
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9171
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env_no_overloading'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env_No_Overloading (Node => Fld.Node, Env => Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Fld.Info);
--# end
--# expr-done 9172
Block_Var := Fld_1; Inc_Ref (Block_Var);
--# bind pfx_env Block_Var
--# expr-start 9175 '<bind at ast.py:18869>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18869
Bound_Env := Block_Var; Inc_Ref (Bound_Env);
--# expr-start 9174 '<FieldAccess for designated_env_no_overloading at ast.py:18870>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18870
--# expr-start 9173 '<FieldAccess for suffix at ast.py:18870>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18870
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9173
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env_no_overloading'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env_No_Overloading (Node => Fld_2.Node, Env => Bound_Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Fld_2.Info);
--# end
--# expr-done 9174
Dyn_Var_Bind_Result := Fld_3; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9175
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9176
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1342;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1342;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Designated_Env_No_Overloading;
--# end
--# property-start DottedName.designated_env /tmp/lal-23.0.0/ada/ast.py:18873
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Designated_Env
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1343 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Fld : Internal_Entity_Name;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Base_Id;
Fld_3 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1343 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1343;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9182 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9178 '<FieldAccess for designated_env at ast.py:18874>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18874
--# expr-start 9177 '<FieldAccess for prefix at ast.py:18874>' Fld /tmp/lal-23.0.0/ada/ast.py:18874
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9177
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld.Node, Env => Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Fld.Info);
--# end
--# expr-done 9178
Block_Var := Fld_1; Inc_Ref (Block_Var);
--# bind pfx_env Block_Var
--# expr-start 9181 '<bind at ast.py:18875>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18875
Bound_Env := Block_Var; Inc_Ref (Bound_Env);
--# expr-start 9180 '<FieldAccess for designated_env at ast.py:18875>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18875
--# expr-start 9179 '<FieldAccess for suffix at ast.py:18875>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18875
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9179
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld_2.Node, Env => Bound_Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Fld_2.Info);
--# end
--# expr-done 9180
Dyn_Var_Bind_Result := Fld_3; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9181
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9182
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1343;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1343;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Designated_Env;
--# end
--# property-start DottedName.all_env_els_impl /tmp/lal-23.0.0/ada/ast.py:18878
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_All_Env_Els_Impl
  (Node : Bare_Dotted_Name
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind seq Seq
   --# bind seq_from Seq_From
   --# bind categories Categories
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1344 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Fld : Internal_Entity_Name;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Base_Id;
Fld_3 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1344 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1344;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9188 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9184 '<FieldAccess for designated_env at ast.py:18883>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18883
--# expr-start 9183 '<FieldAccess for prefix at ast.py:18883>' Fld /tmp/lal-23.0.0/ada/ast.py:18883
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9183
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld.Node, Env => Env, Origin => Origin, No_Visibility => False, E_Info => Fld.Info);
--# end
--# expr-done 9184
Block_Var := Fld_1; Inc_Ref (Block_Var);
--# bind pfx_env Block_Var
--# expr-start 9187 '<bind at ast.py:18884>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18884
Bound_Env := Block_Var; Inc_Ref (Bound_Env);
--# expr-start 9186 '<FieldAccess for all_env_els_impl at ast.py:18886>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18886
--# expr-start 9185 '<FieldAccess for suffix at ast.py:18886>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18886
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9185
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.all_env_els_impl'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_All_Env_Els_Impl (Node => Fld_2.Node, Seq => Seq, Seq_From => Seq_From, Categories => Categories, Env => Bound_Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 9186
Dyn_Var_Bind_Result := Fld_3; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9187
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9188
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1344;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1344;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_All_Env_Els_Impl;
--# end
--# property-start DottedName.scope /tmp/lal-23.0.0/ada/ast.py:18889
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Scope
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1345 with Inline_Always;
            procedure Finalizer_Scope_3001 with Inline_Always;
      Var_Expr : Bare_Base_Id;
Fld : Bare_Base_Id;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1345 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_1345;
            procedure Finalizer_Scope_3001 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
            end Finalizer_Scope_3001;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 9189 '<FieldAccess for suffix at ast.py:18889>' Fld /tmp/lal-23.0.0/ada/ast.py:18889
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Dotted_Name_F_Suffix;
--# expr-done 9189
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind sfx Var_Expr
--# expr-start 9192 '<bind at ast.py:18890>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18890
--# expr-start 9190 '<FieldAccess for parent_scope at ast.py:18890>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18890
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.parent_scope'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Parent_Scope (Node => Self, Env => Env);
--# end
--# expr-done 9190
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 9191 '<FieldAccess for scope at ast.py:18890>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18890
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.scope'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Scope (Node => Var_Expr, Env => Bound_Env);
--# end
--# expr-done 9191
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9192
Scope_Result := Dyn_Var_Bind_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3001;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1345;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1345;
               Finalizer_Scope_3001;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Scope;
--# end
--# property-start DottedName.parent_scope /tmp/lal-23.0.0/ada/ast.py:18894
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Parent_Scope
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1346 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1346 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1346;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9194 '<FieldAccess for scope at ast.py:18894>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18894
--# expr-start 9193 '<FieldAccess for prefix at ast.py:18894>' Fld /tmp/lal-23.0.0/ada/ast.py:18894
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Dotted_Name_F_Prefix;
--# expr-done 9193
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.scope'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Scope (Node => Fld, Env => Env);
--# end
--# expr-done 9194
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1346;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1346;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Parent_Scope;
--# end
--# property-start DottedName.relative_name /tmp/lal-23.0.0/ada/ast.py:18896
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Relative_Name
  (Node : Bare_Dotted_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Base_Id;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9196 '<FieldAccess for relative_name at ast.py:18896>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18896
--# expr-start 9195 '<FieldAccess for suffix at ast.py:18896>' Fld /tmp/lal-23.0.0/ada/ast.py:18896
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9195
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9196
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Relative_Name;
--# end
--# property-start DottedName.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:18899
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Env_Elements_Impl
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1348 with Inline_Always;
      Block_Var : Lexical_Env := Empty_Env;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Name;
Fld_2 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_3 : Internal_Entity_Base_Id;
Fld_4 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result_1 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1348 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1348;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9204 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9200 '<bind at ast.py:18900>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18900
--# expr-start 9197 '<FieldAccess for origin_node at ast.py:18900>' Fld /tmp/lal-23.0.0/ada/ast.py:18900
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9197
Bound_Origin := Fld; 
--# expr-start 9199 '<FieldAccess for designated_env at ast.py:18901>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18901
--# expr-start 9198 '<FieldAccess for prefix at ast.py:18901>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18901
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9198
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_2 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld_1.Node, Env => Env, Origin => Bound_Origin, No_Visibility => False, E_Info => Fld_1.Info);
--# end
--# expr-done 9199
Dyn_Var_Bind_Result := Fld_2; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9200
Block_Var := Dyn_Var_Bind_Result; Inc_Ref (Block_Var);
--# bind pfx_env Block_Var
--# expr-start 9203 '<bind at ast.py:18902>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18902
Bound_Env := Block_Var; Inc_Ref (Bound_Env);
--# expr-start 9202 '<FieldAccess for env_elements_baseid at ast.py:18902>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18902
--# expr-start 9201 '<FieldAccess for suffix at ast.py:18902>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18902
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9201
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.env_elements_baseid
Fld_4 := Libadalang.Implementation.Base_Id_P_Env_Elements_Baseid (Node => Fld_3.Node, Env => Bound_Env, E_Info => Fld_3.Info);
--# end
--# expr-done 9202
Dyn_Var_Bind_Result_1 := Fld_4; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 9203
Let_Result := Dyn_Var_Bind_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9204
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1348;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1348;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Env_Elements_Impl;
--# end
--# property-start DottedName.designated_type_impl /tmp/lal-23.0.0/ada/ast.py:18905
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Designated_Type_Impl
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1349 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Base_Id;
Fld_3 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1349 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_1349;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9210 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9209 '<bind at ast.py:18906>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18906
--# expr-start 9206 '<FieldAccess for designated_env_no_overloading at ast.py:18906>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18906
--# expr-start 9205 '<FieldAccess for prefix at ast.py:18906>' Fld /tmp/lal-23.0.0/ada/ast.py:18906
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9205
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env_no_overloading'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env_No_Overloading (Node => Fld.Node, Env => Env, Origin => Origin, No_Visibility => False, E_Info => Fld.Info);
--# end
--# expr-done 9206
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 9208 '<FieldAccess for designated_type_impl at ast.py:18907>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18907
--# expr-start 9207 '<FieldAccess for suffix at ast.py:18907>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18907
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9207
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld_2.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 9208
Dyn_Var_Bind_Result := Fld_3; 
--# expr-done 9209
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 9210
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1349;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1349;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Designated_Type_Impl;
--# end
--# property-start DottedName.xref_equation /tmp/lal-23.0.0/ada/ast.py:18910
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Xref_Equation
  (Node : Bare_Dotted_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1350 with Inline_Always;
            procedure Finalizer_Scope_3013 with Inline_Always;
      Block_Var : Logic_Equation;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Name;
Fld_3 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Base_Id;
Fld_5 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Logic_Var;
Fld_7 : Bare_Base_Id;
Fld_8 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_9 : Logic_Var;
Fld_10 : Bare_Base_Id;
Fld_11 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_12 : Internal_Entity_Array_Access;
Fld_13 : Bare_Base_Id;
Fld_14 : Logic_Var;
Bind_Result_2 : Logic_Equation;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_15 : Bare_Name;
Cast_Result_1 : Bare_Expr;
Fld_16 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_17 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1350 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1350;
            procedure Finalizer_Scope_3013 is
            begin
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Fld_16);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_3013;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9244 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9218 '<And at ast.py:18911>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18911
--# expr-start 9212 '<FieldAccess for sub_equation at ast.py:18911>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18911
--# expr-start 9211 '<FieldAccess for prefix at ast.py:18911>' Fld /tmp/lal-23.0.0/ada/ast.py:18911
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9211
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9212
--# expr-start 9217 '<bind at ast.py:18912>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18912
--# expr-start 9214 '<FieldAccess for designated_env at ast.py:18912>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18912
--# expr-start 9213 '<FieldAccess for prefix at ast.py:18912>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18912
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9213
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld_2.Node, Env => Env, Origin => Origin, No_Visibility => False, E_Info => Fld_2.Info);
--# end
--# expr-done 9214
Bound_Env := Fld_3; Inc_Ref (Bound_Env);
--# expr-start 9216 '<FieldAccess for sub_equation at ast.py:18913>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18913
--# expr-start 9215 '<FieldAccess for suffix at ast.py:18913>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18913
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9215
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_4.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 9216
Dyn_Var_Bind_Result := Fld_5; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9217
And_Pred := Create_And (Fld_1, Dyn_Var_Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18911") else null)); 
--# expr-done 9218
Block_Var := And_Pred; Inc_Ref (Block_Var);
--# bind base Block_Var
--# expr-start 9243 '<If at ast.py:18915>' If_Result /tmp/lal-23.0.0/ada/ast.py:18915
--# expr-start 9221 '<Not at ast.py:18916>' Not_Val /tmp/lal-23.0.0/ada/ast.py:18916
--# expr-start 9220 '<IsNull at ast.py:18916>' Is_Null /tmp/lal-23.0.0/ada/ast.py:18916
--# expr-start 9219 '<FieldAccess for designated_type_impl at ast.py:18916>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:18916
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_17 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9219
Is_Null := Fld_17.Node = null; 
--# expr-done 9220
Not_Val := not (Is_Null); 
--# expr-done 9221
if Not_Val then
   If_Result := Block_Var;
else
   --# expr-start 9242 '<And at ast.py:18918>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:18918
--# expr-start 9231 '<And at ast.py:18918>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18918
--# expr-start 9226 '<And at ast.py:18918>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18918
--# expr-start 9225 '<Bind at ast.py:18919>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18919
--# expr-start 9222 '<FieldAccess for expected_type_var at ast.py:18919>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18919
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9222
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 9224 '<FieldAccess for expected_type_var at ast.py:18919>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18919
--# expr-start 9223 '<FieldAccess for suffix at ast.py:18919>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18919
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Dotted_Name_F_Suffix;
--# expr-done 9223
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_7);
--# expr-done 9224
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Bind_Result := Solver.Create_Unify (Fld_6, Fld_8, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18919") else null)); 
--# expr-done 9225
And_Pred_1 := Create_And (Block_Var, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18918") else null)); 
--# expr-done 9226
--# expr-start 9230 '<Bind at ast.py:18920>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18920
--# expr-start 9227 '<FieldAccess for type_var at ast.py:18920>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18920
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9227
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 9229 '<FieldAccess for type_var at ast.py:18920>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18920
--# expr-start 9228 '<FieldAccess for suffix at ast.py:18920>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18920
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Dotted_Name_F_Suffix;
--# expr-done 9228
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_10);
--# expr-done 9229
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
Bind_Result_1 := Solver.Create_Unify (Fld_9, Fld_11, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18920") else null)); 
--# expr-done 9230
And_Pred_2 := Create_And (And_Pred_1, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18918") else null)); 
--# expr-done 9231
--# expr-start 9241 '<LogicAny at ast.py:18921>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:18921
--# expr-start 9240 '<Map at ast.py:18921>' Map_Result /tmp/lal-23.0.0/ada/ast.py:18921
   --# expr-start 9232 '<FieldAccess for env_elements at ast.py:18921>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18921
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_12 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Ent.Node, Env => Env, No_Visibility => False, E_Info => Ent.Info);
--# end
--# expr-done 9232
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_12;
      begin
         for Item_288 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_288
      --# expr-start 9239 '<And at ast.py:18923>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:18923
--# expr-start 9235 '<Bind at ast.py:18923>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18923
--# expr-start 9234 '<FieldAccess for ref_var at ast.py:18923>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18923
--# expr-start 9233 '<FieldAccess for suffix at ast.py:18923>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18923
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Self.Dotted_Name_F_Suffix;
--# expr-done 9233
      if Fld_13 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_14 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_13);
--# end
--# expr-done 9234
Fld_14.Value := No_Entity;
Entity_Vars.Reset (Fld_14);
Bind_Result_2 := Solver.Create_Assign (Fld_14, Item_288, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18923") else null)); 
--# expr-done 9235
--# expr-start 9238 '<FieldAccess for constrain_prefix at ast.py:18924>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:18924
--# expr-start 9236 '<Cast to BasicDecl.entity at ast.py:18924>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18924
Cast_Expr := Item_288; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 9236
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9237 '<FieldAccess for prefix at ast.py:18924>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:18924
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Self.Dotted_Name_F_Prefix;
--# expr-done 9237
      Cast_Result_1 := Fld_15;
--# property-call-start '[dispatcher]BasicDecl.constrain_prefix'
Fld_16 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Constrain_Prefix (Node => Cast_Result.Node, Prefix => Cast_Result_1, Origin => Origin, E_Info => Cast_Result.Info);
--# end
--# expr-done 9238
And_Pred_3 := Create_And (Bind_Result_2, Fld_16, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18923") else null)); 
--# expr-done 9239
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3013;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9240
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18921") else null)); 
--# expr-done 9241
And_Pred_4 := Create_And (And_Pred_2, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18918") else null)); 
--# expr-done 9242
   If_Result := And_Pred_4;
end if;
      Inc_Ref (If_Result);
--# expr-done 9243
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9244
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1350;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1350;
               Finalizer_Scope_3013;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Xref_Equation;
--# end
--# property-start DottedName.is_constant /tmp/lal-23.0.0/ada/ast.py:18929
pragma Warnings (Off, "is not referenced");
 function Dotted_Name_P_Is_Constant
  (Node : Bare_Dotted_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Dotted_Name := Bare_Dotted_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Dotted_Name :=
     Internal_Entity_Dotted_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Name;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Base_Id;
Fld_3 : Boolean;
If_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9249 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9246 '<FieldAccess for is_constant at ast.py:18933>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18933
--# expr-start 9245 '<FieldAccess for prefix at ast.py:18933>' Fld /tmp/lal-23.0.0/ada/ast.py:18933
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Dotted_Name_F_Prefix, Info => Ent.Info);
--# expr-done 9245
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.is_constant'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Is_Constant (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9246
if Fld_1 then
   If_Result := True;
else
   --# expr-start 9248 '<FieldAccess for is_constant at ast.py:18934>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18934
--# expr-start 9247 '<FieldAccess for suffix at ast.py:18934>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18934
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Base_Id (Node => Ent.Node.Dotted_Name_F_Suffix, Info => Ent.Info);
--# expr-done 9247
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.is_constant'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Is_Constant (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 9248
   If_Result := Fld_3;
end if;
Let_Result := If_Result; 
--# end
--# expr-done 9249
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dotted_Name_P_Is_Constant;
--# end
   --
   --  Primitives for Bare_End_Name
   --
      procedure Initialize_Fields_For_End_Name
        (Self : Bare_End_Name
         ; End_Name_F_Name : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.End_Name_F_Name := End_Name_F_Name;
      end Initialize_Fields_For_End_Name;
   function End_Name_F_Name
     (Node : Bare_End_Name) return Bare_Name
   is
   begin
         return Node.End_Name_F_Name;
   end;
--# property-start EndName.parent_scope /tmp/lal-23.0.0/ada/ast.py:16217
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Parent_Scope
  (Node : Bare_End_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1165 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1165 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1165;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9251 '<FieldAccess for parent_scope at ast.py:16217>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16217
--# expr-start 9250 '<FieldAccess for name at ast.py:16217>' Fld /tmp/lal-23.0.0/ada/ast.py:16217
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.End_Name_F_Name;
--# expr-done 9250
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.parent_scope'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Parent_Scope (Node => Fld, Env => Env);
--# end
--# expr-done 9251
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1165;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1165;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Parent_Scope;
--# end
--# property-start EndName.scope /tmp/lal-23.0.0/ada/ast.py:16218
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Scope
  (Node : Bare_End_Name
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1166 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1166 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1166;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9253 '<FieldAccess for scope at ast.py:16218>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16218
--# expr-start 9252 '<FieldAccess for name at ast.py:16218>' Fld /tmp/lal-23.0.0/ada/ast.py:16218
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.End_Name_F_Name;
--# expr-done 9252
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.scope'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Scope (Node => Fld, Env => Env);
--# end
--# expr-done 9253
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1166;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1166;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Scope;
--# end
--# property-start EndName.relative_name /tmp/lal-23.0.0/ada/ast.py:16219
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Relative_Name
  (Node : Bare_End_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_End_Name :=
     Internal_Entity_End_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9255 '<FieldAccess for relative_name at ast.py:16219>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16219
--# expr-start 9254 '<FieldAccess for name at ast.py:16219>' Fld /tmp/lal-23.0.0/ada/ast.py:16219
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.End_Name_F_Name, Info => Ent.Info);
--# expr-done 9254
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9255
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Relative_Name;
--# end
--# property-start EndName.ref_var /tmp/lal-23.0.0/ada/ast.py:16220
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Ref_Var
  (Node : Bare_End_Name
  )
   return Logic_Var
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9257 '<FieldAccess for ref_var at ast.py:16220>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16220
--# expr-start 9256 '<FieldAccess for name at ast.py:16220>' Fld /tmp/lal-23.0.0/ada/ast.py:16220
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.End_Name_F_Name;
--# expr-done 9256
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 9257
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Ref_Var;
--# end
--# property-start EndName.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:16221
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Env_Elements_Impl
  (Node : Bare_End_Name
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_End_Name :=
     Internal_Entity_End_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1169 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1169 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1169;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9259 '<FieldAccess for env_elements_impl at ast.py:16221>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16221
--# expr-start 9258 '<FieldAccess for name at ast.py:16221>' Fld /tmp/lal-23.0.0/ada/ast.py:16221
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.End_Name_F_Name, Info => Ent.Info);
--# expr-done 9258
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Fld.Node, Env => Env, E_Info => Fld.Info);
--# end
--# expr-done 9259
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1169;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1169;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Env_Elements_Impl;
--# end
--# property-start EndName.basic_decl /tmp/lal-23.0.0/ada/ast.py:16223
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Basic_Decl
  (Node : Bare_End_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_1170 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Bare_Ada_Node;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Expr : Bare_Ada_Node;
Cast_Result : Bare_Named_Stmt;
Fld : Bare_Named_Stmt_Decl;
Cast_Result_1 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Scope_Result_1 : Internal_Entity_Basic_Decl;
Node_Parents_1 : Bare_Ada_Node_Array_Access;
Is_A_1 : Boolean;
Find_Result_1 : Bare_Ada_Node;
Cast_Result_2 : Bare_Basic_Decl;
As_Entity_1 : Internal_Entity_Basic_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Result_Var_1 : Internal_Entity_Basic_Decl;
            procedure Finalizer_Scope_1170 is
            begin
                     Dec_Ref (Node_Parents);
                     Dec_Ref (Node_Parents_1);
            end Finalizer_Scope_1170;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_End_Name_End_Name_P_Basic_Decl,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_End_Name,
                                As_Bare_End_Name => Self);
               Mmz_K.Items (2) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Basic_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
--# expr-start 9262 '<Find at ast.py:16224>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16224
   --# expr-start 9260 '<FieldAccess for parents at ast.py:16224>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:16224
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 9260
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_289 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_289
      --# expr-start 9261 '<IsA NamedStmt at ast.py:16224>' Is_A /tmp/lal-23.0.0/ada/ast.py:16224
Is_A := Item_289 /= null 
and then Item_289.Kind in Ada_Named_Stmt_Range; 
--# expr-done 9261
      if Is_A then
         Find_Result := Item_289;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 9262
Var_Expr_1 := Find_Result;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind ns Var_Expr_1
--# expr-start 9266 '<as_entity at ast.py:16226>' If_Result /tmp/lal-23.0.0/ada/ast.py:16226
--# expr-start 9265 '<Cast to BasicDecl at ast.py:16226>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16226
--# expr-start 9264 '<FieldAccess for decl at ast.py:16226>' Fld /tmp/lal-23.0.0/ada/ast.py:16226
--# expr-start 9263 '<Cast to NamedStmt at ast.py:16226>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16226
Cast_Expr := Var_Expr_1; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Named_Stmt_Range
   then
      Cast_Result := Cast_Expr;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9263
      if Cast_Result = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Cast_Result.Named_Stmt_F_Decl;
--# expr-done 9264
      Cast_Result_1 := Fld;
--# expr-done 9265
Is_Null := Cast_Result_1 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => E_Info, Node => Cast_Result_1); 
   If_Result := As_Entity;
end if;
--# expr-done 9266
Scope_Result := If_Result;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind e Var_Expr
Scope_Result_1 := Var_Expr;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   --# expr-start 9271 '<as_entity at ast.py:16229>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16229
--# expr-start 9270 '<Cast to BasicDecl at ast.py:16229>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:16229
--# expr-start 9269 '<Find at ast.py:16228>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:16228
   --# expr-start 9267 '<FieldAccess for parents at ast.py:16228>' Node_Parents_1 /tmp/lal-23.0.0/ada/ast.py:16228
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents_1 := Parents (Self, True); 
--# expr-done 9267
      Find_Result_1 := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents_1;
      begin
         for Item_290 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_290
      --# expr-start 9268 '<IsA BasicDecl at ast.py:16228>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:16228
Is_A_1 := Item_290 /= null 
and then Item_290.Kind in Ada_Basic_Decl; 
--# expr-done 9268
      if Is_A_1 then
         Find_Result_1 := Item_290;
      end if;
   --# end
               exit when Is_A_1;
         end loop;
      end;
--# expr-done 9269
   if Find_Result_1 = null
      or else Find_Result_1.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Find_Result_1;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9270
Is_Null_1 := Cast_Result_2 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Cast_Result_2); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 9271
   Result_Var_1 := If_Result_1;
end if;
      Property_Result := Result_Var_1;
   --# end
      Finalizer_Scope_1170;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Basic_Decl,
                        As_Internal_Entity_Basic_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1170;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Basic_Decl;
--# end
--# property-start EndName.xref_equation /tmp/lal-23.0.0/ada/ast.py:16236
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Xref_Equation
  (Node : Bare_End_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_End_Name :=
     Internal_Entity_End_Name'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1171 with Inline_Always;
            procedure Finalizer_Scope_3018 with Inline_Always;
            procedure Finalizer_Scope_3019 with Inline_Always;
      Var_Expr : Internal_Entity_Accept_Stmt_With_Stmts;
Var_Expr_1 : Internal_Entity_Dotted_Name;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Accept_Stmt_With_Stmts;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Entry_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result : Logic_Equation;
Scope_Result : Logic_Equation;
Fld_3 : Logic_Var;
Fld_4 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Result_Var : Logic_Equation;
Fld_5 : Internal_Entity_Name;
Cast_Result_3 : Internal_Entity_Dotted_Name;
Fld_6 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_7 : Internal_Entity_Name;
Fld_8 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1171 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1171;
            procedure Finalizer_Scope_3018 is
            begin
                     Dec_Ref (Bind_Result);
            end Finalizer_Scope_3018;
            procedure Finalizer_Scope_3019 is
            begin
                     Dec_Ref (Fld_6);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Dyn_Var_Bind_Result);
            end Finalizer_Scope_3019;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9287 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9286 '<And at ast.py:16237>' And_Pred /tmp/lal-23.0.0/ada/ast.py:16237
--# expr-start 9273 '<Cast to AcceptStmtWithStmts at ast.py:16237>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16237
--# expr-start 9272 '<parent at ast.py:16237>' Fld /tmp/lal-23.0.0/ada/ast.py:16237
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 9272
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Accept_Stmt_With_Stmts_Range
   then
      Cast_Result := Create_Internal_Entity_Accept_Stmt_With_Stmts
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Accept_Stmt_With_Stmts;
   end if;
--# expr-done 9273
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Accept_Stmt_With_Stmts then
   --# scope-start
   --# bind stmt Var_Expr
--# expr-start 9276 '<Bind at ast.py:16238>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:16238
--# expr-start 9274 '<FieldAccess for ref_var at ast.py:16238>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16238
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9274
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 9275 '<FieldAccess for designated_entry at ast.py:16238>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16238
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AcceptStmt.designated_entry
Fld_2 := Libadalang.Implementation.Accept_Stmt_P_Designated_Entry (Node => Var_Expr.Node, Origin => Origin, Env => Env, E_Info => Var_Expr.Info);
--# end
--# expr-done 9275
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16238") else null)); 
--# expr-done 9276
Scope_Result := Bind_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3018;
   Result_Var := Scope_Result;
else
   --# expr-start 9279 '<Bind at ast.py:16239>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:16239
--# expr-start 9277 '<FieldAccess for ref_var at ast.py:16239>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16239
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9277
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 9278 '<FieldAccess for basic_decl at ast.py:16239>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16239
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start EndName.basic_decl
Fld_4 := Libadalang.Implementation.End_Name_P_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9278
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_3, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16239") else null)); 
--# expr-done 9279
   Result_Var := Bind_Result_1;
end if;
      Inc_Ref (Result_Var);
--# expr-start 9281 '<Cast to DottedName at ast.py:16240>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:16240
--# expr-start 9280 '<FieldAccess for name at ast.py:16240>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16240
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Ent.Node.End_Name_F_Name, Info => Ent.Info);
--# expr-done 9280
   if Fld_5.Node = null
      or else Fld_5.Node.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Dotted_Name
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
   else
         Cast_Result_3 := No_Entity_Dotted_Name;
   end if;
--# expr-done 9281
Var_Expr_1 := Cast_Result_3;
if Var_Expr_1 /= No_Entity_Dotted_Name then
   --# scope-start
   --# bind dn Var_Expr_1
--# expr-start 9285 '<bind at ast.py:16244>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:16244
--# expr-start 9282 '<FieldAccess for std_env at ast.py:16245>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16245
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_env
Fld_6 := Libadalang.Implementation.Ada_Node_P_Std_Env (Node => Ent.Node);
--# end
--# expr-done 9282
Bound_Env := Fld_6; Inc_Ref (Bound_Env);
--# expr-start 9284 '<FieldAccess for xref_no_overloading at ast.py:16246>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16246
--# expr-start 9283 '<FieldAccess for prefix at ast.py:16246>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16246
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Name (Node => Var_Expr_1.Node.Dotted_Name_F_Prefix, Info => Var_Expr_1.Info);
--# expr-done 9283
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_8 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld_7.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_7.Info);
--# end
--# expr-done 9284
Dyn_Var_Bind_Result := Fld_8; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9285
Scope_Result_1 := Dyn_Var_Bind_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3019;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16248") else null)); 
   Result_Var_1 := True_Rel;
end if;
      Inc_Ref (Result_Var_1);
And_Pred := Create_And (Result_Var, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16237") else null)); 
--# expr-done 9286
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 9287
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1171;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1171;
               Finalizer_Scope_3018;
               Finalizer_Scope_3019;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Xref_Equation;
--# end
--# property-start EndName.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:16251
pragma Warnings (Off, "is not referenced");
 function End_Name_P_Xref_Entry_Point
  (Node : Bare_End_Name
  )
   return Boolean
is
   Self : Bare_End_Name := Bare_End_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end End_Name_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_Explicit_Deref
   --
      procedure Initialize_Fields_For_Explicit_Deref
        (Self : Bare_Explicit_Deref
         ; Explicit_Deref_F_Prefix : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Explicit_Deref_F_Prefix := Explicit_Deref_F_Prefix;
      Self.Explicit_Deref_R_Called_Spec := Null_Var_Record;
      end Initialize_Fields_For_Explicit_Deref;
   function Explicit_Deref_F_Prefix
     (Node : Bare_Explicit_Deref) return Bare_Name
   is
   begin
         return Node.Explicit_Deref_F_Prefix;
   end;
--# property-start ExplicitDeref.ref_var /tmp/lal-23.0.0/ada/ast.py:15270
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Ref_Var
  (Node : Bare_Explicit_Deref
  )
   return Logic_Var
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9289 '<FieldAccess for ref_var at ast.py:15270>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15270
--# expr-start 9288 '<FieldAccess for prefix at ast.py:15270>' Fld /tmp/lal-23.0.0/ada/ast.py:15270
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Explicit_Deref_F_Prefix;
--# expr-done 9288
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 9289
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Ref_Var;
--# end
--# property-start ExplicitDeref.subp_spec_var /tmp/lal-23.0.0/ada/ast.py:15274
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Subp_Spec_Var
  (Node : Bare_Explicit_Deref
  )
   return Logic_Var
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9290 '<FieldAccess for r_called_spec at ast.py:15274>' Fld /tmp/lal-23.0.0/ada/ast.py:15274
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Explicit_Deref_R_Called_Spec'Unrestricted_Access;
--# expr-done 9290
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Subp_Spec_Var;
--# end
--# property-start ExplicitDeref.defines_subp_spec_var /tmp/lal-23.0.0/ada/ast.py:15275
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Defines_Subp_Spec_Var
  (Node : Bare_Explicit_Deref
  )
   return Boolean
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Defines_Subp_Spec_Var;
--# end
--# property-start ExplicitDeref.relative_name /tmp/lal-23.0.0/ada/ast.py:15277
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Relative_Name
  (Node : Bare_Explicit_Deref
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9292 '<FieldAccess for relative_name at ast.py:15277>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15277
--# expr-start 9291 '<FieldAccess for prefix at ast.py:15277>' Fld /tmp/lal-23.0.0/ada/ast.py:15277
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9291
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9292
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Relative_Name;
--# end
--# property-start ExplicitDeref.designated_env /tmp/lal-23.0.0/ada/ast.py:15280
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Designated_Env
  (Node : Bare_Explicit_Deref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1101 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1101 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1101;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9295 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9294 '<FieldAccess for designated_env at ast.py:15283>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15283
--# expr-start 9293 '<FieldAccess for prefix at ast.py:15283>' Fld /tmp/lal-23.0.0/ada/ast.py:15283
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9293
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => Fld.Node, Env => Env, Origin => Origin, No_Visibility => No_Visibility, E_Info => Fld.Info);
--# end
--# expr-done 9294
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9295
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1101;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1101;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Designated_Env;
--# end
--# property-start ExplicitDeref.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:15286
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Env_Elements_Impl
  (Node : Bare_Explicit_Deref
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1102 with Inline_Always;
      Block_Var : Internal_Entity_Name;
Block_Var_1 : Internal_Entity_Array_Access;
Var_Expr : Internal_Entity_Attribute_Ref;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Var_Expr_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
Fld_2 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Map_Result : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Attribute_Ref;
Fld_5 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1102 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1102;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9307 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9296 '<FieldAccess for prefix at ast.py:15287>' Fld /tmp/lal-23.0.0/ada/ast.py:15287
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9296
Block_Var := Fld; 
--# bind prefix Block_Var
--# expr-start 9297 '<FieldAccess for env_elements_impl at ast.py:15288>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15288
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Block_Var.Node, Env => Env, E_Info => Block_Var.Info);
--# end
--# expr-done 9297
Block_Var_1 := Fld_1; Inc_Ref (Block_Var_1);
--# bind env_els Block_Var_1
--# expr-start 9306 '<If at ast.py:15289>' If_Result /tmp/lal-23.0.0/ada/ast.py:15289
--# expr-start 9298 '<Cast to AttributeRef at ast.py:15290>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15290
Cast_Expr_1 := Block_Var; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Attribute_Ref
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Attribute_Ref;
   end if;
--# expr-done 9298
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Attribute_Ref then
   --# scope-start
--# expr-start 9299 '<FieldAccess for is_access_attr at ast.py:15290>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15290
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.is_access_attr
Fld_5 := Libadalang.Implementation.Attribute_Ref_P_Is_Access_Attr (Node => Var_Expr.Node);
--# end
--# expr-done 9299
Scope_Result_2 := Fld_5;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
if Result_Var_2 then
   If_Result := Block_Var_1;
else
   --# expr-start 9305 '<bind at ast.py:15292>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:15292
--# expr-start 9300 '<FieldAccess for origin_node at ast.py:15292>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15292
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_2 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9300
Bound_Origin := Fld_2; 
--# expr-start 9304 '<Filter at ast.py:15292>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15292
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var_1;
      begin
         for Item_291 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_291
--# expr-start 9301 '<Cast to BasicDecl at ast.py:15294>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15294
Cast_Expr := Item_291; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 9301
Var_Expr_2 := Cast_Result;
if Var_Expr_2 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 9302 '<FieldAccess for expr_type at ast.py:15294>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15294
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Var_Expr_2.Node, Origin => Bound_Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 9302
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Var_Expr_1 := Result_Var;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind t Var_Expr_1
--# expr-start 9303 '<FieldAccess for is_access_type at ast.py:15295>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15295
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 9303
Scope_Result_1 := Fld_4;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
         if Result_Var_1 then
         declare
            Item_To_Append : constant Internal_Entity := Item_291;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9304
Dyn_Var_Bind_Result := Map_Result; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9305
   If_Result := Dyn_Var_Bind_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 9306
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9307
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1102;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1102;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Env_Elements_Impl;
--# end
--# property-start ExplicitDeref.eq_for_type /tmp/lal-23.0.0/ada/ast.py:15301
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Eq_For_Type
  (Node : Bare_Explicit_Deref
      ; Typ : Internal_Entity_Base_Type_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind typ Typ
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1103 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_2 : Internal_Entity_Name;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
False_Rel : Logic_Equation;
Fld_6 : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1103 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1103;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9320 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9319 '<If at ast.py:15302>' If_Result /tmp/lal-23.0.0/ada/ast.py:15302
--# expr-start 9308 '<FieldAccess for is_access_type at ast.py:15303>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15303
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Typ.Node, Origin => Origin, E_Info => Typ.Info);
--# end
--# expr-done 9308
if Fld_6 then
   --# expr-start 9318 '<And at ast.py:15305>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15305
--# expr-start 9314 '<And at ast.py:15305>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15305
--# expr-start 9311 '<Bind at ast.py:15305>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15305
--# expr-start 9310 '<FieldAccess for expected_type_var at ast.py:15305>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15305
--# expr-start 9309 '<FieldAccess for prefix at ast.py:15305>' Fld /tmp/lal-23.0.0/ada/ast.py:15305
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Explicit_Deref_F_Prefix;
--# expr-done 9309
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 9310
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Cast_Expr := Typ; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15305") else null)); 
--# expr-done 9311
--# expr-start 9313 '<FieldAccess for matches_expected_type at ast.py:15306>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15306
--# expr-start 9312 '<FieldAccess for prefix at ast.py:15306>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15306
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9312
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_3 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_2.Node, Origin => Origin);
--# end
--# expr-done 9313
And_Pred := Create_And (Bind_Result, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15305") else null)); 
--# expr-done 9314
--# expr-start 9317 '<Bind at ast.py:15307>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15307
--# expr-start 9315 '<FieldAccess for type_var at ast.py:15307>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15307
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9315
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 9316 '<FieldAccess for accessed_type at ast.py:15307>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15307
      if Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Typ.Node, Origin => Origin, E_Info => Typ.Info);
--# end
--# expr-done 9316
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_4, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15307") else null)); 
--# expr-done 9317
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15305") else null)); 
--# expr-done 9318
   If_Result := And_Pred_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15309") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 9319
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9320
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1103;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1103;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Eq_For_Type;
--# end
--# property-start ExplicitDeref.xref_equation /tmp/lal-23.0.0/ada/ast.py:15313
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Xref_Equation
  (Node : Bare_Explicit_Deref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1104 with Inline_Always;
      Fld : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1104 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1104;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9322 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9321 '<FieldAccess for bottom_up_name_equation at ast.py:15314>' Fld /tmp/lal-23.0.0/ada/ast.py:15314
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.bottom_up_name_equation
Fld := Libadalang.Implementation.Name_P_Bottom_Up_Name_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9321
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 9322
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1104;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1104;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Xref_Equation;
--# end
--# property-start ExplicitDeref.general_xref_equation /tmp/lal-23.0.0/ada/ast.py:15317
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_General_Xref_Equation
  (Node : Bare_Explicit_Deref
      ; Root : Bare_Name
         := No_Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1105 with Inline_Always;
            procedure Finalizer_Scope_3024 with Inline_Always;
            procedure Finalizer_Scope_3025 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Var_Expr_1 : Internal_Entity_Attribute_Ref;
Fld : Logic_Equation;
Fld_1 : Internal_Entity_Name;
Fld_2 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_3 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_6 : Logic_Var;
Fld_7 : Bare_Name;
Fld_8 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_9 : Internal_Entity_Base_Type_Decl;
Fld_10 : Internal_Entity_Name;
Cast_Result_1 : Internal_Entity_Attribute_Ref;
Fld_11 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Fld_12 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
False_Rel : Logic_Equation;
Result_Var_1 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1105 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_2);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1105;
            procedure Finalizer_Scope_3024 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_3024;
            procedure Finalizer_Scope_3025 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_12);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_3025;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9347 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9346 '<And at ast.py:15318>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:15318
--# expr-start 9326 '<And at ast.py:15318>' And_Pred /tmp/lal-23.0.0/ada/ast.py:15318
--# expr-start 9323 '<FieldAccess for all_args_xref_equation at ast.py:15319>' Fld /tmp/lal-23.0.0/ada/ast.py:15319
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_args_xref_equation
Fld := Libadalang.Implementation.Name_P_All_Args_Xref_Equation (Node => Ent.Node, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9323
--# expr-start 9325 '<FieldAccess for sub_equation at ast.py:15320>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15320
--# expr-start 9324 '<FieldAccess for prefix at ast.py:15320>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15320
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9324
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_2 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_1.Node, Env => Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 9325
And_Pred := Create_And (Fld, Fld_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15318") else null)); 
--# expr-done 9326
--# expr-start 9345 '<LogicAny at ast.py:15321>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:15321
--# expr-start 9344 '<Map at ast.py:15321>' Map_Result /tmp/lal-23.0.0/ada/ast.py:15321
   --# expr-start 9327 '<FieldAccess for env_elements at ast.py:15321>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15321
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld_3 := Libadalang.Implementation.Expr_P_Env_Elements (Node => Ent.Node, Env => Env, No_Visibility => False, E_Info => Ent.Info);
--# end
--# expr-done 9327
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_3;
      begin
         for Item_292 of
               Collection.Items
         loop
   --# scope-start
               --# bind el Item_292
--# expr-start 9329 '<FieldAccess for expr_type at ast.py:15322>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15322
--# expr-start 9328 '<Cast to BasicDecl at ast.py:15322>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:15322
Cast_Expr := Item_292; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 9328
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Cast_Result.Node, Origin => Origin, E_Info => Cast_Result.Info);
--# end
--# expr-done 9329
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr
--# expr-start 9343 '<And at ast.py:15324>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:15324
--# expr-start 9336 '<And at ast.py:15324>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:15324
--# expr-start 9331 '<Bind at ast.py:15324>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:15324
--# expr-start 9330 '<FieldAccess for ref_var at ast.py:15324>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:15324
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9330
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result := Solver.Create_Assign (Fld_5, Item_292, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15324") else null)); 
--# expr-done 9331
--# expr-start 9335 '<Bind at ast.py:15325>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:15325
--# expr-start 9332 '<FieldAccess for ref_var at ast.py:15325>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:15325
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9332
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 9334 '<FieldAccess for ref_var at ast.py:15325>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:15325
--# expr-start 9333 '<FieldAccess for prefix at ast.py:15325>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:15325
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Explicit_Deref_F_Prefix;
--# expr-done 9333
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_7);
--# end
--# expr-done 9334
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Bind_Result_1 := Solver.Create_Unify (Fld_6, Fld_8, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15325") else null)); 
--# expr-done 9335
And_Pred_1 := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15324") else null)); 
--# expr-done 9336
--# expr-start 9342 '<FieldAccess for parent_name_equation at ast.py:15326>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:15326
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9341 '<If at ast.py:15327>' If_Result /tmp/lal-23.0.0/ada/ast.py:15327
--# expr-start 9338 '<Cast to AttributeRef at ast.py:15327>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15327
--# expr-start 9337 '<FieldAccess for prefix at ast.py:15327>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:15327
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9337
   if Fld_10.Node = null
      or else Fld_10.Node.Kind in Ada_Attribute_Ref_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Attribute_Ref
        (Node => Fld_10.Node,
         Info => Fld_10.Info);
   else
         Cast_Result_1 := No_Entity_Attribute_Ref;
   end if;
--# expr-done 9338
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Attribute_Ref then
   --# scope-start
--# expr-start 9339 '<FieldAccess for is_access_attr at ast.py:15327>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:15327
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AttributeRef.is_access_attr
Fld_11 := Libadalang.Implementation.Attribute_Ref_P_Is_Access_Attr (Node => Var_Expr_1.Node);
--# end
--# expr-done 9339
Scope_Result := Fld_11;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   --# expr-start 9340 '<FieldAccess for anonymous_access_type at ast.py:15328>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:15328
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.anonymous_access_type
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Anonymous_Access_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9340
   If_Result := Fld_9;
else
   If_Result := Var_Expr;
end if;
--# expr-done 9341
--# property-call-start Name.parent_name_equation
Fld_12 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Ent.Node, Typ => If_Result, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9342
And_Pred_2 := Create_And (And_Pred_1, Fld_12, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15324") else null)); 
--# expr-done 9343
Scope_Result_1 := And_Pred_2;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3025;
   Result_Var_1 := Scope_Result_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15332") else null)); 
   Result_Var_1 := False_Rel;
end if;
      Inc_Ref (Result_Var_1);
         declare
            Item_To_Append : constant Logic_Equation := Result_Var_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3024;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9344
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15321") else null)); 
--# expr-done 9345
And_Pred_3 := Create_And (And_Pred, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15318") else null)); 
--# expr-done 9346
Let_Result := And_Pred_3; Inc_Ref (Let_Result);
--# end
--# expr-done 9347
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1105;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1105;
               Finalizer_Scope_3024;
               Finalizer_Scope_3025;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_General_Xref_Equation;
--# end
--# property-start ExplicitDeref.is_constant /tmp/lal-23.0.0/ada/ast.py:15338
pragma Warnings (Off, "is not referenced");
 function Explicit_Deref_P_Is_Constant
  (Node : Bare_Explicit_Deref
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Explicit_Deref := Bare_Explicit_Deref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Explicit_Deref :=
     Internal_Entity_Explicit_Deref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Type_Access_Def;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Bare_Explicit_Deref;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Access_Def;
Scope_Result : Internal_Entity_Access_Def;
Result_Var : Internal_Entity_Access_Def;
Cast_Result_1 : Internal_Entity_Type_Access_Def;
Fld_3 : Internal_Entity_Constant_Node;
Fld_4 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9355 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9354 '<bind at ast.py:15341>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:15341
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 9351 '<Cast to TypeAccessDef at ast.py:15344>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:15344
--# expr-start 9349 '<FieldAccess for expression_type at ast.py:15343>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15343
--# expr-start 9348 '<FieldAccess for prefix at ast.py:15343>' Fld /tmp/lal-23.0.0/ada/ast.py:15343
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Explicit_Deref_F_Prefix, Info => Ent.Info);
--# expr-done 9348
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.expression_type
Fld_1 := Libadalang.Implementation.Expr_P_Expression_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9349
Var_Expr_1 := Fld_1;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 9350 '<FieldAccess for access_def at ast.py:15343>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:15343
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.access_def'
Fld_2 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Access_Def (Node => Var_Expr_1.Node, Origin => Bound_Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 9350
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Access_Def;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Type_Access_Def_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Type_Access_Def
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result_1 := No_Entity_Type_Access_Def;
   end if;
--# expr-done 9351
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Type_Access_Def then
   --# scope-start
--# expr-start 9353 '<FieldAccess for as_bool at ast.py:15344>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:15344
--# expr-start 9352 '<FieldAccess for has_constant at ast.py:15344>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:15344
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Constant_Node (Node => Var_Expr.Node.Type_Access_Def_F_Has_Constant, Info => Var_Expr.Info);
--# expr-done 9352
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Constant.as_bool'
Fld_4 := Libadalang.Implementation.Dispatcher_Constant_Node_P_As_Bool (Node => Fld_3.Node);
--# end
--# expr-done 9353
Scope_Result_1 := Fld_4;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
Dyn_Var_Bind_Result := Result_Var_1; 
--# expr-done 9354
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 9355
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Explicit_Deref_P_Is_Constant;
--# end
   --
   --  Primitives for Bare_Qual_Expr
   --
      procedure Initialize_Fields_For_Qual_Expr
        (Self : Bare_Qual_Expr
         ; Qual_Expr_F_Prefix : Bare_Name
         ; Qual_Expr_F_Suffix : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Qual_Expr_F_Prefix := Qual_Expr_F_Prefix;
            Self.Qual_Expr_F_Suffix := Qual_Expr_F_Suffix;
      end Initialize_Fields_For_Qual_Expr;
   function Qual_Expr_F_Prefix
     (Node : Bare_Qual_Expr) return Bare_Name
   is
   begin
         return Node.Qual_Expr_F_Prefix;
   end;
   function Qual_Expr_F_Suffix
     (Node : Bare_Qual_Expr) return Bare_Expr
   is
   begin
         return Node.Qual_Expr_F_Suffix;
   end;
--# property-start QualExpr.ref_var /tmp/lal-23.0.0/ada/ast.py:17992
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Ref_Var
  (Node : Bare_Qual_Expr
  )
   return Logic_Var
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9357 '<FieldAccess for ref_var at ast.py:17992>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17992
--# expr-start 9356 '<FieldAccess for prefix at ast.py:17992>' Fld /tmp/lal-23.0.0/ada/ast.py:17992
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Qual_Expr_F_Prefix;
--# expr-done 9356
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 9357
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Ref_Var;
--# end
--# property-start QualExpr.relative_name /tmp/lal-23.0.0/ada/ast.py:17994
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Relative_Name
  (Node : Bare_Qual_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Qual_Expr :=
     Internal_Entity_Qual_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9359 '<FieldAccess for relative_name at ast.py:17994>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17994
--# expr-start 9358 '<FieldAccess for prefix at ast.py:17994>' Fld /tmp/lal-23.0.0/ada/ast.py:17994
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Qual_Expr_F_Prefix, Info => Ent.Info);
--# expr-done 9358
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9359
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Relative_Name;
--# end
--# property-start QualExpr.is_constant /tmp/lal-23.0.0/ada/ast.py:17996
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Is_Constant
  (Node : Bare_Qual_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Is_Constant;
--# end
--# property-start QualExpr.general_xref_equation /tmp/lal-23.0.0/ada/ast.py:17999
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_General_Xref_Equation
  (Node : Bare_Qual_Expr
      ; Root : Bare_Name
         := No_Bare_Ada_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Qual_Expr :=
     Internal_Entity_Qual_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind root Root
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1292 with Inline_Always;
            procedure Finalizer_Scope_3029 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Fld : Logic_Equation;
Fld_1 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Name;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1292 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1292;
            procedure Finalizer_Scope_3029 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_3029;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9368 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9367 '<And at ast.py:18000>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18000
--# expr-start 9362 '<And at ast.py:18000>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18000
--# expr-start 9360 '<FieldAccess for xref_equation at ast.py:18001>' Fld /tmp/lal-23.0.0/ada/ast.py:18001
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9360
--# expr-start 9361 '<FieldAccess for all_args_xref_equation at ast.py:18002>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18002
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_args_xref_equation
Fld_1 := Libadalang.Implementation.Name_P_All_Args_Xref_Equation (Node => Ent.Node, Root => Root, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9361
And_Pred := Create_And (Fld, Fld_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18000") else null)); 
--# expr-done 9362
--# expr-start 9363 '<FieldAccess for parent_name at ast.py:18003>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18003
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_name
Fld_2 := Libadalang.Implementation.Name_P_Parent_Name (Node => Ent.Node, Stop_At => Root, E_Info => Ent.Info);
--# end
--# expr-done 9363
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind pn Var_Expr
--# expr-start 9366 '<FieldAccess for parent_name_equation at ast.py:18005>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18005
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9365 '<FieldAccess for designated_type_impl at ast.py:18006>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18006
--# expr-start 9364 '<FieldAccess for prefix at ast.py:18006>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18006
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Name (Node => Ent.Node.Qual_Expr_F_Prefix, Info => Ent.Info);
--# expr-done 9364
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 9365
--# property-call-start Name.parent_name_equation
Fld_5 := Libadalang.Implementation.Name_P_Parent_Name_Equation (Node => Var_Expr.Node, Typ => Fld_4, Root => Root, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 9366
Scope_Result := Fld_5;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3029;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18009") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_1 := Create_And (And_Pred, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18000") else null)); 
--# expr-done 9367
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9368
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1292;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1292;
               Finalizer_Scope_3029;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_General_Xref_Equation;
--# end
--# property-start QualExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:18014
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Xref_Equation
  (Node : Bare_Qual_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Qual_Expr :=
     Internal_Entity_Qual_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1293 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Equation;
Fld_4 : Bare_Name;
Fld_5 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_Expr;
Fld_7 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_8 : Internal_Entity_Expr;
Fld_9 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_10 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1293 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1293;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9387 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9370 '<FieldAccess for designated_type_impl at ast.py:18015>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18015
--# expr-start 9369 '<FieldAccess for prefix at ast.py:18015>' Fld /tmp/lal-23.0.0/ada/ast.py:18015
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Qual_Expr_F_Prefix, Info => Ent.Info);
--# expr-done 9369
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9370
Block_Var := Fld_1; 
--# bind typ Block_Var
--# expr-start 9386 '<And at ast.py:18018>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:18018
--# expr-start 9383 '<And at ast.py:18018>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18018
--# expr-start 9380 '<And at ast.py:18018>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18018
--# expr-start 9376 '<And at ast.py:18018>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18018
--# expr-start 9372 '<FieldAccess for sub_equation at ast.py:18018>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18018
--# expr-start 9371 '<FieldAccess for suffix at ast.py:18018>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18018
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Qual_Expr_F_Suffix, Info => Ent.Info);
--# expr-done 9371
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 9372
--# expr-start 9375 '<Bind at ast.py:18019>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18019
--# expr-start 9374 '<FieldAccess for ref_var at ast.py:18019>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18019
--# expr-start 9373 '<FieldAccess for prefix at ast.py:18019>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18019
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Qual_Expr_F_Prefix;
--# expr-done 9373
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_4);
--# end
--# expr-done 9374
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr := Block_Var; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18019") else null)); 
--# expr-done 9375
And_Pred := Create_And (Fld_3, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18018") else null)); 
--# expr-done 9376
--# expr-start 9379 '<Bind at ast.py:18020>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18020
--# expr-start 9378 '<FieldAccess for expected_type_var at ast.py:18020>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18020
--# expr-start 9377 '<FieldAccess for suffix at ast.py:18020>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18020
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Qual_Expr_F_Suffix;
--# expr-done 9377
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_6);
--# expr-done 9378
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Cast_Expr_1 := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_7, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18020") else null)); 
--# expr-done 9379
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18018") else null)); 
--# expr-done 9380
--# expr-start 9382 '<FieldAccess for matches_expected_type at ast.py:18021>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18021
--# expr-start 9381 '<FieldAccess for suffix at ast.py:18021>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18021
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Ent.Node.Qual_Expr_F_Suffix, Info => Ent.Info);
--# expr-done 9381
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_9 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_8.Node, Origin => Origin);
--# end
--# expr-done 9382
And_Pred_2 := Create_And (And_Pred_1, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18018") else null)); 
--# expr-done 9383
--# expr-start 9385 '<Bind at ast.py:18022>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18022
--# expr-start 9384 '<FieldAccess for type_var at ast.py:18022>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18022
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9384
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Cast_Expr_2 := Block_Var; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_10, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18022") else null)); 
--# expr-done 9385
And_Pred_3 := Create_And (And_Pred_2, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18018") else null)); 
--# expr-done 9386
Let_Result := And_Pred_3; Inc_Ref (Let_Result);
--# end
--# expr-done 9387
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1293;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1293;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Xref_Equation;
--# end
--# property-start QualExpr.designated_type /tmp/lal-23.0.0/ada/ast.py:18028
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Designated_Type
  (Node : Bare_Qual_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Qual_Expr :=
     Internal_Entity_Qual_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1294 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result_1 : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1294 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_1294;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9393 '<bind at ast.py:18029>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18029
--# expr-start 9388 '<FieldAccess for node_env at ast.py:18029>' Fld /tmp/lal-23.0.0/ada/ast.py:18029
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 9388
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 9392 '<bind at ast.py:18030>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:18030
--# expr-start 9389 '<FieldAccess for origin_node at ast.py:18030>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18030
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9389
Bound_Origin := Fld_1; 
--# expr-start 9391 '<FieldAccess for designated_type_impl at ast.py:18031>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18031
--# expr-start 9390 '<FieldAccess for prefix at ast.py:18031>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18031
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Qual_Expr_F_Prefix, Info => Ent.Info);
--# expr-done 9390
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld_2.Node, Env => Bound_Env, Origin => Bound_Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 9391
Dyn_Var_Bind_Result := Fld_3; 
--# expr-done 9392
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; 
--# expr-done 9393
      Property_Result := Dyn_Var_Bind_Result_1;
   --# end
      Finalizer_Scope_1294;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1294;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Designated_Type;
--# end
--# property-start QualExpr.designated_env /tmp/lal-23.0.0/ada/ast.py:18035
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Designated_Env
  (Node : Bare_Qual_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Qual_Expr :=
     Internal_Entity_Qual_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1295 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1295 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1295;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9396 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9395 '<FieldAccess for defining_env at ast.py:18036>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18036
--# expr-start 9394 '<FieldAccess for designated_type at ast.py:18036>' Fld /tmp/lal-23.0.0/ada/ast.py:18036
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start QualExpr.designated_type
Fld := Libadalang.Implementation.Qual_Expr_P_Designated_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9394
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Fld.Info);
--# end
--# expr-done 9395
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9396
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1295;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1295;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Designated_Env;
--# end
--# property-start QualExpr.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:18039
pragma Warnings (Off, "is not referenced");
 function Qual_Expr_P_Env_Elements_Impl
  (Node : Bare_Qual_Expr
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Qual_Expr := Bare_Qual_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Qual_Expr :=
     Internal_Entity_Qual_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1296 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1296 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1296;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9399 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9398 '<FieldAccess for env_elements_impl at ast.py:18040>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18040
--# expr-start 9397 '<FieldAccess for prefix at ast.py:18040>' Fld /tmp/lal-23.0.0/ada/ast.py:18040
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Qual_Expr_F_Prefix, Info => Ent.Info);
--# expr-done 9397
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.env_elements_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Env_Elements_Impl (Node => Fld.Node, Env => Env, E_Info => Fld.Info);
--# end
--# expr-done 9398
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9399
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1296;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1296;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Qual_Expr_P_Env_Elements_Impl;
--# end
   --
   --  Primitives for Bare_Reduce_Attribute_Ref
   --
      procedure Initialize_Fields_For_Reduce_Attribute_Ref
        (Self : Bare_Reduce_Attribute_Ref
         ; Reduce_Attribute_Ref_F_Prefix : Bare_Ada_Node
         ; Reduce_Attribute_Ref_F_Attribute : Bare_Identifier
         ; Reduce_Attribute_Ref_F_Args : Bare_Assoc_List
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Reduce_Attribute_Ref_F_Prefix := Reduce_Attribute_Ref_F_Prefix;
            Self.Reduce_Attribute_Ref_F_Attribute := Reduce_Attribute_Ref_F_Attribute;
            Self.Reduce_Attribute_Ref_F_Args := Reduce_Attribute_Ref_F_Args;
      Self.Reduce_Attribute_Ref_R_Ref_Var := Null_Var_Record;
      end Initialize_Fields_For_Reduce_Attribute_Ref;
   function Reduce_Attribute_Ref_F_Prefix
     (Node : Bare_Reduce_Attribute_Ref) return Bare_Ada_Node
   is
   begin
         return Node.Reduce_Attribute_Ref_F_Prefix;
   end;
   function Reduce_Attribute_Ref_F_Attribute
     (Node : Bare_Reduce_Attribute_Ref) return Bare_Identifier
   is
   begin
         return Node.Reduce_Attribute_Ref_F_Attribute;
   end;
   function Reduce_Attribute_Ref_F_Args
     (Node : Bare_Reduce_Attribute_Ref) return Bare_Assoc_List
   is
   begin
         return Node.Reduce_Attribute_Ref_F_Args;
   end;
--# property-start ReduceAttributeRef.ref_var /tmp/lal-23.0.0/ada/ast.py:18691
pragma Warnings (Off, "is not referenced");
 function Reduce_Attribute_Ref_P_Ref_Var
  (Node : Bare_Reduce_Attribute_Ref
  )
   return Logic_Var
is
   Self : Bare_Reduce_Attribute_Ref := Bare_Reduce_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9400 '<FieldAccess for r_ref_var at ast.py:18691>' Fld /tmp/lal-23.0.0/ada/ast.py:18691
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Reduce_Attribute_Ref_R_Ref_Var'Unrestricted_Access;
--# expr-done 9400
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Reduce_Attribute_Ref_P_Ref_Var;
--# end
--# property-start ReduceAttributeRef.xref_equation /tmp/lal-23.0.0/ada/ast.py:18695
pragma Warnings (Off, "is not referenced");
 function Reduce_Attribute_Ref_P_Xref_Equation
  (Node : Bare_Reduce_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Reduce_Attribute_Ref := Bare_Reduce_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Reduce_Attribute_Ref :=
     Internal_Entity_Reduce_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1331 with Inline_Always;
            procedure Finalizer_Scope_3030 with Inline_Always;
            procedure Finalizer_Scope_3032 with Inline_Always;
      Block_Var : Internal_Entity_Expr;
Var_Expr : Boolean;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Assoc_List;
Fld_1 : Bare_Assoc_List;
Fld_2 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_3 : Internal_Entity_Expr;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Base_Id;
Fld_4 : Symbol_Type;
Fld_5 : Bare_Ada_Node;
Fld_6 : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_7 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Cast_Expr_2 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_8 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
False_Rel : Logic_Equation;
Result_Var_1 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1331 is
            begin
                     Dec_Ref (Fld_6);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1331;
            procedure Finalizer_Scope_3030 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (False_Rel);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_3030;
            procedure Finalizer_Scope_3032 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_3032;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9413 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9402 '<FieldAccess for expr at ast.py:18704>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18704
--# expr-start 9401 '<FieldAccess for args at ast.py:18704>' Fld /tmp/lal-23.0.0/ada/ast.py:18704
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Reduce_Attribute_Ref_F_Args, Info => Ent.Info);
--# expr-done 9401
Fld_1 := Fld.Node;
Get_Result := Get (Self, Fld_1, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Get_Result); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 9402
Block_Var := Fld_3; 
--# bind reducer Block_Var
--# expr-start 9412 '<LogicAny at ast.py:18710>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:18710
--# expr-start 9411 '<Map at ast.py:18710>' Map_Result /tmp/lal-23.0.0/ada/ast.py:18710
   --# expr-start 9406 '<FieldAccess for env_get at ast.py:18706>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18706
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9404 '<FieldAccess for sym at ast.py:18708>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18708
--# expr-start 9403 '<Cast to BaseId at ast.py:18708>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18708
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Id
   then
      Cast_Result := Create_Internal_Entity_Base_Id
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Id;
   end if;
--# expr-done 9403
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_4 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Cast_Result.Node);
--# end
--# expr-done 9404
--# expr-start 9405 '<FieldAccess for origin_node at ast.py:18709>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18709
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_5 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9405
--# property-call-start AdaNode.env_get
Fld_6 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Env, Symbol => Fld_4, From_Node => Fld_5);
--# end
--# expr-done 9406
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_6;
      begin
         for Item_293 of
               Collection.Items
         loop
   --# scope-start
               --# bind subp Item_293
--# expr-start 9407 '<Cast to BasicDecl at ast.py:18712>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:18712
Cast_Expr_1 := Item_293; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Basic_Decl;
   end if;
--# expr-done 9407
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 9408 '<FieldAccess for is_valid_reducer_candidate at ast.py:18712>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18712
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_valid_reducer_candidate
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Is_Valid_Reducer_Candidate (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 9408
Scope_Result := Fld_7;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Var_Expr := Result_Var;
if Var_Expr /= False then
   --# scope-start
   --# bind _ Var_Expr
--# expr-start 9410 '<FieldAccess for xref_equation_for_reducer_candidate at ast.py:18714>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18714
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9409 '<Cast to BasicDecl at ast.py:18715>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:18715
Cast_Expr_2 := Item_293; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 9409
--# property-call-start ReduceAttributeRef.xref_equation_for_reducer_candidate
Fld_8 := Libadalang.Implementation.Reduce_Attribute_Ref_P_Xref_Equation_For_Reducer_Candidate (Node => Ent.Node, Subp => Cast_Result_2, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9410
Scope_Result_1 := Fld_8;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3032;
   Result_Var_1 := Scope_Result_1;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18716") else null)); 
   Result_Var_1 := False_Rel;
end if;
      Inc_Ref (Result_Var_1);
         declare
            Item_To_Append : constant Logic_Equation := Result_Var_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3030;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9411
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18710") else null)); 
--# expr-done 9412
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 9413
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1331;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1331;
               Finalizer_Scope_3030;
               Finalizer_Scope_3032;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Reduce_Attribute_Ref_P_Xref_Equation;
--# end
--# property-start ReduceAttributeRef.xref_equation_for_reducer_candidate /tmp/lal-23.0.0/ada/ast.py:18721
pragma Warnings (Off, "is not referenced");
 function Reduce_Attribute_Ref_P_Xref_Equation_For_Reducer_Candidate
  (Node : Bare_Reduce_Attribute_Ref
      ; Subp : Internal_Entity_Basic_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Reduce_Attribute_Ref := Bare_Reduce_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Reduce_Attribute_Ref :=
     Internal_Entity_Reduce_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind subp Subp
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1332 with Inline_Always;
            procedure Finalizer_Scope_3033 with Inline_Always;
      Block_Var : Internal_Entity_Base_Id;
Block_Var_1 : Internal_Entity_Expr;
Block_Var_2 : Internal_Entity_Base_Type_Decl_Array_Access;
Block_Var_3 : Internal_Entity_Base_Type_Decl;
Block_Var_4 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Value_Sequence;
Fld : Internal_Entity_Assoc_List;
Fld_1 : Bare_Assoc_List;
Fld_2 : Internal_Entity_Info;
Get_Result : Bare_Basic_Assoc;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Assoc;
Fld_3 : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Base_Id;
Fld_4 : Internal_Entity_Assoc_List;
Fld_5 : Bare_Assoc_List;
Fld_6 : Internal_Entity_Info;
Get_Result_1 : Bare_Basic_Assoc;
As_Entity_1 : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Assoc;
Fld_7 : Internal_Entity_Expr;
Fld_8 : Internal_Entity_Base_Subp_Spec;
Fld_9 : Internal_Entity_Base_Type_Decl_Array_Access;
Get_Result_2 : Internal_Entity_Base_Type_Decl;
Get_Result_3 : Internal_Entity_Base_Type_Decl;
Fld_10 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Value_Sequence;
Fld_11 : Internal_Entity_Iterated_Assoc;
Fld_12 : Internal_Entity_Expr;
Fld_13 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_14 : Internal_Entity_Iterated_Assoc;
Fld_15 : Internal_Entity_Expr;
Fld_16 : Logic_Equation;
And_Pred : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Fld_17 : Internal_Entity;
Fld_18 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_19 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_20 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_21 : Logic_Var;
Cast_Expr_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_5 : Internal_Entity;
Bind_Result_3 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_22 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Fld_23 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1332 is
            begin
                     Dec_Ref (Fld_9);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_18);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Fld_22);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Fld_23);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1332;
            procedure Finalizer_Scope_3033 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_16);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_3033;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9449 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9416 '<Cast to BaseId at ast.py:18725>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18725
--# expr-start 9415 '<FieldAccess for expr at ast.py:18725>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18725
--# expr-start 9414 '<FieldAccess for args at ast.py:18725>' Fld /tmp/lal-23.0.0/ada/ast.py:18725
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Reduce_Attribute_Ref_F_Args, Info => Ent.Info);
--# expr-done 9414
Fld_1 := Fld.Node;
Get_Result := Get (Self, Fld_1, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Assoc;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Get_Result); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_3 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 9415
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Base_Id
   then
      Cast_Result := Create_Internal_Entity_Base_Id
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result := No_Entity_Base_Id;
   end if;
--# expr-done 9416
Block_Var := Cast_Result; 
--# bind reducer Block_Var
--# expr-start 9418 '<FieldAccess for expr at ast.py:18726>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18726
--# expr-start 9417 '<FieldAccess for args at ast.py:18726>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18726
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Assoc_List (Node => Ent.Node.Reduce_Attribute_Ref_F_Args, Info => Ent.Info);
--# expr-done 9417
Fld_5 := Fld_4.Node;
Get_Result_1 := Get (Self, Fld_5, 1, True); 
Is_Null_1 := Get_Result_1 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Assoc;
else
Fld_6 := Fld_4.Info;
As_Entity_1 := (Info => Fld_6, Node => Get_Result_1); 
   If_Result_1 := As_Entity_1;
end if;
      if If_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => If_Result_1.Node, E_Info => If_Result_1.Info);
--# end
--# expr-done 9418
Block_Var_1 := Fld_7; 
--# bind initial_value_expression Block_Var_1
--# expr-start 9420 '<FieldAccess for param_types at ast.py:18731>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:18731
--# expr-start 9419 '<FieldAccess for subp_spec_or_null at ast.py:18731>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:18731
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_8 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Subp.Node, E_Info => Subp.Info);
--# end
--# expr-done 9419
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.param_types
Fld_9 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Param_Types (Node => Fld_8.Node, Origin => Origin, E_Info => Fld_8.Info);
--# end
--# expr-done 9420
Block_Var_2 := Fld_9; Inc_Ref (Block_Var_2);
--# bind param_types Block_Var_2
--# expr-start 9421 '<at at ast.py:18732>' Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:18732
Get_Result_2 := Get (Self, Block_Var_2, 0, True); 
--# expr-done 9421
Block_Var_3 := Get_Result_2; 
--# bind accum_type Block_Var_3
--# expr-start 9422 '<at at ast.py:18733>' Get_Result_3 /tmp/lal-23.0.0/ada/ast.py:18733
Get_Result_3 := Get (Self, Block_Var_2, 1, True); 
--# expr-done 9422
Block_Var_4 := Get_Result_3; 
--# bind value_type Block_Var_4
--# expr-start 9448 '<And at ast.py:18735>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:18735
--# expr-start 9446 '<And at ast.py:18735>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:18735
--# expr-start 9444 '<And at ast.py:18735>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:18735
--# expr-start 9441 '<And at ast.py:18735>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:18735
--# expr-start 9438 '<And at ast.py:18735>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18735
--# expr-start 9435 '<And at ast.py:18735>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18735
--# expr-start 9424 '<Cast to ValueSequence at ast.py:18736>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:18736
--# expr-start 9423 '<FieldAccess for prefix at ast.py:18736>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:18736
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity (Node => Ent.Node.Reduce_Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 9423
   if Fld_10.Node = null
      or else Fld_10.Node.Kind in Ada_Value_Sequence_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Value_Sequence
        (Node => Fld_10.Node,
         Info => Fld_10.Info);
   else
         Cast_Result_1 := No_Entity_Value_Sequence;
   end if;
--# expr-done 9424
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Value_Sequence then
   --# scope-start
   --# bind vs Var_Expr
--# expr-start 9432 '<And at ast.py:18738>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18738
--# expr-start 9428 '<Bind at ast.py:18738>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18738
--# expr-start 9427 '<FieldAccess for expected_type_var at ast.py:18738>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:18738
--# expr-start 9426 '<FieldAccess for expr at ast.py:18738>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:18738
--# expr-start 9425 '<FieldAccess for iter_assoc at ast.py:18738>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:18738
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Iterated_Assoc (Node => Var_Expr.Node.Value_Sequence_F_Iter_Assoc, Info => Var_Expr.Info);
--# expr-done 9425
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_12 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_11.Node, E_Info => Fld_11.Info);
--# end
--# expr-done 9426
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_12.Node);
--# expr-done 9427
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
Cast_Expr := Block_Var_4; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_13, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18738") else null)); 
--# expr-done 9428
--# expr-start 9431 '<FieldAccess for matches_expected_type at ast.py:18739>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:18739
--# expr-start 9430 '<FieldAccess for expr at ast.py:18739>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:18739
--# expr-start 9429 '<FieldAccess for iter_assoc at ast.py:18739>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:18739
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Iterated_Assoc (Node => Var_Expr.Node.Value_Sequence_F_Iter_Assoc, Info => Var_Expr.Info);
--# expr-done 9429
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_15 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_14.Node, E_Info => Fld_14.Info);
--# end
--# expr-done 9430
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_16 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_15.Node, Origin => Origin);
--# end
--# expr-done 9431
And_Pred := Create_And (Bind_Result, Fld_16, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18738") else null)); 
--# expr-done 9432
Scope_Result := And_Pred;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3033;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18740") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
--# expr-start 9434 '<FieldAccess for sub_equation at ast.py:18742>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:18742
--# expr-start 9433 '<FieldAccess for prefix at ast.py:18742>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:18742
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Create_Internal_Entity (Node => Ent.Node.Reduce_Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 9433
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_18 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_17.Node, Env => Env, Origin => Origin, E_Info => Fld_17.Info);
--# end
--# expr-done 9434
And_Pred_1 := Create_And (Result_Var, Fld_18, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18735") else null)); 
--# expr-done 9435
--# expr-start 9437 '<Bind at ast.py:18744>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18744
--# expr-start 9436 '<FieldAccess for type_var at ast.py:18744>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:18744
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9436
Fld_19.Value := No_Entity;
Entity_Vars.Reset (Fld_19);
Cast_Expr_1 := Block_Var_3; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_19, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18744") else null)); 
--# expr-done 9437
And_Pred_2 := Create_And (And_Pred_1, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18735") else null)); 
--# expr-done 9438
--# expr-start 9440 '<Bind at ast.py:18746>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:18746
--# expr-start 9439 '<FieldAccess for ref_var at ast.py:18746>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:18746
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_20 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Block_Var.Node);
--# end
--# expr-done 9439
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
Cast_Expr_2 := Subp; 
      Cast_Result_4 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_20, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18746") else null)); 
--# expr-done 9440
And_Pred_3 := Create_And (And_Pred_2, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18735") else null)); 
--# expr-done 9441
--# expr-start 9443 '<Bind at ast.py:18748>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:18748
--# expr-start 9442 '<FieldAccess for expected_type_var at ast.py:18748>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:18748
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Block_Var_1.Node);
--# expr-done 9442
Fld_21.Value := No_Entity;
Entity_Vars.Reset (Fld_21);
Cast_Expr_3 := Block_Var_3; 
      Cast_Result_5 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
Bind_Result_3 := Solver.Create_Assign (Fld_21, Cast_Result_5, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18748") else null)); 
--# expr-done 9443
And_Pred_4 := Create_And (And_Pred_3, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18735") else null)); 
--# expr-done 9444
--# expr-start 9445 '<FieldAccess for sub_equation at ast.py:18749>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:18749
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_22 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Block_Var_1.Node, Env => Env, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 9445
And_Pred_5 := Create_And (And_Pred_4, Fld_22, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18735") else null)); 
--# expr-done 9446
--# expr-start 9447 '<FieldAccess for matches_expected_formal_type at ast.py:18750>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:18750
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_type
Fld_23 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Type (Node => Block_Var_1.Node, Origin => Origin);
--# end
--# expr-done 9447
And_Pred_6 := Create_And (And_Pred_5, Fld_23, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18735") else null)); 
--# expr-done 9448
Let_Result := And_Pred_6; Inc_Ref (Let_Result);
--# end
--# expr-done 9449
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1332;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1332;
               Finalizer_Scope_3033;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Reduce_Attribute_Ref_P_Xref_Equation_For_Reducer_Candidate;
--# end
   --
   --  Primitives for Bare_Single_Tok_Node
   --
      procedure Initialize_Fields_For_Single_Tok_Node
        (Self : Bare_Single_Tok_Node
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
      end Initialize_Fields_For_Single_Tok_Node;
--# property-start SingleTokNode.relative_name /tmp/lal-23.0.0/ada/ast.py:15561
pragma Warnings (Off, "is not referenced");
 function Single_Tok_Node_P_Relative_Name
  (Node : Bare_Single_Tok_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Single_Tok_Node := Bare_Single_Tok_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Single_Tok_Node :=
     Internal_Entity_Single_Tok_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Ent;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Tok_Node_P_Relative_Name;
--# end
--# property-start SingleTokNode.defines_subp_spec_var /tmp/lal-23.0.0/ada/ast.py:15573
pragma Warnings (Off, "is not referenced");
 function Single_Tok_Node_P_Defines_Subp_Spec_Var
  (Node : Bare_Single_Tok_Node
  )
   return Boolean
is
   Self : Bare_Single_Tok_Node := Bare_Single_Tok_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Tok_Node_P_Defines_Subp_Spec_Var;
--# end
--# property-start SingleTokNode.sym /tmp/lal-23.0.0/ada/ast.py:15575
pragma Warnings (Off, "is not referenced");
 function Single_Tok_Node_P_Sym
  (Node : Bare_Single_Tok_Node
  )
   return Symbol_Type
is
   Self : Bare_Single_Tok_Node := Bare_Single_Tok_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Sym : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9450 '<GetSymbol at ast.py:15576>' Sym /tmp/lal-23.0.0/ada/ast.py:15576
Sym := Get_Symbol (Self); 
--# expr-done 9450
      Property_Result := Sym;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Tok_Node_P_Sym;
--# end
--# property-start SingleTokNode.canonical_text /tmp/lal-23.0.0/ada/ast.py:15585
pragma Warnings (Off, "is not referenced");
 function Single_Tok_Node_P_Canonical_Text
  (Node : Bare_Single_Tok_Node
  )
   return Symbol_Type
is
   Self : Bare_Single_Tok_Node := Bare_Single_Tok_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Fld : Symbol_Type;
Let_Result : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9452 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9451 '<FieldAccess for sym at ast.py:15586>' Fld /tmp/lal-23.0.0/ada/ast.py:15586
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Self);
--# end
--# expr-done 9451
Let_Result := Fld; 
--# end
--# expr-done 9452
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Tok_Node_P_Canonical_Text;
--# end
--# property-start SingleTokNode.env_get_first_visible /tmp/lal-23.0.0/ada/ast.py:15589
pragma Warnings (Off, "is not referenced");
 function Single_Tok_Node_P_Env_Get_First_Visible
  (Node : Bare_Single_Tok_Node
      ; Lex_Env : Lexical_Env
      ; Lookup_Type : Lookup_Kind
      ; From_Node : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
  )
   return Internal_Entity
is
   Self : Bare_Single_Tok_Node := Bare_Single_Tok_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind lex_env Lex_Env
   --# bind lookup_type Lookup_Type
   --# bind from_node From_Node
   --# bind no_visibility No_Visibility
   Property_Result : Internal_Entity;
            procedure Finalizer_Scope_1124 with Inline_Always;
      Sym : Symbol_Type;
Fld : Internal_Entity_Array_Access;
Fld_1 : Boolean;
If_Result : Boolean;
Find_Result : Internal_Entity;
Let_Result : Internal_Entity;
            procedure Finalizer_Scope_1124 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1124;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9457 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9456 '<Find at ast.py:15606>' Find_Result /tmp/lal-23.0.0/ada/ast.py:15606
   --# expr-start 9454 '<FieldAccess for env_get at ast.py:15598>' Fld /tmp/lal-23.0.0/ada/ast.py:15598
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9453 '<GetSymbol at ast.py:15600>' Sym /tmp/lal-23.0.0/ada/ast.py:15600
Sym := Get_Symbol (Self); 
--# expr-done 9453
--# property-call-start AdaNode.env_get
Fld := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Lex_Env, Symbol => Sym, Lookup => Lookup_Type, From_Node => From_Node, Categories => (Inherited_Primitives => False, Nocat => True));
--# end
--# expr-done 9454
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_294 of
               Collection.Items
         loop
   --# scope-start
               --# bind el Item_294
if No_Visibility then
   If_Result := True;
else
   --# expr-start 9455 '<FieldAccess for has_visibility at ast.py:15606>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:15606
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_visibility
Fld_1 := Libadalang.Implementation.Ada_Node_P_Has_Visibility (Node => Self, Other_Entity => Item_294);
--# end
--# expr-done 9455
   If_Result := Fld_1;
end if;
      if If_Result then
         Find_Result := Item_294;
      end if;
   --# end
               exit when If_Result;
         end loop;
      end;
--# expr-done 9456
Let_Result := Find_Result; 
--# end
--# expr-done 9457
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1124;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1124;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Single_Tok_Node_P_Env_Get_First_Visible;
--# end
   --
   --  Primitives for Bare_Base_Id
   --
      procedure Initialize_Fields_For_Base_Id
        (Self : Bare_Base_Id
        ) is
      begin
            Initialize_Fields_For_Single_Tok_Node
              (Self);
      end Initialize_Fields_For_Base_Id;
--# property-start BaseId.scope /tmp/lal-23.0.0/ada/ast.py:16263
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Scope
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1173 with Inline_Always;
            procedure Finalizer_Scope_3034 with Inline_Always;
      Block_Var : Internal_Entity;
Block_Var_1 : Lexical_Env := Empty_Env;
Var_Expr : Bare_Generic_Package_Decl;
Sym : Symbol_Type;
Fld : Boolean;
If_Result : Lookup_Kind;
Env_Get_Result : Internal_Entity;
Fld_1 : Lexical_Env := Empty_Env;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_2 : Bare_Ada_Node;
Is_A : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Lexical_Env := Empty_Env;
Env_Node : Bare_Ada_Node;
Cast_Result : Bare_Generic_Package_Decl;
Fld_3 : Bare_Generic_Package_Internal;
Fld_4 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1173 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1173;
            procedure Finalizer_Scope_3034 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_3034;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Id_Base_Id_P_Scope,
            Items    => new Mmz_Key_Array (1 ..  2))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Id,
                                As_Bare_Base_Id => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Lexical_Env,
                                      As_Lexical_Env => Env);
                  Inc_Ref (Mmz_K.Items (2).As_Lexical_Env);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Lexical_Env;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 9471 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9460 '<EnvGet at ast.py:16264>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:16264
Sym := Get_Symbol (Self); 
--# expr-start 9459 '<If at ast.py:16266>' If_Result /tmp/lal-23.0.0/ada/ast.py:16266
--# expr-start 9458 '<FieldAccess for is_prefix at ast.py:16266>' Fld /tmp/lal-23.0.0/ada/ast.py:16266
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9458
if Fld then
   If_Result := Recursive;
else
   If_Result := Flat;
end if;
--# expr-done 9459
Env_Get_Result := AST_Envs.Get_First (Self => Env, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (If_Result), Categories => (Inherited_Primitives => False, Nocat => True)); 
--# expr-done 9460
Block_Var := Env_Get_Result; 
--# bind elt Block_Var
--# expr-start 9466 '<If at ast.py:16269>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:16269
--# expr-start 9462 '<Not at ast.py:16270>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16270
--# expr-start 9461 '<IsNull at ast.py:16270>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16270
Is_Null := Block_Var.Node = null; 
--# expr-done 9461
Not_Val := not (Is_Null); 
--# expr-done 9462
if Not_Val then
   --# expr-start 9464 '<IsA BasicDecl at ast.py:16270>' Is_A /tmp/lal-23.0.0/ada/ast.py:16270
--# expr-start 9463 '<FieldAccess for node at ast.py:16270>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16270
Fld_2 := Block_Var.Node;
--# expr-done 9463
Is_A := Fld_2 /= null 
and then Fld_2.Kind in Ada_Basic_Decl; 
--# expr-done 9464
   If_Result_1 := Is_A;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 9465 '<FieldAccess for children_env at ast.py:16273>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16273
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# expr-done 9465
   If_Result_2 := Fld_1;
else
   If_Result_2 := Empty_Env;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 9466
Block_Var_1 := If_Result_2; Inc_Ref (Block_Var_1);
--# bind ret Block_Var_1
--# expr-start 9468 '<Cast to GenericPackageDecl at ast.py:16279>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16279
--# expr-start 9467 '<env_node at ast.py:16279>' Env_Node /tmp/lal-23.0.0/ada/ast.py:16279
Env_Node := AST_Envs.Env_Node (Block_Var_1); 
--# expr-done 9467
   if Env_Node = null
      or else Env_Node.Kind in Ada_Generic_Package_Decl_Range
   then
      Cast_Result := Env_Node;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 9468
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind gen_pkg_decl Var_Expr
--# expr-start 9470 '<FieldAccess for children_env at ast.py:16280>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16280
--# expr-start 9469 '<FieldAccess for package_decl at ast.py:16280>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16280
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Var_Expr.Generic_Package_Decl_F_Package_Decl;
--# expr-done 9469
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Children_Env (Node => Fld_3);
--# expr-done 9470
Scope_Result := Fld_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3034;
   Result_Var := Scope_Result;
else
   Result_Var := Block_Var_1;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 9471
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1173;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Lexical_Env,
                        As_Lexical_Env => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1173;
               Finalizer_Scope_3034;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Scope;
--# end
--# property-start BaseId.designated_env_no_overloading /tmp/lal-23.0.0/ada/ast.py:16285
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Designated_Env_No_Overloading
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1174 with Inline_Always;
            procedure Finalizer_Scope_3035 with Inline_Always;
      Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Basic_Decl;
Fld : Boolean;
If_Result : Lookup_Kind;
Fld_1 : Bare_Ada_Node;
Fld_2 : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Lexical_Env := Empty_Env;
Fld_5 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result_1 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1174 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1174;
            procedure Finalizer_Scope_3035 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (If_Result_1);
            end Finalizer_Scope_3035;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9481 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9476 '<Cast to BasicDecl at ast.py:16290>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16290
--# expr-start 9475 '<FieldAccess for env_get_first_visible at ast.py:16286>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16286
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9473 '<If at ast.py:16288>' If_Result /tmp/lal-23.0.0/ada/ast.py:16288
--# expr-start 9472 '<FieldAccess for is_prefix at ast.py:16288>' Fld /tmp/lal-23.0.0/ada/ast.py:16288
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9472
if Fld then
   If_Result := Recursive;
else
   If_Result := Flat;
end if;
--# expr-done 9473
--# expr-start 9474 '<FieldAccess for origin_node at ast.py:16289>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16289
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9474
--# property-call-start SingleTokNode.env_get_first_visible
Fld_2 := Libadalang.Implementation.Single_Tok_Node_P_Env_Get_First_Visible (Node => Self, Lex_Env => Env, Lookup_Type => If_Result, From_Node => Fld_1, No_Visibility => No_Visibility);
--# end
--# expr-done 9475
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 9476
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr
--# expr-start 9480 '<If at ast.py:16291>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16291
Var_Expr_1 := Var_Expr;
if Var_Expr_1 /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 9477 '<FieldAccess for is_package at ast.py:16292>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16292
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.is_package
Fld_5 := Libadalang.Implementation.Ada_Node_P_Is_Package (Node => Var_Expr_1.Node);
--# end
--# expr-done 9477
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   --# expr-start 9478 '<FieldAccess for pkg_env at ast.py:16292>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16292
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.pkg_env
Fld_3 := Libadalang.Implementation.Base_Id_P_Pkg_Env (Node => Ent.Node, From_Pkg => Var_Expr, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9478
   If_Result_1 := Fld_3;
else
   --# expr-start 9479 '<FieldAccess for defining_env at ast.py:16292>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16292
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Var_Expr.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9479
   If_Result_1 := Fld_4;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 9480
Scope_Result_1 := If_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3035;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Empty_Env;
end if;
      Inc_Ref (Result_Var_1);
Let_Result := Result_Var_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9481
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1174;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1174;
               Finalizer_Scope_3035;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Designated_Env_No_Overloading;
--# end
--# property-start BaseId.designated_env /tmp/lal-23.0.0/ada/ast.py:16297
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Designated_Env
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
      ; No_Visibility : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   --# bind no_visibility No_Visibility
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1175 with Inline_Always;
            procedure Finalizer_Scope_3045 with Inline_Always;
            procedure Finalizer_Scope_3047 with Inline_Always;
      Block_Var : Bare_Ada_Node;
Block_Var_1 : Internal_Entity;
Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Array_Access;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Fld : Boolean;
If_Result : Lookup_Kind;
Fld_1 : Bare_Ada_Node;
Fld_2 : Internal_Entity;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Internal_Entity_Array_Access;
Fld_5 : Bare_Ada_Node;
Cast_Result_1 : Bare_Ada_Node;
Is_Equal : Boolean;
Not_Val : Boolean;
Fld_6 : Boolean;
If_Result_1 : Boolean;
Map_Result : Internal_Entity_Array_Access;
Scope_Result : Internal_Entity_Array_Access;
Result_Var : Internal_Entity_Array_Access;
Cast_Expr_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Basic_Decl;
Fld_7 : Lexical_Env := Empty_Env;
Map_Result_1 : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Cast_Expr_2 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Basic_Decl;
Fld_8 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Cast_Expr_3 : Internal_Entity;
Cast_Result_4 : Internal_Entity_Basic_Decl;
Fld_9 : Bare_Basic_Decl;
Cast_Result_5 : Bare_Ada_Node;
Is_Equal_1 : Boolean;
Not_Val_1 : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1175 is
            begin
                     Dec_Ref (Node_Parents);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Group_Env);
                     Dec_Ref (If_Result_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1175;
            procedure Finalizer_Scope_3045 is
            begin
                     Dec_Ref (Var_Expr_1);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_3045;
            procedure Finalizer_Scope_3047 is
            begin
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_3047;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9508 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9484 '<Find at ast.py:16302>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16302
   --# expr-start 9482 '<FieldAccess for parents at ast.py:16302>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:16302
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 9482
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_295 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_295
      --# expr-start 9483 '<IsA GenericPackageInstantiation at ast.py:16303>' Is_A /tmp/lal-23.0.0/ada/ast.py:16303
Is_A := Item_295 /= null 
and then Item_295.Kind in Ada_Generic_Package_Instantiation_Range; 
--# expr-done 9483
      if Is_A then
         Find_Result := Item_295;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 9484
Block_Var := Find_Result; 
--# bind bd Block_Var
--# expr-start 9488 '<FieldAccess for env_get_first_visible at ast.py:16306>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16306
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9486 '<If at ast.py:16308>' If_Result /tmp/lal-23.0.0/ada/ast.py:16308
--# expr-start 9485 '<FieldAccess for is_prefix at ast.py:16308>' Fld /tmp/lal-23.0.0/ada/ast.py:16308
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9485
if Fld then
   If_Result := Recursive;
else
   If_Result := Flat;
end if;
--# expr-done 9486
--# expr-start 9487 '<FieldAccess for origin_node at ast.py:16309>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16309
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9487
--# property-call-start SingleTokNode.env_get_first_visible
Fld_2 := Libadalang.Implementation.Single_Tok_Node_P_Env_Get_First_Visible (Node => Self, Lex_Env => Env, Lookup_Type => If_Result, From_Node => Fld_1, No_Visibility => No_Visibility);
--# end
--# expr-done 9488
Block_Var_1 := Fld_2; 
--# expr-start 9507 '<If at ast.py:16312>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:16312
--# expr-start 9489 '<Cast to BasicDecl at ast.py:16310>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:16310
Cast_Expr_2 := Block_Var_1; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_3 := No_Entity_Basic_Decl;
   end if;
--# expr-done 9489
Var_Expr := Cast_Result_3;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
--# expr-start 9490 '<FieldAccess for is_package at ast.py:16314>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16314
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.is_package
Fld_8 := Libadalang.Implementation.Ada_Node_P_Is_Package (Node => Var_Expr.Node);
--# end
--# expr-done 9490
Scope_Result_1 := Fld_8;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
if Result_Var_1 then
   --# expr-start 9494 '<Not at ast.py:16314>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:16314
--# expr-start 9493 '<Eq at ast.py:16314>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:16314
--# expr-start 9492 '<FieldAccess for node at ast.py:16314>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:16314
--# expr-start 9491 '<Cast to BasicDecl at ast.py:16310>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:16310
Cast_Expr_3 := Block_Var_1; 
   if Cast_Expr_3.Node = null
      or else Cast_Expr_3.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_4 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
   else
         Cast_Result_4 := No_Entity_Basic_Decl;
   end if;
--# expr-done 9491
Fld_9 := Cast_Result_4.Node;
--# expr-done 9492
      Cast_Result_5 := Fld_9;
Is_Equal_1 := Cast_Result_5 = Block_Var; 
--# expr-done 9493
Not_Val_1 := not (Is_Equal_1); 
--# expr-done 9494
   If_Result_2 := Not_Val_1;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   --# expr-start 9496 '<FieldAccess for pkg_env at ast.py:16315>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16315
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9495 '<Cast to BasicDecl at ast.py:16310>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16310
Cast_Expr := Block_Var_1; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 9495
--# property-call-start BaseId.pkg_env
Fld_3 := Libadalang.Implementation.Base_Id_P_Pkg_Env (Node => Ent.Node, From_Pkg => Cast_Result, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9496
   If_Result_3 := Fld_3;
else
   --# expr-start 9506 '<env_group at ast.py:16325>' Group_Env /tmp/lal-23.0.0/ada/ast.py:16325
--# expr-start 9505 '<Map at ast.py:16325>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:16325
--# expr-start 9497 '<FieldAccess for env_elements_baseid at ast.py:16317>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16317
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.env_elements_baseid
Fld_4 := Libadalang.Implementation.Base_Id_P_Env_Elements_Baseid (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 9497
Var_Expr_1 := Fld_4;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= No_Internal_Entity_Array_Type then
   --# scope-start
   --# bind all_env_els Var_Expr_1
--# expr-start 9502 '<Filter at ast.py:16319>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16319
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Var_Expr_1;
      begin
         for Item_297 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_297
--# expr-start 9500 '<Not at ast.py:16321>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16321
--# expr-start 9499 '<Eq at ast.py:16321>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16321
--# expr-start 9498 '<FieldAccess for node at ast.py:16321>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16321
Fld_5 := Item_297.Node;
--# expr-done 9498
      Cast_Result_1 := Fld_5;
Is_Equal := Cast_Result_1 = Block_Var; 
--# expr-done 9499
Not_Val := not (Is_Equal); 
--# expr-done 9500
if Not_Val then
   --# expr-start 9501 '<FieldAccess for has_visibility at ast.py:16323>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16323
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.has_visibility
Fld_6 := Libadalang.Implementation.Ada_Node_P_Has_Visibility (Node => Self, Other_Entity => Item_297);
--# end
--# expr-done 9501
   If_Result_1 := Fld_6;
else
   If_Result_1 := False;
end if;
         if If_Result_1 then
         declare
            Item_To_Append : constant Internal_Entity := Item_297;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9502
Scope_Result := Map_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3045;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var);
      declare
         Map_Result_1_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Result_Var;
      begin
         for Item_296 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_296
      --# expr-start 9504 '<FieldAccess for defining_env at ast.py:16325>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16325
--# expr-start 9503 '<Cast to BasicDecl at ast.py:16325>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:16325
Cast_Expr_1 := Item_296; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Basic_Decl;
   end if;
--# expr-done 9503
      if Cast_Result_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Cast_Result_2.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Cast_Result_2.Info);
--# end
--# expr-done 9504
         declare
            Item_To_Append : constant Lexical_Env := Fld_7;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3047;
         end loop;
      end;
         Map_Result_1 := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_1_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 9505
Group_Env := Group (Map_Result_1, No_Metadata); 
--# expr-done 9506
   If_Result_3 := Group_Env;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 9507
Let_Result := If_Result_3; Inc_Ref (Let_Result);
--# end
--# expr-done 9508
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1175;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1175;
               Finalizer_Scope_3045;
               Finalizer_Scope_3047;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Designated_Env;
--# end
--# property-start BaseId.pkg_env /tmp/lal-23.0.0/ada/ast.py:16329
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Pkg_Env
  (Node : Bare_Base_Id
      ; From_Pkg : Internal_Entity_Basic_Decl
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind from_pkg From_Pkg
   --# bind env Env
   --# bind origin Origin
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1176 with Inline_Always;
            procedure Finalizer_Scope_3037 with Inline_Always;
            procedure Finalizer_Scope_3038 with Inline_Always;
            procedure Finalizer_Scope_3039 with Inline_Always;
            procedure Finalizer_Scope_3040 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Block_Var_1 : Internal_Entity_Basic_Decl;
Block_Var_2 : Boolean;
Block_Var_3 : Lexical_Env := Empty_Env;
Block_Var_4 : Lexical_Env := Empty_Env;
Block_Var_5 : Lexical_Env := Empty_Env;
Block_Var_6 : Lexical_Env := Empty_Env;
Var_Expr : Internal_Entity_Package_Renaming_Decl;
Var_Expr_1 : Internal_Entity;
Var_Expr_2 : Internal_Entity;
Var_Expr_3 : Internal_Entity;
Var_Expr_4 : Internal_Entity_Generic_Package_Decl;
Var_Expr_5 : Bare_Ada_Node;
Var_Expr_6 : Bare_Ada_Node;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity_Package_Renaming_Decl;
Fld : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Info;
Fld_2 : Env_Rebindings;
Fld_3 : Internal_Entity_Basic_Decl;
Is_A : Boolean;
Fld_4 : Internal_Entity_Info;
Fld_5 : Boolean;
If_Result : Boolean;
Cast_Expr_1 : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity_Generic_Package_Instantiation;
Fld_6 : Lexical_Env := Empty_Env;
Fld_7 : Lexical_Env := Empty_Env;
Is_A_1 : Boolean;
If_Result_1 : Boolean;
If_Result_2 : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Get_Result : Internal_Entity;
Fld_8 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Sym_1 : Symbol_Type;
Env_Get_Result_1 : Internal_Entity_Array_Access;
Get_Result_1 : Internal_Entity;
Fld_9 : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result_2 : Internal_Entity_Array_Access;
Get_Result_2 : Internal_Entity;
Fld_10 : Lexical_Env := Empty_Env;
Scope_Result_2 : Lexical_Env := Empty_Env;
Result_Var_2 : Lexical_Env := Empty_Env;
Fld_11 : Lexical_Env := Empty_Env;
Is_A_2 : Boolean;
If_Result_3 : Lexical_Env := Empty_Env;
Scope_Result_3 : Lexical_Env := Empty_Env;
Result_Var_3 : Lexical_Env := Empty_Env;
Cast_Expr_2 : Internal_Entity_Basic_Decl;
Cast_Result_2 : Internal_Entity_Generic_Package_Decl;
Fld_12 : Internal_Entity_Generic_Formal_Part;
Fld_13 : Lexical_Env := Empty_Env;
Scope_Result_4 : Lexical_Env := Empty_Env;
Result_Var_4 : Lexical_Env := Empty_Env;
Is_Equal : Boolean;
Not_Val : Boolean;
Scope_Result_5 : Bare_Ada_Node;
Cast_Expr_3 : Bare_Base_Id;
Cast_Result_3 : Bare_Ada_Node;
Result_Var_5 : Bare_Ada_Node;
Fld_14 : Lexical_Env := Empty_Env;
Fld_15 : Boolean;
If_Result_4 : Boolean;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Scope_Result_6 : Bare_Ada_Node;
Cast_Expr_4 : Bare_Base_Id;
Cast_Result_4 : Bare_Ada_Node;
Result_Var_6 : Bare_Ada_Node;
Fld_16 : Lexical_Env := Empty_Env;
Fld_17 : Boolean;
Array_Lit_1 : Lexical_Env_Array_Access;
Group_Env_1 : Lexical_Env := Empty_Env;
If_Result_5 : Lexical_Env := Empty_Env;
If_Result_6 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1176 is
            begin
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (If_Result_2);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Block_Var_4);
                     Dec_Ref (Env_Get_Result_1);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Block_Var_5);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Result_Var_4);
                     Dec_Ref (Block_Var_6);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (Group_Env_1);
                     Dec_Ref (If_Result_5);
                     Dec_Ref (If_Result_6);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1176;
            procedure Finalizer_Scope_3037 is
            begin
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_3037;
            procedure Finalizer_Scope_3038 is
            begin
                     Dec_Ref (Fld_9);
                     Dec_Ref (Env_Get_Result_2);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Fld_11);
                     Dec_Ref (If_Result_3);
            end Finalizer_Scope_3038;
            procedure Finalizer_Scope_3039 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_3039;
            procedure Finalizer_Scope_3040 is
            begin
                     Dec_Ref (Fld_13);
            end Finalizer_Scope_3040;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9551 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9509 '<Cast to PackageRenamingDecl at ast.py:16344>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16344
Cast_Expr := From_Pkg; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Package_Renaming_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Package_Renaming_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Package_Renaming_Decl;
   end if;
--# expr-done 9509
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Package_Renaming_Decl then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 9510 '<FieldAccess for final_renamed_package at ast.py:16345>' Fld /tmp/lal-23.0.0/ada/ast.py:16345
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start PackageRenamingDecl.final_renamed_package
Fld := Libadalang.Implementation.Package_Renaming_Decl_P_Final_Renamed_Package (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 9510
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := From_Pkg;
end if;
Block_Var := Result_Var; 
--# bind pkg Block_Var
--# expr-start 9513 '<FieldAccess for unshed_rebindings at ast.py:16356>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16356
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9512 '<FieldAccess for rebindings at ast.py:16356>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16356
--# expr-start 9511 '<FieldAccess for info at ast.py:16356>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16356
Fld_1 := Ent.Info;
--# expr-done 9511
Fld_2 := Fld_1.Rebindings;
--# expr-done 9512
--# property-call-start BasicDecl.unshed_rebindings
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Unshed_Rebindings (Node => Block_Var.Node, Rebindings => Fld_2, E_Info => Block_Var.Info);
--# end
--# expr-done 9513
Block_Var_1 := Fld_3; 
--# bind bd Block_Var_1
--# expr-start 9514 '<IsA GenericPackageInstantiation at ast.py:16358>' Is_A /tmp/lal-23.0.0/ada/ast.py:16358
Is_A := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Generic_Package_Instantiation_Range; 
--# expr-done 9514
if Is_A then
   --# expr-start 9516 '<FieldAccess for from_rebound at ast.py:16359>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16359
--# expr-start 9515 '<FieldAccess for info at ast.py:16359>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16359
Fld_4 := From_Pkg.Info;
--# expr-done 9515
Fld_5 := Fld_4.From_Rebound;
--# expr-done 9516
   If_Result := Fld_5;
else
   If_Result := False;
end if;
Block_Var_2 := If_Result; 
--# bind is_inst_from_formal Block_Var_2
--# expr-start 9521 '<If at ast.py:16361>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:16361
--# expr-start 9517 '<IsA GenericPackageInstantiation at ast.py:16362>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:16362
Is_A_1 := Block_Var_1.Node /= null 
and then Block_Var_1.Node.Kind in Ada_Generic_Package_Instantiation_Range; 
--# expr-done 9517
if Is_A_1 then
   If_Result_1 := Block_Var_2;
else
   If_Result_1 := False;
end if;
if If_Result_1 then
   --# expr-start 9519 '<FieldAccess for defining_env_impl at ast.py:16363>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16363
--# expr-start 9518 '<Cast to GenericPackageInstantiation at ast.py:16363>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16363
Cast_Expr_1 := Block_Var_1; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Generic_Package_Instantiation_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Generic_Package_Instantiation
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Generic_Package_Instantiation;
   end if;
--# expr-done 9518
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericPackageInstantiation.defining_env_impl
Fld_6 := Libadalang.Implementation.Generic_Package_Instantiation_P_Defining_Env_Impl (Node => Cast_Result_1.Node, Inst_From_Formal => True, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 9519
   If_Result_2 := Fld_6;
else
   --# expr-start 9520 '<FieldAccess for defining_env at ast.py:16364>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16364
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Block_Var_1.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => No_Bare_Ada_Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 9520
   If_Result_2 := Fld_7;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 9521
Block_Var_3 := If_Result_2; Inc_Ref (Block_Var_3);
--# bind env Block_Var_3
--# expr-start 9524 '<at at ast.py:16370>' Get_Result /tmp/lal-23.0.0/ada/ast.py:16370
--# expr-start 9523 '<EnvGet at ast.py:16370>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:16370
--# expr-start 9522 '<Symbol __privatepart at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Privatepart); 
--# expr-done 9522
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Block_Var_3, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 9523
Get_Result := Get (Self, Env_Get_Result, 0, True); 
--# expr-done 9524
Var_Expr_1 := Get_Result;
if Var_Expr_1 /= No_Entity then
   --# scope-start
   --# bind pp Var_Expr_1
--# expr-start 9525 '<FieldAccess for children_env at ast.py:16371>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16371
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Children_Env (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# expr-done 9525
Scope_Result_1 := Fld_8;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3037;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Block_Var_3;
end if;
      Inc_Ref (Result_Var_1);
Block_Var_4 := Result_Var_1; Inc_Ref (Block_Var_4);
--# bind private_part_env Block_Var_4
--# expr-start 9528 '<at at ast.py:16377>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:16377
--# expr-start 9527 '<EnvGet at ast.py:16376>' Env_Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:16376
--# expr-start 9526 '<Symbol __nextpart at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Nextpart); 
--# expr-done 9526
Env_Get_Result_1 := Construct_Entity_Array (AST_Envs.Get (Self => Block_Var_4, Key => Sym_1, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 9527
Get_Result_1 := Get (Self, Env_Get_Result_1, 0, True); 
--# expr-done 9528
Var_Expr_2 := Get_Result_1;
if Var_Expr_2 /= No_Entity then
   --# scope-start
   --# bind pb Var_Expr_2
--# expr-start 9536 '<If at ast.py:16378>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:16378
--# expr-start 9529 '<IsA PackageBodyStub at ast.py:16381>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:16381
Is_A_2 := Var_Expr_2.Node /= null 
and then Var_Expr_2.Node.Kind in Ada_Package_Body_Stub_Range; 
--# expr-done 9529
if Is_A_2 then
--# expr-start 9533 '<at at ast.py:16385>' Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:16385
--# expr-start 9532 '<EnvGet at ast.py:16383>' Env_Get_Result_2 /tmp/lal-23.0.0/ada/ast.py:16383
--# expr-start 9530 '<FieldAccess for children_env at ast.py:16383>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:16383
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Children_Env (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# expr-done 9530
--# expr-start 9531 '<Symbol __nextpart at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Nextpart); 
--# expr-done 9531
Env_Get_Result_2 := Construct_Entity_Array (AST_Envs.Get (Self => Fld_9, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 9532
Get_Result_2 := Get (Self, Env_Get_Result_2, 0, True); 
--# expr-done 9533
Var_Expr_3 := Get_Result_2;
if Var_Expr_3 /= No_Entity then
   --# scope-start
   --# bind pb Var_Expr_3
--# expr-start 9534 '<FieldAccess for children_env at ast.py:16385>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:16385
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Children_Env (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# expr-done 9534
Scope_Result_2 := Fld_10;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_3039;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Empty_Env;
end if;
      Inc_Ref (Result_Var_2);
   If_Result_3 := Result_Var_2;
else
   --# expr-start 9535 '<FieldAccess for children_env at ast.py:16387>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:16387
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Children_Env (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# expr-done 9535
   If_Result_3 := Fld_11;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 9536
Scope_Result_3 := If_Result_3;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_3038;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := Empty_Env;
end if;
      Inc_Ref (Result_Var_3);
Block_Var_5 := Result_Var_3; Inc_Ref (Block_Var_5);
--# bind package_body_env Block_Var_5
--# expr-start 9537 '<Cast to GenericPackageDecl at ast.py:16392>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:16392
Cast_Expr_2 := Block_Var_1; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Generic_Package_Decl_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Generic_Package_Decl
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_2 := No_Entity_Generic_Package_Decl;
   end if;
--# expr-done 9537
Var_Expr_4 := Cast_Result_2;
if Var_Expr_4 /= No_Entity_Generic_Package_Decl then
   --# scope-start
   --# bind pkg_g Var_Expr_4
--# expr-start 9539 '<FieldAccess for children_env at ast.py:16393>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:16393
--# expr-start 9538 '<FieldAccess for formal_part at ast.py:16393>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:16393
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Generic_Formal_Part (Node => Var_Expr_4.Node.Generic_Decl_F_Formal_Part, Info => Var_Expr_4.Info);
--# expr-done 9538
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Children_Env (Node => Fld_12.Node, E_Info => Fld_12.Info);
--# expr-done 9539
Scope_Result_4 := Fld_13;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_3040;
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := Empty_Env;
end if;
      Inc_Ref (Result_Var_4);
Block_Var_6 := Result_Var_4; Inc_Ref (Block_Var_6);
--# bind formals_env Block_Var_6
--# expr-start 9550 '<Cond at ast.py:16397>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:16397
--# expr-start 9541 '<Not at ast.py:16401>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16401
--# expr-start 9540 '<Eq at ast.py:16401>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16401
Is_Equal := Equivalent (Block_Var_5, Empty_Env); 
--# expr-done 9540
Not_Val := not (Is_Equal); 
--# expr-done 9541
if Not_Val then
   --# expr-start 9543 '<FieldAccess for is_children_env at ast.py:16402>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:16402
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9542 '<FieldAccess for node_env at ast.py:16403>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:16403
Var_Expr_5 := Origin;
if Var_Expr_5 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr_5
Scope_Result_5 := Var_Expr_5;
   --# end
   Result_Var_5 := Scope_Result_5;
else
Cast_Expr_3 := Self; 
      Cast_Result_3 := Cast_Expr_3;
   Result_Var_5 := Cast_Result_3;
end if;
      if Result_Var_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Libadalang.Implementation.Node_Env (Node => Result_Var_5);
--# expr-done 9542
--# property-call-start AdaNode.is_children_env
Fld_15 := Libadalang.Implementation.Ada_Node_P_Is_Children_Env (Node => Self, Parent => Block_Var_5, Current_Env => Fld_14);
--# end
--# expr-done 9543
   If_Result_4 := Fld_15;
else
   If_Result_4 := False;
end if;
if If_Result_4 then
   --# expr-start 9545 '<env_group at ast.py:16406>' Group_Env /tmp/lal-23.0.0/ada/ast.py:16406
--# expr-start 9544 '<ArrayLiteral at ast.py:16404>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:16404
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Block_Var_5, 2 => Block_Var_4, 3 => Block_Var_3, 4 => Block_Var_6)); 
--# expr-done 9544
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 9545
   If_Result_6 := Group_Env;
else
--# expr-start 9547 '<FieldAccess for is_children_env at ast.py:16410>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:16410
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9546 '<FieldAccess for node_env at ast.py:16411>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:16411
Var_Expr_6 := Origin;
if Var_Expr_6 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr_6
Scope_Result_6 := Var_Expr_6;
   --# end
   Result_Var_6 := Scope_Result_6;
else
Cast_Expr_4 := Self; 
      Cast_Result_4 := Cast_Expr_4;
   Result_Var_6 := Cast_Result_4;
end if;
      if Result_Var_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Libadalang.Implementation.Node_Env (Node => Result_Var_6);
--# expr-done 9546
--# property-call-start AdaNode.is_children_env
Fld_17 := Libadalang.Implementation.Ada_Node_P_Is_Children_Env (Node => Self, Parent => Block_Var_4, Current_Env => Fld_16);
--# end
--# expr-done 9547
if Fld_17 then
   --# expr-start 9549 '<env_group at ast.py:16412>' Group_Env_1 /tmp/lal-23.0.0/ada/ast.py:16412
--# expr-start 9548 '<ArrayLiteral at ast.py:16412>' Array_Lit_1 /tmp/lal-23.0.0/ada/ast.py:16412
Array_Lit_1 := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Block_Var_4, 2 => Block_Var_3, 3 => Block_Var_6)); 
--# expr-done 9548
Group_Env_1 := Group (Array_Lit_1, No_Metadata); 
--# expr-done 9549
   If_Result_5 := Group_Env_1;
else
   If_Result_5 := Block_Var_3;
end if;
      Inc_Ref (If_Result_5);
   If_Result_6 := If_Result_5;
end if;
      Inc_Ref (If_Result_6);
--# expr-done 9550
Let_Result := If_Result_6; Inc_Ref (Let_Result);
--# end
--# expr-done 9551
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1176;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1176;
               Finalizer_Scope_3037;
               Finalizer_Scope_3038;
               Finalizer_Scope_3039;
               Finalizer_Scope_3040;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Pkg_Env;
--# end
--# property-start BaseId.parent_scope /tmp/lal-23.0.0/ada/ast.py:16421
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Parent_Scope
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
  )
   return Lexical_Env
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   Property_Result : Lexical_Env;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := Env;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Parent_Scope;
--# end
--# property-start BaseId.designated_type_impl_get_real_type /tmp/lal-23.0.0/ada/ast.py:16424
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Designated_Type_Impl_Get_Real_Type
  (Node : Bare_Base_Id
      ; N : Internal_Entity
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind n N
   Property_Result : Internal_Entity_Base_Type_Decl;
      Match_0 : Internal_Entity_Base_Type_Decl;
Match_1 : Internal_Entity_Task_Body;
Match_2 : Internal_Entity;
Fld : Internal_Entity_Task_Type_Decl;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity_Task_Body;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Let_Result_2 : Internal_Entity_Base_Type_Decl;
Scope_Result_2 : Internal_Entity_Base_Type_Decl;
Match_Result : Internal_Entity_Base_Type_Decl;
Let_Result_3 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9554 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 9553 '<Match at ast.py:16429>' Match_Result /tmp/lal-23.0.0/ada/ast.py:16429
      if N.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := N; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind t Match_0
Let_Result := Match_0; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Task_Body =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Task_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind tb Match_1
--# expr-start 9552 '<FieldAccess for task_type at ast.py:16431>' Fld /tmp/lal-23.0.0/ada/ast.py:16431
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TaskBody.task_type
Fld := Libadalang.Implementation.Task_Body_P_Task_Type (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 9552
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
Let_Result_1 := Cast_Result_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Package_Decl | Ada_Abstract_Subp_Decl .. Ada_Protected_Body | Ada_Entry_Index_Spec .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_3; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Base_Type_Decl; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 9553
Let_Result_3 := Match_Result; 
--# end
--# expr-done 9554
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Designated_Type_Impl_Get_Real_Type;
--# end
--# property-start BaseId.designated_type_impl /tmp/lal-23.0.0/ada/ast.py:16436
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Designated_Type_Impl
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1179 with Inline_Always;
            procedure Finalizer_Scope_3055 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Block_Var_3 : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity;
Var_Expr_1 : Internal_Entity;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Var_Expr_3 : Bare_Ada_Node;
Var_Expr_4 : Internal_Entity_Base_Type_Decl;
Var_Expr_5 : Internal_Entity_Base_Type_Decl;
Var_Expr_6 : Internal_Entity_Base_Type_Decl;
Var_Expr_7 : Internal_Entity_Base_Type_Decl;
Var_Expr_8 : Internal_Entity_Generic_Formal_Type_Decl;
Fld : Boolean;
If_Result : Lookup_Kind;
Cast_Expr : Bare_Base_Id;
Cast_Result : Bare_Ada_Node;
Fld_1 : Internal_Entity;
Fld_2 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Fld_3 : Boolean;
If_Result_1 : Lookup_Kind;
Fld_4 : Internal_Entity;
Fld_5 : Internal_Entity_Base_Type_Decl;
Scope_Result_1 : Internal_Entity_Base_Type_Decl;
Result_Var_1 : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Is_Equiv : Boolean;
Fld_6 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_2 : Internal_Entity_Base_Type_Decl;
If_Result_3 : Internal_Entity_Base_Type_Decl;
If_Result_4 : Internal_Entity_Base_Type_Decl;
Fld_7 : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Fld_8 : Internal_Entity_Array_Access;
Scope_Result_3 : Internal_Entity_Array_Access;
Result_Var_3 : Internal_Entity_Array_Access;
Cast_Expr_3 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
Is_A : Boolean;
Cast_Expr_4 : Internal_Entity;
Cast_Result_4 : Internal_Entity_Base_Type_Decl;
Fld_9 : Boolean;
Scope_Result_4 : Boolean;
Result_Var_4 : Boolean;
If_Result_5 : Boolean;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Get_Result : Internal_Entity_Base_Type_Decl;
Scope_Result_5 : Internal_Entity_Base_Type_Decl;
Result_Var_5 : Internal_Entity_Base_Type_Decl;
Fld_10 : Internal_Entity;
Cast_Result_5 : Internal_Entity_Generic_Formal_Type_Decl;
Fld_11 : Internal_Entity_Base_Type_Decl;
Scope_Result_6 : Internal_Entity_Base_Type_Decl;
Result_Var_6 : Internal_Entity_Base_Type_Decl;
Scope_Result_7 : Internal_Entity_Base_Type_Decl;
Result_Var_7 : Internal_Entity_Base_Type_Decl;
Scope_Result_8 : Internal_Entity_Base_Type_Decl;
Result_Var_8 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1179 is
            begin
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1179;
            procedure Finalizer_Scope_3055 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
            end Finalizer_Scope_3055;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9579 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9557 '<FieldAccess for env_get_first_visible at ast.py:16438>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16438
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9556 '<If at ast.py:16441>' If_Result /tmp/lal-23.0.0/ada/ast.py:16441
--# expr-start 9555 '<FieldAccess for is_prefix at ast.py:16441>' Fld /tmp/lal-23.0.0/ada/ast.py:16441
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9555
if Fld then
   If_Result := Recursive;
else
   If_Result := Minimal;
end if;
--# expr-done 9556
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
--# property-call-start SingleTokNode.env_get_first_visible
Fld_1 := Libadalang.Implementation.Single_Tok_Node_P_Env_Get_First_Visible (Node => Self, Lex_Env => Env, Lookup_Type => If_Result, From_Node => Cast_Result, No_Visibility => False);
--# end
--# expr-done 9557
Var_Expr := Fld_1;
if Var_Expr /= No_Entity then
   --# scope-start
   --# bind env_el Var_Expr
--# expr-start 9558 '<FieldAccess for designated_type_impl_get_real_type at ast.py:16443>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16443
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.designated_type_impl_get_real_type
Fld_2 := Libadalang.Implementation.Base_Id_P_Designated_Type_Impl_Get_Real_Type (Node => Self, N => Var_Expr);
--# end
--# expr-done 9558
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Block_Var := Result_Var; 
--# bind des_type_1 Block_Var
--# expr-start 9561 '<FieldAccess for env_get_first_visible at ast.py:16447>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16447
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9560 '<If at ast.py:16450>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16450
--# expr-start 9559 '<FieldAccess for is_prefix at ast.py:16450>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16450
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld_3 := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9559
if Fld_3 then
   If_Result_1 := Recursive;
else
   If_Result_1 := Minimal;
end if;
--# expr-done 9560
--# property-call-start SingleTokNode.env_get_first_visible
Fld_4 := Libadalang.Implementation.Single_Tok_Node_P_Env_Get_First_Visible (Node => Self, Lex_Env => Env, Lookup_Type => If_Result_1, From_Node => Origin, No_Visibility => False);
--# end
--# expr-done 9561
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= No_Entity then
   --# scope-start
   --# bind env_el Var_Expr_1
--# expr-start 9562 '<FieldAccess for designated_type_impl_get_real_type at ast.py:16452>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16452
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.designated_type_impl_get_real_type
Fld_5 := Libadalang.Implementation.Base_Id_P_Designated_Type_Impl_Get_Real_Type (Node => Self, N => Var_Expr_1);
--# end
--# expr-done 9562
Scope_Result_1 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Base_Type_Decl;
end if;
Block_Var_1 := Result_Var_1; 
--# bind des_type_2 Block_Var_1
--# expr-start 9566 '<Cond at ast.py:16455>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:16455
--# expr-start 9563 '<IsNull at ast.py:16457>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16457
Is_Null := Block_Var.Node = null; 
--# expr-done 9563
if Is_Null then
   If_Result_4 := Block_Var_1;
else
--# expr-start 9564 '<Eq at ast.py:16461>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:16461
Cast_Expr_1 := Block_Var; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Cast_Expr_2 := Block_Var_1; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Is_Equiv := Equivalent (Cast_Result_1, Cast_Result_2); 
--# expr-done 9564
if Is_Equiv then
   If_Result_3 := Block_Var;
else
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind d Var_Expr_2
--# expr-start 9565 '<FieldAccess for is_view_of_type at ast.py:16465>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16465
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_view_of_type
Fld_6 := Libadalang.Implementation.Base_Type_Decl_P_Is_View_Of_Type (Node => Var_Expr_2.Node, Comp_View => Block_Var_1, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 9565
Scope_Result_2 := Fld_6;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
if Result_Var_2 then
   If_Result_2 := Block_Var_1;
else
   If_Result_2 := Block_Var;
end if;
   If_Result_3 := If_Result_2;
end if;
   If_Result_4 := If_Result_3;
end if;
--# expr-done 9566
Block_Var_2 := If_Result_4; 
--# bind des_type Block_Var_2
--# expr-start 9575 '<at at ast.py:16482>' Get_Result /tmp/lal-23.0.0/ada/ast.py:16482
--# expr-start 9574 '<FilterMap at ast.py:16477>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16477
Var_Expr_3 := Origin;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind o Var_Expr_3
--# expr-start 9569 '<FieldAccess for env_get at ast.py:16475>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16475
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9567 '<FieldAccess for children_env at ast.py:16476>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16476
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Children_Env (Node => Var_Expr_3);
--# expr-done 9567
--# expr-start 9568 '<GetSymbol at ast.py:16476>' Sym /tmp/lal-23.0.0/ada/ast.py:16476
Sym := Get_Symbol (Self); 
--# expr-done 9568
--# property-call-start AdaNode.env_get
Fld_8 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Fld_7, Symbol => Sym, From_Node => Origin, Categories => (Inherited_Primitives => False, Nocat => True));
--# end
--# expr-done 9569
Scope_Result_3 := Fld_8;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_3055;
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Internal_Entity_Array_Type;
end if;
      Inc_Ref (Result_Var_3);
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Result_Var_3;
      begin
         for Item_298 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_298
--# expr-start 9570 '<IsA BaseTypeDecl at ast.py:16480>' Is_A /tmp/lal-23.0.0/ada/ast.py:16480
Is_A := Item_298.Node /= null 
and then Item_298.Node.Kind in Ada_Base_Type_Decl; 
--# expr-done 9570
if Is_A then
Var_Expr_4 := Block_Var_2;
if Var_Expr_4 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind d Var_Expr_4
--# expr-start 9572 '<FieldAccess for is_view_of_type at ast.py:16481>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:16481
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9571 '<Cast to BaseTypeDecl at ast.py:16481>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:16481
Cast_Expr_4 := Item_298; 
   if Cast_Expr_4.Node = null
      or else Cast_Expr_4.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_4 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_4.Node,
         Info => Cast_Expr_4.Info);
   else
         Cast_Result_4 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 9571
--# property-call-start BaseTypeDecl.is_view_of_type
Fld_9 := Libadalang.Implementation.Base_Type_Decl_P_Is_View_Of_Type (Node => Var_Expr_4.Node, Comp_View => Cast_Result_4, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 9572
Scope_Result_4 := Fld_9;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := False;
end if;
   If_Result_5 := Result_Var_4;
else
   If_Result_5 := False;
end if;
         if If_Result_5 then
      --# expr-start 9573 '<Cast to BaseTypeDecl at ast.py:16478>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:16478
Cast_Expr_3 := Item_298; 
   if Cast_Expr_3.Node = null
      or else Cast_Expr_3.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
   else
         Cast_Result_3 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 9573
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Cast_Result_3;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9574
Get_Result := Get (Self, Map_Result, 0, True); 
--# expr-done 9575
Block_Var_3 := Get_Result; 
--# bind completer_view Block_Var_3
Var_Expr_6 := Block_Var_3;
if Var_Expr_6 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr_6
Scope_Result_5 := Var_Expr_6;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := Block_Var_2;
end if;
Var_Expr_5 := Result_Var_5;
if Var_Expr_5 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind precise Var_Expr_5
--# expr-start 9577 '<Cast to GenericFormalTypeDecl at ast.py:16491>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:16491
--# expr-start 9576 '<parent at ast.py:16491>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:16491
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Libadalang.Implementation.Parent (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# expr-done 9576
   if Fld_10.Node = null
      or else Fld_10.Node.Kind in Ada_Generic_Formal_Type_Decl_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Generic_Formal_Type_Decl
        (Node => Fld_10.Node,
         Info => Fld_10.Info);
   else
         Cast_Result_5 := No_Entity_Generic_Formal_Type_Decl;
   end if;
--# expr-done 9577
Var_Expr_8 := Cast_Result_5;
if Var_Expr_8 /= No_Entity_Generic_Formal_Type_Decl then
   --# scope-start
--# expr-start 9578 '<FieldAccess for default_type at ast.py:16491>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:16491
      if Var_Expr_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start GenericFormalTypeDecl.default_type
Fld_11 := Libadalang.Implementation.Generic_Formal_Type_Decl_P_Default_Type (Node => Var_Expr_8.Node, E_Info => Var_Expr_8.Info);
--# end
--# expr-done 9578
Scope_Result_6 := Fld_11;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Base_Type_Decl;
end if;
Var_Expr_7 := Result_Var_6;
if Var_Expr_7 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind e Var_Expr_7
Scope_Result_7 := Var_Expr_7;
   --# end
   Result_Var_7 := Scope_Result_7;
else
   Result_Var_7 := Var_Expr_5;
end if;
Scope_Result_8 := Result_Var_7;
   --# end
   Result_Var_8 := Scope_Result_8;
else
   Result_Var_8 := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var_8; 
--# end
--# expr-done 9579
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1179;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1179;
               Finalizer_Scope_3055;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Designated_Type_Impl;
--# end
--# property-start BaseId.env_elements_impl /tmp/lal-23.0.0/ada/ast.py:16496
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Env_Elements_Impl
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1180 with Inline_Always;
      Fld : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1180 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1180;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9581 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9580 '<FieldAccess for env_elements_baseid at ast.py:16497>' Fld /tmp/lal-23.0.0/ada/ast.py:16497
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.env_elements_baseid
Fld := Libadalang.Implementation.Base_Id_P_Env_Elements_Baseid (Node => Ent.Node, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 9580
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 9581
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1180;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1180;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Env_Elements_Impl;
--# end
--# property-start BaseId.all_env_els_impl /tmp/lal-23.0.0/ada/ast.py:16500
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_All_Env_Els_Impl
  (Node : Bare_Base_Id
      ; Seq : Boolean
         := True
      ; Seq_From : Bare_Ada_Node
         := No_Bare_Ada_Node
      ; Categories : Ref_Categories
         := (Inherited_Primitives => True, Nocat => True)
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind seq Seq
   --# bind seq_from Seq_From
   --# bind categories Categories
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1181 with Inline_Always;
      Fld : Symbol_Type;
Fld_1 : Boolean;
If_Result : Lookup_Kind;
Cast_Expr : Bare_Base_Id;
Cast_Result : Bare_Ada_Node;
Is_Null : Boolean;
Not_Val : Boolean;
If_Result_1 : Bare_Ada_Node;
If_Result_2 : Bare_Ada_Node;
Fld_2 : Internal_Entity_Array_Access;
Let_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1181 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1181;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9590 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9589 '<FieldAccess for env_get at ast.py:16505>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16505
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9582 '<FieldAccess for name_symbol at ast.py:16507>' Fld /tmp/lal-23.0.0/ada/ast.py:16507
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Self);
--# end
--# expr-done 9582
--# expr-start 9584 '<If at ast.py:16508>' If_Result /tmp/lal-23.0.0/ada/ast.py:16508
--# expr-start 9583 '<FieldAccess for is_prefix at ast.py:16508>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16508
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld_1 := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9583
if Fld_1 then
   If_Result := Recursive;
else
   If_Result := Flat;
end if;
--# expr-done 9584
--# expr-start 9588 '<If at ast.py:16509>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:16509
if Seq then
   --# expr-start 9587 '<If at ast.py:16509>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16509
--# expr-start 9586 '<Not at ast.py:16509>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16509
--# expr-start 9585 '<IsNull at ast.py:16509>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16509
Is_Null := Seq_From = null; 
--# expr-done 9585
Not_Val := not (Is_Null); 
--# expr-done 9586
if Not_Val then
   If_Result_1 := Seq_From;
else
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
   If_Result_1 := Cast_Result;
end if;
--# expr-done 9587
   If_Result_2 := If_Result_1;
else
   If_Result_2 := No_Bare_Ada_Node;
end if;
--# expr-done 9588
--# property-call-start AdaNode.env_get
Fld_2 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Env, Symbol => Fld, Lookup => If_Result, From_Node => If_Result_2, Categories => Categories);
--# end
--# expr-done 9589
Let_Result := Fld_2; Inc_Ref (Let_Result);
--# end
--# expr-done 9590
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1181;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1181;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_All_Env_Els_Impl;
--# end
--# property-start BaseId.env_elements_baseid /tmp/lal-23.0.0/ada/ast.py:16515
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Env_Elements_Baseid
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Array_Access
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   Property_Result : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1182 with Inline_Always;
            procedure Finalizer_Scope_3004 with Inline_Always;
      Block_Var : Internal_Entity_Array_Access;
Block_Var_1 : Internal_Entity_Call_Expr;
Block_Var_2 : Boolean;
Var_Expr : Internal_Entity_Base_Subp_Body;
Var_Expr_1 : Internal_Entity_Assoc_List;
Match_0 : Internal_Entity_Base_Type_Decl;
Match_1 : Internal_Entity_Basic_Decl;
Match_2 : Internal_Entity;
Var_Expr_2 : Internal_Entity_Base_Subp_Spec;
Real_Pc : Internal_Entity_Call_Expr;
Var_Expr_3 : Internal_Entity_Entry_Spec;
Var_Expr_4 : Internal_Entity_Call_Expr;
Sym : Symbol_Type;
Fld : Boolean;
If_Result : Lookup_Kind;
Fld_1 : Bare_Ada_Node;
Fld_2 : Boolean;
If_Result_1 : Ref_Categories;
Fld_3 : Internal_Entity_Array_Access;
Fld_4 : Internal_Entity_Call_Expr;
Fld_5 : Boolean;
Not_Val : Boolean;
Fld_6 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Is_Null : Boolean;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_7 : Boolean;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Subp_Body;
Fld_8 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Boolean;
Map_Result : Internal_Entity_Array_Access;
Fld_9 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Assoc_List;
Fld_10 : Bare_Assoc_List;
Len : Integer;
Is_Equal : Boolean;
Fld_11 : Internal_Entity_Base_Subp_Spec;
Fld_12 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Call_Expr;
Cast_Expr_2 : Internal_Entity_Base_Subp_Spec;
Cast_Result_4 : Internal_Entity_Entry_Spec;
Fld_13 : Internal_Entity;
Scope_Result_1 : Internal_Entity;
Result_Var_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_4 : Internal_Entity_Call_Expr;
Is_Null_2 : Boolean;
Fld_14 : Internal_Entity_Info;
Fld_15 : Internal_Metadata;
Fld_16 : Boolean;
Fld_17 : Boolean;
Fld_18 : Internal_Entity;
Cast_Result_5 : Internal_Entity_Call_Expr;
Fld_19 : Internal_Entity_Base_Type_Decl;
Fld_20 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
If_Result_5 : Boolean;
If_Result_6 : Boolean;
Fld_21 : Internal_Entity_Base_Type_Decl;
Fld_22 : Boolean;
Fld_23 : Internal_Entity_Info;
Fld_24 : Internal_Metadata;
Fld_25 : Boolean;
Fld_26 : Boolean;
If_Result_7 : Boolean;
If_Result_8 : Boolean;
Let_Result : Boolean;
Scope_Result_3 : Boolean;
Fld_27 : Internal_Entity_Base_Type_Decl;
Fld_28 : Boolean;
Result_Var_3 : Boolean;
Match_Prefix : Internal_Entity;
Cast_Result_6 : Internal_Entity_Base_Type_Decl;
Let_Result_1 : Boolean;
Scope_Result_4 : Boolean;
Cast_Result_7 : Internal_Entity_Basic_Decl;
Let_Result_2 : Boolean;
Scope_Result_5 : Boolean;
Cast_Result_8 : Internal_Entity;
Let_Result_3 : Boolean;
Scope_Result_6 : Boolean;
Match_Result : Boolean;
Map_Result_1 : Internal_Entity_Array_Access;
Scope_Result_7 : Internal_Entity_Array_Access;
Is_A : Boolean;
Not_Val_1 : Boolean;
Map_Result_2 : Internal_Entity_Array_Access;
Result_Var_4 : Internal_Entity_Array_Access;
If_Result_9 : Internal_Entity_Array_Access;
Dyn_Var_Bind_Result : Internal_Entity_Array_Access;
Let_Result_4 : Internal_Entity_Array_Access;
            procedure Finalizer_Scope_1182 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Result_Var_4);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_1182;
            procedure Finalizer_Scope_3004 is
            begin
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_3004;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Base_Id_Base_Id_P_Env_Elements_Baseid,
            Items    => new Mmz_Key_Array (1 ..  3))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Base_Id,
                                As_Bare_Base_Id => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Lexical_Env,
                                      As_Lexical_Env => Env);
                  Inc_Ref (Mmz_K.Items (2).As_Lexical_Env);
               Mmz_K.Items (3) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 9644 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 9597 '<FieldAccess for env_get at ast.py:16520>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16520
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9591 '<GetSymbol at ast.py:16522>' Sym /tmp/lal-23.0.0/ada/ast.py:16522
Sym := Get_Symbol (Self); 
--# expr-done 9591
--# expr-start 9593 '<If at ast.py:16523>' If_Result /tmp/lal-23.0.0/ada/ast.py:16523
--# expr-start 9592 '<FieldAccess for is_prefix at ast.py:16523>' Fld /tmp/lal-23.0.0/ada/ast.py:16523
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_prefix
Fld := Libadalang.Implementation.Name_P_Is_Prefix (Node => Self);
--# end
--# expr-done 9592
if Fld then
   If_Result := Recursive;
else
   If_Result := Flat;
end if;
--# expr-done 9593
--# expr-start 9594 '<FieldAccess for origin_node at ast.py:16525>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16525
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9594
--# expr-start 9596 '<If at ast.py:16526>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16526
--# expr-start 9595 '<FieldAccess for can_designate_primitive at ast.py:16527>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16527
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.can_designate_primitive
Fld_2 := Libadalang.Implementation.Name_P_Can_Designate_Primitive (Node => Self);
--# end
--# expr-done 9595
if Fld_2 then
   If_Result_1 := (Inherited_Primitives => True, Nocat => True);
else
   If_Result_1 := (Inherited_Primitives => False, Nocat => True);
end if;
--# expr-done 9596
--# property-call-start AdaNode.env_get
Fld_3 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Env, Symbol => Sym, Lookup => If_Result, From_Node => Fld_1, Categories => If_Result_1);
--# end
--# expr-done 9597
Block_Var := Fld_3; Inc_Ref (Block_Var);
--# bind items Block_Var
--# expr-start 9598 '<FieldAccess for parent_callexpr at ast.py:16536>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16536
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.parent_callexpr
Fld_4 := Libadalang.Implementation.Name_P_Parent_Callexpr (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9598
Block_Var_1 := Fld_4; 
--# bind pc Block_Var_1
--# expr-start 9600 '<Not at ast.py:16537>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16537
--# expr-start 9599 '<FieldAccess for is_suffix at ast.py:16537>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16537
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_suffix
Fld_5 := Libadalang.Implementation.Name_P_Is_Suffix (Node => Self);
--# end
--# expr-done 9599
Not_Val := not (Fld_5); 
--# expr-done 9600
Block_Var_2 := Not_Val; 
--# bind is_prefix Block_Var_2
--# expr-start 9643 '<bind at ast.py:16539>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:16539
--# expr-start 9601 '<FieldAccess for origin_node at ast.py:16539>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16539
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_6 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9601
Bound_Origin := Fld_6; 
--# expr-start 9642 '<Cond at ast.py:16539>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:16539
--# expr-start 9602 '<IsNull at ast.py:16540>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16540
Is_Null := Block_Var_1.Node = null; 
--# expr-done 9602
if Is_Null then
   --# expr-start 9607 '<Filter at ast.py:16546>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16546
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_299 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_299
--# expr-start 9604 '<FieldAccess for can_be_paramless at ast.py:16551>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16551
--# expr-start 9603 '<Cast to BasicDecl at ast.py:16551>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16551
Cast_Expr := Item_299; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9603
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.can_be_paramless
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Can_Be_Paramless (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 9604
if Fld_7 then
   If_Result_3 := True;
else
if Block_Var_2 then
--# expr-start 9605 '<Cast to BaseSubpBody at ast.py:16556>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16556
Cast_Expr_1 := Item_299; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Subp_Body
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 9605
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Base_Subp_Body then
   --# scope-start
--# expr-start 9606 '<FieldAccess for in_scope at ast.py:16556>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16556
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.in_scope
Fld_8 := Libadalang.Implementation.Body_Node_P_In_Scope (Node => Var_Expr.Node, Origin => Bound_Origin);
--# end
--# expr-done 9606
Scope_Result := Fld_8;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result_2 := Result_Var;
else
   If_Result_2 := False;
end if;
   If_Result_3 := If_Result_2;
end if;
         if If_Result_3 then
         declare
            Item_To_Append : constant Internal_Entity := Item_299;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9607
   If_Result_9 := Map_Result;
else
--# expr-start 9609 '<Cast to AssocList at ast.py:16566>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:16566
--# expr-start 9608 '<FieldAccess for suffix at ast.py:16566>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:16566
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity (Node => Block_Var_1.Node.Call_Expr_F_Suffix, Info => Block_Var_1.Info);
--# expr-done 9608
   if Fld_9.Node = null
      or else Fld_9.Node.Kind in Ada_Assoc_List_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Assoc_List
        (Node => Fld_9.Node,
         Info => Fld_9.Info);
   else
         Cast_Result_2 := No_Entity_Assoc_List;
   end if;
--# expr-done 9609
Var_Expr_1 := Cast_Result_2;
if Var_Expr_1 /= No_Entity_Assoc_List then
   --# scope-start
   --# bind params Var_Expr_1
--# expr-start 9638 '<Filter at ast.py:16567>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:16567
      declare
         Map_Result_1_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_301 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_301
         --# expr-start 9637 '<Match at ast.py:16567>' Match_Result /tmp/lal-23.0.0/ada/ast.py:16567
      if Item_301.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_301; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_6; 
--# bind _ Match_0
--# expr-start 9611 '<Eq at ast.py:16569>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16569
--# expr-start 9610 '<length at ast.py:16569>' Len /tmp/lal-23.0.0/ada/ast.py:16569
Fld_10 := Var_Expr_1.Node; 
Len := Length (Fld_10); 
--# expr-done 9610
Is_Equal := Len = 1; 
--# expr-done 9611
Let_Result_1 := Is_Equal; 
--# end
Scope_Result_4 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Abstract_State_Decl .. Ada_Package_Decl | Ada_Abstract_Subp_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_7; 
--# bind b Match_1
--# expr-start 9612 '<FieldAccess for subp_spec_or_null at ast.py:16572>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:16572
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_11 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Match_1.Node, E_Info => Match_1.Info);
--# end
--# expr-done 9612
Var_Expr_2 := Fld_11;
if Var_Expr_2 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind spec Var_Expr_2
--# expr-start 9634 '<Let at ast.py:16573>' Let_Result /tmp/lal-23.0.0/ada/ast.py:16573
--# scope-start
--# expr-start 9618 '<If at ast.py:16574>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:16574
--# expr-start 9615 '<IsNull at ast.py:16575>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:16575
--# expr-start 9613 '<Cast to EntrySpec at ast.py:16575>' Cast_Result_4 /tmp/lal-23.0.0/ada/ast.py:16575
Cast_Expr_2 := Var_Expr_2; 
   if Cast_Expr_2.Node = null
      or else Cast_Expr_2.Node.Kind in Ada_Entry_Spec_Range
   then
      Cast_Result_4 := Create_Internal_Entity_Entry_Spec
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
   else
         Cast_Result_4 := No_Entity_Entry_Spec;
   end if;
--# expr-done 9613
Var_Expr_3 := Cast_Result_4;
if Var_Expr_3 /= No_Entity_Entry_Spec then
   --# scope-start
--# expr-start 9614 '<FieldAccess for family_type at ast.py:16575>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:16575
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity (Node => Var_Expr_3.Node.Entry_Spec_F_Family_Type, Info => Var_Expr_3.Info);
--# expr-done 9614
Scope_Result_1 := Fld_13;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity;
end if;
Is_Null_1 := Result_Var_1.Node = null; 
--# expr-done 9615
if Is_Null_1 then
   If_Result_4 := Block_Var_1;
else
   --# expr-start 9617 '<Cast to CallExpr at ast.py:16576>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:16576
--# expr-start 9616 '<parent at ast.py:16576>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:16576
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Parent (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# expr-done 9616
   if Fld_12.Node = null
      or else Fld_12.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Call_Expr
        (Node => Fld_12.Node,
         Info => Fld_12.Info);
   else
         Cast_Result_3 := No_Entity_Call_Expr;
   end if;
--# expr-done 9617
   If_Result_4 := Cast_Result_3;
end if;
--# expr-done 9618
Real_Pc := If_Result_4; 
--# bind real_pc Real_Pc
--# expr-start 9619 '<IsNull at ast.py:16582>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:16582
Is_Null_2 := Real_Pc.Node = null; 
--# expr-done 9619
if Is_Null_2 then
   If_Result_6 := True;
else
--# expr-start 9623 '<FieldAccess for is_matching_param_list at ast.py:16587>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:16587
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9622 '<FieldAccess for dottable_subp at ast.py:16588>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:16588
--# expr-start 9621 '<FieldAccess for md at ast.py:16588>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:16588
--# expr-start 9620 '<FieldAccess for info at ast.py:16588>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:16588
Fld_14 := Match_1.Info;
--# expr-done 9620
Fld_15 := Fld_14.Md;
--# expr-done 9621
Fld_16 := Fld_15.Dottable_Subp;
--# expr-done 9622
--# property-call-start BaseFormalParamHolder.is_matching_param_list
Fld_17 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Is_Matching_Param_List (Node => Var_Expr_2.Node, Params => Var_Expr_1, Is_Dottable_Subp => Fld_16, Env => Env);
--# end
--# expr-done 9623
if Fld_17 then
--# expr-start 9625 '<Cast to CallExpr at ast.py:16590>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:16590
--# expr-start 9624 '<parent at ast.py:16590>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:16590
      if Real_Pc.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Libadalang.Implementation.Parent (Node => Real_Pc.Node, E_Info => Real_Pc.Info);
--# expr-done 9624
   if Fld_18.Node = null
      or else Fld_18.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result_5 := Create_Internal_Entity_Call_Expr
        (Node => Fld_18.Node,
         Info => Fld_18.Info);
   else
         Cast_Result_5 := No_Entity_Call_Expr;
   end if;
--# expr-done 9625
Var_Expr_4 := Cast_Result_5;
if Var_Expr_4 /= No_Entity_Call_Expr then
   --# scope-start
   --# bind ce Var_Expr_4
--# expr-start 9627 '<FieldAccess for check_for_type at ast.py:16591>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:16591
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9626 '<FieldAccess for expr_type at ast.py:16591>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:16591
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_19 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Match_1.Node, Origin => Bound_Origin, E_Info => Match_1.Info);
--# end
--# expr-done 9626
--# property-call-start CallExpr.check_for_type
Fld_20 := Libadalang.Implementation.Call_Expr_P_Check_For_Type (Node => Var_Expr_4.Node, Typ => Fld_19, Env => Env, Origin => Bound_Origin, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 9627
Scope_Result_2 := Fld_20;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := True;
end if;
   If_Result_5 := Result_Var_2;
else
   If_Result_5 := False;
end if;
   If_Result_6 := If_Result_5;
end if;
if If_Result_6 then
   If_Result_8 := True;
else
--# expr-start 9629 '<FieldAccess for check_for_type at ast.py:16598>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:16598
      if Real_Pc.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9628 '<FieldAccess for expr_type at ast.py:16598>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:16598
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_21 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Match_1.Node, Origin => Bound_Origin, E_Info => Match_1.Info);
--# end
--# expr-done 9628
--# property-call-start CallExpr.check_for_type
Fld_22 := Libadalang.Implementation.Call_Expr_P_Check_For_Type (Node => Real_Pc.Node, Typ => Fld_21, Env => Env, Origin => Bound_Origin, E_Info => Real_Pc.Info);
--# end
--# expr-done 9629
if Fld_22 then
   --# expr-start 9633 '<FieldAccess for paramless at ast.py:16599>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:16599
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9632 '<FieldAccess for dottable_subp at ast.py:16599>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:16599
--# expr-start 9631 '<FieldAccess for md at ast.py:16599>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:16599
--# expr-start 9630 '<FieldAccess for info at ast.py:16599>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:16599
Fld_23 := Match_1.Info;
--# expr-done 9630
Fld_24 := Fld_23.Md;
--# expr-done 9631
Fld_25 := Fld_24.Dottable_Subp;
--# expr-done 9632
--# property-call-start BaseFormalParamHolder.paramless
Fld_26 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Paramless (Node => Var_Expr_2.Node, Dottable_Subp => Fld_25);
--# end
--# expr-done 9633
   If_Result_7 := Fld_26;
else
   If_Result_7 := False;
end if;
   If_Result_8 := If_Result_7;
end if;
Let_Result := If_Result_8; 
--# end
--# expr-done 9634
Scope_Result_3 := Let_Result;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   --# expr-start 9636 '<FieldAccess for check_for_type at ast.py:16605>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:16605
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9635 '<FieldAccess for expr_type at ast.py:16605>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:16605
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld_27 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Match_1.Node, Origin => Bound_Origin, E_Info => Match_1.Info);
--# end
--# expr-done 9635
--# property-call-start CallExpr.check_for_type
Fld_28 := Libadalang.Implementation.Call_Expr_P_Check_For_Type (Node => Block_Var_1.Node, Typ => Fld_27, Env => Env, Origin => Bound_Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 9636
   Result_Var_3 := Fld_28;
end if;
Let_Result_2 := Result_Var_3; 
--# end
Scope_Result_5 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Abort_Absent .. Ada_Param_Assoc | Ada_Case_Stmt_Alternative .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_8; 
--# bind _ Match_2
Let_Result_3 := False; 
--# end
Scope_Result_6 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_6; 
end case;
--# expr-done 9637
         if Match_Result then
         declare
            Item_To_Append : constant Internal_Entity := Item_301;
         begin
            Internal_Entity_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 9638
Scope_Result_7 := Map_Result_1;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_3004;
   Result_Var_4 := Scope_Result_7;
else
   --# expr-start 9641 '<Filter at ast.py:16613>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:16613
      declare
         Map_Result_2_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_300 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_300
         --# expr-start 9640 '<Not at ast.py:16613>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:16613
--# expr-start 9639 '<IsA BaseTypeDecl at ast.py:16613>' Is_A /tmp/lal-23.0.0/ada/ast.py:16613
Is_A := Item_300.Node /= null 
and then Item_300.Node.Kind in Ada_Base_Type_Decl; 
--# expr-done 9639
Not_Val_1 := not (Is_A); 
--# expr-done 9640
         if Not_Val_1 then
         declare
            Item_To_Append : constant Internal_Entity := Item_300;
         begin
            Internal_Entity_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 9641
   Result_Var_4 := Map_Result_2;
end if;
      Inc_Ref (Result_Var_4);
   If_Result_9 := Result_Var_4;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 9642
Dyn_Var_Bind_Result := If_Result_9; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9643
Let_Result_4 := Dyn_Var_Bind_Result; Inc_Ref (Let_Result_4);
--# end
--# expr-done 9644
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1182;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Array_Access,
                        As_Internal_Entity_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1182;
               Finalizer_Scope_3004;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Env_Elements_Baseid;
--# end
--# property-start BaseId.denotes_the_property_function /tmp/lal-23.0.0/ada/ast.py:16618
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Denotes_The_Property_Function
  (Node : Bare_Base_Id
      ; Subp_Spec : Internal_Entity_Base_Subp_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind subp_spec Subp_Spec
   Property_Result : Boolean;
            procedure Finalizer_Scope_1183 with Inline_Always;
            procedure Finalizer_Scope_3064 with Inline_Always;
      Block_Var : Internal_Entity_Base_Type_Decl_Array_Access;
Match_0 : Internal_Entity_Type_Decl;
Match_1 : Internal_Entity_Subp_Decl;
Match_2 : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_1 : Internal_Entity_Param_Spec_Array_Access;
Len : Integer;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Basic_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Type_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
Find_Result : Internal_Entity_Base_Type_Decl;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_3 : Internal_Entity_Subp_Spec;
Fld_4 : Internal_Entity_Base_Type_Decl_Array_Access;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Cast_Expr_3 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Is_Equiv_1 : Boolean;
Find_Result_1 : Internal_Entity_Base_Type_Decl;
Is_Null_1 : Boolean;
Not_Val_1 : Boolean;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Is_Equal_1 : Boolean;
Not_Val_2 : Boolean;
Match_Prefix : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity_Type_Decl;
Let_Result : Boolean;
Scope_Result : Boolean;
Cast_Result_5 : Internal_Entity_Subp_Decl;
Let_Result_1 : Boolean;
Scope_Result_1 : Boolean;
Cast_Result_6 : Internal_Entity_Basic_Decl;
Let_Result_2 : Boolean;
Scope_Result_2 : Boolean;
Match_Result : Boolean;
If_Result : Boolean;
Let_Result_3 : Boolean;
            procedure Finalizer_Scope_1183 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1183;
            procedure Finalizer_Scope_3064 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_3064;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9664 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 9645 '<FieldAccess for primitive_subp_types at ast.py:16624>' Fld /tmp/lal-23.0.0/ada/ast.py:16624
      if Subp_Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_subp_types
Fld := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Subp_Types (Node => Subp_Spec.Node, Imprecise_Fallback => False, E_Info => Subp_Spec.Info);
--# end
--# expr-done 9645
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind primitive_types Block_Var
--# expr-start 9648 '<Eq at ast.py:16630>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16630
--# expr-start 9647 '<length at ast.py:16630>' Len /tmp/lal-23.0.0/ada/ast.py:16630
--# expr-start 9646 '<FieldAccess for params at ast.py:16630>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16630
      if Subp_Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.params'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Params (Node => Subp_Spec.Node, E_Info => Subp_Spec.Info);
--# end
--# expr-done 9646
Len := Length (Fld_1); 
--# expr-done 9647
Is_Equal := Len = 1; 
--# expr-done 9648
if Is_Equal then
   --# expr-start 9663 '<Match at ast.py:16634>' Match_Result /tmp/lal-23.0.0/ada/ast.py:16634
--# expr-start 9649 '<FieldAccess for parent_basic_decl at ast.py:16634>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16634
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld_2 := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 9649
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_2; 
case Ada_Basic_Decl (Match_Prefix.Node.Kind) is
         when Ada_Anonymous_Type_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_4; 
--# bind td Match_0
--# expr-start 9653 '<Not at ast.py:16637>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16637
--# expr-start 9652 '<IsNull at ast.py:16640>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16640
--# expr-start 9651 '<Find at ast.py:16638>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16638
      Find_Result := No_Entity_Base_Type_Decl;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Block_Var;
      begin
         for Item_302 of
               Collection.Items
         loop
   --# scope-start
               --# bind t Item_302
      --# expr-start 9650 '<Eq at ast.py:16639>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:16639
Cast_Expr := Item_302; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Cast_Expr_1 := Match_0; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Cast_Result, Cast_Result_1); 
--# expr-done 9650
      if Is_Equiv then
         Find_Result := Item_302;
      end if;
   --# end
               exit when Is_Equiv;
         end loop;
      end;
--# expr-done 9651
Is_Null := Find_Result.Node = null; 
--# expr-done 9652
Not_Val := not (Is_Null); 
--# expr-done 9653
Let_Result := Not_Val; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Subp_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Subp_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_5; 
--# bind sd Match_1
--# expr-start 9662 '<Not at ast.py:16643>' Not_Val_2 /tmp/lal-23.0.0/ada/ast.py:16643
--# expr-start 9661 '<IsNull at ast.py:16650>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:16650
--# expr-start 9660 '<Filter at ast.py:16644>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16644
   --# expr-start 9655 '<FieldAccess for primitive_subp_types at ast.py:16644>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16644
--# expr-start 9654 '<FieldAccess for subp_spec at ast.py:16644>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16644
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Subp_Spec (Node => Match_1.Node.Classic_Subp_Decl_F_Subp_Spec, Info => Match_1.Info);
--# expr-done 9654
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.primitive_subp_types
Fld_4 := Libadalang.Implementation.Base_Subp_Spec_P_Primitive_Subp_Types (Node => Fld_3.Node, Imprecise_Fallback => False, E_Info => Fld_3.Info);
--# end
--# expr-done 9655
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_4;
      begin
         for Item_303 of
               Collection.Items
         loop
   --# scope-start
               --# bind t1 Item_303
         --# expr-start 9659 '<Not at ast.py:16645>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:16645
--# expr-start 9658 '<IsNull at ast.py:16648>' Is_Null_1 /tmp/lal-23.0.0/ada/ast.py:16648
--# expr-start 9657 '<Find at ast.py:16646>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:16646
      Find_Result_1 := No_Entity_Base_Type_Decl;
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Block_Var;
      begin
         for Item_304 of
               Collection.Items
         loop
   --# scope-start
               --# bind t2 Item_304
      --# expr-start 9656 '<Eq at ast.py:16647>' Is_Equiv_1 /tmp/lal-23.0.0/ada/ast.py:16647
Cast_Expr_2 := Item_303; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Cast_Expr_3 := Item_304; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_3.Node,
         Info => Cast_Expr_3.Info);
Is_Equiv_1 := Equivalent (Cast_Result_2, Cast_Result_3); 
--# expr-done 9656
      if Is_Equiv_1 then
         Find_Result_1 := Item_304;
      end if;
   --# end
               exit when Is_Equiv_1;
         end loop;
      end;
--# expr-done 9657
Is_Null_1 := Find_Result_1.Node = null; 
--# expr-done 9658
Not_Val_1 := not (Is_Null_1); 
--# expr-done 9659
         if Not_Val_1 then
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Item_303;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9660
Is_Equal_1 := Equivalent (Map_Result, No_Internal_Entity_Base_Type_Decl_Array_Type); 
--# expr-done 9661
Not_Val_2 := not (Is_Equal_1); 
--# expr-done 9662
Let_Result_1 := Not_Val_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
      Finalizer_Scope_3064;
            Match_Result := Scope_Result_1; 
         when Ada_Abstract_State_Decl .. Ada_Single_Task_Type_Decl | Ada_Abstract_Subp_Decl .. Ada_Concrete_Formal_Subp_Decl | Ada_Entry_Decl .. Ada_Single_Task_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity_Basic_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_6; 
--# bind _ Match_2
Let_Result_2 := False; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 9663
   If_Result := Match_Result;
else
   If_Result := False;
end if;
Let_Result_3 := If_Result; 
--# end
--# expr-done 9664
      Property_Result := Let_Result_3;
   --# end
      Finalizer_Scope_1183;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1183;
               Finalizer_Scope_3064;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Denotes_The_Property_Function;
--# end
--# property-start BaseId.xref_equation /tmp/lal-23.0.0/ada/ast.py:16657
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Xref_Equation
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1184 with Inline_Always;
      Fld : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1184 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1184;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9666 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9665 '<FieldAccess for base_id_xref_equation at ast.py:16658>' Fld /tmp/lal-23.0.0/ada/ast.py:16658
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.base_id_xref_equation
Fld := Libadalang.Implementation.Base_Id_P_Base_Id_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9665
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 9666
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1184;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1184;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Xref_Equation;
--# end
--# property-start BaseId.base_id_xref_equation /tmp/lal-23.0.0/ada/ast.py:16661
pragma Warnings (Off, "is not referenced");
 function Base_Id_P_Base_Id_Xref_Equation
  (Node : Bare_Base_Id
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Base_Id := Bare_Base_Id (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Id :=
     Internal_Entity_Base_Id'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1185 with Inline_Always;
            procedure Finalizer_Scope_3068 with Inline_Always;
      Block_Var : Internal_Entity_Array_Access;
Block_Var_1 : Boolean;
Var_Expr : Internal_Entity_Base_Subp_Body;
Fld : Internal_Entity_Array_Access;
Fld_1 : Boolean;
Not_Val : Boolean;
Fld_2 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_3 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Logic_Var;
Bind_Result_2 : Logic_Equation;
Fld_6 : Logic_Var;
Fld_7 : Logic_Var;
Bind_Result_3 : Logic_Equation;
And_Pred : Logic_Equation;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Subp_Body;
Fld_8 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
If_Result : Boolean;
If_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1185 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1185;
            procedure Finalizer_Scope_3068 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3068;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9687 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9667 '<FieldAccess for env_elements at ast.py:16662>' Fld /tmp/lal-23.0.0/ada/ast.py:16662
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.env_elements
Fld := Libadalang.Implementation.Expr_P_Env_Elements (Node => Ent.Node, Env => Env, No_Visibility => False, E_Info => Ent.Info);
--# end
--# expr-done 9667
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind env_els Block_Var
--# expr-start 9669 '<Not at ast.py:16663>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16663
--# expr-start 9668 '<FieldAccess for is_suffix at ast.py:16663>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16663
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.is_suffix
Fld_1 := Libadalang.Implementation.Name_P_Is_Suffix (Node => Self);
--# end
--# expr-done 9668
Not_Val := not (Fld_1); 
--# expr-done 9669
Block_Var_1 := Not_Val; 
--# bind is_prefix Block_Var_1
--# expr-start 9686 '<LogicAny at ast.py:16665>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:16665
--# expr-start 9685 '<Map at ast.py:16665>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16665
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var;
      begin
         for Item_305 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_305
      --# expr-start 9684 '<And at ast.py:16667>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:16667
--# expr-start 9671 '<Bind at ast.py:16667>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:16667
--# expr-start 9670 '<FieldAccess for ref_var at ast.py:16667>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16667
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9670
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Bind_Result := Solver.Create_Assign (Fld_2, Item_305, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16667") else null)); 
--# expr-done 9671
--# expr-start 9683 '<If at ast.py:16668>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16668
if Block_Var_1 then
--# expr-start 9672 '<Cast to BaseSubpBody at ast.py:16671>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16671
Cast_Expr_1 := Item_305; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Subp_Body
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 9672
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Base_Subp_Body then
   --# scope-start
--# expr-start 9673 '<FieldAccess for in_scope at ast.py:16671>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:16671
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Body.in_scope
Fld_8 := Libadalang.Implementation.Body_Node_P_In_Scope (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 9673
Scope_Result := Fld_8;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
   If_Result := Result_Var;
else
   If_Result := False;
end if;
if If_Result then
   --# expr-start 9675 '<Bind at ast.py:16673>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:16673
--# expr-start 9674 '<FieldAccess for type_var at ast.py:16673>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16673
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9674
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Cast_Expr := No_Entity_Base_Type_Decl; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_3, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16673") else null)); 
--# expr-done 9675
   If_Result_1 := Bind_Result_1;
else
   --# expr-start 9682 '<And at ast.py:16680>' And_Pred /tmp/lal-23.0.0/ada/ast.py:16680
--# expr-start 9678 '<Bind at ast.py:16680>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:16680
--# expr-start 9676 '<FieldAccess for ref_var at ast.py:16680>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16680
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9676
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 9677 '<FieldAccess for type_var at ast.py:16680>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16680
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9677
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result_2 := Solver.Create_Propagate (Fld_4, Fld_5, Logic_Functor_211'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16680") else null)); 
--# expr-done 9678
--# expr-start 9681 '<Bind at ast.py:16682>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:16682
--# expr-start 9679 '<FieldAccess for ref_var at ast.py:16682>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16682
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9679
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 9680 '<FieldAccess for subp_spec_var at ast.py:16682>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16682
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Self);
--# end
--# expr-done 9680
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result_3 := Solver.Create_Propagate (Fld_6, Fld_7, Logic_Functor_213'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16682") else null)); 
--# expr-done 9681
And_Pred := Create_And (Bind_Result_2, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16680") else null)); 
--# expr-done 9682
   If_Result_1 := And_Pred;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 9683
And_Pred_1 := Create_And (Bind_Result, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16667") else null)); 
--# expr-done 9684
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3068;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9685
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16665") else null)); 
--# expr-done 9686
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 9687
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1185;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1185;
               Finalizer_Scope_3068;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Id_P_Base_Id_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Char_Literal
   --
      procedure Initialize_Fields_For_Char_Literal
        (Self : Bare_Char_Literal
        ) is
      begin
            Initialize_Fields_For_Base_Id
              (Self);
      end Initialize_Fields_For_Char_Literal;
--# property-start CharLiteral.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:16950
pragma Warnings (Off, "is not referenced");
 function Char_Literal_P_Has_Context_Free_Type
  (Node : Bare_Char_Literal
  )
   return Boolean
is
   Self : Bare_Char_Literal := Bare_Char_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Char_Literal_P_Has_Context_Free_Type;
--# end
--# property-start CharLiteral.xref_equation /tmp/lal-23.0.0/ada/ast.py:16953
pragma Warnings (Off, "is not referenced");
 function Char_Literal_P_Xref_Equation
  (Node : Bare_Char_Literal
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Char_Literal := Bare_Char_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1211 with Inline_Always;
      Fld : Logic_Var;
Pred : Logic_Equation;
Fld_1 : Logic_Var;
Fld_2 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Cast_Expr : Bare_Char_Literal;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_3 : Logic_Var;
Fld_4 : Logic_Var;
Bind_Result_1 : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1211 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1211;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9699 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9698 '<And at ast.py:16954>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:16954
--# expr-start 9693 '<And at ast.py:16954>' And_Pred /tmp/lal-23.0.0/ada/ast.py:16954
--# expr-start 9689 '<Predicate on BaseTypeDecl.is_non_null_char_type at ast.py:16955>' Pred /tmp/lal-23.0.0/ada/ast.py:16955
--# expr-start 9688 '<FieldAccess for expected_type_var at ast.py:16956>' Fld /tmp/lal-23.0.0/ada/ast.py:16956
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9688
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
Pred := Solver.Create_Predicate (Fld, Create_Base_Type_Decl_P_Is_Non_Null_Char_Type_0_Predicate (Origin)); 
--# expr-done 9689
--# expr-start 9692 '<Bind at ast.py:16957>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:16957
--# expr-start 9690 '<FieldAccess for expected_type_var at ast.py:16957>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16957
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9690
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 9691 '<FieldAccess for type_var at ast.py:16957>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16957
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9691
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Bind_Result := Solver.Create_Unify (Fld_1, Fld_2, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16957") else null)); 
--# expr-done 9692
And_Pred := Create_And (Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16954") else null)); 
--# expr-done 9693
--# expr-start 9697 '<bind at ast.py:16966>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:16966
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 9696 '<Bind at ast.py:16968>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:16968
--# expr-start 9694 '<FieldAccess for type_var at ast.py:16968>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16968
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9694
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 9695 '<FieldAccess for ref_var at ast.py:16968>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16968
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9695
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Bind_Result_1 := Solver.Create_Propagate (Fld_3, Fld_4, Logic_Functor_697'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Bound_Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16968") else null)); 
--# expr-done 9696
Dyn_Var_Bind_Result := Bind_Result_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 9697
And_Pred_1 := Create_And (And_Pred, Dyn_Var_Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16954") else null)); 
--# expr-done 9698
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9699
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1211;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1211;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Char_Literal_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Identifier
   --
      procedure Initialize_Fields_For_Identifier
        (Self : Bare_Identifier
        ) is
      begin
            Initialize_Fields_For_Base_Id
              (Self);
      end Initialize_Fields_For_Identifier;
--# property-start Identifier.is_attr_with_args /tmp/lal-23.0.0/ada/ast.py:16797
pragma Warnings (Off, "is not referenced");
 function Identifier_P_Is_Attr_With_Args
  (Node : Bare_Identifier
  )
   return Boolean
is
   Self : Bare_Identifier := Bare_Identifier (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal : Boolean;
Sym_2 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Sym_4 : Symbol_Type;
Sym_5 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Sym_6 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 9702 '<Eq at ast.py:16798>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:16798
--# expr-start 9700 '<GetSymbol at ast.py:16798>' Sym /tmp/lal-23.0.0/ada/ast.py:16798
Sym := Get_Symbol (Self); 
--# expr-done 9700
--# expr-start 9701 '<Symbol First at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_First); 
--# expr-done 9701
Is_Equal := Sym = Sym_1; 
--# expr-done 9702
if Is_Equal then
   If_Result := True;
else
   --# expr-start 9705 '<Eq at ast.py:16798>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:16798
--# expr-start 9703 '<GetSymbol at ast.py:16798>' Sym_2 /tmp/lal-23.0.0/ada/ast.py:16798
Sym_2 := Get_Symbol (Self); 
--# expr-done 9703
--# expr-start 9704 '<Symbol Last at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Last); 
--# expr-done 9704
Is_Equal_1 := Sym_2 = Sym_3; 
--# expr-done 9705
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 9708 '<Eq at ast.py:16798>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:16798
--# expr-start 9706 '<GetSymbol at ast.py:16798>' Sym_4 /tmp/lal-23.0.0/ada/ast.py:16798
Sym_4 := Get_Symbol (Self); 
--# expr-done 9706
--# expr-start 9707 '<Symbol Range at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Range); 
--# expr-done 9707
Is_Equal_2 := Sym_4 = Sym_5; 
--# expr-done 9708
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 9711 '<Eq at ast.py:16798>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:16798
--# expr-start 9709 '<GetSymbol at ast.py:16798>' Sym_6 /tmp/lal-23.0.0/ada/ast.py:16798
Sym_6 := Get_Symbol (Self); 
--# expr-done 9709
--# expr-start 9710 '<Symbol Length at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Length); 
--# expr-done 9710
Is_Equal_3 := Sym_6 = Sym_7; 
--# expr-done 9711
   If_Result_2 := Is_Equal_3;
end if;
      Property_Result := If_Result_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Identifier_P_Is_Attr_With_Args;
--# end
--# property-start Identifier.complete_items /tmp/lal-23.0.0/ada/ast.py:16802
pragma Warnings (Off, "is not referenced");
 function Identifier_P_Complete_Items
  (Node : Bare_Identifier
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Array_Access
is
   Self : Bare_Identifier := Bare_Identifier (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Identifier :=
     Internal_Entity_Identifier'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_1193 with Inline_Always;
      Fld : Internal_Entity;
Fld_1 : Internal_Completion_Item_Array_Access;
Let_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_1193 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1193;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9714 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9713 '<FieldAccess for complete_items at ast.py:16803>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16803
--# expr-start 9712 '<parent at ast.py:16803>' Fld /tmp/lal-23.0.0/ada/ast.py:16803
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 9712
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.complete_items'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Complete_Items (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9713
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9714
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1193;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1193;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Identifier_P_Complete_Items;
--# end
--# property-start Identifier.is_constant /tmp/lal-23.0.0/ada/ast.py:16806
pragma Warnings (Off, "is not referenced");
 function Identifier_P_Is_Constant
  (Node : Bare_Identifier
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Identifier := Bare_Identifier (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Identifier :=
     Internal_Entity_Identifier'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
            procedure Finalizer_Scope_1194 with Inline_Always;
            procedure Finalizer_Scope_3072 with Inline_Always;
      Block_Var : Internal_Entity_Basic_Decl;
Var_Expr : Internal_Entity;
Var_Expr_1 : Internal_Entity_Base_Subp_Body;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Boolean;
Fld_2 : Boolean;
Not_Val : Boolean;
Is_A : Boolean;
If_Result : Boolean;
If_Result_1 : Boolean;
Fld_3 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Base_Subp_Body;
Fld_4 : Internal_Entity_Subp_Spec;
Fld_5 : Internal_Entity_Subp_Kind;
Scope_Result : Internal_Entity_Subp_Kind;
Result_Var : Internal_Entity_Subp_Kind;
Is_A_1 : Boolean;
Find_Result : Internal_Entity;
Fld_6 : Boolean;
Fld_7 : Internal_Entity_Array_Access;
Is_A_2 : Boolean;
Find_Result_1 : Internal_Entity;
Is_Null : Boolean;
Not_Val_1 : Boolean;
If_Result_2 : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
If_Result_3 : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_1194 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_1194;
            procedure Finalizer_Scope_3072 is
            begin
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_3072;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9733 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9715 '<FieldAccess for referenced_decl at ast.py:16807>' Fld /tmp/lal-23.0.0/ada/ast.py:16807
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Ent.Node, Imprecise_Fallback => False, E_Info => Ent.Info);
--# end
--# expr-done 9715
Block_Var := Fld; 
--# bind rd Block_Var
--# expr-start 9720 '<If at ast.py:16812>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:16812
--# expr-start 9717 '<Not at ast.py:16813>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16813
--# expr-start 9716 '<FieldAccess for is_subprogram at ast.py:16813>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16813
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_2 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Block_Var.Node);
--# end
--# expr-done 9716
Not_Val := not (Fld_2); 
--# expr-done 9717
if Not_Val then
   If_Result := True;
else
   --# expr-start 9718 '<IsA EnumLiteralDecl at ast.py:16813>' Is_A /tmp/lal-23.0.0/ada/ast.py:16813
Is_A := Block_Var.Node /= null 
and then Block_Var.Node.Kind in Ada_Enum_Literal_Decl_Range; 
--# expr-done 9718
   If_Result := Is_A;
end if;
if If_Result then
   --# expr-start 9719 '<FieldAccess for is_constant_object at ast.py:16814>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16814
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_constant_object'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Constant_Object (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 9719
   If_Result_1 := Fld_1;
else
   If_Result_1 := False;
end if;
--# expr-done 9720
if If_Result_1 then
   If_Result_3 := True;
else
--# expr-start 9726 '<Find at ast.py:16820>' Find_Result /tmp/lal-23.0.0/ada/ast.py:16820
   --# expr-start 9721 '<FieldAccess for parents at ast.py:16820>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16820
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Parents (Node => Ent.Node, With_Self => True, E_Info => Ent.Info);
--# expr-done 9721
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_3;
      begin
         for Item_306 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_306
      --# expr-start 9725 '<IsA SubpKind.Function at ast.py:16826>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:16826
--# expr-start 9722 '<Cast to BaseSubpBody at ast.py:16825>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16825
Cast_Expr := Item_306; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Base_Subp_Body
   then
      Cast_Result := Create_Internal_Entity_Base_Subp_Body
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Base_Subp_Body;
   end if;
--# expr-done 9722
Var_Expr_1 := Cast_Result;
if Var_Expr_1 /= No_Entity_Base_Subp_Body then
   --# scope-start
--# expr-start 9724 '<FieldAccess for subp_kind at ast.py:16826>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:16826
--# expr-start 9723 '<FieldAccess for subp_spec at ast.py:16825>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16825
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Subp_Spec (Node => Var_Expr_1.Node.Base_Subp_Body_F_Subp_Spec, Info => Var_Expr_1.Info);
--# expr-done 9723
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Subp_Kind (Node => Fld_4.Node.Subp_Spec_F_Subp_Kind, Info => Fld_4.Info);
--# expr-done 9724
Scope_Result := Fld_5;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Subp_Kind;
end if;
Is_A_1 := Result_Var.Node /= null 
and then Result_Var.Node.Kind in Ada_Subp_Kind_Function_Range; 
--# expr-done 9725
      if Is_A_1 then
         Find_Result := Item_306;
      end if;
   --# end
               exit when Is_A_1;
         end loop;
      end;
--# expr-done 9726
Var_Expr := Find_Result;
if Var_Expr /= No_Entity then
   --# scope-start
   --# bind _ Var_Expr
--# expr-start 9727 '<FieldAccess for is_in_private_part at ast.py:16829>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:16829
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_in_private_part'
Fld_6 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_In_Private_Part (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 9727
if Fld_6 then
   --# expr-start 9732 '<Not at ast.py:16830>' Not_Val_1 /tmp/lal-23.0.0/ada/ast.py:16830
--# expr-start 9731 '<IsNull at ast.py:16833>' Is_Null /tmp/lal-23.0.0/ada/ast.py:16833
--# expr-start 9730 '<Find at ast.py:16831>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:16831
   --# expr-start 9728 '<FieldAccess for parents at ast.py:16831>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:16831
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Parents (Node => Block_Var.Node, With_Self => True, E_Info => Block_Var.Info);
--# expr-done 9728
      Find_Result_1 := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_7;
      begin
         for Item_307 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_307
      --# expr-start 9729 '<IsA ProtectedTypeDecl at ast.py:16832>' Is_A_2 /tmp/lal-23.0.0/ada/ast.py:16832
Is_A_2 := Item_307.Node /= null 
and then Item_307.Node.Kind in Ada_Protected_Type_Decl_Range; 
--# expr-done 9729
      if Is_A_2 then
         Find_Result_1 := Item_307;
      end if;
   --# end
               exit when Is_A_2;
         end loop;
      end;
--# expr-done 9730
Is_Null := Find_Result_1.Node = null; 
--# expr-done 9731
Not_Val_1 := not (Is_Null); 
--# expr-done 9732
   If_Result_2 := Not_Val_1;
else
   If_Result_2 := False;
end if;
Scope_Result_1 := If_Result_2;
   --# end
      Finalizer_Scope_3072;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
   If_Result_3 := Result_Var_1;
end if;
Let_Result := If_Result_3; 
--# end
--# expr-done 9733
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1194;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1194;
               Finalizer_Scope_3072;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Identifier_P_Is_Constant;
--# end
   --
   --  Primitives for Bare_Op
   --
      procedure Initialize_Fields_For_Op
        (Self : Bare_Op
        ) is
      begin
            Initialize_Fields_For_Base_Id
              (Self);
      end Initialize_Fields_For_Op;
--# property-start Op.subprogram_symbol /tmp/lal-23.0.0/ada/ast.py:16702
pragma Warnings (Off, "is not referenced");
 function Op_P_Subprogram_Symbol
  (Node : Bare_Op
  )
   return Symbol_Type
is
   Self : Bare_Op := Bare_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Match_0 : Bare_Op_And;
Match_1 : Bare_Op_Or;
Match_2 : Bare_Op_Xor;
Match_3 : Bare_Op_Abs;
Match_4 : Bare_Op_Not;
Match_5 : Bare_Op_Pow;
Match_6 : Bare_Op_Mult;
Match_7 : Bare_Op_Div;
Match_8 : Bare_Op_Mod;
Match_9 : Bare_Op_Rem;
Match_10 : Bare_Op_Plus;
Match_11 : Bare_Op_Minus;
Match_12 : Bare_Op_Concat;
Match_13 : Bare_Op_Eq;
Match_14 : Bare_Op_Neq;
Match_15 : Bare_Op_Lt;
Match_16 : Bare_Op_Lte;
Match_17 : Bare_Op_Gt;
Match_18 : Bare_Op_Gte;
Match_19 : Bare_Op;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Sym_2 : Symbol_Type;
Sym_3 : Symbol_Type;
Sym_4 : Symbol_Type;
Sym_5 : Symbol_Type;
Sym_6 : Symbol_Type;
Sym_7 : Symbol_Type;
Sym_8 : Symbol_Type;
Sym_9 : Symbol_Type;
Sym_10 : Symbol_Type;
Sym_11 : Symbol_Type;
Sym_12 : Symbol_Type;
Sym_13 : Symbol_Type;
Sym_14 : Symbol_Type;
Sym_15 : Symbol_Type;
Sym_16 : Symbol_Type;
Sym_17 : Symbol_Type;
Sym_18 : Symbol_Type;
Sym_19 : Symbol_Type;
Match_Prefix : Bare_Op;
Cast_Result : Bare_Op_And;
Let_Result : Symbol_Type;
Scope_Result : Symbol_Type;
Cast_Result_1 : Bare_Op_Or;
Let_Result_1 : Symbol_Type;
Scope_Result_1 : Symbol_Type;
Cast_Result_2 : Bare_Op_Xor;
Let_Result_2 : Symbol_Type;
Scope_Result_2 : Symbol_Type;
Cast_Result_3 : Bare_Op_Abs;
Let_Result_3 : Symbol_Type;
Scope_Result_3 : Symbol_Type;
Cast_Result_4 : Bare_Op_Not;
Let_Result_4 : Symbol_Type;
Scope_Result_4 : Symbol_Type;
Cast_Result_5 : Bare_Op_Pow;
Let_Result_5 : Symbol_Type;
Scope_Result_5 : Symbol_Type;
Cast_Result_6 : Bare_Op_Mult;
Let_Result_6 : Symbol_Type;
Scope_Result_6 : Symbol_Type;
Cast_Result_7 : Bare_Op_Div;
Let_Result_7 : Symbol_Type;
Scope_Result_7 : Symbol_Type;
Cast_Result_8 : Bare_Op_Mod;
Let_Result_8 : Symbol_Type;
Scope_Result_8 : Symbol_Type;
Cast_Result_9 : Bare_Op_Rem;
Let_Result_9 : Symbol_Type;
Scope_Result_9 : Symbol_Type;
Cast_Result_10 : Bare_Op_Plus;
Let_Result_10 : Symbol_Type;
Scope_Result_10 : Symbol_Type;
Cast_Result_11 : Bare_Op_Minus;
Let_Result_11 : Symbol_Type;
Scope_Result_11 : Symbol_Type;
Cast_Result_12 : Bare_Op_Concat;
Let_Result_12 : Symbol_Type;
Scope_Result_12 : Symbol_Type;
Cast_Result_13 : Bare_Op_Eq;
Let_Result_13 : Symbol_Type;
Scope_Result_13 : Symbol_Type;
Cast_Result_14 : Bare_Op_Neq;
Let_Result_14 : Symbol_Type;
Scope_Result_14 : Symbol_Type;
Cast_Result_15 : Bare_Op_Lt;
Let_Result_15 : Symbol_Type;
Scope_Result_15 : Symbol_Type;
Cast_Result_16 : Bare_Op_Lte;
Let_Result_16 : Symbol_Type;
Scope_Result_16 : Symbol_Type;
Cast_Result_17 : Bare_Op_Gt;
Let_Result_17 : Symbol_Type;
Scope_Result_17 : Symbol_Type;
Cast_Result_18 : Bare_Op_Gte;
Let_Result_18 : Symbol_Type;
Scope_Result_18 : Symbol_Type;
Cast_Result_19 : Bare_Op;
Let_Result_19 : Symbol_Type;
Scope_Result_19 : Symbol_Type;
Match_Result : Symbol_Type;
Let_Result_20 : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9755 '<Block at ???>' Let_Result_20 None
--# scope-start
--# expr-start 9754 '<Match at ast.py:16707>' Match_Result /tmp/lal-23.0.0/ada/ast.py:16707
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Self; 
case Ada_Op (Match_Prefix.Kind) is
         when Ada_Op_And =>
   --# scope-start
--# scope-start
      Cast_Result := Match_Prefix;
Match_0 := Cast_Result; 
--# bind _ Match_0
--# expr-start 9734 '<Symbol "and" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_And); 
--# expr-done 9734
Let_Result := Sym; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Op_Or =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Match_Prefix;
Match_1 := Cast_Result_1; 
--# bind _ Match_1
--# expr-start 9735 '<Symbol "or" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Or); 
--# expr-done 9735
Let_Result_1 := Sym_1; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Op_Xor =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Match_Prefix;
Match_2 := Cast_Result_2; 
--# bind _ Match_2
--# expr-start 9736 '<Symbol "xor" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Xor); 
--# expr-done 9736
Let_Result_2 := Sym_2; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Op_Abs =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Match_Prefix;
Match_3 := Cast_Result_3; 
--# bind _ Match_3
--# expr-start 9737 '<Symbol "abs" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 9737
Let_Result_3 := Sym_3; 
--# end
Scope_Result_3 := Let_Result_3;
   --# end
            Match_Result := Scope_Result_3; 
         when Ada_Op_Not =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Match_Prefix;
Match_4 := Cast_Result_4; 
--# bind _ Match_4
--# expr-start 9738 '<Symbol "not" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Not); 
--# expr-done 9738
Let_Result_4 := Sym_4; 
--# end
Scope_Result_4 := Let_Result_4;
   --# end
            Match_Result := Scope_Result_4; 
         when Ada_Op_Pow =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Match_Prefix;
Match_5 := Cast_Result_5; 
--# bind _ Match_5
--# expr-start 9739 '<Symbol "**" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_3); 
--# expr-done 9739
Let_Result_5 := Sym_5; 
--# end
Scope_Result_5 := Let_Result_5;
   --# end
            Match_Result := Scope_Result_5; 
         when Ada_Op_Mult =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Match_Prefix;
Match_6 := Cast_Result_6; 
--# bind _ Match_6
--# expr-start 9740 '<Symbol "*" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 9740
Let_Result_6 := Sym_6; 
--# end
Scope_Result_6 := Let_Result_6;
   --# end
            Match_Result := Scope_Result_6; 
         when Ada_Op_Div =>
   --# scope-start
--# scope-start
      Cast_Result_7 := Match_Prefix;
Match_7 := Cast_Result_7; 
--# bind _ Match_7
--# expr-start 9741 '<Symbol "/" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 9741
Let_Result_7 := Sym_7; 
--# end
Scope_Result_7 := Let_Result_7;
   --# end
            Match_Result := Scope_Result_7; 
         when Ada_Op_Mod =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Match_Prefix;
Match_8 := Cast_Result_8; 
--# bind _ Match_8
--# expr-start 9742 '<Symbol "mod" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod); 
--# expr-done 9742
Let_Result_8 := Sym_8; 
--# end
Scope_Result_8 := Let_Result_8;
   --# end
            Match_Result := Scope_Result_8; 
         when Ada_Op_Rem =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Match_Prefix;
Match_9 := Cast_Result_9; 
--# bind _ Match_9
--# expr-start 9743 '<Symbol "rem" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rem); 
--# expr-done 9743
Let_Result_9 := Sym_9; 
--# end
Scope_Result_9 := Let_Result_9;
   --# end
            Match_Result := Scope_Result_9; 
         when Ada_Op_Plus =>
   --# scope-start
--# scope-start
      Cast_Result_10 := Match_Prefix;
Match_10 := Cast_Result_10; 
--# bind _ Match_10
--# expr-start 9744 '<Symbol "+" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 9744
Let_Result_10 := Sym_10; 
--# end
Scope_Result_10 := Let_Result_10;
   --# end
            Match_Result := Scope_Result_10; 
         when Ada_Op_Minus =>
   --# scope-start
--# scope-start
      Cast_Result_11 := Match_Prefix;
Match_11 := Cast_Result_11; 
--# bind _ Match_11
--# expr-start 9745 '<Symbol "-" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 9745
Let_Result_11 := Sym_11; 
--# end
Scope_Result_11 := Let_Result_11;
   --# end
            Match_Result := Scope_Result_11; 
         when Ada_Op_Concat =>
   --# scope-start
--# scope-start
      Cast_Result_12 := Match_Prefix;
Match_12 := Cast_Result_12; 
--# bind _ Match_12
--# expr-start 9746 '<Symbol "&" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym); 
--# expr-done 9746
Let_Result_12 := Sym_12; 
--# end
Scope_Result_12 := Let_Result_12;
   --# end
            Match_Result := Scope_Result_12; 
         when Ada_Op_Eq =>
   --# scope-start
--# scope-start
      Cast_Result_13 := Match_Prefix;
Match_13 := Cast_Result_13; 
--# bind _ Match_13
--# expr-start 9747 '<Symbol "=" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 9747
Let_Result_13 := Sym_13; 
--# end
Scope_Result_13 := Let_Result_13;
   --# end
            Match_Result := Scope_Result_13; 
         when Ada_Op_Neq =>
   --# scope-start
--# scope-start
      Cast_Result_14 := Match_Prefix;
Match_14 := Cast_Result_14; 
--# bind _ Match_14
--# expr-start 9748 '<Symbol "/=" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 9748
Let_Result_14 := Sym_14; 
--# end
Scope_Result_14 := Let_Result_14;
   --# end
            Match_Result := Scope_Result_14; 
         when Ada_Op_Lt =>
   --# scope-start
--# scope-start
      Cast_Result_15 := Match_Prefix;
Match_15 := Cast_Result_15; 
--# bind _ Match_15
--# expr-start 9749 '<Symbol "<" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 9749
Let_Result_15 := Sym_15; 
--# end
Scope_Result_15 := Let_Result_15;
   --# end
            Match_Result := Scope_Result_15; 
         when Ada_Op_Lte =>
   --# scope-start
--# scope-start
      Cast_Result_16 := Match_Prefix;
Match_16 := Cast_Result_16; 
--# bind _ Match_16
--# expr-start 9750 '<Symbol "<=" at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 9750
Let_Result_16 := Sym_16; 
--# end
Scope_Result_16 := Let_Result_16;
   --# end
            Match_Result := Scope_Result_16; 
         when Ada_Op_Gt =>
   --# scope-start
--# scope-start
      Cast_Result_17 := Match_Prefix;
Match_17 := Cast_Result_17; 
--# bind _ Match_17
--# expr-start 9751 '<Symbol ">" at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 9751
Let_Result_17 := Sym_17; 
--# end
Scope_Result_17 := Let_Result_17;
   --# end
            Match_Result := Scope_Result_17; 
         when Ada_Op_Gte =>
   --# scope-start
--# scope-start
      Cast_Result_18 := Match_Prefix;
Match_18 := Cast_Result_18; 
--# bind _ Match_18
--# expr-start 9752 '<Symbol ">=" at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 9752
Let_Result_18 := Sym_18; 
--# end
Scope_Result_18 := Let_Result_18;
   --# end
            Match_Result := Scope_Result_18; 
         when Ada_Op_And_Then | Ada_Op_Double_Dot | Ada_Op_In | Ada_Op_Not_In | Ada_Op_Or_Else =>
   --# scope-start
--# scope-start
      Cast_Result_19 := Match_Prefix;
Match_19 := Cast_Result_19; 
--# bind _ Match_19
--# expr-start 9753 '<Symbol <<>> at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_20); 
--# expr-done 9753
Let_Result_19 := Sym_19; 
--# end
Scope_Result_19 := Let_Result_19;
   --# end
            Match_Result := Scope_Result_19; 
end case;
--# expr-done 9754
Let_Result_20 := Match_Result; 
--# end
--# expr-done 9755
      Property_Result := Let_Result_20;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Op_P_Subprogram_Symbol;
--# end
--# property-start Op.subprograms_for_symbol /tmp/lal-23.0.0/ada/ast.py:16731
pragma Warnings (Off, "is not referenced");
 function Op_P_Subprograms_For_Symbol
  (Node : Bare_Op
      ; Sym : Symbol_Type
      ; From_Node : Internal_Entity
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Op := Bare_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind sym Sym
   --# bind from_node From_Node
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_1187 with Inline_Always;
      Fld : Internal_Entity_Basic_Decl_Array_Access;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Bare_Ada_Node;
Fld_3 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Cast_Expr_1 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Basic_Decl;
Fld_4 : Boolean;
Is_A : Boolean;
Not_Val : Boolean;
If_Result : Boolean;
Map_Result : Internal_Entity_Basic_Decl_Array_Access;
Concat_Result : Internal_Entity_Basic_Decl_Array_Access;
Let_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_1187 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1187;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9767 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9766 '<Concat at ast.py:16738>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:16738
--# expr-start 9756 '<FieldAccess for root_type_ops at ast.py:16738>' Fld /tmp/lal-23.0.0/ada/ast.py:16738
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_type_ops
Fld := Libadalang.Implementation.Ada_Node_P_Root_Type_Ops (Node => Self, Sym => Sym);
--# end
--# expr-done 9756
--# expr-start 9765 '<FilterMap at ast.py:16740>' Map_Result /tmp/lal-23.0.0/ada/ast.py:16740
   --# expr-start 9759 '<FieldAccess for env_get at ast.py:16738>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16738
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9757 '<FieldAccess for node_env at ast.py:16739>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16739
      if From_Node.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Node_Env (Node => From_Node.Node, E_Info => From_Node.Info);
--# expr-done 9757
--# expr-start 9758 '<FieldAccess for node at ast.py:16739>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16739
Fld_2 := From_Node.Node;
--# expr-done 9758
--# property-call-start AdaNode.env_get
Fld_3 := Libadalang.Implementation.Ada_Node_P_Env_Get (Node => Self, Env => Fld_1, Symbol => Sym, From_Node => Fld_2);
--# end
--# expr-done 9759
      declare
         Map_Result_Vec : Internal_Entity_Basic_Decl_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_3;
      begin
         for Item_308 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_308
--# expr-start 9761 '<FieldAccess for is_subprogram at ast.py:16743>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16743
--# expr-start 9760 '<Cast to BasicDecl at ast.py:16743>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:16743
Cast_Expr_1 := Item_308; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9760
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_subprogram
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Is_Subprogram (Node => Cast_Result_1.Node);
--# end
--# expr-done 9761
if Fld_4 then
   --# expr-start 9763 '<Not at ast.py:16750>' Not_Val /tmp/lal-23.0.0/ada/ast.py:16750
--# expr-start 9762 '<IsA SyntheticSubpDecl at ast.py:16750>' Is_A /tmp/lal-23.0.0/ada/ast.py:16750
Is_A := Item_308.Node /= null 
and then Item_308.Node.Kind in Ada_Synthetic_Subp_Decl_Range; 
--# expr-done 9762
Not_Val := not (Is_A); 
--# expr-done 9763
   If_Result := Not_Val;
else
   If_Result := False;
end if;
         if If_Result then
      --# expr-start 9764 '<Cast to BasicDecl at ast.py:16741>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16741
Cast_Expr := Item_308; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9764
         declare
            Item_To_Append : constant Internal_Entity_Basic_Decl := Cast_Result;
         begin
            Internal_Entity_Basic_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Basic_Decl_Array
           (Items_Count => Natural (Internal_Entity_Basic_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Basic_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Basic_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Basic_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9765
Concat_Result := Concat (Fld, Map_Result); 
--# expr-done 9766
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9767
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1187;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1187;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Op_P_Subprograms_For_Symbol;
--# end
--# property-start Op.subprograms /tmp/lal-23.0.0/ada/ast.py:16754
pragma Warnings (Off, "is not referenced");
 function Op_P_Subprograms
  (Node : Bare_Op
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Basic_Decl_Array_Access
is
   Self : Bare_Op := Bare_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Op :=
     Internal_Entity_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_1188 with Inline_Always;
      Fld : Symbol_Type;
Cast_Expr : Internal_Entity_Op;
Cast_Result : Internal_Entity;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
            procedure Finalizer_Scope_1188 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1188;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9769 '<FieldAccess for subprograms_for_symbol at ast.py:16755>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16755
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9768 '<FieldAccess for subprogram_symbol at ast.py:16755>' Fld /tmp/lal-23.0.0/ada/ast.py:16755
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Op.subprogram_symbol
Fld := Libadalang.Implementation.Op_P_Subprogram_Symbol (Node => Self);
--# end
--# expr-done 9768
Cast_Expr := Ent; 
      Cast_Result := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
--# property-call-start Op.subprograms_for_symbol
Fld_1 := Libadalang.Implementation.Op_P_Subprograms_For_Symbol (Node => Self, Sym => Fld, From_Node => Cast_Result);
--# end
--# expr-done 9769
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1188;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1188;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Op_P_Subprograms;
--# end
--# property-start Op.name_symbol /tmp/lal-23.0.0/ada/ast.py:16762
pragma Warnings (Off, "is not referenced");
 function Op_P_Name_Symbol
  (Node : Bare_Op
  )
   return Symbol_Type
is
   Self : Bare_Op := Bare_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Fld : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9770 '<FieldAccess for subprogram_symbol at ast.py:16762>' Fld /tmp/lal-23.0.0/ada/ast.py:16762
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Op.subprogram_symbol
Fld := Libadalang.Implementation.Op_P_Subprogram_Symbol (Node => Self);
--# end
--# expr-done 9770
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Op_P_Name_Symbol;
--# end
--# property-start Op.xref_equation /tmp/lal-23.0.0/ada/ast.py:16765
pragma Warnings (Off, "is not referenced");
 function Op_P_Xref_Equation
  (Node : Bare_Op
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Op := Bare_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1190 with Inline_Always;
      False_Rel : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1190 is
            begin
                     Dec_Ref (False_Rel);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1190;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9771 '<Block at ???>' Let_Result None
--# scope-start
False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16768") else null)); 
Let_Result := False_Rel; Inc_Ref (Let_Result);
--# end
--# expr-done 9771
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1190;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1190;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Op_P_Xref_Equation;
--# end
--# property-start Op.is_dispatching_call /tmp/lal-23.0.0/ada/ast.py:16771
pragma Warnings (Off, "is not referenced");
 function Op_P_Is_Dispatching_Call
  (Node : Bare_Op
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Op := Bare_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Op :=
     Internal_Entity_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
Fld_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9775 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9774 '<FieldAccess for is_dispatching_call at ast.py:16774>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16774
--# expr-start 9773 '<Cast to Expr at ast.py:16774>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:16774
--# expr-start 9772 '<parent at ast.py:16774>' Fld /tmp/lal-23.0.0/ada/ast.py:16774
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 9772
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Expr;
   end if;
--# expr-done 9773
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.is_dispatching_call'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Is_Dispatching_Call (Node => Cast_Result.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Cast_Result.Info);
--# end
--# expr-done 9774
Let_Result := Fld_1; 
--# end
--# expr-done 9775
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Op_P_Is_Dispatching_Call;
--# end
   --
   --  Primitives for Bare_Op_Abs
   --
      procedure Initialize_Fields_For_Op_Abs
        (Self : Bare_Op_Abs
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Abs;
   --
   --  Primitives for Bare_Op_And
   --
      procedure Initialize_Fields_For_Op_And
        (Self : Bare_Op_And
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_And;
   --
   --  Primitives for Bare_Op_And_Then
   --
      procedure Initialize_Fields_For_Op_And_Then
        (Self : Bare_Op_And_Then
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_And_Then;
   --
   --  Primitives for Bare_Op_Concat
   --
      procedure Initialize_Fields_For_Op_Concat
        (Self : Bare_Op_Concat
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Concat;
   --
   --  Primitives for Bare_Op_Div
   --
      procedure Initialize_Fields_For_Op_Div
        (Self : Bare_Op_Div
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Div;
   --
   --  Primitives for Bare_Op_Double_Dot
   --
      procedure Initialize_Fields_For_Op_Double_Dot
        (Self : Bare_Op_Double_Dot
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Double_Dot;
   --
   --  Primitives for Bare_Op_Eq
   --
      procedure Initialize_Fields_For_Op_Eq
        (Self : Bare_Op_Eq
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Eq;
   --
   --  Primitives for Bare_Op_Gt
   --
      procedure Initialize_Fields_For_Op_Gt
        (Self : Bare_Op_Gt
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Gt;
   --
   --  Primitives for Bare_Op_Gte
   --
      procedure Initialize_Fields_For_Op_Gte
        (Self : Bare_Op_Gte
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Gte;
   --
   --  Primitives for Bare_Op_In
   --
      procedure Initialize_Fields_For_Op_In
        (Self : Bare_Op_In
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_In;
   --
   --  Primitives for Bare_Op_Lt
   --
      procedure Initialize_Fields_For_Op_Lt
        (Self : Bare_Op_Lt
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Lt;
   --
   --  Primitives for Bare_Op_Lte
   --
      procedure Initialize_Fields_For_Op_Lte
        (Self : Bare_Op_Lte
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Lte;
   --
   --  Primitives for Bare_Op_Minus
   --
      procedure Initialize_Fields_For_Op_Minus
        (Self : Bare_Op_Minus
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Minus;
   --
   --  Primitives for Bare_Op_Mod
   --
      procedure Initialize_Fields_For_Op_Mod
        (Self : Bare_Op_Mod
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Mod;
   --
   --  Primitives for Bare_Op_Mult
   --
      procedure Initialize_Fields_For_Op_Mult
        (Self : Bare_Op_Mult
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Mult;
   --
   --  Primitives for Bare_Op_Neq
   --
      procedure Initialize_Fields_For_Op_Neq
        (Self : Bare_Op_Neq
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Neq;
   --
   --  Primitives for Bare_Op_Not
   --
      procedure Initialize_Fields_For_Op_Not
        (Self : Bare_Op_Not
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Not;
   --
   --  Primitives for Bare_Op_Not_In
   --
      procedure Initialize_Fields_For_Op_Not_In
        (Self : Bare_Op_Not_In
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Not_In;
   --
   --  Primitives for Bare_Op_Or
   --
      procedure Initialize_Fields_For_Op_Or
        (Self : Bare_Op_Or
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Or;
   --
   --  Primitives for Bare_Op_Or_Else
   --
      procedure Initialize_Fields_For_Op_Or_Else
        (Self : Bare_Op_Or_Else
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Or_Else;
   --
   --  Primitives for Bare_Op_Plus
   --
      procedure Initialize_Fields_For_Op_Plus
        (Self : Bare_Op_Plus
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Plus;
   --
   --  Primitives for Bare_Op_Pow
   --
      procedure Initialize_Fields_For_Op_Pow
        (Self : Bare_Op_Pow
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Pow;
   --
   --  Primitives for Bare_Op_Rem
   --
      procedure Initialize_Fields_For_Op_Rem
        (Self : Bare_Op_Rem
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Rem;
   --
   --  Primitives for Bare_Op_Xor
   --
      procedure Initialize_Fields_For_Op_Xor
        (Self : Bare_Op_Xor
        ) is
      begin
            Initialize_Fields_For_Op
              (Self);
      end Initialize_Fields_For_Op_Xor;
   --
   --  Primitives for Bare_String_Literal
   --
      procedure Initialize_Fields_For_String_Literal
        (Self : Bare_String_Literal
        ) is
      begin
            Initialize_Fields_For_Base_Id
              (Self);
      end Initialize_Fields_For_String_Literal;
--# property-start StringLiteral.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:16855
pragma Warnings (Off, "is not referenced");
 function String_Literal_P_Has_Context_Free_Type
  (Node : Bare_String_Literal
  )
   return Boolean
is
   Self : Bare_String_Literal := Bare_String_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end String_Literal_P_Has_Context_Free_Type;
--# end
--# property-start StringLiteral.xref_equation /tmp/lal-23.0.0/ada/ast.py:16858
pragma Warnings (Off, "is not referenced");
 function String_Literal_P_Xref_Equation
  (Node : Bare_String_Literal
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_String_Literal := Bare_String_Literal (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_String_Literal :=
     Internal_Entity_String_Literal'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1197 with Inline_Always;
      Fld : Logic_Equation;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Bare_Ada_Node;
Is_A : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1197 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1197;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9786 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9785 '<If at ast.py:16859>' If_Result /tmp/lal-23.0.0/ada/ast.py:16859
--# expr-start 9777 '<IsA Name at ast.py:16862>' Is_A /tmp/lal-23.0.0/ada/ast.py:16862
--# expr-start 9776 '<parent at ast.py:16862>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:16862
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Parent; 
--# expr-done 9776
Is_A := Fld_4 /= null 
and then Fld_4.Kind in Ada_Name; 
--# expr-done 9777
if Is_A then
   --# expr-start 9778 '<FieldAccess for base_id_xref_equation at ast.py:16863>' Fld /tmp/lal-23.0.0/ada/ast.py:16863
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseId.base_id_xref_equation
Fld := Libadalang.Implementation.Base_Id_P_Base_Id_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 9778
   If_Result := Fld;
else
   --# expr-start 9784 '<And at ast.py:16864>' And_Pred /tmp/lal-23.0.0/ada/ast.py:16864
--# expr-start 9780 '<Predicate on BaseTypeDecl.allows_string_literal at ast.py:16864>' Pred /tmp/lal-23.0.0/ada/ast.py:16864
--# expr-start 9779 '<FieldAccess for expected_type_var at ast.py:16865>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16865
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9779
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_Predicate (Fld_1, Create_Base_Type_Decl_P_Allows_String_Literal_0_Predicate (Origin)); 
--# expr-done 9780
--# expr-start 9783 '<Bind at ast.py:16866>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:16866
--# expr-start 9781 '<FieldAccess for expected_type_var at ast.py:16866>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:16866
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9781
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 9782 '<FieldAccess for type_var at ast.py:16866>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:16866
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9782
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Bind_Result := Solver.Create_Unify (Fld_2, Fld_3, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16866") else null)); 
--# expr-done 9783
And_Pred := Create_And (Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:16864") else null)); 
--# expr-done 9784
   If_Result := And_Pred;
end if;
      Inc_Ref (If_Result);
--# expr-done 9785
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9786
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1197;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1197;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end String_Literal_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Null_Literal
   --
      procedure Initialize_Fields_For_Null_Literal
        (Self : Bare_Null_Literal
        ) is
      begin
            Initialize_Fields_For_Single_Tok_Node
              (Self);
      end Initialize_Fields_For_Null_Literal;
--# property-start NullLiteral.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:17024
pragma Warnings (Off, "is not referenced");
 function Null_Literal_P_Has_Context_Free_Type
  (Node : Bare_Null_Literal
  )
   return Boolean
is
   Self : Bare_Null_Literal := Bare_Null_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Null_Literal_P_Has_Context_Free_Type;
--# end
--# property-start NullLiteral.xref_equation /tmp/lal-23.0.0/ada/ast.py:17027
pragma Warnings (Off, "is not referenced");
 function Null_Literal_P_Xref_Equation
  (Node : Bare_Null_Literal
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Null_Literal := Bare_Null_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1217 with Inline_Always;
      Fld : Logic_Var;
Pred : Logic_Equation;
Fld_1 : Logic_Var;
Fld_2 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1217 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1217;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9793 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9792 '<And at ast.py:17028>' And_Pred /tmp/lal-23.0.0/ada/ast.py:17028
--# expr-start 9788 '<Predicate on BaseTypeDecl.is_access_type_predicate at ast.py:17029>' Pred /tmp/lal-23.0.0/ada/ast.py:17029
--# expr-start 9787 '<FieldAccess for expected_type_var at ast.py:17030>' Fld /tmp/lal-23.0.0/ada/ast.py:17030
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9787
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
Pred := Solver.Create_Predicate (Fld, Create_Base_Type_Decl_P_Is_Access_Type_Predicate_0_Predicate (Origin)); 
--# expr-done 9788
--# expr-start 9791 '<Bind at ast.py:17031>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:17031
--# expr-start 9789 '<FieldAccess for expected_type_var at ast.py:17031>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17031
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9789
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 9790 '<FieldAccess for type_var at ast.py:17031>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17031
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9790
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
Bind_Result := Solver.Create_Unify (Fld_1, Fld_2, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17031") else null)); 
--# expr-done 9791
And_Pred := Create_And (Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17028") else null)); 
--# expr-done 9792
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 9793
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1217;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1217;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Null_Literal_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Num_Literal
   --
      procedure Initialize_Fields_For_Num_Literal
        (Self : Bare_Num_Literal
        ) is
      begin
            Initialize_Fields_For_Single_Tok_Node
              (Self);
      end Initialize_Fields_For_Num_Literal;
--# property-start NumLiteral.is_constant /tmp/lal-23.0.0/ada/ast.py:16982
pragma Warnings (Off, "is not referenced");
 function Num_Literal_P_Is_Constant
  (Node : Bare_Num_Literal
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Num_Literal := Bare_Num_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Num_Literal_P_Is_Constant;
--# end
   --
   --  Primitives for Bare_Int_Literal
   --
      procedure Initialize_Fields_For_Int_Literal
        (Self : Bare_Int_Literal
        ) is
      begin
            Initialize_Fields_For_Num_Literal
              (Self);
      end Initialize_Fields_For_Int_Literal;
--# property-start IntLiteral.xref_equation /tmp/lal-23.0.0/ada/ast.py:17005
pragma Warnings (Off, "is not referenced");
 function Int_Literal_P_Xref_Equation
  (Node : Bare_Int_Literal
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Int_Literal := Bare_Int_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1214 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1214 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1214;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9796 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9795 '<FieldAccess for universal_int_bind at ast.py:17006>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17006
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9794 '<FieldAccess for type_var at ast.py:17006>' Fld /tmp/lal-23.0.0/ada/ast.py:17006
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9794
--# property-call-start AdaNode.universal_int_bind
Fld_1 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld, Origin => Origin);
--# end
--# expr-done 9795
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9796
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1214;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1214;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Int_Literal_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Real_Literal
   --
      procedure Initialize_Fields_For_Real_Literal
        (Self : Bare_Real_Literal
        ) is
      begin
            Initialize_Fields_For_Num_Literal
              (Self);
      end Initialize_Fields_For_Real_Literal;
--# property-start RealLiteral.xref_equation /tmp/lal-23.0.0/ada/ast.py:16993
pragma Warnings (Off, "is not referenced");
 function Real_Literal_P_Xref_Equation
  (Node : Bare_Real_Literal
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Real_Literal := Bare_Real_Literal (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1213 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1213 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1213;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9799 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9798 '<FieldAccess for universal_real_bind at ast.py:16994>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:16994
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9797 '<FieldAccess for type_var at ast.py:16994>' Fld /tmp/lal-23.0.0/ada/ast.py:16994
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9797
--# property-call-start AdaNode.universal_real_bind
Fld_1 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Self, Type_Var => Fld, Origin => Origin);
--# end
--# expr-done 9798
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9799
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1213;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1213;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Real_Literal_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Synthetic_Identifier
   --
      procedure Initialize_Fields_For_Synthetic_Identifier
        (Self : Bare_Synthetic_Identifier
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
      Self.Synthetic_Identifier_Sym := null;
      end Initialize_Fields_For_Synthetic_Identifier;
--# property-start SyntheticIdentifier.name_symbol /tmp/lal-23.0.0/ada/ast.py:17452
pragma Warnings (Off, "is not referenced");
 function Synthetic_Identifier_P_Name_Symbol
  (Node : Bare_Synthetic_Identifier
  )
   return Symbol_Type
is
   Self : Bare_Synthetic_Identifier := Bare_Synthetic_Identifier (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Symbol_Type;
      Fld : Symbol_Type;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9800 '<FieldAccess for sym at ast.py:17452>' Fld /tmp/lal-23.0.0/ada/ast.py:17452
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Synthetic_Identifier_Sym;
--# expr-done 9800
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Identifier_P_Name_Symbol;
--# end
   --
   --  Primitives for Bare_Target_Name
   --
      procedure Initialize_Fields_For_Target_Name
        (Self : Bare_Target_Name
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
      Self.Target_Name_R_Ref_Var := Null_Var_Record;
      end Initialize_Fields_For_Target_Name;
--# property-start TargetName.ref_var /tmp/lal-23.0.0/ada/ast.py:14137
pragma Warnings (Off, "is not referenced");
 function Target_Name_P_Ref_Var
  (Node : Bare_Target_Name
  )
   return Logic_Var
is
   Self : Bare_Target_Name := Bare_Target_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9801 '<FieldAccess for r_ref_var at ast.py:14137>' Fld /tmp/lal-23.0.0/ada/ast.py:14137
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Target_Name_R_Ref_Var'Unrestricted_Access;
--# expr-done 9801
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Target_Name_P_Ref_Var;
--# end
--# property-start TargetName.assign_statement /tmp/lal-23.0.0/ada/ast.py:14139
pragma Warnings (Off, "is not referenced");
 function Target_Name_P_Assign_Statement
  (Node : Bare_Target_Name
  )
   return Bare_Assign_Stmt
is
   Self : Bare_Target_Name := Bare_Target_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Assign_Stmt;
            procedure Finalizer_Scope_1045 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Assign_Stmt;
            procedure Finalizer_Scope_1045 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_1045;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9805 '<Cast to AssignStmt at ast.py:14141>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:14141
--# expr-start 9804 '<Find at ast.py:14140>' Find_Result /tmp/lal-23.0.0/ada/ast.py:14140
   --# expr-start 9802 '<FieldAccess for parents at ast.py:14140>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:14140
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 9802
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_309 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_309
      --# expr-start 9803 '<IsA AssignStmt at ast.py:14140>' Is_A /tmp/lal-23.0.0/ada/ast.py:14140
Is_A := Item_309 /= null 
and then Item_309.Kind in Ada_Assign_Stmt_Range; 
--# expr-done 9803
      if Is_A then
         Find_Result := Item_309;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 9804
   if Find_Result = null
      or else Find_Result.Kind in Ada_Assign_Stmt_Range
   then
      Cast_Result := Find_Result;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9805
      Property_Result := Cast_Result;
   --# end
      Finalizer_Scope_1045;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1045;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Target_Name_P_Assign_Statement;
--# end
--# property-start TargetName.relative_name /tmp/lal-23.0.0/ada/ast.py:14145
pragma Warnings (Off, "is not referenced");
 function Target_Name_P_Relative_Name
  (Node : Bare_Target_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Single_Tok_Node
is
   Self : Bare_Target_Name := Bare_Target_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Single_Tok_Node;
      Fld : Bare_Assign_Stmt;
Fld_1 : Bare_Name;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_2 : Internal_Entity_Single_Tok_Node;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9809 '<FieldAccess for relative_name at ast.py:14146>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14146
--# expr-start 9808 '<as_entity at ast.py:14146>' If_Result /tmp/lal-23.0.0/ada/ast.py:14146
--# expr-start 9807 '<FieldAccess for dest at ast.py:14146>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14146
--# expr-start 9806 '<FieldAccess for assign_statement at ast.py:14146>' Fld /tmp/lal-23.0.0/ada/ast.py:14146
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TargetName.assign_statement
Fld := Libadalang.Implementation.Target_Name_P_Assign_Statement (Node => Self);
--# end
--# expr-done 9806
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Assign_Stmt_F_Dest;
--# expr-done 9807
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
As_Entity := (Info => E_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 9808
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.relative_name'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Relative_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 9809
      Property_Result := Fld_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Target_Name_P_Relative_Name;
--# end
--# property-start TargetName.xref_equation /tmp/lal-23.0.0/ada/ast.py:14150
pragma Warnings (Off, "is not referenced");
 function Target_Name_P_Xref_Equation
  (Node : Bare_Target_Name
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Target_Name := Bare_Target_Name (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1047 with Inline_Always;
      Fld : Logic_Var;
Fld_1 : Bare_Assign_Stmt;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_4 : Logic_Var;
Fld_5 : Bare_Assign_Stmt;
Fld_6 : Bare_Name;
Fld_7 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1047 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1047;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9821 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9820 '<And at ast.py:14151>' And_Pred /tmp/lal-23.0.0/ada/ast.py:14151
--# expr-start 9814 '<Bind at ast.py:14152>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:14152
--# expr-start 9810 '<FieldAccess for type_var at ast.py:14152>' Fld /tmp/lal-23.0.0/ada/ast.py:14152
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9810
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 9813 '<FieldAccess for type_var at ast.py:14152>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:14152
--# expr-start 9812 '<FieldAccess for dest at ast.py:14152>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:14152
--# expr-start 9811 '<FieldAccess for assign_statement at ast.py:14152>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:14152
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TargetName.assign_statement
Fld_1 := Libadalang.Implementation.Target_Name_P_Assign_Statement (Node => Self);
--# end
--# expr-done 9811
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Fld_1.Assign_Stmt_F_Dest;
--# expr-done 9812
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_2);
--# expr-done 9813
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Bind_Result := Solver.Create_Unify (Fld, Fld_3, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14152") else null)); 
--# expr-done 9814
--# expr-start 9819 '<Bind at ast.py:14153>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:14153
--# expr-start 9815 '<FieldAccess for ref_var at ast.py:14153>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:14153
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Self);
--# end
--# expr-done 9815
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 9818 '<FieldAccess for ref_var at ast.py:14153>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:14153
--# expr-start 9817 '<FieldAccess for dest at ast.py:14153>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:14153
--# expr-start 9816 '<FieldAccess for assign_statement at ast.py:14153>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:14153
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TargetName.assign_statement
Fld_5 := Libadalang.Implementation.Target_Name_P_Assign_Statement (Node => Self);
--# end
--# expr-done 9816
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Fld_5.Assign_Stmt_F_Dest;
--# expr-done 9817
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_6);
--# end
--# expr-done 9818
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result_1 := Solver.Create_Unify (Fld_4, Fld_7, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14153") else null)); 
--# expr-done 9819
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:14151") else null)); 
--# expr-done 9820
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 9821
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1047;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1047;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Target_Name_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Update_Attribute_Ref
   --
      procedure Initialize_Fields_For_Update_Attribute_Ref
        (Self : Bare_Update_Attribute_Ref
         ; Update_Attribute_Ref_F_Prefix : Bare_Name
         ; Update_Attribute_Ref_F_Attribute : Bare_Identifier
         ; Update_Attribute_Ref_F_Values : Bare_Base_Aggregate
        ) is
      begin
            Initialize_Fields_For_Name
              (Self);
            Self.Update_Attribute_Ref_F_Prefix := Update_Attribute_Ref_F_Prefix;
            Self.Update_Attribute_Ref_F_Attribute := Update_Attribute_Ref_F_Attribute;
            Self.Update_Attribute_Ref_F_Values := Update_Attribute_Ref_F_Values;
      Self.Update_Attribute_Ref_R_Ref_Var := Null_Var_Record;
      end Initialize_Fields_For_Update_Attribute_Ref;
   function Update_Attribute_Ref_F_Prefix
     (Node : Bare_Update_Attribute_Ref) return Bare_Name
   is
   begin
         return Node.Update_Attribute_Ref_F_Prefix;
   end;
   function Update_Attribute_Ref_F_Attribute
     (Node : Bare_Update_Attribute_Ref) return Bare_Identifier
   is
   begin
         return Node.Update_Attribute_Ref_F_Attribute;
   end;
   function Update_Attribute_Ref_F_Values
     (Node : Bare_Update_Attribute_Ref) return Bare_Base_Aggregate
   is
   begin
         return Node.Update_Attribute_Ref_F_Values;
   end;
--# property-start UpdateAttributeRef.ref_var /tmp/lal-23.0.0/ada/ast.py:18764
pragma Warnings (Off, "is not referenced");
 function Update_Attribute_Ref_P_Ref_Var
  (Node : Bare_Update_Attribute_Ref
  )
   return Logic_Var
is
   Self : Bare_Update_Attribute_Ref := Bare_Update_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Logic_Var;
      Fld : Logic_Var;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9822 '<FieldAccess for r_ref_var at ast.py:18764>' Fld /tmp/lal-23.0.0/ada/ast.py:18764
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Update_Attribute_Ref_R_Ref_Var'Unrestricted_Access;
--# expr-done 9822
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Update_Attribute_Ref_P_Ref_Var;
--# end
--# property-start UpdateAttributeRef.xref_equation /tmp/lal-23.0.0/ada/ast.py:18768
pragma Warnings (Off, "is not referenced");
 function Update_Attribute_Ref_P_Xref_Equation
  (Node : Bare_Update_Attribute_Ref
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Update_Attribute_Ref := Bare_Update_Attribute_Ref (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Update_Attribute_Ref :=
     Internal_Entity_Update_Attribute_Ref'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1334 with Inline_Always;
      Block_Var : Boolean;
Block_Var_1 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_4 : Internal_Entity_Base_Aggregate;
Cast_Result_1 : Internal_Entity_Aggregate;
Fld_5 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_6 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_3 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1334 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1334;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9835 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9824 '<FieldAccess for resolve_names_internal at ast.py:18773>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18773
--# expr-start 9823 '<FieldAccess for prefix at ast.py:18773>' Fld /tmp/lal-23.0.0/ada/ast.py:18773
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Update_Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 9823
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_internal
Fld_1 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9824
Block_Var := Fld_1; 
--# expr-start 9827 '<Cast to BaseTypeDecl at ast.py:18774>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:18774
--# expr-start 9826 '<FieldAccess for type_val at ast.py:18774>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18774
--# expr-start 9825 '<FieldAccess for prefix at ast.py:18774>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18774
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Update_Attribute_Ref_F_Prefix, Info => Ent.Info);
--# expr-done 9825
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_3 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld_2.Node);
--# end
--# expr-done 9826
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 9827
Block_Var_1 := Cast_Result; 
--# bind prefix_type Block_Var_1
--# expr-start 9834 '<And at ast.py:18775>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18775
--# expr-start 9831 '<Bind at ast.py:18776>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18776
--# expr-start 9830 '<FieldAccess for type_var at ast.py:18776>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18776
--# expr-start 9829 '<Cast to Aggregate at ast.py:18776>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:18776
--# expr-start 9828 '<FieldAccess for values at ast.py:18776>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18776
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Base_Aggregate (Node => Ent.Node.Update_Attribute_Ref_F_Values, Info => Ent.Info);
--# expr-done 9828
   if Fld_4.Node = null
      or else Fld_4.Node.Kind in Ada_Aggregate_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Aggregate
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9829
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Cast_Result_1.Node);
--# expr-done 9830
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Cast_Expr := Block_Var_1; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18776") else null)); 
--# expr-done 9831
--# expr-start 9833 '<Bind at ast.py:18777>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18777
--# expr-start 9832 '<FieldAccess for type_var at ast.py:18777>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18777
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9832
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
Cast_Expr_1 := Block_Var_1; 
      Cast_Result_3 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_6, Cast_Result_3, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18777") else null)); 
--# expr-done 9833
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18775") else null)); 
--# expr-done 9834
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 9835
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1334;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1334;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Update_Attribute_Ref_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Paren_Expr
   --
      procedure Initialize_Fields_For_Paren_Expr
        (Self : Bare_Paren_Expr
         ; Paren_Expr_F_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Paren_Expr_F_Expr := Paren_Expr_F_Expr;
      end Initialize_Fields_For_Paren_Expr;
   function Paren_Expr_F_Expr
     (Node : Bare_Paren_Expr) return Bare_Expr
   is
   begin
         return Node.Paren_Expr_F_Expr;
   end;
--# property-start ParenExpr.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12145
pragma Warnings (Off, "is not referenced");
 function Paren_Expr_P_Has_Context_Free_Type
  (Node : Bare_Paren_Expr
  )
   return Boolean
is
   Self : Bare_Paren_Expr := Bare_Paren_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Expr;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9837 '<FieldAccess for has_context_free_type at ast.py:12145>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12145
--# expr-start 9836 '<FieldAccess for expr at ast.py:12145>' Fld /tmp/lal-23.0.0/ada/ast.py:12145
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Paren_Expr_F_Expr;
--# expr-done 9836
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.has_context_free_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Expr_P_Has_Context_Free_Type (Node => Fld);
--# end
--# expr-done 9837
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Paren_Expr_P_Has_Context_Free_Type;
--# end
--# property-start ParenExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:12148
pragma Warnings (Off, "is not referenced");
 function Paren_Expr_P_Xref_Equation
  (Node : Bare_Paren_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Paren_Expr := Bare_Paren_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Paren_Expr :=
     Internal_Entity_Paren_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_949 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Fld_4 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Bare_Expr;
Fld_6 : Logic_Var;
Fld_7 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_949 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_949;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9850 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9849 '<And at ast.py:12150>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12150
--# expr-start 9844 '<And at ast.py:12150>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12150
--# expr-start 9839 '<FieldAccess for sub_equation at ast.py:12150>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12150
--# expr-start 9838 '<FieldAccess for expr at ast.py:12150>' Fld /tmp/lal-23.0.0/ada/ast.py:12150
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Paren_Expr_F_Expr, Info => Ent.Info);
--# expr-done 9838
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9839
--# expr-start 9843 '<Bind at ast.py:12151>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12151
--# expr-start 9841 '<FieldAccess for expected_type_var at ast.py:12151>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12151
--# expr-start 9840 '<FieldAccess for expr at ast.py:12151>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12151
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Paren_Expr_F_Expr;
--# expr-done 9840
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2);
--# expr-done 9841
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 9842 '<FieldAccess for expected_type_var at ast.py:12151>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12151
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9842
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Bind_Result := Solver.Create_Unify (Fld_3, Fld_4, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12151") else null)); 
--# expr-done 9843
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12150") else null)); 
--# expr-done 9844
--# expr-start 9848 '<Bind at ast.py:12152>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12152
--# expr-start 9846 '<FieldAccess for type_var at ast.py:12152>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12152
--# expr-start 9845 '<FieldAccess for expr at ast.py:12152>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12152
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Paren_Expr_F_Expr;
--# expr-done 9845
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_5);
--# expr-done 9846
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 9847 '<FieldAccess for type_var at ast.py:12152>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12152
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9847
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Bind_Result_1 := Solver.Create_Unify (Fld_6, Fld_7, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12152") else null)); 
--# expr-done 9848
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12150") else null)); 
--# expr-done 9849
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9850
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_949;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_949;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Paren_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Quantified_Expr
   --
      procedure Initialize_Fields_For_Quantified_Expr
        (Self : Bare_Quantified_Expr
         ; Quantified_Expr_F_Quantifier : Bare_Quantifier
         ; Quantified_Expr_F_Loop_Spec : Bare_For_Loop_Spec
         ; Quantified_Expr_F_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Quantified_Expr_F_Quantifier := Quantified_Expr_F_Quantifier;
            Self.Quantified_Expr_F_Loop_Spec := Quantified_Expr_F_Loop_Spec;
            Self.Quantified_Expr_F_Expr := Quantified_Expr_F_Expr;
      end Initialize_Fields_For_Quantified_Expr;
   function Quantified_Expr_F_Quantifier
     (Node : Bare_Quantified_Expr) return Bare_Quantifier
   is
   begin
         return Node.Quantified_Expr_F_Quantifier;
   end;
   function Quantified_Expr_F_Loop_Spec
     (Node : Bare_Quantified_Expr) return Bare_For_Loop_Spec
   is
   begin
         return Node.Quantified_Expr_F_Loop_Spec;
   end;
   function Quantified_Expr_F_Expr
     (Node : Bare_Quantified_Expr) return Bare_Expr
   is
   begin
         return Node.Quantified_Expr_F_Expr;
   end;
--# property-start QuantifiedExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:17938
pragma Warnings (Off, "is not referenced");
 function Quantified_Expr_P_Xref_Equation
  (Node : Bare_Quantified_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Quantified_Expr := Bare_Quantified_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Quantified_Expr :=
     Internal_Entity_Quantified_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1285 with Inline_Always;
      Block_Var : Boolean;
Fld : Internal_Entity_For_Loop_Spec;
Fld_1 : Boolean;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Fld_4 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Internal_Entity_Expr;
Fld_8 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_9 : Logic_Var;
Fld_10 : Bare_Expr;
Fld_11 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
False_Rel : Logic_Equation;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1285 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_8);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1285;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9869 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9852 '<FieldAccess for resolve_names at ast.py:17941>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17941
--# expr-start 9851 '<FieldAccess for loop_spec at ast.py:17941>' Fld /tmp/lal-23.0.0/ada/ast.py:17941
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_For_Loop_Spec (Node => Ent.Node.Quantified_Expr_F_Loop_Spec, Info => Ent.Info);
--# expr-done 9851
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names
Fld_1 := Libadalang.Implementation.Ada_Node_P_Resolve_Names (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9852
Block_Var := Fld_1; 
--# bind spec_success Block_Var
--# expr-start 9868 '<If at ast.py:17943>' If_Result /tmp/lal-23.0.0/ada/ast.py:17943
if Block_Var then
   --# expr-start 9867 '<And at ast.py:17945>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:17945
--# expr-start 9862 '<And at ast.py:17945>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:17945
--# expr-start 9859 '<And at ast.py:17945>' And_Pred /tmp/lal-23.0.0/ada/ast.py:17945
--# expr-start 9856 '<Bind at ast.py:17945>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:17945
--# expr-start 9854 '<FieldAccess for expected_type_var at ast.py:17945>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17945
--# expr-start 9853 '<FieldAccess for expr at ast.py:17945>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17945
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Quantified_Expr_F_Expr;
--# expr-done 9853
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2);
--# expr-done 9854
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 9855 '<FieldAccess for bool_type at ast.py:17945>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17945
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_4 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 9855
      Cast_Result := Create_Internal_Entity
        (Node => Fld_4.Node,
         Info => Fld_4.Info);
Bind_Result := Solver.Create_Assign (Fld_3, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17945") else null)); 
--# expr-done 9856
--# expr-start 9858 '<FieldAccess for sub_equation at ast.py:17946>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17946
--# expr-start 9857 '<FieldAccess for expr at ast.py:17946>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17946
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Quantified_Expr_F_Expr, Info => Ent.Info);
--# expr-done 9857
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_6 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_5.Node, Env => Env, Origin => Origin, E_Info => Fld_5.Info);
--# end
--# expr-done 9858
And_Pred := Create_And (Bind_Result, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17945") else null)); 
--# expr-done 9859
--# expr-start 9861 '<FieldAccess for matches_expected_formal_prim_type at ast.py:17947>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17947
--# expr-start 9860 '<FieldAccess for expr at ast.py:17947>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17947
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Expr (Node => Ent.Node.Quantified_Expr_F_Expr, Info => Ent.Info);
--# expr-done 9860
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_8 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_7.Node, Origin => Origin);
--# end
--# expr-done 9861
And_Pred_1 := Create_And (And_Pred, Fld_8, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17945") else null)); 
--# expr-done 9862
--# expr-start 9866 '<Bind at ast.py:17948>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:17948
--# expr-start 9863 '<FieldAccess for type_var at ast.py:17948>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:17948
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9863
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 9865 '<FieldAccess for type_var at ast.py:17948>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:17948
--# expr-start 9864 '<FieldAccess for expr at ast.py:17948>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:17948
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Quantified_Expr_F_Expr;
--# expr-done 9864
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_10);
--# expr-done 9865
Fld_11.Value := No_Entity;
Entity_Vars.Reset (Fld_11);
Bind_Result_1 := Solver.Create_Unify (Fld_9, Fld_11, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17948") else null)); 
--# expr-done 9866
And_Pred_2 := Create_And (And_Pred_1, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17945") else null)); 
--# expr-done 9867
   If_Result := And_Pred_2;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17949") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 9868
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9869
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1285;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1285;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Quantified_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Raise_Expr
   --
      procedure Initialize_Fields_For_Raise_Expr
        (Self : Bare_Raise_Expr
         ; Raise_Expr_F_Exception_Name : Bare_Name
         ; Raise_Expr_F_Error_Message : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Raise_Expr_F_Exception_Name := Raise_Expr_F_Exception_Name;
            Self.Raise_Expr_F_Error_Message := Raise_Expr_F_Error_Message;
      end Initialize_Fields_For_Raise_Expr;
   function Raise_Expr_F_Exception_Name
     (Node : Bare_Raise_Expr) return Bare_Name
   is
   begin
         return Node.Raise_Expr_F_Exception_Name;
   end;
   function Raise_Expr_F_Error_Message
     (Node : Bare_Raise_Expr) return Bare_Expr
   is
   begin
         return Node.Raise_Expr_F_Error_Message;
   end;
--# property-start RaiseExpr.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:18789
pragma Warnings (Off, "is not referenced");
 function Raise_Expr_P_Has_Context_Free_Type
  (Node : Bare_Raise_Expr
  )
   return Boolean
is
   Self : Bare_Raise_Expr := Bare_Raise_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Raise_Expr_P_Has_Context_Free_Type;
--# end
--# property-start RaiseExpr.xref_equation /tmp/lal-23.0.0/ada/ast.py:18792
pragma Warnings (Off, "is not referenced");
 function Raise_Expr_P_Xref_Equation
  (Node : Bare_Raise_Expr
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Raise_Expr := Bare_Raise_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Raise_Expr :=
     Internal_Entity_Raise_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1336 with Inline_Always;
            procedure Finalizer_Scope_3096 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Logic_Var;
Fld_3 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Internal_Entity_Expr;
Fld_5 : Logic_Var;
Sym : Symbol_Type;
Fld_6 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1336 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1336;
            procedure Finalizer_Scope_3096 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3096;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9884 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9883 '<And at ast.py:18793>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:18793
--# expr-start 9875 '<And at ast.py:18793>' And_Pred /tmp/lal-23.0.0/ada/ast.py:18793
--# expr-start 9871 '<FieldAccess for sub_equation at ast.py:18794>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18794
--# expr-start 9870 '<FieldAccess for exception_name at ast.py:18794>' Fld /tmp/lal-23.0.0/ada/ast.py:18794
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Raise_Expr_F_Exception_Name, Info => Ent.Info);
--# expr-done 9870
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9871
--# expr-start 9874 '<Bind at ast.py:18795>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:18795
--# expr-start 9872 '<FieldAccess for expected_type_var at ast.py:18795>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:18795
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9872
Fld_2.Value := No_Entity;
Entity_Vars.Reset (Fld_2);
--# expr-start 9873 '<FieldAccess for type_var at ast.py:18795>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:18795
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9873
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Bind_Result := Solver.Create_Unify (Fld_2, Fld_3, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18795") else null)); 
--# expr-done 9874
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18793") else null)); 
--# expr-done 9875
--# expr-start 9876 '<FieldAccess for error_message at ast.py:18796>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:18796
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Expr (Node => Ent.Node.Raise_Expr_F_Error_Message, Info => Ent.Info);
--# expr-done 9876
Var_Expr := Fld_4;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind er Var_Expr
--# expr-start 9882 '<And at ast.py:18797>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:18797
--# expr-start 9880 '<Bind at ast.py:18800>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:18800
--# expr-start 9877 '<FieldAccess for expected_type_var at ast.py:18800>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:18800
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 9877
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 9879 '<FieldAccess for std_entity at ast.py:18800>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:18800
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9878 '<Symbol String at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 9878
--# property-call-start AdaNode.std_entity
Fld_6 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 9879
Bind_Result_1 := Solver.Create_Assign (Fld_5, Fld_6, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18800") else null)); 
--# expr-done 9880
--# expr-start 9881 '<FieldAccess for sub_equation at ast.py:18801>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:18801
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_7 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 9881
And_Pred_1 := Create_And (Bind_Result_1, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18797") else null)); 
--# expr-done 9882
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3096;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18803") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_2 := Create_And (And_Pred, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:18793") else null)); 
--# expr-done 9883
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 9884
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1336;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1336;
               Finalizer_Scope_3096;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Raise_Expr_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Un_Op
   --
      procedure Initialize_Fields_For_Un_Op
        (Self : Bare_Un_Op
         ; Un_Op_F_Op : Bare_Op
         ; Un_Op_F_Expr : Bare_Expr
        ) is
      begin
            Initialize_Fields_For_Expr
              (Self);
            Self.Un_Op_F_Op := Un_Op_F_Op;
            Self.Un_Op_F_Expr := Un_Op_F_Expr;
      end Initialize_Fields_For_Un_Op;
   function Un_Op_F_Op
     (Node : Bare_Un_Op) return Bare_Op
   is
   begin
         return Node.Un_Op_F_Op;
   end;
   function Un_Op_F_Expr
     (Node : Bare_Un_Op) return Bare_Expr
   is
   begin
         return Node.Un_Op_F_Expr;
   end;
--# property-start UnOp.has_context_free_type /tmp/lal-23.0.0/ada/ast.py:12168
pragma Warnings (Off, "is not referenced");
 function Un_Op_P_Has_Context_Free_Type
  (Node : Bare_Un_Op
  )
   return Boolean
is
   Self : Bare_Un_Op := Bare_Un_Op (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Un_Op_P_Has_Context_Free_Type;
--# end
--# property-start UnOp.xref_equation /tmp/lal-23.0.0/ada/ast.py:12171
pragma Warnings (Off, "is not referenced");
 function Un_Op_P_Xref_Equation
  (Node : Bare_Un_Op
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Un_Op := Bare_Un_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Un_Op :=
     Internal_Entity_Un_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_951 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
True_Rel : Logic_Equation;
Fld_2 : Logic_Equation;
Fld_3 : Logic_Var;
Fld_4 : Bare_Expr;
Fld_5 : Logic_Var;
Bind_Result : Logic_Equation;
Fld_6 : Logic_Var;
Fld_7 : Bare_Expr;
Fld_8 : Logic_Var;
Bind_Result_1 : Logic_Equation;
And_Pred : Logic_Equation;
Or_Pred : Logic_Equation;
Sym : Symbol_Type;
Fld_9 : Boolean;
Sym_1 : Symbol_Type;
Fld_10 : Boolean;
If_Result : Boolean;
If_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_951 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Or_Pred);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_951;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9904 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9903 '<And at ast.py:12172>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12172
--# expr-start 9886 '<FieldAccess for sub_equation at ast.py:12172>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12172
--# expr-start 9885 '<FieldAccess for expr at ast.py:12172>' Fld /tmp/lal-23.0.0/ada/ast.py:12172
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Un_Op_F_Expr, Info => Ent.Info);
--# expr-done 9885
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9886
--# expr-start 9902 '<If at ast.py:12172>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:12172
--# expr-start 9888 '<FieldAccess for in_aspect at ast.py:12173>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12173
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9887 '<Symbol Depends at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Depends); 
--# expr-done 9887
--# property-call-start AdaNode.in_aspect
Fld_9 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym);
--# end
--# expr-done 9888
if Fld_9 then
   If_Result := True;
else
   --# expr-start 9890 '<FieldAccess for in_aspect at ast.py:12173>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12173
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9889 '<Symbol Refined_Depends at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Refined_Depends); 
--# expr-done 9889
--# property-call-start AdaNode.in_aspect
Fld_10 := Libadalang.Implementation.Ada_Node_P_In_Aspect (Node => Self, Name => Sym_1);
--# end
--# expr-done 9890
   If_Result := Fld_10;
end if;
if If_Result then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12174") else null)); 
   If_Result_1 := True_Rel;
else
   --# expr-start 9901 '<Or at ast.py:12175>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:12175
--# expr-start 9891 '<FieldAccess for overload_equation at ast.py:12175>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12175
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UnOp.overload_equation
Fld_2 := Libadalang.Implementation.Un_Op_P_Overload_Equation (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 9891
--# expr-start 9900 '<And at ast.py:12176>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12176
--# expr-start 9895 '<Bind at ast.py:12176>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12176
--# expr-start 9892 '<FieldAccess for expected_type_var at ast.py:12176>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12176
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Self);
--# expr-done 9892
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 9894 '<FieldAccess for expected_type_var at ast.py:12176>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12176
--# expr-start 9893 '<FieldAccess for expr at ast.py:12176>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12176
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Un_Op_F_Expr;
--# expr-done 9893
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_4);
--# expr-done 9894
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result := Solver.Create_Unify (Fld_3, Fld_5, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12176") else null)); 
--# expr-done 9895
--# expr-start 9899 '<Bind at ast.py:12177>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12177
--# expr-start 9896 '<FieldAccess for type_var at ast.py:12177>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12177
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9896
Fld_6.Value := No_Entity;
Entity_Vars.Reset (Fld_6);
--# expr-start 9898 '<FieldAccess for type_var at ast.py:12177>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12177
--# expr-start 9897 '<FieldAccess for expr at ast.py:12177>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12177
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Un_Op_F_Expr;
--# expr-done 9897
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_7);
--# expr-done 9898
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Bind_Result_1 := Solver.Create_Unify (Fld_6, Fld_8, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12177") else null)); 
--# expr-done 9899
And_Pred := Create_And (Bind_Result, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12176") else null)); 
--# expr-done 9900
Or_Pred := Create_Or (Fld_2, And_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12175") else null)); 
--# expr-done 9901
   If_Result_1 := Or_Pred;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 9902
And_Pred_1 := Create_And (Fld_1, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12172") else null)); 
--# expr-done 9903
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 9904
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_951;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_951;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Un_Op_P_Xref_Equation;
--# end
--# property-start UnOp.overload_equation /tmp/lal-23.0.0/ada/ast.py:12181
pragma Warnings (Off, "is not referenced");
 function Un_Op_P_Overload_Equation
  (Node : Bare_Un_Op
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Un_Op := Bare_Un_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Un_Op :=
     Internal_Entity_Un_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_952 with Inline_Always;
            procedure Finalizer_Scope_3097 with Inline_Always;
      Fld : Internal_Entity_Op;
Fld_1 : Internal_Entity_Basic_Decl_Array_Access;
Fld_2 : Logic_Equation;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_952 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_952;
            procedure Finalizer_Scope_3097 is
            begin
                     Dec_Ref (Fld_2);
            end Finalizer_Scope_3097;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9910 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9909 '<LogicAny at ast.py:12182>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:12182
--# expr-start 9908 '<Map at ast.py:12182>' Map_Result /tmp/lal-23.0.0/ada/ast.py:12182
   --# expr-start 9906 '<FieldAccess for subprograms at ast.py:12182>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12182
--# expr-start 9905 '<FieldAccess for op at ast.py:12182>' Fld /tmp/lal-23.0.0/ada/ast.py:12182
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Op (Node => Ent.Node.Un_Op_F_Op, Info => Ent.Info);
--# expr-done 9905
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Op.subprograms
Fld_1 := Libadalang.Implementation.Op_P_Subprograms (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 9906
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := Fld_1;
      begin
         for Item_310 of
               Collection.Items
         loop
   --# scope-start
               --# bind subp Item_310
      --# expr-start 9907 '<FieldAccess for entity_eq at ast.py:12183>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12183
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UnOp.entity_eq
Fld_2 := Libadalang.Implementation.Un_Op_P_Entity_Eq (Node => Ent.Node, Subp => Item_310, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 9907
         declare
            Item_To_Append : constant Logic_Equation := Fld_2;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3097;
         end loop;
      end;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 9908
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12182") else null)); 
--# expr-done 9909
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 9910
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_952;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_952;
               Finalizer_Scope_3097;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Un_Op_P_Overload_Equation;
--# end
--# property-start UnOp.entity_eq /tmp/lal-23.0.0/ada/ast.py:12187
pragma Warnings (Off, "is not referenced");
 function Un_Op_P_Entity_Eq
  (Node : Bare_Un_Op
      ; Subp : Internal_Entity_Basic_Decl
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Un_Op := Bare_Un_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Un_Op :=
     Internal_Entity_Un_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind subp Subp
   --# bind origin Origin
   --# bind env Env
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_953 with Inline_Always;
      Block_Var : Internal_Entity_Base_Subp_Spec;
Block_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Fld : Internal_Entity_Base_Subp_Spec;
Fld_1 : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_2 : Internal_Entity_Base_Formal_Param_Decl;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
Fld_5 : Logic_Var;
Fld_6 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Bare_Op;
Fld_8 : Logic_Var;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_9 : Bare_Op;
Fld_10 : Logic_Var;
Cast_Expr_1 : Internal_Entity_Base_Subp_Spec;
Cast_Result_2 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
And_Pred_2 : Logic_Equation;
False_Rel : Logic_Equation;
Len : Integer;
Is_Equal : Boolean;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_953 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_953;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9932 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9911 '<FieldAccess for subp_spec_or_null at ast.py:12188>' Fld /tmp/lal-23.0.0/ada/ast.py:12188
      if Subp.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Subp.Node, E_Info => Subp.Info);
--# end
--# expr-done 9911
Block_Var := Fld; 
--# bind spec Block_Var
--# expr-start 9912 '<FieldAccess for unpacked_formal_params at ast.py:12189>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12189
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.unpacked_formal_params
Fld_1 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Unpacked_Formal_Params (Node => Block_Var.Node, E_Info => Block_Var.Info);
--# end
--# expr-done 9912
Block_Var_1 := Fld_1; Inc_Ref (Block_Var_1);
--# bind ps Block_Var_1
--# expr-start 9931 '<If at ast.py:12190>' If_Result /tmp/lal-23.0.0/ada/ast.py:12190
--# expr-start 9914 '<Eq at ast.py:12191>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:12191
--# expr-start 9913 '<length at ast.py:12191>' Len /tmp/lal-23.0.0/ada/ast.py:12191
Len := Length (Block_Var_1); 
--# expr-done 9913
Is_Equal := Len = 1; 
--# expr-done 9914
if Is_Equal then
   --# expr-start 9930 '<And at ast.py:12194>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:12194
--# expr-start 9926 '<And at ast.py:12194>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:12194
--# expr-start 9922 '<And at ast.py:12194>' And_Pred /tmp/lal-23.0.0/ada/ast.py:12194
--# expr-start 9918 '<FieldAccess for call_argument_equation at ast.py:12194>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:12194
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9916 '<FieldAccess for formal_decl at ast.py:12194>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12194
--# expr-start 9915 '<at at ast.py:12194>' Get_Result /tmp/lal-23.0.0/ada/ast.py:12194
Get_Result := Get (Self, Block_Var_1, 0, True); 
--# expr-done 9915
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.formal_decl
Fld_2 := Libadalang.Implementation.Defining_Name_P_Formal_Decl (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 9916
--# expr-start 9917 '<FieldAccess for expr at ast.py:12194>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:12194
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Un_Op_F_Expr, Info => Ent.Info);
--# expr-done 9917
--# property-call-start BaseFormalParamHolder.call_argument_equation
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Call_Argument_Equation (Node => Block_Var.Node, Param => Fld_2, Arg => Fld_3, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 9918
--# expr-start 9921 '<Bind at ast.py:12197>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:12197
--# expr-start 9919 '<FieldAccess for type_var at ast.py:12197>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:12197
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Self);
--# expr-done 9919
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
--# expr-start 9920 '<FieldAccess for return_type at ast.py:12197>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:12197
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_6 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 9920
      Cast_Result := Create_Internal_Entity
        (Node => Fld_6.Node,
         Info => Fld_6.Info);
Bind_Result := Solver.Create_Assign (Fld_5, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12197") else null)); 
--# expr-done 9921
And_Pred := Create_And (Fld_4, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12194") else null)); 
--# expr-done 9922
--# expr-start 9925 '<Bind at ast.py:12200>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:12200
--# expr-start 9924 '<FieldAccess for ref_var at ast.py:12200>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:12200
--# expr-start 9923 '<FieldAccess for op at ast.py:12200>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:12200
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Un_Op_F_Op;
--# expr-done 9923
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld_7);
--# end
--# expr-done 9924
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
Cast_Expr := Subp; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_8, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12200") else null)); 
--# expr-done 9925
And_Pred_1 := Create_And (And_Pred, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12194") else null)); 
--# expr-done 9926
--# expr-start 9929 '<Bind at ast.py:12201>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:12201
--# expr-start 9928 '<FieldAccess for subp_spec_var at ast.py:12201>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:12201
--# expr-start 9927 '<FieldAccess for op at ast.py:12201>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:12201
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Self.Un_Op_F_Op;
--# expr-done 9927
      if Fld_9 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.subp_spec_var'
Fld_10 := Libadalang.Implementation.Dispatcher_Name_P_Subp_Spec_Var (Node => Fld_9);
--# end
--# expr-done 9928
Fld_10.Value := No_Entity;
Entity_Vars.Reset (Fld_10);
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Bind_Result_2 := Solver.Create_Assign (Fld_10, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12201") else null)); 
--# expr-done 9929
And_Pred_2 := Create_And (And_Pred_1, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12194") else null)); 
--# expr-done 9930
   If_Result := And_Pred_2;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:12202") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 9931
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 9932
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_953;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_953;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Un_Op_P_Entity_Eq;
--# end
--# property-start UnOp.potential_actuals_for_dispatch /tmp/lal-23.0.0/ada/ast.py:12206
pragma Warnings (Off, "is not referenced");
 function Un_Op_P_Potential_Actuals_For_Dispatch
  (Node : Bare_Un_Op
      ; Spec : Internal_Entity_Base_Subp_Spec
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Expected_Type_For_Expr_Array_Access
is
   Self : Bare_Un_Op := Bare_Un_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Un_Op :=
     Internal_Entity_Un_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind spec Spec
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Internal_Expected_Type_For_Expr_Array_Access;
            procedure Finalizer_Scope_954 with Inline_Always;
      Fld : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Get_Result : Internal_Entity_Base_Formal_Param_Decl;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Internal_Entity_Expr;
New_Struct : Internal_Expected_Type_For_Expr;
Singleton : Internal_Expected_Type_For_Expr_Array_Access;
Let_Result : Internal_Expected_Type_For_Expr_Array_Access;
            procedure Finalizer_Scope_954 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Singleton);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_954;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9938 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9937 '<New ExpectedTypeForExpr at ast.py:12207>' New_Struct /tmp/lal-23.0.0/ada/ast.py:12207
--# expr-start 9935 '<FieldAccess for type_expression at ast.py:12208>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12208
--# expr-start 9934 '<at at ast.py:12208>' Get_Result /tmp/lal-23.0.0/ada/ast.py:12208
--# expr-start 9933 '<FieldAccess for abstract_formal_params at ast.py:12208>' Fld /tmp/lal-23.0.0/ada/ast.py:12208
      if Spec.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseFormalParamHolder.abstract_formal_params'
Fld := Libadalang.Implementation.Dispatcher_Base_Formal_Param_Holder_P_Abstract_Formal_Params (Node => Spec.Node, E_Info => Spec.Info);
--# end
--# expr-done 9933
Get_Result := Get (Self, Fld, 0, True); 
--# expr-done 9934
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.type_expression'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Type_Expression (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# end
--# expr-done 9935
--# expr-start 9936 '<FieldAccess for expr at ast.py:12209>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12209
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Un_Op_F_Expr, Info => Ent.Info);
--# expr-done 9936
New_Struct := (Expected_Type => Fld_1, Expr => Fld_2); 
--# expr-done 9937
                Singleton := Create_Internal_Expected_Type_For_Expr_Array (Items_Count => 1);
                Singleton.Items (1) := New_Struct;
Let_Result := Singleton; Inc_Ref (Let_Result);
--# end
--# expr-done 9938
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_954;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_954;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Un_Op_P_Potential_Actuals_For_Dispatch;
--# end
--# property-start UnOp.is_dispatching_call /tmp/lal-23.0.0/ada/ast.py:12213
pragma Warnings (Off, "is not referenced");
 function Un_Op_P_Is_Dispatching_Call
  (Node : Bare_Un_Op
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Un_Op := Bare_Un_Op (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Un_Op :=
     Internal_Entity_Un_Op'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Basic_Decl;
Fld : Internal_Entity_Op;
Fld_1 : Internal_Entity_Basic_Decl;
Fld_2 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 9942 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9940 '<FieldAccess for referenced_decl at ast.py:12214>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:12214
--# expr-start 9939 '<FieldAccess for op at ast.py:12214>' Fld /tmp/lal-23.0.0/ada/ast.py:12214
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Op (Node => Ent.Node.Un_Op_F_Op, Info => Ent.Info);
--# expr-done 9939
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_1 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 9940
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind decl Var_Expr
--# expr-start 9941 '<FieldAccess for is_dispatching_call_impl at ast.py:12215>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:12215
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_dispatching_call_impl
Fld_2 := Libadalang.Implementation.Expr_P_Is_Dispatching_Call_Impl (Node => Ent.Node, Decl => Var_Expr, Imprecise_Fallback => Imprecise_Fallback, E_Info => Ent.Info);
--# end
--# expr-done 9941
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 9942
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Un_Op_P_Is_Dispatching_Call;
--# end
   --
   --  Primitives for Bare_Handled_Stmts
   --
      procedure Initialize_Fields_For_Handled_Stmts
        (Self : Bare_Handled_Stmts
         ; Handled_Stmts_F_Stmts : Bare_Stmt_List
         ; Handled_Stmts_F_Exceptions : Bare_Ada_Node_List
        ) is
      begin
            Self.Handled_Stmts_F_Stmts := Handled_Stmts_F_Stmts;
            Self.Handled_Stmts_F_Exceptions := Handled_Stmts_F_Exceptions;
      end Initialize_Fields_For_Handled_Stmts;
   function Handled_Stmts_F_Stmts
     (Node : Bare_Handled_Stmts) return Bare_Stmt_List
   is
   begin
         return Node.Handled_Stmts_F_Stmts;
   end;
   function Handled_Stmts_F_Exceptions
     (Node : Bare_Handled_Stmts) return Bare_Ada_Node_List
   is
   begin
         return Node.Handled_Stmts_F_Exceptions;
   end;
   --
   --  Primitives for Bare_Interface_Kind
   --
   --
   --  Primitives for Bare_Interface_Kind_Limited
   --
   --
   --  Primitives for Bare_Interface_Kind_Protected
   --
   --
   --  Primitives for Bare_Interface_Kind_Synchronized
   --
   --
   --  Primitives for Bare_Interface_Kind_Task
   --
   --
   --  Primitives for Bare_Iter_Type
   --
   --
   --  Primitives for Bare_Iter_Type_In
   --
   --
   --  Primitives for Bare_Iter_Type_Of
   --
   --
   --  Primitives for Bare_Library_Item
   --
      procedure Initialize_Fields_For_Library_Item
        (Self : Bare_Library_Item
         ; Library_Item_F_Has_Private : Bare_Private_Node
         ; Library_Item_F_Item : Bare_Basic_Decl
        ) is
      begin
            Self.Library_Item_F_Has_Private := Library_Item_F_Has_Private;
            Self.Library_Item_F_Item := Library_Item_F_Item;
      end Initialize_Fields_For_Library_Item;
   function Library_Item_F_Has_Private
     (Node : Bare_Library_Item) return Bare_Private_Node
   is
   begin
         return Node.Library_Item_F_Has_Private;
   end;
   function Library_Item_F_Item
     (Node : Bare_Library_Item) return Bare_Basic_Decl
   is
   begin
         return Node.Library_Item_F_Item;
   end;
   --
   --  Primitives for Bare_Limited_Node
   --
--# property-start '[dispatcher]Limited.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Limited_Node_P_As_Bool
  (Node : Bare_Limited_Node
  )
   return Boolean
is
   Self : Bare_Limited_Node := Bare_Limited_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Limited_Node (Self.Kind) is
               when Ada_Limited_Absent =>
                  --# property-call-start Limited.Absent.as_bool
                  Property_Result := Limited_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Limited_Present =>
                  --# property-call-start Limited.Present.as_bool
                  Property_Result := Limited_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Limited_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Limited_Absent
   --
--# property-start Limited.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:4981
pragma Warnings (Off, "is not referenced");
 function Limited_Absent_P_As_Bool
  (Node : Bare_Limited_Absent
  )
   return Boolean
is
   Self : Bare_Limited_Absent := Bare_Limited_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Limited_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Limited_Present
   --
--# property-start Limited.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:4981
pragma Warnings (Off, "is not referenced");
 function Limited_Present_P_As_Bool
  (Node : Bare_Limited_Present
  )
   return Boolean
is
   Self : Bare_Limited_Present := Bare_Limited_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Limited_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Loop_Spec
   --
   --
   --  Primitives for Bare_For_Loop_Spec
   --
      procedure Initialize_Fields_For_For_Loop_Spec
        (Self : Bare_For_Loop_Spec
         ; For_Loop_Spec_F_Var_Decl : Bare_For_Loop_Var_Decl
         ; For_Loop_Spec_F_Loop_Type : Bare_Iter_Type
         ; For_Loop_Spec_F_Has_Reverse : Bare_Reverse_Node
         ; For_Loop_Spec_F_Iter_Expr : Bare_Ada_Node
         ; For_Loop_Spec_F_Iter_Filter : Bare_Expr
        ) is
      begin
            Self.For_Loop_Spec_F_Var_Decl := For_Loop_Spec_F_Var_Decl;
            Self.For_Loop_Spec_F_Loop_Type := For_Loop_Spec_F_Loop_Type;
            Self.For_Loop_Spec_F_Has_Reverse := For_Loop_Spec_F_Has_Reverse;
            Self.For_Loop_Spec_F_Iter_Expr := For_Loop_Spec_F_Iter_Expr;
            Self.For_Loop_Spec_F_Iter_Filter := For_Loop_Spec_F_Iter_Filter;
      end Initialize_Fields_For_For_Loop_Spec;
   function For_Loop_Spec_F_Var_Decl
     (Node : Bare_For_Loop_Spec) return Bare_For_Loop_Var_Decl
   is
   begin
         return Node.For_Loop_Spec_F_Var_Decl;
   end;
   function For_Loop_Spec_F_Loop_Type
     (Node : Bare_For_Loop_Spec) return Bare_Iter_Type
   is
   begin
         return Node.For_Loop_Spec_F_Loop_Type;
   end;
   function For_Loop_Spec_F_Has_Reverse
     (Node : Bare_For_Loop_Spec) return Bare_Reverse_Node
   is
   begin
         return Node.For_Loop_Spec_F_Has_Reverse;
   end;
   function For_Loop_Spec_F_Iter_Expr
     (Node : Bare_For_Loop_Spec) return Bare_Ada_Node
   is
   begin
         return Node.For_Loop_Spec_F_Iter_Expr;
   end;
   function For_Loop_Spec_F_Iter_Filter
     (Node : Bare_For_Loop_Spec) return Bare_Expr
   is
   begin
         return Node.For_Loop_Spec_F_Iter_Filter;
   end;
--# property-start ForLoopSpec.is_iterated_assoc_spec /tmp/lal-23.0.0/ada/ast.py:17807
pragma Warnings (Off, "is not referenced");
 function For_Loop_Spec_P_Is_Iterated_Assoc_Spec
  (Node : Bare_For_Loop_Spec
  )
   return Boolean
is
   Self : Bare_For_Loop_Spec := Bare_For_Loop_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 9945 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9944 '<IsA IteratedAssoc at ast.py:17812>' Is_A /tmp/lal-23.0.0/ada/ast.py:17812
--# expr-start 9943 '<parent at ast.py:17812>' Fld /tmp/lal-23.0.0/ada/ast.py:17812
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 9943
Is_A := Fld /= null 
and then Fld.Kind in Ada_Iterated_Assoc_Range; 
--# expr-done 9944
Let_Result := Is_A; 
--# end
--# expr-done 9945
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Spec_P_Is_Iterated_Assoc_Spec;
--# end
--# property-start ForLoopSpec.iter_type /tmp/lal-23.0.0/ada/ast.py:17816
pragma Warnings (Off, "is not referenced");
 function For_Loop_Spec_P_Iter_Type
  (Node : Bare_For_Loop_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_For_Loop_Spec := Bare_For_Loop_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Spec :=
     Internal_Entity_For_Loop_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1281 with Inline_Always;
      Block_Var : Logic_Var;
Block_Var_1 : Boolean;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity;
Pred : Logic_Equation;
True_Rel : Logic_Equation;
Fld_3 : Bare_Ada_Node;
Cast_Result_1 : Bare_Expr;
Fld_4 : Logic_Var;
Fld_5 : Internal_Entity_For_Loop_Var_Decl;
Fld_6 : Internal_Entity_Type_Expr;
Fld_7 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_8 : Bare_For_Loop_Var_Decl;
Fld_9 : Bare_Type_Expr;
Is_Null : Boolean;
If_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_10 : Boolean;
Is_Logic_Var_Defined : Boolean;
Eq_Solution : Internal_Entity;
If_Result_1 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Base_Type_Decl;
If_Result_2 : Internal_Entity_Base_Type_Decl;
Fld_11 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_12 : Internal_Entity_Base_Type_Decl;
Fld_13 : Boolean;
If_Result_3 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1281 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_1281;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_For_Loop_Spec_For_Loop_Spec_P_Iter_Type,
            Items    => new Mmz_Key_Array (1 ..  4))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_For_Loop_Spec,
                                As_Bare_For_Loop_Spec => Self);
               Mmz_K.Items (2) := (Kind => Mmz_Lexical_Env,
                                      As_Lexical_Env => Env);
                  Inc_Ref (Mmz_K.Items (2).As_Lexical_Env);
               Mmz_K.Items (3) := (Kind => Mmz_Bare_Ada_Node,
                                      As_Bare_Ada_Node => Origin);
               Mmz_K.Items (4) :=
                 (Kind => Mmz_Internal_Entity_Info,
                  As_Internal_Entity_Info => E_Info);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Entity_Base_Type_Decl;
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 9972 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 9948 '<FieldAccess for type_var at ast.py:17817>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17817
--# expr-start 9947 '<Cast to Expr at ast.py:17817>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17817
--# expr-start 9946 '<FieldAccess for iter_expr at ast.py:17817>' Fld /tmp/lal-23.0.0/ada/ast.py:17817
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.For_Loop_Spec_F_Iter_Expr, Info => Ent.Info);
--# expr-done 9946
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 9947
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Cast_Result.Node);
--# expr-done 9948
Block_Var := Fld_1; 
--# bind type_var Block_Var
--# expr-start 9963 '<FieldAccess for resolve_names_internal_with_eq at ast.py:17819>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:17819
--# expr-start 9949 '<FieldAccess for iter_expr at ast.py:17819>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17819
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity (Node => Ent.Node.For_Loop_Spec_F_Iter_Expr, Info => Ent.Info);
--# expr-done 9949
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 9962 '<And at ast.py:17821>' And_Pred /tmp/lal-23.0.0/ada/ast.py:17821
--# expr-start 9950 '<Predicate on AdaNode.is_not_null at ast.py:17821>' Pred /tmp/lal-23.0.0/ada/ast.py:17821
Block_Var.Value := No_Entity;
Entity_Vars.Reset (Block_Var);
Pred := Solver.Create_Predicate (Block_Var, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 9950
--# expr-start 9961 '<If at ast.py:17825>' If_Result /tmp/lal-23.0.0/ada/ast.py:17825
--# expr-start 9953 '<IsNull at ast.py:17826>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17826
--# expr-start 9952 '<FieldAccess for id_type at ast.py:17826>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:17826
--# expr-start 9951 '<FieldAccess for var_decl at ast.py:17826>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17826
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 9951
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Fld_8.For_Loop_Var_Decl_F_Id_Type;
--# expr-done 9952
Is_Null := Fld_9 = null; 
--# expr-done 9953
if Is_Null then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17827") else null)); 
   If_Result := True_Rel;
else
   --# expr-start 9960 '<Bind at ast.py:17828>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:17828
--# expr-start 9956 '<FieldAccess for expected_type_var at ast.py:17828>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17828
--# expr-start 9955 '<Cast to Expr at ast.py:17828>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:17828
--# expr-start 9954 '<FieldAccess for iter_expr at ast.py:17828>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17828
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.For_Loop_Spec_F_Iter_Expr;
--# expr-done 9954
   if Fld_3 = null
      or else Fld_3.Kind in Ada_Expr
   then
      Cast_Result_1 := Fld_3;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 9955
      if Cast_Result_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Cast_Result_1);
--# expr-done 9956
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
--# expr-start 9959 '<FieldAccess for designated_type at ast.py:17829>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17829
--# expr-start 9958 '<FieldAccess for id_type at ast.py:17829>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17829
--# expr-start 9957 '<FieldAccess for var_decl at ast.py:17829>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17829
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_For_Loop_Var_Decl (Node => Ent.Node.For_Loop_Spec_F_Var_Decl, Info => Ent.Info);
--# expr-done 9957
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Type_Expr (Node => Fld_5.Node.For_Loop_Var_Decl_F_Id_Type, Info => Fld_5.Info);
--# expr-done 9958
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_7 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_6.Node, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 9959
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_7.Node,
         Info => Fld_7.Info);
Bind_Result := Solver.Create_Assign (Fld_4, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17828") else null)); 
--# expr-done 9960
   If_Result := Bind_Result;
end if;
      Inc_Ref (If_Result);
--# expr-done 9961
And_Pred := Create_And (Pred, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17821") else null)); 
--# expr-done 9962
--# property-call-start AdaNode.resolve_names_internal_with_eq
Fld_10 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal_With_Eq (Node => Fld_2.Node, Additional_Equation => And_Pred, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 9963
Block_Var_1 := Fld_10; 
--# bind p Block_Var_1
--# expr-start 9966 '<If at ast.py:17833>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:17833
if Block_Var_1 then
   --# expr-start 9965 '<Cast to BaseTypeDecl at ast.py:17835>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:17835
--# expr-start 9964 '<get_value at ast.py:17835>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:17835
Is_Logic_Var_Defined := Entity_Vars.Is_Defined (Block_Var); 
if Is_Logic_Var_Defined then
Eq_Solution := Entity_Vars.Get_Value (Block_Var); 
   If_Result_1 := Eq_Solution;
else
   If_Result_1 := No_Entity;
end if;
--# expr-done 9964
   if If_Result_1.Node = null
      or else If_Result_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_3 := Create_Internal_Entity_Base_Type_Decl
        (Node => If_Result_1.Node,
         Info => If_Result_1.Info);
   else
         Cast_Result_3 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 9965
   If_Result_2 := Cast_Result_3;
else
   If_Result_2 := No_Entity_Base_Type_Decl;
end if;
--# expr-done 9966
Block_Var_2 := If_Result_2; 
--# bind typ Block_Var_2
--# expr-start 9971 '<bind at ast.py:17839>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:17839
--# expr-start 9967 '<FieldAccess for origin_node at ast.py:17839>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:17839
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_11 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 9967
Bound_Origin := Fld_11; 
--# expr-start 9970 '<If at ast.py:17839>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:17839
--# expr-start 9968 '<FieldAccess for is_implicit_deref at ast.py:17840>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:17840
      if Block_Var_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.is_implicit_deref
Fld_13 := Libadalang.Implementation.Base_Type_Decl_P_Is_Implicit_Deref (Node => Block_Var_2.Node, Origin => Bound_Origin, E_Info => Block_Var_2.Info);
--# end
--# expr-done 9968
if Fld_13 then
   --# expr-start 9969 '<FieldAccess for accessed_type at ast.py:17841>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:17841
      if Block_Var_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_12 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var_2.Node, Origin => Bound_Origin, E_Info => Block_Var_2.Info);
--# end
--# expr-done 9969
   If_Result_3 := Fld_12;
else
   If_Result_3 := Block_Var_2;
end if;
--# expr-done 9970
Dyn_Var_Bind_Result := If_Result_3; 
--# expr-done 9971
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 9972
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1281;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Entity_Base_Type_Decl,
                        As_Internal_Entity_Base_Type_Decl => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1281;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Spec_P_Iter_Type;
--# end
--# property-start ForLoopSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:17846
pragma Warnings (Off, "is not referenced");
 function For_Loop_Spec_P_Xref_Equation
  (Node : Bare_For_Loop_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_For_Loop_Spec := Bare_For_Loop_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Spec :=
     Internal_Entity_For_Loop_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1282 with Inline_Always;
            procedure Finalizer_Scope_3099 with Inline_Always;
            procedure Finalizer_Scope_3100 with Inline_Always;
            procedure Finalizer_Scope_3101 with Inline_Always;
            procedure Finalizer_Scope_3102 with Inline_Always;
            procedure Finalizer_Scope_3103 with Inline_Always;
            procedure Finalizer_Scope_3104 with Inline_Always;
            procedure Finalizer_Scope_3105 with Inline_Always;
            procedure Finalizer_Scope_3106 with Inline_Always;
      Match_0 : Bare_Iter_Type_In;
Match_1 : Bare_Iter_Type_Of;
Match_0_1 : Internal_Entity_Bin_Op;
Match_1_1 : Internal_Entity_Subtype_Indication;
Match_2 : Internal_Entity_Attribute_Ref;
Match_3 : Internal_Entity_Name;
Match_4 : Internal_Entity;
Var_Expr : Internal_Entity_Base_Type_Decl;
It_Typ : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_For_Loop_Var_Decl;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Iter_Type;
Fld_3 : Internal_Entity;
Fld_4 : Logic_Equation;
Fld_5 : Logic_Var;
Pred : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Bare_For_Loop_Var_Decl;
Fld_7 : Bare_Defining_Name;
Fld_8 : Logic_Var;
Fld_9 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_10 : Logic_Equation;
Fld_11 : Bare_For_Loop_Var_Decl;
Fld_12 : Bare_Defining_Name;
Fld_13 : Logic_Var;
Fld_14 : Internal_Entity_Base_Type_Decl;
Fld_15 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_16 : Logic_Equation;
Fld_17 : Bare_For_Loop_Var_Decl;
Fld_18 : Bare_Defining_Name;
Fld_19 : Logic_Var;
Fld_20 : Logic_Var;
Bind_Result_2 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_21 : Internal_Entity_Base_Type_Decl;
Fld_22 : Logic_Equation;
Fld_23 : Bare_For_Loop_Var_Decl;
Fld_24 : Bare_Defining_Name;
Fld_25 : Logic_Var;
Fld_26 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Bind_Result_3 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Scope_Result : Logic_Equation;
Fld_27 : Logic_Equation;
Result_Var : Logic_Equation;
True_Rel : Logic_Equation;
Match_Prefix : Internal_Entity;
Cast_Result_2 : Internal_Entity_Bin_Op;
Let_Result : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_3 : Internal_Entity_Subtype_Indication;
Let_Result_1 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_4 : Internal_Entity_Attribute_Ref;
Let_Result_2 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Cast_Result_5 : Internal_Entity_Name;
Let_Result_3 : Logic_Equation;
Scope_Result_4 : Logic_Equation;
Cast_Result_6 : Internal_Entity;
Let_Result_4 : Logic_Equation;
Scope_Result_5 : Logic_Equation;
Match_Result : Logic_Equation;
Fld_28 : Internal_Entity_Base_Type_Decl;
Fld_29 : Bare_For_Loop_Var_Decl;
Fld_30 : Bare_Defining_Name;
Fld_31 : Logic_Var;
Fld_32 : Internal_Entity_Base_Type_Decl;
Cast_Result_7 : Internal_Entity;
Bind_Result_4 : Logic_Equation;
False_Rel : Logic_Equation;
Fld_33 : Boolean;
If_Result : Logic_Equation;
Let_Result_5 : Logic_Equation;
Match_Prefix_1 : Bare_Iter_Type;
Cast_Result_8 : Bare_Iter_Type_In;
Let_Result_6 : Logic_Equation;
Scope_Result_6 : Logic_Equation;
Cast_Result_9 : Bare_Iter_Type_Of;
Let_Result_7 : Logic_Equation;
Scope_Result_7 : Logic_Equation;
Match_Result_1 : Logic_Equation;
And_Pred_5 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Fld_34 : Bare_Expr;
Fld_35 : Logic_Var;
Fld_36 : Internal_Entity_Base_Type_Decl;
Cast_Result_10 : Internal_Entity;
Bind_Result_5 : Logic_Equation;
Fld_37 : Bare_Expr;
Fld_38 : Logic_Var;
Fld_39 : Internal_Entity_Base_Type_Decl;
Cast_Result_11 : Internal_Entity;
Bind_Result_6 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Fld_40 : Internal_Entity_Expr;
Fld_41 : Logic_Equation;
And_Pred_7 : Logic_Equation;
Fld_42 : Internal_Entity_Expr;
Is_Null : Boolean;
If_Result_1 : Logic_Equation;
And_Pred_8 : Logic_Equation;
Let_Result_8 : Logic_Equation;
            procedure Finalizer_Scope_1282 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result_6);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Let_Result_7);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Match_Result_1);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (Bind_Result_6);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (Fld_41);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (And_Pred_8);
                     Dec_Ref (Let_Result_8);
            end Finalizer_Scope_1282;
            procedure Finalizer_Scope_3099 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Let_Result_4);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_3099;
            procedure Finalizer_Scope_3100 is
            begin
                     Dec_Ref (Fld_4);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3100;
            procedure Finalizer_Scope_3101 is
            begin
                     Dec_Ref (Fld_10);
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (And_Pred_2);
            end Finalizer_Scope_3101;
            procedure Finalizer_Scope_3102 is
            begin
                     Dec_Ref (Fld_16);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_3102;
            procedure Finalizer_Scope_3103 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Fld_27);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_3103;
            procedure Finalizer_Scope_3104 is
            begin
                     Dec_Ref (Fld_22);
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (And_Pred_4);
            end Finalizer_Scope_3104;
            procedure Finalizer_Scope_3105 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_3105;
            procedure Finalizer_Scope_3106 is
            begin
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result_5);
            end Finalizer_Scope_3106;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10039 '<Block at ???>' Let_Result_8 None
--# scope-start
--# expr-start 10038 '<And at ast.py:17847>' And_Pred_8 /tmp/lal-23.0.0/ada/ast.py:17847
--# expr-start 10022 '<And at ast.py:17847>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:17847
--# expr-start 9974 '<FieldAccess for sub_equation at ast.py:17847>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17847
--# expr-start 9973 '<FieldAccess for var_decl at ast.py:17847>' Fld /tmp/lal-23.0.0/ada/ast.py:17847
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_For_Loop_Var_Decl (Node => Ent.Node.For_Loop_Spec_F_Var_Decl, Info => Ent.Info);
--# expr-done 9973
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 9974
--# expr-start 10021 '<Match at ast.py:17847>' Match_Result_1 /tmp/lal-23.0.0/ada/ast.py:17847
--# expr-start 9975 '<FieldAccess for loop_type at ast.py:17847>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17847
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.For_Loop_Spec_F_Loop_Type;
--# expr-done 9975
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix_1 := Fld_2; 
case Ada_Iter_Type (Match_Prefix_1.Kind) is
         when Ada_Iter_Type_In =>
   --# scope-start
--# scope-start
      Cast_Result_8 := Match_Prefix_1;
Match_0 := Cast_Result_8; 
--# bind _ Match_0
--# expr-start 10011 '<Match at ast.py:17853>' Match_Result /tmp/lal-23.0.0/ada/ast.py:17853
--# expr-start 9976 '<FieldAccess for iter_expr at ast.py:17853>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17853
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity (Node => Ent.Node.For_Loop_Spec_F_Iter_Expr, Info => Ent.Info);
--# expr-done 9976
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Fld_3; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Bin_Op .. Ada_Relation_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Bin_Op
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0_1 := Cast_Result_2; 
--# bind binop Match_0_1
--# expr-start 9986 '<And at ast.py:17856>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:17856
--# expr-start 9980 '<And at ast.py:17856>' And_Pred /tmp/lal-23.0.0/ada/ast.py:17856
--# expr-start 9977 '<FieldAccess for sub_equation at ast.py:17856>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17856
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_0_1.Node, Env => Env, Origin => Origin, E_Info => Match_0_1.Info);
--# end
--# expr-done 9977
--# expr-start 9979 '<Predicate on BaseTypeDecl.is_not_root_int_type at ast.py:17859>' Pred /tmp/lal-23.0.0/ada/ast.py:17859
--# expr-start 9978 '<FieldAccess for type_var at ast.py:17859>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17859
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Match_0_1.Node);
--# expr-done 9978
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Pred := Solver.Create_Predicate (Fld_5, Create_Base_Type_Decl_P_Is_Not_Root_Int_Type_0_Predicate); 
--# expr-done 9979
And_Pred := Create_And (Fld_4, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17856") else null)); 
--# expr-done 9980
--# expr-start 9985 '<Bind at ast.py:17860>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:17860
--# expr-start 9983 '<FieldAccess for type_var at ast.py:17860>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17860
--# expr-start 9982 '<FieldAccess for id at ast.py:17860>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17860
--# expr-start 9981 '<FieldAccess for var_decl at ast.py:17860>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17860
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 9981
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Fld_6.For_Loop_Var_Decl_F_Id;
--# expr-done 9982
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_7);
--# expr-done 9983
Fld_8.Value := No_Entity;
Entity_Vars.Reset (Fld_8);
--# expr-start 9984 '<FieldAccess for type_var at ast.py:17860>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:17860
      if Match_0_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Match_0_1.Node);
--# expr-done 9984
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
Bind_Result := Solver.Create_Unify (Fld_8, Fld_9, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17860") else null)); 
--# expr-done 9985
And_Pred_1 := Create_And (And_Pred, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17856") else null)); 
--# expr-done 9986
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
Scope_Result_1 := Let_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3100;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1_1 := Cast_Result_3; 
--# bind t Match_1_1
--# expr-start 9994 '<And at ast.py:17865>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:17865
--# expr-start 9987 '<FieldAccess for sub_equation at ast.py:17865>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:17865
      if Match_1_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_10 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_1_1.Node, Env => Env, Origin => Origin, E_Info => Match_1_1.Info);
--# end
--# expr-done 9987
--# expr-start 9993 '<Bind at ast.py:17866>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:17866
--# expr-start 9990 '<FieldAccess for type_var at ast.py:17866>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:17866
--# expr-start 9989 '<FieldAccess for id at ast.py:17866>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:17866
--# expr-start 9988 '<FieldAccess for var_decl at ast.py:17866>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:17866
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 9988
      if Fld_11 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Fld_11.For_Loop_Var_Decl_F_Id;
--# expr-done 9989
      if Fld_12 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_12);
--# expr-done 9990
Fld_13.Value := No_Entity;
Entity_Vars.Reset (Fld_13);
--# expr-start 9992 '<FieldAccess for canonical_type at ast.py:17867>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:17867
--# expr-start 9991 '<FieldAccess for designated_type at ast.py:17867>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:17867
      if Match_1_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_14 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Match_1_1.Node, Origin => Origin, E_Info => Match_1_1.Info);
--# end
--# expr-done 9991
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_15 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Fld_14.Node, Origin => Origin, E_Info => Fld_14.Info);
--# end
--# expr-done 9992
      Cast_Result := Create_Internal_Entity
        (Node => Fld_15.Node,
         Info => Fld_15.Info);
Bind_Result_1 := Solver.Create_Assign (Fld_13, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17866") else null)); 
--# expr-done 9993
And_Pred_2 := Create_And (Fld_10, Bind_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17865") else null)); 
--# expr-done 9994
Let_Result_1 := And_Pred_2; Inc_Ref (Let_Result_1);
--# end
Scope_Result_2 := Let_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_3101;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Attribute_Ref
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind r Match_2
--# expr-start 10001 '<And at ast.py:17870>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:17870
--# expr-start 9995 '<FieldAccess for sub_equation at ast.py:17870>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:17870
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_16 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_2.Node, Env => Env, Origin => Origin, E_Info => Match_2.Info);
--# end
--# expr-done 9995
--# expr-start 10000 '<Bind at ast.py:17871>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:17871
--# expr-start 9998 '<FieldAccess for type_var at ast.py:17871>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:17871
--# expr-start 9997 '<FieldAccess for id at ast.py:17871>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:17871
--# expr-start 9996 '<FieldAccess for var_decl at ast.py:17871>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:17871
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 9996
      if Fld_17 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Fld_17.For_Loop_Var_Decl_F_Id;
--# expr-done 9997
      if Fld_18 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_18);
--# expr-done 9998
Fld_19.Value := No_Entity;
Entity_Vars.Reset (Fld_19);
--# expr-start 9999 '<FieldAccess for type_var at ast.py:17871>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:17871
      if Match_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Match_2.Node);
--# expr-done 9999
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
Bind_Result_2 := Solver.Create_Unify (Fld_19, Fld_20, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17871") else null)); 
--# expr-done 10000
And_Pred_3 := Create_And (Fld_16, Bind_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17870") else null)); 
--# expr-done 10001
Let_Result_2 := And_Pred_3; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_3102;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Call_Expr .. Ada_Update_Attribute_Ref =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity_Name
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_5; 
--# bind t Match_3
--# expr-start 10002 '<FieldAccess for name_designated_type at ast.py:17877>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:17877
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_21 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Match_3.Node, E_Info => Match_3.Info);
--# end
--# expr-done 10002
Var_Expr := Fld_21;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind typ Var_Expr
--# expr-start 10009 '<And at ast.py:17879>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:17879
--# expr-start 10003 '<FieldAccess for sub_equation at ast.py:17879>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:17879
      if Match_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_22 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_3.Node, Env => Env, Origin => Origin, E_Info => Match_3.Info);
--# end
--# expr-done 10003
--# expr-start 10008 '<Bind at ast.py:17880>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:17880
--# expr-start 10006 '<FieldAccess for type_var at ast.py:17880>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:17880
--# expr-start 10005 '<FieldAccess for id at ast.py:17880>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:17880
--# expr-start 10004 '<FieldAccess for var_decl at ast.py:17880>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:17880
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_23 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 10004
      if Fld_23 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Fld_23.For_Loop_Var_Decl_F_Id;
--# expr-done 10005
      if Fld_24 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_25 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_24);
--# expr-done 10006
Fld_25.Value := No_Entity;
Entity_Vars.Reset (Fld_25);
--# expr-start 10007 '<FieldAccess for canonical_type at ast.py:17880>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:17880
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_26 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10007
      Cast_Result_1 := Create_Internal_Entity
        (Node => Fld_26.Node,
         Info => Fld_26.Info);
Bind_Result_3 := Solver.Create_Assign (Fld_25, Cast_Result_1, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17880") else null)); 
--# expr-done 10008
And_Pred_4 := Create_And (Fld_22, Bind_Result_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17879") else null)); 
--# expr-done 10009
Scope_Result := And_Pred_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3104;
   Result_Var := Scope_Result;
else
   --# expr-start 10010 '<FieldAccess for iterator_xref_equation at ast.py:17881>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:17881
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ForLoopSpec.iterator_xref_equation
Fld_27 := Libadalang.Implementation.For_Loop_Spec_P_Iterator_Xref_Equation (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 10010
   Result_Var := Fld_27;
end if;
      Inc_Ref (Result_Var);
Let_Result_3 := Result_Var; Inc_Ref (Let_Result_3);
--# end
Scope_Result_4 := Let_Result_3;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_3103;
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Null_Record_Aggregate | Ada_Box_Expr .. Ada_Membership_Expr | Ada_Paren_Expr .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_6 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_4 := Cast_Result_6; 
--# bind _ Match_4
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17884") else null)); 
Let_Result_4 := True_Rel; Inc_Ref (Let_Result_4);
--# end
Scope_Result_5 := Let_Result_4;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_3105;
            Match_Result := Scope_Result_5; Inc_Ref (Match_Result);
end case;
--# expr-done 10011
Let_Result_6 := Match_Result; Inc_Ref (Let_Result_6);
--# end
Scope_Result_6 := Let_Result_6;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_3099;
            Match_Result_1 := Scope_Result_6; Inc_Ref (Match_Result_1);
         when Ada_Iter_Type_Of =>
   --# scope-start
--# scope-start
      Cast_Result_9 := Match_Prefix_1;
Match_1 := Cast_Result_9; 
--# bind _ Match_1
--# expr-start 10020 '<Let at ast.py:17888>' Let_Result_5 /tmp/lal-23.0.0/ada/ast.py:17888
--# scope-start
--# expr-start 10012 '<FieldAccess for iter_type at ast.py:17888>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:17888
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ForLoopSpec.iter_type
Fld_28 := Libadalang.Implementation.For_Loop_Spec_P_Iter_Type (Node => Ent.Node, Env => Env, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 10012
It_Typ := Fld_28; 
--# bind it_typ It_Typ
--# expr-start 10019 '<If at ast.py:17888>' If_Result /tmp/lal-23.0.0/ada/ast.py:17888
--# expr-start 10013 '<FieldAccess for is_iterable_type at ast.py:17889>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:17889
      if It_Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_iterable_type'
Fld_33 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Iterable_Type (Node => It_Typ.Node, Origin => Origin, E_Info => It_Typ.Info);
--# end
--# expr-done 10013
if Fld_33 then
   --# expr-start 10018 '<Bind at ast.py:17893>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:17893
--# expr-start 10016 '<FieldAccess for type_var at ast.py:17893>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:17893
--# expr-start 10015 '<FieldAccess for id at ast.py:17893>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:17893
--# expr-start 10014 '<FieldAccess for var_decl at ast.py:17893>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:17893
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_29 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 10014
      if Fld_29 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_30 := Fld_29.For_Loop_Var_Decl_F_Id;
--# expr-done 10015
      if Fld_30 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_30);
--# expr-done 10016
Fld_31.Value := No_Entity;
Entity_Vars.Reset (Fld_31);
--# expr-start 10017 '<FieldAccess for iterable_comp_type at ast.py:17893>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:17893
      if It_Typ.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.iterable_comp_type'
Fld_32 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Iterable_Comp_Type (Node => It_Typ.Node, Origin => Origin, E_Info => It_Typ.Info);
--# end
--# expr-done 10017
      Cast_Result_7 := Create_Internal_Entity
        (Node => Fld_32.Node,
         Info => Fld_32.Info);
Bind_Result_4 := Solver.Create_Assign (Fld_31, Cast_Result_7, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17893") else null)); 
--# expr-done 10018
   If_Result := Bind_Result_4;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17895") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 10019
Let_Result_5 := If_Result; Inc_Ref (Let_Result_5);
--# end
--# expr-done 10020
Let_Result_7 := Let_Result_5; Inc_Ref (Let_Result_7);
--# end
Scope_Result_7 := Let_Result_7;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_3106;
            Match_Result_1 := Scope_Result_7; Inc_Ref (Match_Result_1);
end case;
--# expr-done 10021
And_Pred_5 := Create_And (Fld_1, Match_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17847") else null)); 
--# expr-done 10022
--# expr-start 10037 '<If at ast.py:17897>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:17897
--# expr-start 10024 '<IsNull at ast.py:17898>' Is_Null /tmp/lal-23.0.0/ada/ast.py:17898
--# expr-start 10023 '<FieldAccess for iter_filter at ast.py:17898>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:17898
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_42 := Create_Internal_Entity_Expr (Node => Ent.Node.For_Loop_Spec_F_Iter_Filter, Info => Ent.Info);
--# expr-done 10023
Is_Null := Fld_42.Node = null; 
--# expr-done 10024
if Is_Null then
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17899") else null)); 
   If_Result_1 := True_Rel_1;
else
   --# expr-start 10036 '<And at ast.py:17900>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:17900
--# expr-start 10033 '<And at ast.py:17900>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:17900
--# expr-start 10028 '<Bind at ast.py:17900>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:17900
--# expr-start 10026 '<FieldAccess for expected_type_var at ast.py:17900>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:17900
--# expr-start 10025 '<FieldAccess for iter_filter at ast.py:17900>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:17900
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_34 := Self.For_Loop_Spec_F_Iter_Filter;
--# expr-done 10025
      if Fld_34 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_35 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_34);
--# expr-done 10026
Fld_35.Value := No_Entity;
Entity_Vars.Reset (Fld_35);
--# expr-start 10027 '<FieldAccess for bool_type at ast.py:17900>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:17900
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_36 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10027
      Cast_Result_10 := Create_Internal_Entity
        (Node => Fld_36.Node,
         Info => Fld_36.Info);
Bind_Result_5 := Solver.Create_Assign (Fld_35, Cast_Result_10, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17900") else null)); 
--# expr-done 10028
--# expr-start 10032 '<Bind at ast.py:17901>' Bind_Result_6 /tmp/lal-23.0.0/ada/ast.py:17901
--# expr-start 10030 '<FieldAccess for type_var at ast.py:17901>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:17901
--# expr-start 10029 '<FieldAccess for iter_filter at ast.py:17901>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:17901
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_37 := Self.For_Loop_Spec_F_Iter_Filter;
--# expr-done 10029
      if Fld_37 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_38 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_37);
--# expr-done 10030
Fld_38.Value := No_Entity;
Entity_Vars.Reset (Fld_38);
--# expr-start 10031 '<FieldAccess for bool_type at ast.py:17901>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:17901
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_39 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10031
      Cast_Result_11 := Create_Internal_Entity
        (Node => Fld_39.Node,
         Info => Fld_39.Info);
Bind_Result_6 := Solver.Create_Assign (Fld_38, Cast_Result_11, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17901") else null)); 
--# expr-done 10032
And_Pred_6 := Create_And (Bind_Result_5, Bind_Result_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17900") else null)); 
--# expr-done 10033
--# expr-start 10035 '<FieldAccess for sub_equation at ast.py:17902>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:17902
--# expr-start 10034 '<FieldAccess for iter_filter at ast.py:17902>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:17902
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_40 := Create_Internal_Entity_Expr (Node => Ent.Node.For_Loop_Spec_F_Iter_Filter, Info => Ent.Info);
--# expr-done 10034
      if Fld_40.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_41 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_40.Node, Env => Env, Origin => Origin, E_Info => Fld_40.Info);
--# end
--# expr-done 10035
And_Pred_7 := Create_And (And_Pred_6, Fld_41, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17900") else null)); 
--# expr-done 10036
   If_Result_1 := And_Pred_7;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 10037
And_Pred_8 := Create_And (And_Pred_5, If_Result_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17847") else null)); 
--# expr-done 10038
Let_Result_8 := And_Pred_8; Inc_Ref (Let_Result_8);
--# end
--# expr-done 10039
      Property_Result := Let_Result_8;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1282;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1282;
               Finalizer_Scope_3099;
               Finalizer_Scope_3100;
               Finalizer_Scope_3101;
               Finalizer_Scope_3102;
               Finalizer_Scope_3103;
               Finalizer_Scope_3104;
               Finalizer_Scope_3105;
               Finalizer_Scope_3106;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Spec_P_Xref_Equation;
--# end
--# property-start ForLoopSpec.iterator_xref_equation /tmp/lal-23.0.0/ada/ast.py:17906
pragma Warnings (Off, "is not referenced");
 function For_Loop_Spec_P_Iterator_Xref_Equation
  (Node : Bare_For_Loop_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_For_Loop_Spec := Bare_For_Loop_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_For_Loop_Spec :=
     Internal_Entity_For_Loop_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1283 with Inline_Always;
      Block_Var : Internal_Entity_Expr;
Block_Var_1 : Boolean;
Block_Var_2 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Pred : Logic_Equation;
Fld_2 : Boolean;
Fld_3 : Internal_Entity;
Fld_4 : Lexical_Env := Empty_Env;
Sym : Symbol_Type;
Env_Get_Result : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_5 : Bare_For_Loop_Var_Decl;
Fld_6 : Bare_Defining_Name;
Fld_7 : Logic_Var;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result : Logic_Equation;
False_Rel : Logic_Equation;
If_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1283 is
            begin
                     Dec_Ref (Pred);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (False_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1283;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10055 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10041 '<Cast to Expr at ast.py:17907>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17907
--# expr-start 10040 '<FieldAccess for iter_expr at ast.py:17907>' Fld /tmp/lal-23.0.0/ada/ast.py:17907
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity (Node => Ent.Node.For_Loop_Spec_F_Iter_Expr, Info => Ent.Info);
--# expr-done 10040
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Expr
   then
      Cast_Result := Create_Internal_Entity_Expr
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 10041
Block_Var := Cast_Result; 
--# bind iter_expr Block_Var
--# expr-start 10044 '<FieldAccess for resolve_names_internal_with_eq at ast.py:17909>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17909
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10043 '<Predicate on BaseTypeDecl.is_iterator_type at ast.py:17910>' Pred /tmp/lal-23.0.0/ada/ast.py:17910
--# expr-start 10042 '<FieldAccess for type_var at ast.py:17911>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17911
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Block_Var.Node);
--# expr-done 10042
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
Pred := Solver.Create_Predicate (Fld_1, Create_Base_Type_Decl_P_Is_Iterator_Type_0_Predicate (Origin)); 
--# expr-done 10043
--# property-call-start AdaNode.resolve_names_internal_with_eq
Fld_2 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal_With_Eq (Node => Block_Var.Node, Additional_Equation => Pred, Env => Env, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 10044
Block_Var_1 := Fld_2; 
--# bind p Block_Var_1
--# expr-start 10049 '<Cast to BaseTypeDecl at ast.py:17915>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:17915
--# expr-start 10048 '<EnvGet at ast.py:17915>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:17915
--# expr-start 10046 '<FieldAccess for children_env at ast.py:17914>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17914
--# expr-start 10045 '<FieldAccess for type_val at ast.py:17914>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17914
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_3 := Libadalang.Implementation.Expr_P_Type_Val (Node => Block_Var.Node);
--# end
--# expr-done 10045
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Children_Env (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# expr-done 10046
--# expr-start 10047 '<Symbol Cursor at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Cursor); 
--# expr-done 10047
Env_Get_Result := AST_Envs.Get_First (Self => Fld_4, Key => Sym, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 10048
   if Env_Get_Result.Node = null
      or else Env_Get_Result.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Env_Get_Result.Node,
         Info => Env_Get_Result.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 10049
Block_Var_2 := Cast_Result_1; 
--# bind cursor_type Block_Var_2
--# expr-start 10054 '<If at ast.py:17917>' If_Result /tmp/lal-23.0.0/ada/ast.py:17917
if Block_Var_1 then
   --# expr-start 10053 '<Bind at ast.py:17919>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:17919
--# expr-start 10052 '<FieldAccess for type_var at ast.py:17919>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17919
--# expr-start 10051 '<FieldAccess for id at ast.py:17919>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17919
--# expr-start 10050 '<FieldAccess for var_decl at ast.py:17919>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17919
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.For_Loop_Spec_F_Var_Decl;
--# expr-done 10050
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Fld_5.For_Loop_Var_Decl_F_Id;
--# expr-done 10051
      if Fld_6 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_6);
--# expr-done 10052
Fld_7.Value := No_Entity;
Entity_Vars.Reset (Fld_7);
Cast_Expr := Block_Var_2; 
      Cast_Result_2 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Bind_Result := Solver.Create_Assign (Fld_7, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17919") else null)); 
--# expr-done 10053
   If_Result := Bind_Result;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:17920") else null)); 
   If_Result := False_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 10054
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 10055
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1283;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1283;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Spec_P_Iterator_Xref_Equation;
--# end
--# property-start ForLoopSpec.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:17926
pragma Warnings (Off, "is not referenced");
 function For_Loop_Spec_P_Xref_Entry_Point
  (Node : Bare_For_Loop_Spec
  )
   return Boolean
is
   Self : Bare_For_Loop_Spec := Bare_For_Loop_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10057 '<Not at ast.py:17926>' Not_Val /tmp/lal-23.0.0/ada/ast.py:17926
--# expr-start 10056 '<FieldAccess for is_iterated_assoc_spec at ast.py:17926>' Fld /tmp/lal-23.0.0/ada/ast.py:17926
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ForLoopSpec.is_iterated_assoc_spec
Fld := Libadalang.Implementation.For_Loop_Spec_P_Is_Iterated_Assoc_Spec (Node => Self);
--# end
--# expr-done 10056
Not_Val := not (Fld); 
--# expr-done 10057
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end For_Loop_Spec_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_While_Loop_Spec
   --
      procedure Initialize_Fields_For_While_Loop_Spec
        (Self : Bare_While_Loop_Spec
         ; While_Loop_Spec_F_Expr : Bare_Expr
        ) is
      begin
            Self.While_Loop_Spec_F_Expr := While_Loop_Spec_F_Expr;
      end Initialize_Fields_For_While_Loop_Spec;
   function While_Loop_Spec_F_Expr
     (Node : Bare_While_Loop_Spec) return Bare_Expr
   is
   begin
         return Node.While_Loop_Spec_F_Expr;
   end;
--# property-start WhileLoopSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:19973
pragma Warnings (Off, "is not referenced");
 function While_Loop_Spec_P_Xref_Equation
  (Node : Bare_While_Loop_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_While_Loop_Spec := Bare_While_Loop_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_While_Loop_Spec :=
     Internal_Entity_While_Loop_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1408 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1408 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1408;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10068 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10067 '<And at ast.py:19974>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19974
--# expr-start 10064 '<And at ast.py:19974>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19974
--# expr-start 10061 '<Bind at ast.py:19975>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19975
--# expr-start 10059 '<FieldAccess for expected_type_var at ast.py:19975>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19975
--# expr-start 10058 '<FieldAccess for expr at ast.py:19975>' Fld /tmp/lal-23.0.0/ada/ast.py:19975
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.While_Loop_Spec_F_Expr;
--# expr-done 10058
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 10059
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10060 '<FieldAccess for bool_type at ast.py:19975>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19975
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10060
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19975") else null)); 
--# expr-done 10061
--# expr-start 10063 '<FieldAccess for sub_equation at ast.py:19976>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19976
--# expr-start 10062 '<FieldAccess for expr at ast.py:19976>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19976
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.While_Loop_Spec_F_Expr, Info => Ent.Info);
--# expr-done 10062
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 10063
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19974") else null)); 
--# expr-done 10064
--# expr-start 10066 '<FieldAccess for matches_expected_formal_prim_type at ast.py:19977>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19977
--# expr-start 10065 '<FieldAccess for expr at ast.py:19977>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19977
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.While_Loop_Spec_F_Expr, Info => Ent.Info);
--# expr-done 10065
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 10066
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19974") else null)); 
--# expr-done 10067
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10068
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1408;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1408;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end While_Loop_Spec_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Mode
   --
--# property-start Mode.is_writable /tmp/lal-23.0.0/ada/ast.py:9225
pragma Warnings (Off, "is not referenced");
 function Mode_P_Is_Writable
  (Node : Bare_Mode
  )
   return Boolean
is
   Self : Bare_Mode := Bare_Mode (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Is_A : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10070 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10069 '<IsA Mode.Out, Mode.InOut at ast.py:9230>' Is_A /tmp/lal-23.0.0/ada/ast.py:9230
Is_A := Self /= null 
and then Self.Kind in Ada_Mode_Out_Range | Ada_Mode_In_Out_Range; 
--# expr-done 10069
Let_Result := Is_A; 
--# end
--# expr-done 10070
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Mode_P_Is_Writable;
--# end
   --
   --  Primitives for Bare_Mode_Default
   --
   --
   --  Primitives for Bare_Mode_In
   --
   --
   --  Primitives for Bare_Mode_In_Out
   --
   --
   --  Primitives for Bare_Mode_Out
   --
   --
   --  Primitives for Bare_Multi_Abstract_State_Decl
   --
      procedure Initialize_Fields_For_Multi_Abstract_State_Decl
        (Self : Bare_Multi_Abstract_State_Decl
         ; Multi_Abstract_State_Decl_F_Decls : Bare_Abstract_State_Decl_List
        ) is
      begin
            Self.Multi_Abstract_State_Decl_F_Decls := Multi_Abstract_State_Decl_F_Decls;
      end Initialize_Fields_For_Multi_Abstract_State_Decl;
   function Multi_Abstract_State_Decl_F_Decls
     (Node : Bare_Multi_Abstract_State_Decl) return Bare_Abstract_State_Decl_List
   is
   begin
         return Node.Multi_Abstract_State_Decl_F_Decls;
   end;
   --
   --  Primitives for Bare_Not_Null
   --
--# property-start '[dispatcher]NotNull.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Not_Null_P_As_Bool
  (Node : Bare_Not_Null
  )
   return Boolean
is
   Self : Bare_Not_Null := Bare_Not_Null (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Not_Null (Self.Kind) is
               when Ada_Not_Null_Absent =>
                  --# property-call-start NotNull.Absent.as_bool
                  Property_Result := Not_Null_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Not_Null_Present =>
                  --# property-call-start NotNull.Present.as_bool
                  Property_Result := Not_Null_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Not_Null_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Not_Null_Absent
   --
--# property-start NotNull.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5005
pragma Warnings (Off, "is not referenced");
 function Not_Null_Absent_P_As_Bool
  (Node : Bare_Not_Null_Absent
  )
   return Boolean
is
   Self : Bare_Not_Null_Absent := Bare_Not_Null_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Not_Null_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Not_Null_Present
   --
--# property-start NotNull.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5005
pragma Warnings (Off, "is not referenced");
 function Not_Null_Present_P_As_Bool
  (Node : Bare_Not_Null_Present
  )
   return Boolean
is
   Self : Bare_Not_Null_Present := Bare_Not_Null_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Not_Null_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Null_Component_Decl
   --
   --
   --  Primitives for Bare_Others_Designator
   --
--# property-start OthersDesignator.xref_equation /tmp/lal-23.0.0/ada/ast.py:15362
pragma Warnings (Off, "is not referenced");
 function Others_Designator_P_Xref_Equation
  (Node : Bare_Others_Designator
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Others_Designator := Bare_Others_Designator (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1108 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_1108 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_1108;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:15362") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1108;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1108;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Others_Designator_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Overriding_Node
   --
   --
   --  Primitives for Bare_Overriding_Not_Overriding
   --
   --
   --  Primitives for Bare_Overriding_Overriding
   --
   --
   --  Primitives for Bare_Overriding_Unspecified
   --
   --
   --  Primitives for Bare_Params
   --
      procedure Initialize_Fields_For_Params
        (Self : Bare_Params
         ; Params_F_Params : Bare_Param_Spec_List
        ) is
      begin
            Self.Params_F_Params := Params_F_Params;
      end Initialize_Fields_For_Params;
   function Params_F_Params
     (Node : Bare_Params) return Bare_Param_Spec_List
   is
   begin
         return Node.Params_F_Params;
   end;
   --
   --  Primitives for Bare_Paren_Abstract_State_Decl
   --
      procedure Initialize_Fields_For_Paren_Abstract_State_Decl
        (Self : Bare_Paren_Abstract_State_Decl
         ; Paren_Abstract_State_Decl_F_Decl : Bare_Ada_Node
        ) is
      begin
            Self.Paren_Abstract_State_Decl_F_Decl := Paren_Abstract_State_Decl_F_Decl;
      end Initialize_Fields_For_Paren_Abstract_State_Decl;
   function Paren_Abstract_State_Decl_F_Decl
     (Node : Bare_Paren_Abstract_State_Decl) return Bare_Ada_Node
   is
   begin
         return Node.Paren_Abstract_State_Decl_F_Decl;
   end;
   --
   --  Primitives for Bare_Pp_Directive
   --
   --
   --  Primitives for Bare_Pp_Else_Directive
   --
   --
   --  Primitives for Bare_Pp_Elsif_Directive
   --
      procedure Initialize_Fields_For_Pp_Elsif_Directive
        (Self : Bare_Pp_Elsif_Directive
         ; Pp_Elsif_Directive_F_Expr : Bare_Expr
         ; Pp_Elsif_Directive_F_Then_Kw : Bare_Pp_Then_Kw
        ) is
      begin
            Self.Pp_Elsif_Directive_F_Expr := Pp_Elsif_Directive_F_Expr;
            Self.Pp_Elsif_Directive_F_Then_Kw := Pp_Elsif_Directive_F_Then_Kw;
      end Initialize_Fields_For_Pp_Elsif_Directive;
   function Pp_Elsif_Directive_F_Expr
     (Node : Bare_Pp_Elsif_Directive) return Bare_Expr
   is
   begin
         return Node.Pp_Elsif_Directive_F_Expr;
   end;
   function Pp_Elsif_Directive_F_Then_Kw
     (Node : Bare_Pp_Elsif_Directive) return Bare_Pp_Then_Kw
   is
   begin
         return Node.Pp_Elsif_Directive_F_Then_Kw;
   end;
   --
   --  Primitives for Bare_Pp_End_If_Directive
   --
   --
   --  Primitives for Bare_Pp_If_Directive
   --
      procedure Initialize_Fields_For_Pp_If_Directive
        (Self : Bare_Pp_If_Directive
         ; Pp_If_Directive_F_Expr : Bare_Expr
         ; Pp_If_Directive_F_Then_Kw : Bare_Pp_Then_Kw
        ) is
      begin
            Self.Pp_If_Directive_F_Expr := Pp_If_Directive_F_Expr;
            Self.Pp_If_Directive_F_Then_Kw := Pp_If_Directive_F_Then_Kw;
      end Initialize_Fields_For_Pp_If_Directive;
   function Pp_If_Directive_F_Expr
     (Node : Bare_Pp_If_Directive) return Bare_Expr
   is
   begin
         return Node.Pp_If_Directive_F_Expr;
   end;
   function Pp_If_Directive_F_Then_Kw
     (Node : Bare_Pp_If_Directive) return Bare_Pp_Then_Kw
   is
   begin
         return Node.Pp_If_Directive_F_Then_Kw;
   end;
   --
   --  Primitives for Bare_Pp_Then_Kw
   --
   --
   --  Primitives for Bare_Pragma_Node
   --
      procedure Pragma_Pre_Env_Actions
        (Self            : Bare_Pragma_Node;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_36 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:9802");
      end;
      end;
      procedure Initialize_Fields_For_Pragma_Node
        (Self : Bare_Pragma_Node
         ; Pragma_Node_F_Id : Bare_Identifier
         ; Pragma_Node_F_Args : Bare_Base_Assoc_List
        ) is
      begin
            Self.Pragma_Node_F_Id := Pragma_Node_F_Id;
            Self.Pragma_Node_F_Args := Pragma_Node_F_Args;
      end Initialize_Fields_For_Pragma_Node;
   function Pragma_Node_F_Id
     (Node : Bare_Pragma_Node) return Bare_Identifier
   is
   begin
         return Node.Pragma_Node_F_Id;
   end;
   function Pragma_Node_F_Args
     (Node : Bare_Pragma_Node) return Bare_Base_Assoc_List
   is
   begin
         return Node.Pragma_Node_F_Args;
   end;
--# property-start Pragma.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:9501
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Xref_Entry_Point
  (Node : Bare_Pragma_Node
  )
   return Boolean
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Xref_Entry_Point;
--# end
--# property-start Pragma.is_ghost_code /tmp/lal-23.0.0/ada/ast.py:9504
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Is_Ghost_Code
  (Node : Bare_Pragma_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Fld : Internal_Entity_Identifier;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Identifier;
Fld_3 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_4 : Internal_Entity_Identifier;
Fld_5 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_6 : Internal_Entity_Identifier;
Fld_7 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10087 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10074 '<Eq at ast.py:9510>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10072 '<FieldAccess for sym at ast.py:9510>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10071 '<FieldAccess for id at ast.py:9510>' Fld /tmp/lal-23.0.0/ada/ast.py:9510
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10071
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_1 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld.Node);
--# end
--# expr-done 10072
--# expr-start 10073 '<Symbol Assert at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Assert); 
--# expr-done 10073
Is_Equal := Fld_1 = Sym; 
--# expr-done 10074
if Is_Equal then
   If_Result := True;
else
   --# expr-start 10078 '<Eq at ast.py:9510>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10076 '<FieldAccess for sym at ast.py:9510>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10075 '<FieldAccess for id at ast.py:9510>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9510
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10075
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_3 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_2.Node);
--# end
--# expr-done 10076
--# expr-start 10077 '<Symbol Assert_And_Cut at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Assert_And_Cut); 
--# expr-done 10077
Is_Equal_1 := Fld_3 = Sym_1; 
--# expr-done 10078
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 10082 '<Eq at ast.py:9510>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10080 '<FieldAccess for sym at ast.py:9510>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10079 '<FieldAccess for id at ast.py:9510>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9510
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10079
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_5 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_4.Node);
--# end
--# expr-done 10080
--# expr-start 10081 '<Symbol Assume at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Assume); 
--# expr-done 10081
Is_Equal_2 := Fld_5 = Sym_2; 
--# expr-done 10082
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 10086 '<Eq at ast.py:9510>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10084 '<FieldAccess for sym at ast.py:9510>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9510
--# expr-start 10083 '<FieldAccess for id at ast.py:9510>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9510
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10083
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SingleTokNode.sym
Fld_7 := Libadalang.Implementation.Single_Tok_Node_P_Sym (Node => Fld_6.Node);
--# end
--# expr-done 10084
--# expr-start 10085 '<Symbol Loop_Invariant at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Loop_Invariant); 
--# expr-done 10085
Is_Equal_3 := Fld_7 = Sym_3; 
--# expr-done 10086
   If_Result_2 := Is_Equal_3;
end if;
Let_Result := If_Result_2; 
--# end
--# expr-done 10087
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Is_Ghost_Code;
--# end
--# property-start Pragma.xref_initial_env /tmp/lal-23.0.0/ada/ast.py:9515
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Xref_Initial_Env
  (Node : Bare_Pragma_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_778 with Inline_Always;
      Fld : Internal_Entity_Defining_Name_Array_Access;
Get_Result : Internal_Entity_Defining_Name;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Internal_Entity_Identifier;
Fld_4 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_5 : Internal_Entity_Identifier;
Fld_6 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_7 : Internal_Entity_Identifier;
Fld_8 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_9 : Internal_Entity_Identifier;
Fld_10 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_11 : Internal_Entity_Identifier;
Fld_12 : Symbol_Type;
Sym_4 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_3 : Boolean;
Fld_13 : Internal_Entity_Identifier;
Fld_14 : Symbol_Type;
Sym_5 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_4 : Boolean;
Fld_15 : Internal_Entity_Identifier;
Fld_16 : Symbol_Type;
Sym_6 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_5 : Boolean;
Fld_17 : Internal_Entity_Identifier;
Fld_18 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_6 : Boolean;
Fld_19 : Internal_Entity_Identifier;
Fld_20 : Symbol_Type;
Sym_8 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_7 : Boolean;
Fld_21 : Internal_Entity_Identifier;
Fld_22 : Symbol_Type;
Sym_9 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_8 : Boolean;
If_Result_9 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_778 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_2);
                     Dec_Ref (If_Result_9);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_778;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10133 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10132 '<If at ast.py:9523>' If_Result_9 /tmp/lal-23.0.0/ada/ast.py:9523
--# expr-start 10091 '<Eq at ast.py:9524>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10089 '<FieldAccess for name_symbol at ast.py:9524>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10088 '<FieldAccess for id at ast.py:9524>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10088
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_3.Node);
--# end
--# expr-done 10089
--# expr-start 10090 '<Symbol Pre at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre); 
--# expr-done 10090
Is_Equal := Fld_4 = Sym; 
--# expr-done 10091
if Is_Equal then
   If_Result := True;
else
   --# expr-start 10095 '<Eq at ast.py:9524>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10093 '<FieldAccess for name_symbol at ast.py:9524>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10092 '<FieldAccess for id at ast.py:9524>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10092
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_5.Node);
--# end
--# expr-done 10093
--# expr-start 10094 '<Symbol Post at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post); 
--# expr-done 10094
Is_Equal_1 := Fld_6 = Sym_1; 
--# expr-done 10095
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 10099 '<Eq at ast.py:9524>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10097 '<FieldAccess for name_symbol at ast.py:9524>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10096 '<FieldAccess for id at ast.py:9524>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10096
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_8 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_7.Node);
--# end
--# expr-done 10097
--# expr-start 10098 '<Symbol Pre'"'"'Class at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre_Class); 
--# expr-done 10098
Is_Equal_2 := Fld_8 = Sym_2; 
--# expr-done 10099
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 10103 '<Eq at ast.py:9524>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10101 '<FieldAccess for name_symbol at ast.py:9524>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10100 '<FieldAccess for id at ast.py:9524>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10100
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_10 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_9.Node);
--# end
--# expr-done 10101
--# expr-start 10102 '<Symbol Post'"'"'Class at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post_Class); 
--# expr-done 10102
Is_Equal_3 := Fld_10 = Sym_3; 
--# expr-done 10103
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 10107 '<Eq at ast.py:9524>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10105 '<FieldAccess for name_symbol at ast.py:9524>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10104 '<FieldAccess for id at ast.py:9524>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10104
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_12 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_11.Node);
--# end
--# expr-done 10105
--# expr-start 10106 '<Symbol Precondition at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Precondition); 
--# expr-done 10106
Is_Equal_4 := Fld_12 = Sym_4; 
--# expr-done 10107
   If_Result_3 := Is_Equal_4;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 10111 '<Eq at ast.py:9524>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10109 '<FieldAccess for name_symbol at ast.py:9524>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10108 '<FieldAccess for id at ast.py:9524>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10108
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_14 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_13.Node);
--# end
--# expr-done 10109
--# expr-start 10110 '<Symbol Postcondition at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Postcondition); 
--# expr-done 10110
Is_Equal_5 := Fld_14 = Sym_5; 
--# expr-done 10111
   If_Result_4 := Is_Equal_5;
end if;
if If_Result_4 then
   If_Result_5 := True;
else
   --# expr-start 10115 '<Eq at ast.py:9524>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10113 '<FieldAccess for name_symbol at ast.py:9524>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10112 '<FieldAccess for id at ast.py:9524>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10112
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_16 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_15.Node);
--# end
--# expr-done 10113
--# expr-start 10114 '<Symbol Precondition'"'"'Class at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Precondition_Class); 
--# expr-done 10114
Is_Equal_6 := Fld_16 = Sym_6; 
--# expr-done 10115
   If_Result_5 := Is_Equal_6;
end if;
if If_Result_5 then
   If_Result_6 := True;
else
   --# expr-start 10119 '<Eq at ast.py:9524>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10117 '<FieldAccess for name_symbol at ast.py:9524>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10116 '<FieldAccess for id at ast.py:9524>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_17 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10116
      if Fld_17.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_18 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_17.Node);
--# end
--# expr-done 10117
--# expr-start 10118 '<Symbol Postcondition'"'"'Class at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Postcondition_Class); 
--# expr-done 10118
Is_Equal_7 := Fld_18 = Sym_7; 
--# expr-done 10119
   If_Result_6 := Is_Equal_7;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 10123 '<Eq at ast.py:9524>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10121 '<FieldAccess for name_symbol at ast.py:9524>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10120 '<FieldAccess for id at ast.py:9524>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10120
      if Fld_19.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_20 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_19.Node);
--# end
--# expr-done 10121
--# expr-start 10122 '<Symbol Test_Case at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Test_Case); 
--# expr-done 10122
Is_Equal_8 := Fld_20 = Sym_8; 
--# expr-done 10123
   If_Result_7 := Is_Equal_8;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 10127 '<Eq at ast.py:9524>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10125 '<FieldAccess for name_symbol at ast.py:9524>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:9524
--# expr-start 10124 '<FieldAccess for id at ast.py:9524>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:9524
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_21 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10124
      if Fld_21.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_22 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_21.Node);
--# end
--# expr-done 10125
--# expr-start 10126 '<Symbol Contract_Cases at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 10126
Is_Equal_9 := Fld_22 = Sym_9; 
--# expr-done 10127
   If_Result_8 := Is_Equal_9;
end if;
if If_Result_8 then
   --# expr-start 10130 '<FieldAccess for children_env at ast.py:9530>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9530
--# expr-start 10129 '<at at ast.py:9530>' Get_Result /tmp/lal-23.0.0/ada/ast.py:9530
--# expr-start 10128 '<FieldAccess for associated_entities at ast.py:9530>' Fld /tmp/lal-23.0.0/ada/ast.py:9530
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.associated_entities
Fld := Libadalang.Implementation.Pragma_Node_P_Associated_Entities (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10128
Get_Result := Get (Self, Fld, 0, True); 
--# expr-done 10129
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Get_Result.Node, E_Info => Get_Result.Info);
--# expr-done 10130
   If_Result_9 := Fld_1;
else
   --# expr-start 10131 '<FieldAccess for children_env at ast.py:9531>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9531
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 10131
   If_Result_9 := Fld_2;
end if;
      Inc_Ref (If_Result_9);
--# expr-done 10132
Let_Result := If_Result_9; Inc_Ref (Let_Result);
--# end
--# expr-done 10133
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_778;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_778;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Xref_Initial_Env;
--# end
--# property-start Pragma.xref_equation /tmp/lal-23.0.0/ada/ast.py:9535
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Xref_Equation
  (Node : Bare_Pragma_Node
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_779 with Inline_Always;
            procedure Finalizer_Scope_3108 with Inline_Always;
            procedure Finalizer_Scope_3109 with Inline_Always;
            procedure Finalizer_Scope_3110 with Inline_Always;
            procedure Finalizer_Scope_3112 with Inline_Always;
            procedure Finalizer_Scope_3113 with Inline_Always;
            procedure Finalizer_Scope_3117 with Inline_Always;
            procedure Finalizer_Scope_3118 with Inline_Always;
            procedure Finalizer_Scope_3120 with Inline_Always;
      Expr : Internal_Entity_Expr;
Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Base_Assoc;
Var_Expr_2 : Internal_Entity_Expr;
Var_Expr_3 : Internal_Entity_Base_Assoc;
Var_Expr_4 : Internal_Entity_Expr;
Var_Expr_5 : Internal_Entity_Pragma_Argument_Assoc;
Expr_1 : Internal_Entity_Expr;
Proc : Internal_Entity_Expr;
Var_Expr_6 : Internal_Entity_Base_Assoc;
Fld : Internal_Entity_Identifier;
Sym : Symbol_Type;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Identifier;
Sym_1 : Symbol_Type;
Fld_3 : Boolean;
If_Result : Boolean;
Fld_4 : Internal_Entity_Identifier;
Sym_2 : Symbol_Type;
Fld_5 : Boolean;
If_Result_1 : Boolean;
Fld_6 : Internal_Entity_Identifier;
Sym_3 : Symbol_Type;
Fld_7 : Boolean;
If_Result_2 : Boolean;
Fld_8 : Internal_Entity_Base_Assoc_List;
Fld_9 : Bare_Base_Assoc_List;
Fld_10 : Internal_Entity_Info;
Get_Result : Bare_Base_Assoc;
As_Entity : Internal_Entity_Base_Assoc;
Is_Null : Boolean;
If_Result_3 : Internal_Entity_Base_Assoc;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Logic_Var;
Fld_13 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_14 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_15 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
Fld_16 : Internal_Entity_Base_Assoc_List;
Fld_17 : Bare_Base_Assoc_List;
Fld_18 : Internal_Entity_Info;
Get_Result_1 : Bare_Base_Assoc;
As_Entity_1 : Internal_Entity_Base_Assoc;
Is_Null_1 : Boolean;
If_Result_4 : Internal_Entity_Base_Assoc;
Fld_19 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Fld_20 : Logic_Var;
Sym_4 : Symbol_Type;
Fld_21 : Internal_Entity;
Bind_Result_1 : Logic_Equation;
Fld_22 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_23 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_24 : Internal_Entity_Identifier;
Sym_5 : Symbol_Type;
Fld_25 : Boolean;
Fld_26 : Internal_Entity_Base_Assoc_List;
Fld_27 : Bare_Base_Assoc_List;
Fld_28 : Internal_Entity_Info;
As_Entity_2 : Internal_Entity_Base_Assoc;
Is_Null_2 : Boolean;
If_Result_5 : Internal_Entity_Base_Assoc;
Fld_29 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_30 : Logic_Equation;
Item_311 : Internal_Entity_Base_Assoc;
Bare_Item_311 : Bare_Base_Assoc;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Fld_31 : Internal_Entity_Identifier;
Fld_32 : Symbol_Type;
Sym_6 : Symbol_Type;
Is_Equal : Boolean;
Fld_33 : Internal_Entity_Identifier;
Fld_34 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result_6 : Boolean;
Fld_35 : Internal_Entity_Identifier;
Fld_36 : Symbol_Type;
Sym_8 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_7 : Boolean;
Fld_37 : Internal_Entity_Identifier;
Fld_38 : Symbol_Type;
Sym_9 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_8 : Boolean;
Fld_39 : Internal_Entity_Identifier;
Fld_40 : Symbol_Type;
Sym_10 : Symbol_Type;
Is_Equal_4 : Boolean;
If_Result_9 : Boolean;
Fld_41 : Internal_Entity_Identifier;
Fld_42 : Symbol_Type;
Sym_11 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_10 : Boolean;
Fld_43 : Internal_Entity_Identifier;
Fld_44 : Symbol_Type;
Sym_12 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_11 : Boolean;
Fld_45 : Internal_Entity_Identifier;
Fld_46 : Symbol_Type;
Sym_13 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_12 : Boolean;
Fld_47 : Internal_Entity_Identifier;
Fld_48 : Symbol_Type;
Sym_14 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_13 : Boolean;
Fld_49 : Internal_Entity_Identifier;
Fld_50 : Symbol_Type;
Sym_15 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_14 : Boolean;
Fld_51 : Internal_Entity_Name_Array_Access;
Fld_52 : Logic_Equation;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
Fld_53 : Internal_Entity_Identifier;
Sym_16 : Symbol_Type;
Fld_54 : Boolean;
Fld_55 : Internal_Entity_Base_Assoc_List;
Fld_56 : Bare_Base_Assoc_List;
Fld_57 : Internal_Entity_Info;
Get_Result_2 : Bare_Base_Assoc;
As_Entity_3 : Internal_Entity_Base_Assoc;
Is_Null_3 : Boolean;
If_Result_15 : Internal_Entity_Base_Assoc;
Fld_58 : Internal_Entity_Expr;
Scope_Result_2 : Internal_Entity_Expr;
Result_Var_2 : Internal_Entity_Expr;
Fld_59 : Logic_Equation;
Fld_60 : Logic_Var;
Sym_17 : Symbol_Type;
Fld_61 : Internal_Entity;
Bind_Result_2 : Logic_Equation;
Fld_62 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Fld_63 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Is_A : Boolean;
If_Result_16 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_3 : Logic_Equation;
Fld_64 : Internal_Entity_Identifier;
Fld_65 : Symbol_Type;
Sym_18 : Symbol_Type;
Is_Equal_10 : Boolean;
Fld_66 : Internal_Entity_Identifier;
Fld_67 : Symbol_Type;
Sym_19 : Symbol_Type;
Is_Equal_11 : Boolean;
If_Result_17 : Boolean;
Fld_68 : Internal_Entity_Identifier;
Fld_69 : Symbol_Type;
Sym_20 : Symbol_Type;
Is_Equal_12 : Boolean;
If_Result_18 : Boolean;
True_Rel_2 : Logic_Equation;
Fld_70 : Internal_Entity_Identifier;
Fld_71 : Symbol_Type;
Sym_21 : Symbol_Type;
Is_Equal_13 : Boolean;
Fld_72 : Internal_Entity_Identifier;
Fld_73 : Symbol_Type;
Sym_22 : Symbol_Type;
Is_Equal_14 : Boolean;
If_Result_19 : Boolean;
Fld_74 : Internal_Entity_Identifier;
Fld_75 : Symbol_Type;
Sym_23 : Symbol_Type;
Is_Equal_15 : Boolean;
If_Result_20 : Boolean;
Fld_76 : Internal_Entity_Identifier;
Fld_77 : Symbol_Type;
Sym_24 : Symbol_Type;
Is_Equal_16 : Boolean;
If_Result_21 : Boolean;
Fld_78 : Internal_Entity_Identifier;
Fld_79 : Symbol_Type;
Sym_25 : Symbol_Type;
Is_Equal_17 : Boolean;
If_Result_22 : Boolean;
Fld_80 : Internal_Entity_Identifier;
Fld_81 : Symbol_Type;
Sym_26 : Symbol_Type;
Is_Equal_18 : Boolean;
If_Result_23 : Boolean;
Fld_82 : Internal_Entity_Identifier;
Fld_83 : Symbol_Type;
Sym_27 : Symbol_Type;
Is_Equal_19 : Boolean;
If_Result_24 : Boolean;
Fld_84 : Internal_Entity_Identifier;
Fld_85 : Symbol_Type;
Sym_28 : Symbol_Type;
Is_Equal_20 : Boolean;
If_Result_25 : Boolean;
Fld_86 : Internal_Entity_Base_Assoc_List;
Fld_87 : Bare_Base_Assoc_List;
Fld_88 : Internal_Entity_Info;
Get_Result_3 : Bare_Base_Assoc;
As_Entity_4 : Internal_Entity_Base_Assoc;
Is_Null_4 : Boolean;
If_Result_26 : Internal_Entity_Base_Assoc;
Fld_89 : Internal_Entity_Expr;
Fld_90 : Logic_Var;
Fld_91 : Internal_Entity_Base_Type_Decl;
Cast_Result_2 : Internal_Entity;
Bind_Result_3 : Logic_Equation;
Fld_92 : Logic_Equation;
And_Pred_7 : Logic_Equation;
Fld_93 : Logic_Equation;
And_Pred_8 : Logic_Equation;
Scope_Result_4 : Logic_Equation;
False_Rel : Logic_Equation;
Result_Var_4 : Logic_Equation;
Fld_94 : Internal_Entity_Identifier;
Sym_29 : Symbol_Type;
Fld_95 : Boolean;
Fld_96 : Internal_Entity_Base_Assoc_List;
Fld_97 : Bare_Base_Assoc_List;
Fld_98 : Internal_Entity_Info;
As_Entity_5 : Internal_Entity_Base_Assoc;
Is_Null_5 : Boolean;
If_Result_27 : Internal_Entity_Base_Assoc;
Item_314 : Internal_Entity_Base_Assoc;
Bare_Item_314 : Bare_Base_Assoc;
Cast_Expr : Internal_Entity_Base_Assoc;
Cast_Result_3 : Internal_Entity_Pragma_Argument_Assoc;
Fld_99 : Internal_Entity_Name;
Fld_100 : Symbol_Type;
Sym_30 : Symbol_Type;
Is_Equal_21 : Boolean;
Fld_101 : Internal_Entity_Name;
Fld_102 : Symbol_Type;
Sym_31 : Symbol_Type;
Is_Equal_22 : Boolean;
If_Result_28 : Boolean;
Scope_Result_5 : Boolean;
Result_Var_5 : Boolean;
Map_Result_2 : Internal_Entity_Base_Assoc_Array_Access;
Fld_103 : Internal_Entity_Expr;
Fld_104 : Logic_Var;
Fld_105 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result_4 : Logic_Equation;
Fld_106 : Internal_Entity_Expr;
Fld_107 : Logic_Equation;
And_Pred_9 : Logic_Equation;
Fld_108 : Internal_Entity_Expr;
Fld_109 : Logic_Equation;
And_Pred_10 : Logic_Equation;
Map_Result_3 : Logic_Equation_Array_Access;
Logic_Boolean_Op_2 : Logic_Equation;
Fld_110 : Internal_Entity_Identifier;
Sym_32 : Symbol_Type;
Fld_111 : Boolean;
Fld_112 : Internal_Entity_Base_Assoc_List;
Fld_113 : Bare_Base_Assoc_List;
Fld_114 : Internal_Entity_Info;
Get_Result_4 : Bare_Base_Assoc;
As_Entity_6 : Internal_Entity_Base_Assoc;
Is_Null_6 : Boolean;
If_Result_29 : Internal_Entity_Base_Assoc;
Fld_115 : Internal_Entity_Expr;
Cast_Result_5 : Internal_Entity_Base_Aggregate;
Fld_116 : Internal_Entity_Assoc_List;
Fld_117 : Bare_Assoc_List;
Fld_118 : Internal_Entity_Info;
As_Entity_7 : Internal_Entity_Basic_Assoc;
Is_Null_7 : Boolean;
If_Result_30 : Internal_Entity_Basic_Assoc;
Cast_Expr_1 : Internal_Entity_Basic_Assoc;
Cast_Result_6 : Internal_Entity_Aggregate_Assoc;
Fld_119 : Logic_Equation;
Item_315 : Internal_Entity_Basic_Assoc;
Bare_Item_315 : Bare_Basic_Assoc;
Map_Result_4 : Logic_Equation_Array_Access;
Logic_Boolean_Op_3 : Logic_Equation;
Fld_120 : Internal_Entity_Identifier;
Sym_33 : Symbol_Type;
Fld_121 : Boolean;
Fld_122 : Internal_Entity_Base_Assoc_List;
Fld_123 : Bare_Base_Assoc_List;
Fld_124 : Internal_Entity_Info;
Get_Result_5 : Bare_Base_Assoc;
As_Entity_8 : Internal_Entity_Base_Assoc;
Is_Null_8 : Boolean;
If_Result_31 : Internal_Entity_Base_Assoc;
Fld_125 : Internal_Entity_Expr;
Fld_126 : Logic_Var;
Fld_127 : Internal_Entity_Base_Type_Decl;
Cast_Result_7 : Internal_Entity;
Bind_Result_5 : Logic_Equation;
Fld_128 : Logic_Equation;
And_Pred_11 : Logic_Equation;
Fld_129 : Logic_Equation;
And_Pred_12 : Logic_Equation;
Let_Result_1 : Logic_Equation;
True_Rel_3 : Logic_Equation;
Fld_130 : Internal_Entity_Base_Assoc_List;
Fld_131 : Bare_Base_Assoc_List;
Len : Integer;
Is_Equal_23 : Boolean;
If_Result_32 : Logic_Equation;
Fld_132 : Internal_Entity_Base_Assoc_List;
Fld_133 : Bare_Base_Assoc_List;
Len_1 : Integer;
Arith_Result : Integer;
Fld_134 : Internal_Entity_Base_Assoc_List;
Fld_135 : Bare_Base_Assoc_List;
Fld_136 : Internal_Entity_Info;
Get_Result_6 : Bare_Base_Assoc;
As_Entity_9 : Internal_Entity_Base_Assoc;
Is_Null_9 : Boolean;
If_Result_33 : Internal_Entity_Base_Assoc;
Fld_137 : Internal_Entity_Expr;
Scope_Result_6 : Internal_Entity_Expr;
Result_Var_6 : Internal_Entity_Expr;
Fld_138 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_8 : Internal_Entity;
Bind_Result_6 : Logic_Equation;
Fld_139 : Logic_Equation;
And_Pred_13 : Logic_Equation;
Let_Result_2 : Logic_Equation;
And_Pred_14 : Logic_Equation;
Fld_140 : Internal_Entity_Base_Assoc_List;
Fld_141 : Bare_Base_Assoc_List;
Fld_142 : Internal_Entity_Info;
As_Entity_10 : Internal_Entity_Base_Assoc;
Is_Null_10 : Boolean;
If_Result_34 : Internal_Entity_Base_Assoc;
Fld_143 : Internal_Entity_Expr;
Fld_144 : Logic_Equation;
True_Rel_4 : Logic_Equation;
Or_Pred : Logic_Equation;
Item_316 : Internal_Entity_Base_Assoc;
Bare_Item_316 : Bare_Base_Assoc;
Map_Result_5 : Logic_Equation_Array_Access;
Logic_Boolean_Op_4 : Logic_Equation;
If_Result_35 : Logic_Equation;
If_Result_36 : Logic_Equation;
If_Result_37 : Logic_Equation;
If_Result_38 : Logic_Equation;
If_Result_39 : Logic_Equation;
If_Result_40 : Logic_Equation;
If_Result_41 : Logic_Equation;
If_Result_42 : Logic_Equation;
If_Result_43 : Logic_Equation;
Let_Result_3 : Logic_Equation;
            procedure Finalizer_Scope_779 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_14);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_15);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Fld_51);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_3);
                     Dec_Ref (True_Rel_2);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (False_Rel);
                     Dec_Ref (Result_Var_4);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Map_Result_3);
                     Dec_Ref (Logic_Boolean_Op_2);
                     Dec_Ref (Map_Result_4);
                     Dec_Ref (Logic_Boolean_Op_3);
                     Dec_Ref (Bind_Result_5);
                     Dec_Ref (Fld_128);
                     Dec_Ref (And_Pred_11);
                     Dec_Ref (Fld_129);
                     Dec_Ref (And_Pred_12);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (True_Rel_3);
                     Dec_Ref (If_Result_32);
                     Dec_Ref (Bind_Result_6);
                     Dec_Ref (Fld_139);
                     Dec_Ref (And_Pred_13);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (And_Pred_14);
                     Dec_Ref (Map_Result_5);
                     Dec_Ref (Logic_Boolean_Op_4);
                     Dec_Ref (If_Result_35);
                     Dec_Ref (If_Result_36);
                     Dec_Ref (If_Result_37);
                     Dec_Ref (If_Result_38);
                     Dec_Ref (If_Result_39);
                     Dec_Ref (If_Result_40);
                     Dec_Ref (If_Result_41);
                     Dec_Ref (If_Result_42);
                     Dec_Ref (If_Result_43);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_779;
            procedure Finalizer_Scope_3108 is
            begin
                     Dec_Ref (Bind_Result_1);
                     Dec_Ref (Fld_22);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_23);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_3108;
            procedure Finalizer_Scope_3109 is
            begin
                     Dec_Ref (Fld_30);
            end Finalizer_Scope_3109;
            procedure Finalizer_Scope_3110 is
            begin
                     Dec_Ref (Fld_52);
            end Finalizer_Scope_3110;
            procedure Finalizer_Scope_3112 is
            begin
                     Dec_Ref (Fld_59);
                     Dec_Ref (Bind_Result_2);
                     Dec_Ref (Fld_62);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Fld_63);
                     Dec_Ref (And_Pred_6);
                     Dec_Ref (If_Result_16);
            end Finalizer_Scope_3112;
            procedure Finalizer_Scope_3113 is
            begin
                     Dec_Ref (Bind_Result_3);
                     Dec_Ref (Fld_92);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (Fld_93);
                     Dec_Ref (And_Pred_8);
            end Finalizer_Scope_3113;
            procedure Finalizer_Scope_3117 is
            begin
                     Dec_Ref (Bind_Result_4);
                     Dec_Ref (Fld_107);
                     Dec_Ref (And_Pred_9);
                     Dec_Ref (Fld_109);
                     Dec_Ref (And_Pred_10);
            end Finalizer_Scope_3117;
            procedure Finalizer_Scope_3118 is
            begin
                     Dec_Ref (Fld_119);
            end Finalizer_Scope_3118;
            procedure Finalizer_Scope_3120 is
            begin
                     Dec_Ref (Fld_144);
                     Dec_Ref (True_Rel_4);
                     Dec_Ref (Or_Pred);
            end Finalizer_Scope_3120;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10361 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 10360 '<Cond at ast.py:9536>' If_Result_43 /tmp/lal-23.0.0/ada/ast.py:9536
--# expr-start 10136 '<FieldAccess for name_is at ast.py:9538>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9538
--# expr-start 10134 '<FieldAccess for id at ast.py:9538>' Fld /tmp/lal-23.0.0/ada/ast.py:9538
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10134
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10135 '<Symbol Assert at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Assert); 
--# expr-done 10135
--# property-call-start Name.name_is
Fld_1 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld.Node, Sym => Sym);
--# end
--# expr-done 10136
if Fld_1 then
   If_Result := True;
else
   --# expr-start 10139 '<FieldAccess for name_is at ast.py:9539>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9539
--# expr-start 10137 '<FieldAccess for id at ast.py:9539>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9539
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10137
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10138 '<Symbol Loop_Invariant at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Loop_Invariant); 
--# expr-done 10138
--# property-call-start Name.name_is
Fld_3 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_2.Node, Sym => Sym_1);
--# end
--# expr-done 10139
   If_Result := Fld_3;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 10142 '<FieldAccess for name_is at ast.py:9540>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9540
--# expr-start 10140 '<FieldAccess for id at ast.py:9540>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9540
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10140
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10141 '<Symbol Compile_Time_Warning at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Compile_Time_Warning); 
--# expr-done 10141
--# property-call-start Name.name_is
Fld_5 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_4.Node, Sym => Sym_2);
--# end
--# expr-done 10142
   If_Result_1 := Fld_5;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 10145 '<FieldAccess for name_is at ast.py:9541>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9541
--# expr-start 10143 '<FieldAccess for id at ast.py:9541>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9541
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10143
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10144 '<Symbol Compile_Time_Error at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Compile_Time_Error); 
--# expr-done 10144
--# property-call-start Name.name_is
Fld_7 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_6.Node, Sym => Sym_3);
--# end
--# expr-done 10145
   If_Result_2 := Fld_7;
end if;
if If_Result_2 then
   --# expr-start 10166 '<And at ast.py:9543>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:9543
--# expr-start 10155 '<Let at ast.py:9543>' Let_Result /tmp/lal-23.0.0/ada/ast.py:9543
--# scope-start
--# expr-start 10147 '<FieldAccess for assoc_expr at ast.py:9544>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9544
--# expr-start 10146 '<FieldAccess for args at ast.py:9544>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9544
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10146
Fld_9 := Fld_8.Node;
Get_Result := Get (Self, Fld_9, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result_3 := No_Entity_Base_Assoc;
else
Fld_10 := Fld_8.Info;
As_Entity := (Info => Fld_10, Node => Get_Result); 
   If_Result_3 := As_Entity;
end if;
      if If_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_11 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => If_Result_3.Node, E_Info => If_Result_3.Info);
--# end
--# expr-done 10147
Expr := Fld_11; 
--# bind expr Expr
--# expr-start 10154 '<And at ast.py:9545>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:9545
--# expr-start 10152 '<And at ast.py:9545>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9545
--# expr-start 10150 '<Bind at ast.py:9545>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:9545
--# expr-start 10148 '<FieldAccess for expected_type_var at ast.py:9545>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9545
      if Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Expr.Node);
--# expr-done 10148
Fld_12.Value := No_Entity;
Entity_Vars.Reset (Fld_12);
--# expr-start 10149 '<FieldAccess for bool_type at ast.py:9545>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9545
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_13 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10149
      Cast_Result := Create_Internal_Entity
        (Node => Fld_13.Node,
         Info => Fld_13.Info);
Bind_Result := Solver.Create_Assign (Fld_12, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9545") else null)); 
--# expr-done 10150
--# expr-start 10151 '<FieldAccess for sub_equation at ast.py:9546>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:9546
      if Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_14 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Expr.Node, Env => Env, Origin => Origin, E_Info => Expr.Info);
--# end
--# expr-done 10151
And_Pred := Create_And (Bind_Result, Fld_14, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9545") else null)); 
--# expr-done 10152
--# expr-start 10153 '<FieldAccess for matches_expected_formal_prim_type at ast.py:9547>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:9547
      if Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_15 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Expr.Node, Origin => Origin);
--# end
--# expr-done 10153
And_Pred_1 := Create_And (And_Pred, Fld_15, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9545") else null)); 
--# expr-done 10154
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10155
--# expr-start 10156 '<FieldAccess for args at ast.py:9548>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:9548
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10156
Fld_17 := Fld_16.Node;
Get_Result_1 := Get (Self, Fld_17, 1, True); 
Is_Null_1 := Get_Result_1 = null; 
if Is_Null_1 then
   If_Result_4 := No_Entity_Base_Assoc;
else
Fld_18 := Fld_16.Info;
As_Entity_1 := (Info => Fld_18, Node => Get_Result_1); 
   If_Result_4 := As_Entity_1;
end if;
Var_Expr_1 := If_Result_4;
if Var_Expr_1 /= No_Entity_Base_Assoc then
   --# scope-start
--# expr-start 10157 '<FieldAccess for assoc_expr at ast.py:9548>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:9548
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_19 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 10157
Scope_Result := Fld_19;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Expr;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind msg Var_Expr
--# expr-start 10165 '<And at ast.py:9550>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:9550
--# expr-start 10163 '<And at ast.py:9550>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:9550
--# expr-start 10161 '<Bind at ast.py:9550>' Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:9550
--# expr-start 10158 '<FieldAccess for expected_type_var at ast.py:9550>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:9550
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 10158
Fld_20.Value := No_Entity;
Entity_Vars.Reset (Fld_20);
--# expr-start 10160 '<FieldAccess for std_entity at ast.py:9550>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:9550
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10159 '<Symbol String at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 10159
--# property-call-start AdaNode.std_entity
Fld_21 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_4);
--# end
--# expr-done 10160
Bind_Result_1 := Solver.Create_Assign (Fld_20, Fld_21, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9550") else null)); 
--# expr-done 10161
--# expr-start 10162 '<FieldAccess for sub_equation at ast.py:9551>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:9551
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_22 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10162
And_Pred_2 := Create_And (Bind_Result_1, Fld_22, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9550") else null)); 
--# expr-done 10163
--# expr-start 10164 '<FieldAccess for matches_expected_type at ast.py:9552>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:9552
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_23 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 10164
And_Pred_3 := Create_And (And_Pred_2, Fld_23, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9550") else null)); 
--# expr-done 10165
Scope_Result_1 := And_Pred_3;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3108;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9553") else null)); 
   Result_Var_1 := True_Rel;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_4 := Create_And (Let_Result, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9543") else null)); 
--# expr-done 10166
   If_Result_43 := And_Pred_4;
else
--# expr-start 10169 '<FieldAccess for name_is at ast.py:9556>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:9556
--# expr-start 10167 '<FieldAccess for id at ast.py:9556>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:9556
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10167
      if Fld_24.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10168 '<Symbol Unreferenced at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unreferenced); 
--# expr-done 10168
--# property-call-start Name.name_is
Fld_25 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_24.Node, Sym => Sym_5);
--# end
--# expr-done 10169
if Fld_25 then
   --# expr-start 10175 '<LogicAll at ast.py:9557>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:9557
--# expr-start 10174 '<Map at ast.py:9557>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9557
   --# expr-start 10170 '<FieldAccess for args at ast.py:9557>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:9557
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10170
Fld_27 := Fld_26.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_27 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Base_Assoc_List := Fld_27;
      begin
         for Untyped_Item_311 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_311 := Untyped_Item_311; 
Is_Null_2 := Bare_Item_311 = null; 
if Is_Null_2 then
   If_Result_5 := No_Entity_Base_Assoc;
else
Fld_28 := Fld_26.Info;
As_Entity_2 := (Info => Fld_28, Node => Bare_Item_311); 
   If_Result_5 := As_Entity_2;
end if;
                  Item_311 := If_Result_5; 
   --# scope-start
               --# bind assoc Item_311
      --# expr-start 10173 '<FieldAccess for xref_no_overloading at ast.py:9559>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:9559
--# expr-start 10172 '<Cast to Name at ast.py:9559>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9559
--# expr-start 10171 '<FieldAccess for assoc_expr at ast.py:9559>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:9559
      if Item_311.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_29 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Item_311.Node, E_Info => Item_311.Info);
--# end
--# expr-done 10171
   if Fld_29.Node = null
      or else Fld_29.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Fld_29.Node,
         Info => Fld_29.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 10172
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_30 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result_1.Node, Env => Env, Origin => Origin, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 10173
         declare
            Item_To_Append : constant Logic_Equation := Fld_30;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3109;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10174
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9557") else null)); 
--# expr-done 10175
   If_Result_42 := Logic_Boolean_Op;
else
--# expr-start 10179 '<Eq at ast.py:9562>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10177 '<FieldAccess for name_symbol at ast.py:9562>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10176 '<FieldAccess for id at ast.py:9562>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_31 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10176
      if Fld_31.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_32 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_31.Node);
--# end
--# expr-done 10177
--# expr-start 10178 '<Symbol Import at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import); 
--# expr-done 10178
Is_Equal := Fld_32 = Sym_6; 
--# expr-done 10179
if Is_Equal then
   If_Result_6 := True;
else
   --# expr-start 10183 '<Eq at ast.py:9562>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10181 '<FieldAccess for name_symbol at ast.py:9562>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10180 '<FieldAccess for id at ast.py:9562>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_33 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10180
      if Fld_33.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_34 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_33.Node);
--# end
--# expr-done 10181
--# expr-start 10182 '<Symbol Export at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Export); 
--# expr-done 10182
Is_Equal_1 := Fld_34 = Sym_7; 
--# expr-done 10183
   If_Result_6 := Is_Equal_1;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 10187 '<Eq at ast.py:9562>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10185 '<FieldAccess for name_symbol at ast.py:9562>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10184 '<FieldAccess for id at ast.py:9562>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_35 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10184
      if Fld_35.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_36 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_35.Node);
--# end
--# expr-done 10185
--# expr-start 10186 '<Symbol Interface at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Interface); 
--# expr-done 10186
Is_Equal_2 := Fld_36 = Sym_8; 
--# expr-done 10187
   If_Result_7 := Is_Equal_2;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 10191 '<Eq at ast.py:9562>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10189 '<FieldAccess for name_symbol at ast.py:9562>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10188 '<FieldAccess for id at ast.py:9562>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_37 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10188
      if Fld_37.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_38 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_37.Node);
--# end
--# expr-done 10189
--# expr-start 10190 '<Symbol Convention at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Convention); 
--# expr-done 10190
Is_Equal_3 := Fld_38 = Sym_9; 
--# expr-done 10191
   If_Result_8 := Is_Equal_3;
end if;
if If_Result_8 then
   If_Result_9 := True;
else
   --# expr-start 10195 '<Eq at ast.py:9562>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10193 '<FieldAccess for name_symbol at ast.py:9562>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10192 '<FieldAccess for id at ast.py:9562>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_39 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10192
      if Fld_39.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_40 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_39.Node);
--# end
--# expr-done 10193
--# expr-start 10194 '<Symbol Pack at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pack); 
--# expr-done 10194
Is_Equal_4 := Fld_40 = Sym_10; 
--# expr-done 10195
   If_Result_9 := Is_Equal_4;
end if;
if If_Result_9 then
   If_Result_10 := True;
else
   --# expr-start 10199 '<Eq at ast.py:9562>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10197 '<FieldAccess for name_symbol at ast.py:9562>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10196 '<FieldAccess for id at ast.py:9562>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_41 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10196
      if Fld_41.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_42 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_41.Node);
--# end
--# expr-done 10197
--# expr-start 10198 '<Symbol Pure at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pure); 
--# expr-done 10198
Is_Equal_5 := Fld_42 = Sym_11; 
--# expr-done 10199
   If_Result_10 := Is_Equal_5;
end if;
if If_Result_10 then
   If_Result_11 := True;
else
   --# expr-start 10203 '<Eq at ast.py:9562>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10201 '<FieldAccess for name_symbol at ast.py:9562>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10200 '<FieldAccess for id at ast.py:9562>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_43 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10200
      if Fld_43.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_44 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_43.Node);
--# end
--# expr-done 10201
--# expr-start 10202 '<Symbol Preelaborate at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Preelaborate); 
--# expr-done 10202
Is_Equal_6 := Fld_44 = Sym_12; 
--# expr-done 10203
   If_Result_11 := Is_Equal_6;
end if;
if If_Result_11 then
   If_Result_12 := True;
else
   --# expr-start 10207 '<Eq at ast.py:9562>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10205 '<FieldAccess for name_symbol at ast.py:9562>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10204 '<FieldAccess for id at ast.py:9562>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_45 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10204
      if Fld_45.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_46 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_45.Node);
--# end
--# expr-done 10205
--# expr-start 10206 '<Symbol Elaborate_Body at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Elaborate_Body); 
--# expr-done 10206
Is_Equal_7 := Fld_46 = Sym_13; 
--# expr-done 10207
   If_Result_12 := Is_Equal_7;
end if;
if If_Result_12 then
   If_Result_13 := True;
else
   --# expr-start 10211 '<Eq at ast.py:9562>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10209 '<FieldAccess for name_symbol at ast.py:9562>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10208 '<FieldAccess for id at ast.py:9562>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_47 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10208
      if Fld_47.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_48 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_47.Node);
--# end
--# expr-done 10209
--# expr-start 10210 '<Symbol Inline at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Inline); 
--# expr-done 10210
Is_Equal_8 := Fld_48 = Sym_14; 
--# expr-done 10211
   If_Result_13 := Is_Equal_8;
end if;
if If_Result_13 then
   If_Result_14 := True;
else
   --# expr-start 10215 '<Eq at ast.py:9562>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10213 '<FieldAccess for name_symbol at ast.py:9562>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:9562
--# expr-start 10212 '<FieldAccess for id at ast.py:9562>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:9562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_49 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10212
      if Fld_49.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_50 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_49.Node);
--# end
--# expr-done 10213
--# expr-start 10214 '<Symbol Volatile at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Volatile); 
--# expr-done 10214
Is_Equal_9 := Fld_50 = Sym_15; 
--# expr-done 10215
   If_Result_14 := Is_Equal_9;
end if;
if If_Result_14 then
   --# expr-start 10219 '<LogicAll at ast.py:9567>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:9567
--# expr-start 10218 '<Map at ast.py:9567>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:9567
   --# expr-start 10216 '<FieldAccess for associated_entity_names at ast.py:9567>' Fld_51 /tmp/lal-23.0.0/ada/ast.py:9567
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.associated_entity_names
Fld_51 := Libadalang.Implementation.Pragma_Node_P_Associated_Entity_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10216
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Name_Array_Access := Fld_51;
      begin
         for Item_312 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_312
      --# expr-start 10217 '<FieldAccess for xref_no_overloading at ast.py:9568>' Fld_52 /tmp/lal-23.0.0/ada/ast.py:9568
      if Item_312.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_52 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Item_312.Node, Env => Env, Origin => Origin, E_Info => Item_312.Info);
--# end
--# expr-done 10217
         declare
            Item_To_Append : constant Logic_Equation := Fld_52;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3110;
         end loop;
      end;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 10218
Logic_Boolean_Op_1 := Solver.Create_All (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9567") else null)); 
--# expr-done 10219
   If_Result_41 := Logic_Boolean_Op_1;
else
--# expr-start 10222 '<FieldAccess for name_is at ast.py:9571>' Fld_54 /tmp/lal-23.0.0/ada/ast.py:9571
--# expr-start 10220 '<FieldAccess for id at ast.py:9571>' Fld_53 /tmp/lal-23.0.0/ada/ast.py:9571
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_53 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10220
      if Fld_53.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10221 '<Symbol Warnings at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Warnings); 
--# expr-done 10221
--# property-call-start Name.name_is
Fld_54 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_53.Node, Sym => Sym_16);
--# end
--# expr-done 10222
if Fld_54 then
--# expr-start 10223 '<FieldAccess for args at ast.py:9572>' Fld_55 /tmp/lal-23.0.0/ada/ast.py:9572
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_55 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10223
Fld_56 := Fld_55.Node;
Get_Result_2 := Get (Self, Fld_56, 1, True); 
Is_Null_3 := Get_Result_2 = null; 
if Is_Null_3 then
   If_Result_15 := No_Entity_Base_Assoc;
else
Fld_57 := Fld_55.Info;
As_Entity_3 := (Info => Fld_57, Node => Get_Result_2); 
   If_Result_15 := As_Entity_3;
end if;
Var_Expr_3 := If_Result_15;
if Var_Expr_3 /= No_Entity_Base_Assoc then
   --# scope-start
--# expr-start 10224 '<FieldAccess for assoc_expr at ast.py:9572>' Fld_58 /tmp/lal-23.0.0/ada/ast.py:9572
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_58 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Var_Expr_3.Node, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 10224
Scope_Result_2 := Fld_58;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := No_Entity_Expr;
end if;
Var_Expr_2 := Result_Var_2;
if Var_Expr_2 /= No_Entity_Expr then
   --# scope-start
   --# bind expr Var_Expr_2
--# expr-start 10235 '<If at ast.py:9573>' If_Result_16 /tmp/lal-23.0.0/ada/ast.py:9573
--# expr-start 10225 '<IsA Identifier at ast.py:9574>' Is_A /tmp/lal-23.0.0/ada/ast.py:9574
Is_A := Var_Expr_2.Node /= null 
and then Var_Expr_2.Node.Kind in Ada_Identifier_Range; 
--# expr-done 10225
if Is_A then
   --# expr-start 10226 '<FieldAccess for sub_equation at ast.py:9576>' Fld_59 /tmp/lal-23.0.0/ada/ast.py:9576
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_59 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr_2.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 10226
   If_Result_16 := Fld_59;
else
   --# expr-start 10234 '<And at ast.py:9578>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:9578
--# expr-start 10232 '<And at ast.py:9578>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:9578
--# expr-start 10230 '<Bind at ast.py:9578>' Bind_Result_2 /tmp/lal-23.0.0/ada/ast.py:9578
--# expr-start 10227 '<FieldAccess for expected_type_var at ast.py:9578>' Fld_60 /tmp/lal-23.0.0/ada/ast.py:9578
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_60 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr_2.Node);
--# expr-done 10227
Fld_60.Value := No_Entity;
Entity_Vars.Reset (Fld_60);
--# expr-start 10229 '<FieldAccess for std_entity at ast.py:9578>' Fld_61 /tmp/lal-23.0.0/ada/ast.py:9578
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10228 '<Symbol String at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 10228
--# property-call-start AdaNode.std_entity
Fld_61 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_17);
--# end
--# expr-done 10229
Bind_Result_2 := Solver.Create_Assign (Fld_60, Fld_61, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9578") else null)); 
--# expr-done 10230
--# expr-start 10231 '<FieldAccess for sub_equation at ast.py:9579>' Fld_62 /tmp/lal-23.0.0/ada/ast.py:9579
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_62 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr_2.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 10231
And_Pred_5 := Create_And (Bind_Result_2, Fld_62, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9578") else null)); 
--# expr-done 10232
--# expr-start 10233 '<FieldAccess for matches_expected_type at ast.py:9580>' Fld_63 /tmp/lal-23.0.0/ada/ast.py:9580
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_63 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Var_Expr_2.Node, Origin => Origin);
--# end
--# expr-done 10233
And_Pred_6 := Create_And (And_Pred_5, Fld_63, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9578") else null)); 
--# expr-done 10234
   If_Result_16 := And_Pred_6;
end if;
      Inc_Ref (If_Result_16);
--# expr-done 10235
Scope_Result_3 := If_Result_16;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_3112;
   Result_Var_3 := Scope_Result_3;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9582") else null)); 
   Result_Var_3 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_3);
   If_Result_40 := Result_Var_3;
else
--# expr-start 10239 '<Eq at ast.py:9590>' Is_Equal_10 /tmp/lal-23.0.0/ada/ast.py:9590
--# expr-start 10237 '<FieldAccess for name_symbol at ast.py:9590>' Fld_65 /tmp/lal-23.0.0/ada/ast.py:9590
--# expr-start 10236 '<FieldAccess for id at ast.py:9590>' Fld_64 /tmp/lal-23.0.0/ada/ast.py:9590
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_64 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10236
      if Fld_64.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_65 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_64.Node);
--# end
--# expr-done 10237
--# expr-start 10238 '<Symbol Style_Checks at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Style_Checks); 
--# expr-done 10238
Is_Equal_10 := Fld_65 = Sym_18; 
--# expr-done 10239
if Is_Equal_10 then
   If_Result_17 := True;
else
   --# expr-start 10243 '<Eq at ast.py:9590>' Is_Equal_11 /tmp/lal-23.0.0/ada/ast.py:9590
--# expr-start 10241 '<FieldAccess for name_symbol at ast.py:9590>' Fld_67 /tmp/lal-23.0.0/ada/ast.py:9590
--# expr-start 10240 '<FieldAccess for id at ast.py:9590>' Fld_66 /tmp/lal-23.0.0/ada/ast.py:9590
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_66 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10240
      if Fld_66.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_67 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_66.Node);
--# end
--# expr-done 10241
--# expr-start 10242 '<Symbol Import_Function at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import_Function); 
--# expr-done 10242
Is_Equal_11 := Fld_67 = Sym_19; 
--# expr-done 10243
   If_Result_17 := Is_Equal_11;
end if;
if If_Result_17 then
   If_Result_18 := True;
else
   --# expr-start 10247 '<Eq at ast.py:9590>' Is_Equal_12 /tmp/lal-23.0.0/ada/ast.py:9590
--# expr-start 10245 '<FieldAccess for name_symbol at ast.py:9590>' Fld_69 /tmp/lal-23.0.0/ada/ast.py:9590
--# expr-start 10244 '<FieldAccess for id at ast.py:9590>' Fld_68 /tmp/lal-23.0.0/ada/ast.py:9590
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_68 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10244
      if Fld_68.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_69 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_68.Node);
--# end
--# expr-done 10245
--# expr-start 10246 '<Symbol Import_Procedure at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import_Procedure); 
--# expr-done 10246
Is_Equal_12 := Fld_69 = Sym_20; 
--# expr-done 10247
   If_Result_18 := Is_Equal_12;
end if;
if If_Result_18 then
   True_Rel_2 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9593") else null)); 
   If_Result_39 := True_Rel_2;
else
--# expr-start 10251 '<Eq at ast.py:9595>' Is_Equal_13 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10249 '<FieldAccess for name_symbol at ast.py:9595>' Fld_71 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10248 '<FieldAccess for id at ast.py:9595>' Fld_70 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_70 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10248
      if Fld_70.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_71 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_70.Node);
--# end
--# expr-done 10249
--# expr-start 10250 '<Symbol Pre at ???>' Sym_21 None
Sym_21 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre); 
--# expr-done 10250
Is_Equal_13 := Fld_71 = Sym_21; 
--# expr-done 10251
if Is_Equal_13 then
   If_Result_19 := True;
else
   --# expr-start 10255 '<Eq at ast.py:9595>' Is_Equal_14 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10253 '<FieldAccess for name_symbol at ast.py:9595>' Fld_73 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10252 '<FieldAccess for id at ast.py:9595>' Fld_72 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_72 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10252
      if Fld_72.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_73 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_72.Node);
--# end
--# expr-done 10253
--# expr-start 10254 '<Symbol Post at ???>' Sym_22 None
Sym_22 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post); 
--# expr-done 10254
Is_Equal_14 := Fld_73 = Sym_22; 
--# expr-done 10255
   If_Result_19 := Is_Equal_14;
end if;
if If_Result_19 then
   If_Result_20 := True;
else
   --# expr-start 10259 '<Eq at ast.py:9595>' Is_Equal_15 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10257 '<FieldAccess for name_symbol at ast.py:9595>' Fld_75 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10256 '<FieldAccess for id at ast.py:9595>' Fld_74 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_74 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10256
      if Fld_74.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_75 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_74.Node);
--# end
--# expr-done 10257
--# expr-start 10258 '<Symbol Pre'"'"'Class at ???>' Sym_23 None
Sym_23 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pre_Class); 
--# expr-done 10258
Is_Equal_15 := Fld_75 = Sym_23; 
--# expr-done 10259
   If_Result_20 := Is_Equal_15;
end if;
if If_Result_20 then
   If_Result_21 := True;
else
   --# expr-start 10263 '<Eq at ast.py:9595>' Is_Equal_16 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10261 '<FieldAccess for name_symbol at ast.py:9595>' Fld_77 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10260 '<FieldAccess for id at ast.py:9595>' Fld_76 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_76 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10260
      if Fld_76.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_77 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_76.Node);
--# end
--# expr-done 10261
--# expr-start 10262 '<Symbol Post'"'"'Class at ???>' Sym_24 None
Sym_24 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Post_Class); 
--# expr-done 10262
Is_Equal_16 := Fld_77 = Sym_24; 
--# expr-done 10263
   If_Result_21 := Is_Equal_16;
end if;
if If_Result_21 then
   If_Result_22 := True;
else
   --# expr-start 10267 '<Eq at ast.py:9595>' Is_Equal_17 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10265 '<FieldAccess for name_symbol at ast.py:9595>' Fld_79 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10264 '<FieldAccess for id at ast.py:9595>' Fld_78 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_78 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10264
      if Fld_78.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_79 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_78.Node);
--# end
--# expr-done 10265
--# expr-start 10266 '<Symbol Precondition at ???>' Sym_25 None
Sym_25 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Precondition); 
--# expr-done 10266
Is_Equal_17 := Fld_79 = Sym_25; 
--# expr-done 10267
   If_Result_22 := Is_Equal_17;
end if;
if If_Result_22 then
   If_Result_23 := True;
else
   --# expr-start 10271 '<Eq at ast.py:9595>' Is_Equal_18 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10269 '<FieldAccess for name_symbol at ast.py:9595>' Fld_81 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10268 '<FieldAccess for id at ast.py:9595>' Fld_80 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_80 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10268
      if Fld_80.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_81 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_80.Node);
--# end
--# expr-done 10269
--# expr-start 10270 '<Symbol Postcondition at ???>' Sym_26 None
Sym_26 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Postcondition); 
--# expr-done 10270
Is_Equal_18 := Fld_81 = Sym_26; 
--# expr-done 10271
   If_Result_23 := Is_Equal_18;
end if;
if If_Result_23 then
   If_Result_24 := True;
else
   --# expr-start 10275 '<Eq at ast.py:9595>' Is_Equal_19 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10273 '<FieldAccess for name_symbol at ast.py:9595>' Fld_83 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10272 '<FieldAccess for id at ast.py:9595>' Fld_82 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_82 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10272
      if Fld_82.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_83 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_82.Node);
--# end
--# expr-done 10273
--# expr-start 10274 '<Symbol Precondition'"'"'Class at ???>' Sym_27 None
Sym_27 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Precondition_Class); 
--# expr-done 10274
Is_Equal_19 := Fld_83 = Sym_27; 
--# expr-done 10275
   If_Result_24 := Is_Equal_19;
end if;
if If_Result_24 then
   If_Result_25 := True;
else
   --# expr-start 10279 '<Eq at ast.py:9595>' Is_Equal_20 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10277 '<FieldAccess for name_symbol at ast.py:9595>' Fld_85 /tmp/lal-23.0.0/ada/ast.py:9595
--# expr-start 10276 '<FieldAccess for id at ast.py:9595>' Fld_84 /tmp/lal-23.0.0/ada/ast.py:9595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_84 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10276
      if Fld_84.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_85 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_84.Node);
--# end
--# expr-done 10277
--# expr-start 10278 '<Symbol Postcondition'"'"'Class at ???>' Sym_28 None
Sym_28 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Postcondition_Class); 
--# expr-done 10278
Is_Equal_20 := Fld_85 = Sym_28; 
--# expr-done 10279
   If_Result_25 := Is_Equal_20;
end if;
if If_Result_25 then
--# expr-start 10281 '<FieldAccess for assoc_expr at ast.py:9600>' Fld_89 /tmp/lal-23.0.0/ada/ast.py:9600
--# expr-start 10280 '<FieldAccess for args at ast.py:9600>' Fld_86 /tmp/lal-23.0.0/ada/ast.py:9600
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_86 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10280
Fld_87 := Fld_86.Node;
Get_Result_3 := Get (Self, Fld_87, 0, True); 
Is_Null_4 := Get_Result_3 = null; 
if Is_Null_4 then
   If_Result_26 := No_Entity_Base_Assoc;
else
Fld_88 := Fld_86.Info;
As_Entity_4 := (Info => Fld_88, Node => Get_Result_3); 
   If_Result_26 := As_Entity_4;
end if;
      if If_Result_26.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_89 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => If_Result_26.Node, E_Info => If_Result_26.Info);
--# end
--# expr-done 10281
Var_Expr_4 := Fld_89;
if Var_Expr_4 /= No_Entity_Expr then
   --# scope-start
   --# bind expr Var_Expr_4
--# expr-start 10288 '<And at ast.py:9602>' And_Pred_8 /tmp/lal-23.0.0/ada/ast.py:9602
--# expr-start 10286 '<And at ast.py:9602>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:9602
--# expr-start 10284 '<Bind at ast.py:9602>' Bind_Result_3 /tmp/lal-23.0.0/ada/ast.py:9602
--# expr-start 10282 '<FieldAccess for expected_type_var at ast.py:9602>' Fld_90 /tmp/lal-23.0.0/ada/ast.py:9602
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_90 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr_4.Node);
--# expr-done 10282
Fld_90.Value := No_Entity;
Entity_Vars.Reset (Fld_90);
--# expr-start 10283 '<FieldAccess for bool_type at ast.py:9602>' Fld_91 /tmp/lal-23.0.0/ada/ast.py:9602
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_91 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10283
      Cast_Result_2 := Create_Internal_Entity
        (Node => Fld_91.Node,
         Info => Fld_91.Info);
Bind_Result_3 := Solver.Create_Assign (Fld_90, Cast_Result_2, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9602") else null)); 
--# expr-done 10284
--# expr-start 10285 '<FieldAccess for sub_equation at ast.py:9603>' Fld_92 /tmp/lal-23.0.0/ada/ast.py:9603
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_92 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr_4.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_4.Info);
--# end
--# expr-done 10285
And_Pred_7 := Create_And (Bind_Result_3, Fld_92, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9602") else null)); 
--# expr-done 10286
--# expr-start 10287 '<FieldAccess for matches_expected_formal_prim_type at ast.py:9604>' Fld_93 /tmp/lal-23.0.0/ada/ast.py:9604
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_93 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Var_Expr_4.Node, Origin => Origin);
--# end
--# expr-done 10287
And_Pred_8 := Create_And (And_Pred_7, Fld_93, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9602") else null)); 
--# expr-done 10288
Scope_Result_4 := And_Pred_8;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_3113;
   Result_Var_4 := Scope_Result_4;
else
   False_Rel := Solver.Create_False ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9605") else null)); 
   Result_Var_4 := False_Rel;
end if;
      Inc_Ref (Result_Var_4);
   If_Result_38 := Result_Var_4;
else
--# expr-start 10291 '<FieldAccess for name_is at ast.py:9608>' Fld_95 /tmp/lal-23.0.0/ada/ast.py:9608
--# expr-start 10289 '<FieldAccess for id at ast.py:9608>' Fld_94 /tmp/lal-23.0.0/ada/ast.py:9608
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_94 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10289
      if Fld_94.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10290 '<Symbol Test_Case at ???>' Sym_29 None
Sym_29 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Test_Case); 
--# expr-done 10290
--# property-call-start Name.name_is
Fld_95 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_94.Node, Sym => Sym_29);
--# end
--# expr-done 10291
if Fld_95 then
   --# expr-start 10314 '<LogicAll at ast.py:9615>' Logic_Boolean_Op_2 /tmp/lal-23.0.0/ada/ast.py:9615
--# expr-start 10313 '<Map at ast.py:9615>' Map_Result_3 /tmp/lal-23.0.0/ada/ast.py:9615
   --# expr-start 10302 '<Filter at ast.py:9609>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:9609
   --# expr-start 10292 '<FieldAccess for args at ast.py:9609>' Fld_96 /tmp/lal-23.0.0/ada/ast.py:9609
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_96 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10292
Fld_97 := Fld_96.Node;
      declare
         Map_Result_2_Vec : Internal_Entity_Base_Assoc_Vectors.Vector;
      begin
      if Fld_97 = null then
      Map_Result_2 := Create_Internal_Entity_Base_Assoc_Array (0);
      else
      declare
         Collection : constant Bare_Base_Assoc_List := Fld_97;
      begin
         for Untyped_Item_314 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_314 := Untyped_Item_314; 
Is_Null_5 := Bare_Item_314 = null; 
if Is_Null_5 then
   If_Result_27 := No_Entity_Base_Assoc;
else
Fld_98 := Fld_96.Info;
As_Entity_5 := (Info => Fld_98, Node => Bare_Item_314); 
   If_Result_27 := As_Entity_5;
end if;
                  Item_314 := If_Result_27; 
   --# scope-start
               --# bind arg Item_314
--# expr-start 10293 '<Cast to PragmaArgumentAssoc at ast.py:9610>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:9610
Cast_Expr := Item_314; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Pragma_Argument_Assoc_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Pragma_Argument_Assoc
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_3 := No_Entity_Pragma_Argument_Assoc;
   end if;
--# expr-done 10293
Var_Expr_5 := Cast_Result_3;
if Var_Expr_5 /= No_Entity_Pragma_Argument_Assoc then
   --# scope-start
   --# bind parg Var_Expr_5
--# expr-start 10297 '<Eq at ast.py:9611>' Is_Equal_21 /tmp/lal-23.0.0/ada/ast.py:9611
--# expr-start 10295 '<FieldAccess for name_symbol at ast.py:9611>' Fld_100 /tmp/lal-23.0.0/ada/ast.py:9611
--# expr-start 10294 '<FieldAccess for name at ast.py:9611>' Fld_99 /tmp/lal-23.0.0/ada/ast.py:9611
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_99 := Create_Internal_Entity_Name (Node => Var_Expr_5.Node.Pragma_Argument_Assoc_F_Name, Info => Var_Expr_5.Info);
--# expr-done 10294
      if Fld_99.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_100 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_99.Node);
--# end
--# expr-done 10295
--# expr-start 10296 '<Symbol Requires at ???>' Sym_30 None
Sym_30 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Requires); 
--# expr-done 10296
Is_Equal_21 := Fld_100 = Sym_30; 
--# expr-done 10297
if Is_Equal_21 then
   If_Result_28 := True;
else
   --# expr-start 10301 '<Eq at ast.py:9611>' Is_Equal_22 /tmp/lal-23.0.0/ada/ast.py:9611
--# expr-start 10299 '<FieldAccess for name_symbol at ast.py:9611>' Fld_102 /tmp/lal-23.0.0/ada/ast.py:9611
--# expr-start 10298 '<FieldAccess for name at ast.py:9611>' Fld_101 /tmp/lal-23.0.0/ada/ast.py:9611
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_101 := Create_Internal_Entity_Name (Node => Var_Expr_5.Node.Pragma_Argument_Assoc_F_Name, Info => Var_Expr_5.Info);
--# expr-done 10298
      if Fld_101.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_102 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_101.Node);
--# end
--# expr-done 10299
--# expr-start 10300 '<Symbol Ensures at ???>' Sym_31 None
Sym_31 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ensures); 
--# expr-done 10300
Is_Equal_22 := Fld_102 = Sym_31; 
--# expr-done 10301
   If_Result_28 := Is_Equal_22;
end if;
Scope_Result_5 := If_Result_28;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := False;
end if;
         if Result_Var_5 then
         declare
            Item_To_Append : constant Internal_Entity_Base_Assoc := Item_314;
         begin
            Internal_Entity_Base_Assoc_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result_2 := Create_Internal_Entity_Base_Assoc_Array
           (Items_Count => Natural (Internal_Entity_Base_Assoc_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Base_Assoc_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Base_Assoc_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Base_Assoc_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 10302
      declare
         Map_Result_3_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Assoc_Array_Access := Map_Result_2;
      begin
         for Item_313 of
               Collection.Items
         loop
   --# scope-start
               --# bind arg Item_313
      --# expr-start 10312 '<And at ast.py:9617>' And_Pred_10 /tmp/lal-23.0.0/ada/ast.py:9617
--# expr-start 10309 '<And at ast.py:9617>' And_Pred_9 /tmp/lal-23.0.0/ada/ast.py:9617
--# expr-start 10306 '<Bind at ast.py:9617>' Bind_Result_4 /tmp/lal-23.0.0/ada/ast.py:9617
--# expr-start 10304 '<FieldAccess for expected_type_var at ast.py:9617>' Fld_104 /tmp/lal-23.0.0/ada/ast.py:9617
--# expr-start 10303 '<FieldAccess for assoc_expr at ast.py:9617>' Fld_103 /tmp/lal-23.0.0/ada/ast.py:9617
      if Item_313.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_103 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Item_313.Node, E_Info => Item_313.Info);
--# end
--# expr-done 10303
      if Fld_103.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_104 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_103.Node);
--# expr-done 10304
Fld_104.Value := No_Entity;
Entity_Vars.Reset (Fld_104);
--# expr-start 10305 '<FieldAccess for bool_type at ast.py:9617>' Fld_105 /tmp/lal-23.0.0/ada/ast.py:9617
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_105 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10305
      Cast_Result_4 := Create_Internal_Entity
        (Node => Fld_105.Node,
         Info => Fld_105.Info);
Bind_Result_4 := Solver.Create_Assign (Fld_104, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9617") else null)); 
--# expr-done 10306
--# expr-start 10308 '<FieldAccess for sub_equation at ast.py:9618>' Fld_107 /tmp/lal-23.0.0/ada/ast.py:9618
--# expr-start 10307 '<FieldAccess for assoc_expr at ast.py:9618>' Fld_106 /tmp/lal-23.0.0/ada/ast.py:9618
      if Item_313.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_106 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Item_313.Node, E_Info => Item_313.Info);
--# end
--# expr-done 10307
      if Fld_106.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_107 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_106.Node, Env => Env, Origin => Origin, E_Info => Fld_106.Info);
--# end
--# expr-done 10308
And_Pred_9 := Create_And (Bind_Result_4, Fld_107, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9617") else null)); 
--# expr-done 10309
--# expr-start 10311 '<FieldAccess for matches_expected_formal_prim_type at ast.py:9619>' Fld_109 /tmp/lal-23.0.0/ada/ast.py:9619
--# expr-start 10310 '<FieldAccess for assoc_expr at ast.py:9619>' Fld_108 /tmp/lal-23.0.0/ada/ast.py:9619
      if Item_313.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_108 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Item_313.Node, E_Info => Item_313.Info);
--# end
--# expr-done 10310
      if Fld_108.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_109 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_108.Node, Origin => Origin);
--# end
--# expr-done 10311
And_Pred_10 := Create_And (And_Pred_9, Fld_109, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9617") else null)); 
--# expr-done 10312
         declare
            Item_To_Append : constant Logic_Equation := And_Pred_10;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_3_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3117;
         end loop;
      end;
         Map_Result_3 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_3_Vec)));
         for I in Map_Result_3.Items'Range loop
            Map_Result_3.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_3_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_3.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_3_Vec);
      end;
--# expr-done 10313
Logic_Boolean_Op_2 := Solver.Create_All (Relation_Array (Map_Result_3.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9615") else null)); 
--# expr-done 10314
   If_Result_37 := Logic_Boolean_Op_2;
else
--# expr-start 10317 '<FieldAccess for name_is at ast.py:9622>' Fld_111 /tmp/lal-23.0.0/ada/ast.py:9622
--# expr-start 10315 '<FieldAccess for id at ast.py:9622>' Fld_110 /tmp/lal-23.0.0/ada/ast.py:9622
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_110 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10315
      if Fld_110.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10316 '<Symbol Contract_Cases at ???>' Sym_32 None
Sym_32 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Contract_Cases); 
--# expr-done 10316
--# property-call-start Name.name_is
Fld_111 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_110.Node, Sym => Sym_32);
--# end
--# expr-done 10317
if Fld_111 then
   --# expr-start 10325 '<LogicAll at ast.py:9623>' Logic_Boolean_Op_3 /tmp/lal-23.0.0/ada/ast.py:9623
--# expr-start 10324 '<Map at ast.py:9623>' Map_Result_4 /tmp/lal-23.0.0/ada/ast.py:9623
   --# expr-start 10321 '<FieldAccess for assocs at ast.py:9623>' Fld_116 /tmp/lal-23.0.0/ada/ast.py:9623
--# expr-start 10320 '<Cast to BaseAggregate at ast.py:9623>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:9623
--# expr-start 10319 '<FieldAccess for assoc_expr at ast.py:9623>' Fld_115 /tmp/lal-23.0.0/ada/ast.py:9623
--# expr-start 10318 '<FieldAccess for args at ast.py:9623>' Fld_112 /tmp/lal-23.0.0/ada/ast.py:9623
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_112 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10318
Fld_113 := Fld_112.Node;
Get_Result_4 := Get (Self, Fld_113, 0, True); 
Is_Null_6 := Get_Result_4 = null; 
if Is_Null_6 then
   If_Result_29 := No_Entity_Base_Assoc;
else
Fld_114 := Fld_112.Info;
As_Entity_6 := (Info => Fld_114, Node => Get_Result_4); 
   If_Result_29 := As_Entity_6;
end if;
      if If_Result_29.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_115 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => If_Result_29.Node, E_Info => If_Result_29.Info);
--# end
--# expr-done 10319
   if Fld_115.Node = null
      or else Fld_115.Node.Kind in Ada_Base_Aggregate
   then
      Cast_Result_5 := Create_Internal_Entity_Base_Aggregate
        (Node => Fld_115.Node,
         Info => Fld_115.Info);
   else
         Cast_Result_5 := No_Entity_Base_Aggregate;
   end if;
--# expr-done 10320
      if Cast_Result_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_116 := Create_Internal_Entity_Assoc_List (Node => Cast_Result_5.Node.Base_Aggregate_F_Assocs, Info => Cast_Result_5.Info);
--# expr-done 10321
Fld_117 := Fld_116.Node;
      declare
         Map_Result_4_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_117 = null then
      Map_Result_4 := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_117;
      begin
         for Untyped_Item_315 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_315 := Untyped_Item_315; 
Is_Null_7 := Bare_Item_315 = null; 
if Is_Null_7 then
   If_Result_30 := No_Entity_Basic_Assoc;
else
Fld_118 := Fld_116.Info;
As_Entity_7 := (Info => Fld_118, Node => Bare_Item_315); 
   If_Result_30 := As_Entity_7;
end if;
                  Item_315 := If_Result_30; 
   --# scope-start
               --# bind assoc Item_315
      --# expr-start 10323 '<FieldAccess for contract_cases_assoc_equation at ast.py:9625>' Fld_119 /tmp/lal-23.0.0/ada/ast.py:9625
--# expr-start 10322 '<Cast to AggregateAssoc at ast.py:9625>' Cast_Result_6 /tmp/lal-23.0.0/ada/ast.py:9625
Cast_Expr_1 := Item_315; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Aggregate_Assoc_Range
   then
      Cast_Result_6 := Create_Internal_Entity_Aggregate_Assoc
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_6 := No_Entity_Aggregate_Assoc;
   end if;
--# expr-done 10322
      if Cast_Result_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AggregateAssoc.contract_cases_assoc_equation
Fld_119 := Libadalang.Implementation.Aggregate_Assoc_P_Contract_Cases_Assoc_Equation (Node => Cast_Result_6.Node, Env => Env, Origin => Origin, E_Info => Cast_Result_6.Info);
--# end
--# expr-done 10323
         declare
            Item_To_Append : constant Logic_Equation := Fld_119;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_4_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3118;
         end loop;
      end;
      end if;
         Map_Result_4 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_4_Vec)));
         for I in Map_Result_4.Items'Range loop
            Map_Result_4.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_4_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_4.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_4_Vec);
      end;
--# expr-done 10324
Logic_Boolean_Op_3 := Solver.Create_All (Relation_Array (Map_Result_4.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9623") else null)); 
--# expr-done 10325
   If_Result_36 := Logic_Boolean_Op_3;
else
--# expr-start 10328 '<FieldAccess for name_is at ast.py:9628>' Fld_121 /tmp/lal-23.0.0/ada/ast.py:9628
--# expr-start 10326 '<FieldAccess for id at ast.py:9628>' Fld_120 /tmp/lal-23.0.0/ada/ast.py:9628
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_120 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10326
      if Fld_120.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10327 '<Symbol Debug at ???>' Sym_33 None
Sym_33 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Debug); 
--# expr-done 10327
--# property-call-start Name.name_is
Fld_121 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_120.Node, Sym => Sym_33);
--# end
--# expr-done 10328
if Fld_121 then
   --# expr-start 10353 '<And at ast.py:9629>' And_Pred_14 /tmp/lal-23.0.0/ada/ast.py:9629
--# expr-start 10342 '<If at ast.py:9629>' If_Result_32 /tmp/lal-23.0.0/ada/ast.py:9629
--# expr-start 10331 '<Eq at ast.py:9632>' Is_Equal_23 /tmp/lal-23.0.0/ada/ast.py:9632
--# expr-start 10330 '<length at ast.py:9632>' Len /tmp/lal-23.0.0/ada/ast.py:9632
--# expr-start 10329 '<FieldAccess for args at ast.py:9632>' Fld_130 /tmp/lal-23.0.0/ada/ast.py:9632
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_130 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10329
Fld_131 := Fld_130.Node; 
Len := Length (Fld_131); 
--# expr-done 10330
Is_Equal_23 := Len = 2; 
--# expr-done 10331
if Is_Equal_23 then
   --# expr-start 10341 '<Let at ast.py:9633>' Let_Result_1 /tmp/lal-23.0.0/ada/ast.py:9633
--# scope-start
--# expr-start 10333 '<FieldAccess for assoc_expr at ast.py:9634>' Fld_125 /tmp/lal-23.0.0/ada/ast.py:9634
--# expr-start 10332 '<FieldAccess for args at ast.py:9634>' Fld_122 /tmp/lal-23.0.0/ada/ast.py:9634
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_122 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10332
Fld_123 := Fld_122.Node;
Get_Result_5 := Get (Self, Fld_123, 0, True); 
Is_Null_8 := Get_Result_5 = null; 
if Is_Null_8 then
   If_Result_31 := No_Entity_Base_Assoc;
else
Fld_124 := Fld_122.Info;
As_Entity_8 := (Info => Fld_124, Node => Get_Result_5); 
   If_Result_31 := As_Entity_8;
end if;
      if If_Result_31.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_125 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => If_Result_31.Node, E_Info => If_Result_31.Info);
--# end
--# expr-done 10333
Expr_1 := Fld_125; 
--# bind expr Expr_1
--# expr-start 10340 '<And at ast.py:9635>' And_Pred_12 /tmp/lal-23.0.0/ada/ast.py:9635
--# expr-start 10338 '<And at ast.py:9635>' And_Pred_11 /tmp/lal-23.0.0/ada/ast.py:9635
--# expr-start 10336 '<Bind at ast.py:9635>' Bind_Result_5 /tmp/lal-23.0.0/ada/ast.py:9635
--# expr-start 10334 '<FieldAccess for expected_type_var at ast.py:9635>' Fld_126 /tmp/lal-23.0.0/ada/ast.py:9635
      if Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_126 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Expr_1.Node);
--# expr-done 10334
Fld_126.Value := No_Entity;
Entity_Vars.Reset (Fld_126);
--# expr-start 10335 '<FieldAccess for bool_type at ast.py:9635>' Fld_127 /tmp/lal-23.0.0/ada/ast.py:9635
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_127 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10335
      Cast_Result_7 := Create_Internal_Entity
        (Node => Fld_127.Node,
         Info => Fld_127.Info);
Bind_Result_5 := Solver.Create_Assign (Fld_126, Cast_Result_7, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9635") else null)); 
--# expr-done 10336
--# expr-start 10337 '<FieldAccess for sub_equation at ast.py:9636>' Fld_128 /tmp/lal-23.0.0/ada/ast.py:9636
      if Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_128 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Expr_1.Node, Env => Env, Origin => Origin, E_Info => Expr_1.Info);
--# end
--# expr-done 10337
And_Pred_11 := Create_And (Bind_Result_5, Fld_128, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9635") else null)); 
--# expr-done 10338
--# expr-start 10339 '<FieldAccess for matches_expected_formal_prim_type at ast.py:9637>' Fld_129 /tmp/lal-23.0.0/ada/ast.py:9637
      if Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_129 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Expr_1.Node, Origin => Origin);
--# end
--# expr-done 10339
And_Pred_12 := Create_And (And_Pred_11, Fld_129, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9635") else null)); 
--# expr-done 10340
Let_Result_1 := And_Pred_12; Inc_Ref (Let_Result_1);
--# end
--# expr-done 10341
   If_Result_32 := Let_Result_1;
else
   True_Rel_3 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9639") else null)); 
   If_Result_32 := True_Rel_3;
end if;
      Inc_Ref (If_Result_32);
--# expr-done 10342
--# expr-start 10352 '<Let at ast.py:9640>' Let_Result_2 /tmp/lal-23.0.0/ada/ast.py:9640
--# scope-start
--# expr-start 10343 '<FieldAccess for args at ast.py:9642>' Fld_134 /tmp/lal-23.0.0/ada/ast.py:9642
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_134 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10343
Fld_135 := Fld_134.Node;
--# expr-start 10346 '<Arithmetic - at ast.py:9642>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:9642
--# expr-start 10345 '<length at ast.py:9642>' Len_1 /tmp/lal-23.0.0/ada/ast.py:9642
--# expr-start 10344 '<FieldAccess for args at ast.py:9642>' Fld_132 /tmp/lal-23.0.0/ada/ast.py:9642
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_132 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10344
Fld_133 := Fld_132.Node; 
Len_1 := Length (Fld_133); 
--# expr-done 10345
Arith_Result := (Len_1 - 1); 
--# expr-done 10346
Get_Result_6 := Get (Self, Fld_135, Arith_Result, True); 
Is_Null_9 := Get_Result_6 = null; 
if Is_Null_9 then
   If_Result_33 := No_Entity_Base_Assoc;
else
Fld_136 := Fld_134.Info;
As_Entity_9 := (Info => Fld_136, Node => Get_Result_6); 
   If_Result_33 := As_Entity_9;
end if;
Var_Expr_6 := If_Result_33;
if Var_Expr_6 /= No_Entity_Base_Assoc then
   --# scope-start
--# expr-start 10347 '<FieldAccess for assoc_expr at ast.py:9642>' Fld_137 /tmp/lal-23.0.0/ada/ast.py:9642
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_137 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 10347
Scope_Result_6 := Fld_137;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Expr;
end if;
Proc := Result_Var_6; 
--# bind proc Proc
--# expr-start 10351 '<And at ast.py:9643>' And_Pred_13 /tmp/lal-23.0.0/ada/ast.py:9643
--# expr-start 10349 '<Bind at ast.py:9643>' Bind_Result_6 /tmp/lal-23.0.0/ada/ast.py:9643
--# expr-start 10348 '<FieldAccess for type_var at ast.py:9643>' Fld_138 /tmp/lal-23.0.0/ada/ast.py:9643
      if Proc.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_138 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Proc.Node);
--# expr-done 10348
Fld_138.Value := No_Entity;
Entity_Vars.Reset (Fld_138);
Cast_Expr_2 := No_Entity_Base_Type_Decl; 
      Cast_Result_8 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result_6 := Solver.Create_Assign (Fld_138, Cast_Result_8, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9643") else null)); 
--# expr-done 10349
--# expr-start 10350 '<FieldAccess for sub_equation at ast.py:9644>' Fld_139 /tmp/lal-23.0.0/ada/ast.py:9644
      if Proc.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_139 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Proc.Node, Env => Env, Origin => Origin, E_Info => Proc.Info);
--# end
--# expr-done 10350
And_Pred_13 := Create_And (Bind_Result_6, Fld_139, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9643") else null)); 
--# expr-done 10351
Let_Result_2 := And_Pred_13; Inc_Ref (Let_Result_2);
--# end
--# expr-done 10352
And_Pred_14 := Create_And (If_Result_32, Let_Result_2, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9629") else null)); 
--# expr-done 10353
   If_Result_35 := And_Pred_14;
else
   --# expr-start 10359 '<LogicAll at ast.py:9647>' Logic_Boolean_Op_4 /tmp/lal-23.0.0/ada/ast.py:9647
--# expr-start 10358 '<Map at ast.py:9647>' Map_Result_5 /tmp/lal-23.0.0/ada/ast.py:9647
   --# expr-start 10354 '<FieldAccess for args at ast.py:9647>' Fld_140 /tmp/lal-23.0.0/ada/ast.py:9647
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_140 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10354
Fld_141 := Fld_140.Node;
      declare
         Map_Result_5_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_141 = null then
      Map_Result_5 := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Base_Assoc_List := Fld_141;
      begin
         for Untyped_Item_316 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_316 := Untyped_Item_316; 
Is_Null_10 := Bare_Item_316 = null; 
if Is_Null_10 then
   If_Result_34 := No_Entity_Base_Assoc;
else
Fld_142 := Fld_140.Info;
As_Entity_10 := (Info => Fld_142, Node => Bare_Item_316); 
   If_Result_34 := As_Entity_10;
end if;
                  Item_316 := If_Result_34; 
   --# scope-start
               --# bind a Item_316
      --# expr-start 10357 '<Or at ast.py:9651>' Or_Pred /tmp/lal-23.0.0/ada/ast.py:9651
--# expr-start 10356 '<FieldAccess for sub_equation at ast.py:9651>' Fld_144 /tmp/lal-23.0.0/ada/ast.py:9651
--# expr-start 10355 '<FieldAccess for assoc_expr at ast.py:9651>' Fld_143 /tmp/lal-23.0.0/ada/ast.py:9651
      if Item_316.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_143 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Item_316.Node, E_Info => Item_316.Info);
--# end
--# expr-done 10355
      if Fld_143.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_144 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_143.Node, Env => Env, Origin => Origin, E_Info => Fld_143.Info);
--# end
--# expr-done 10356
True_Rel_4 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9651") else null)); 
Or_Pred := Create_Or (Fld_144, True_Rel_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9651") else null)); 
--# expr-done 10357
         declare
            Item_To_Append : constant Logic_Equation := Or_Pred;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_5_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3120;
         end loop;
      end;
      end if;
         Map_Result_5 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_5_Vec)));
         for I in Map_Result_5.Items'Range loop
            Map_Result_5.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_5_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_5.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_5_Vec);
      end;
--# expr-done 10358
Logic_Boolean_Op_4 := Solver.Create_All (Relation_Array (Map_Result_5.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9647") else null)); 
--# expr-done 10359
   If_Result_35 := Logic_Boolean_Op_4;
end if;
      Inc_Ref (If_Result_35);
   If_Result_36 := If_Result_35;
end if;
      Inc_Ref (If_Result_36);
   If_Result_37 := If_Result_36;
end if;
      Inc_Ref (If_Result_37);
   If_Result_38 := If_Result_37;
end if;
      Inc_Ref (If_Result_38);
   If_Result_39 := If_Result_38;
end if;
      Inc_Ref (If_Result_39);
   If_Result_40 := If_Result_39;
end if;
      Inc_Ref (If_Result_40);
   If_Result_41 := If_Result_40;
end if;
      Inc_Ref (If_Result_41);
   If_Result_42 := If_Result_41;
end if;
      Inc_Ref (If_Result_42);
   If_Result_43 := If_Result_42;
end if;
      Inc_Ref (If_Result_43);
--# expr-done 10360
Let_Result_3 := If_Result_43; Inc_Ref (Let_Result_3);
--# end
--# expr-done 10361
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_779;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_779;
               Finalizer_Scope_3108;
               Finalizer_Scope_3109;
               Finalizer_Scope_3110;
               Finalizer_Scope_3112;
               Finalizer_Scope_3113;
               Finalizer_Scope_3117;
               Finalizer_Scope_3118;
               Finalizer_Scope_3120;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Xref_Equation;
--# end
--# property-start Pragma.value_expr /tmp/lal-23.0.0/ada/ast.py:9656
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Value_Expr
  (Node : Bare_Pragma_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Expr
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Expr;
      Var_Expr : Internal_Entity_Base_Assoc;
Var_Expr_1 : Internal_Entity_Base_Assoc_List;
Fld : Internal_Entity_Base_Assoc_List;
Fld_1 : Bare_Base_Assoc_List;
Fld_2 : Internal_Entity_Info;
Get_Result : Bare_Base_Assoc;
As_Entity : Internal_Entity_Base_Assoc;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Assoc;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Internal_Entity_Base_Assoc_List;
Saved : Internal_Entity_Base_Assoc_List;
Fld_5 : Bare_Base_Assoc_List;
Fld_6 : Internal_Entity_Info;
Get_Result_1 : Bare_Base_Assoc;
As_Entity_1 : Internal_Entity_Base_Assoc;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Base_Assoc;
Scope_Result : Internal_Entity_Base_Assoc;
Result_Var : Internal_Entity_Base_Assoc;
Fld_7 : Internal_Entity_Expr;
Scope_Result_1 : Internal_Entity_Expr;
Result_Var_1 : Internal_Entity_Expr;
Fld_8 : Internal_Entity_Identifier;
Fld_9 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_10 : Internal_Entity_Identifier;
Fld_11 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result_2 : Boolean;
Fld_12 : Internal_Entity_Identifier;
Fld_13 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_3 : Boolean;
Fld_14 : Internal_Entity_Identifier;
Fld_15 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_4 : Boolean;
If_Result_5 : Internal_Entity_Expr;
Let_Result : Internal_Entity_Expr;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10383 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10382 '<If at ast.py:9667>' If_Result_5 /tmp/lal-23.0.0/ada/ast.py:9667
--# expr-start 10365 '<Eq at ast.py:9668>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10363 '<FieldAccess for name_symbol at ast.py:9668>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10362 '<FieldAccess for id at ast.py:9668>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9668
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10362
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_9 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_8.Node);
--# end
--# expr-done 10363
--# expr-start 10364 '<Symbol Import at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import); 
--# expr-done 10364
Is_Equal := Fld_9 = Sym; 
--# expr-done 10365
if Is_Equal then
   If_Result_2 := True;
else
   --# expr-start 10369 '<Eq at ast.py:9668>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10367 '<FieldAccess for name_symbol at ast.py:9668>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10366 '<FieldAccess for id at ast.py:9668>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9668
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10366
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_11 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_10.Node);
--# end
--# expr-done 10367
--# expr-start 10368 '<Symbol Export at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Export); 
--# expr-done 10368
Is_Equal_1 := Fld_11 = Sym_1; 
--# expr-done 10369
   If_Result_2 := Is_Equal_1;
end if;
if If_Result_2 then
   If_Result_3 := True;
else
   --# expr-start 10373 '<Eq at ast.py:9668>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10371 '<FieldAccess for name_symbol at ast.py:9668>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10370 '<FieldAccess for id at ast.py:9668>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9668
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10370
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_13 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_12.Node);
--# end
--# expr-done 10371
--# expr-start 10372 '<Symbol Interface at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Interface); 
--# expr-done 10372
Is_Equal_2 := Fld_13 = Sym_2; 
--# expr-done 10373
   If_Result_3 := Is_Equal_2;
end if;
if If_Result_3 then
   If_Result_4 := True;
else
   --# expr-start 10377 '<Eq at ast.py:9668>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10375 '<FieldAccess for name_symbol at ast.py:9668>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:9668
--# expr-start 10374 '<FieldAccess for id at ast.py:9668>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:9668
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10374
      if Fld_14.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_15 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_14.Node);
--# end
--# expr-done 10375
--# expr-start 10376 '<Symbol Convention at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Convention); 
--# expr-done 10376
Is_Equal_3 := Fld_15 = Sym_3; 
--# expr-done 10377
   If_Result_4 := Is_Equal_3;
end if;
if If_Result_4 then
   --# expr-start 10379 '<FieldAccess for assoc_expr at ast.py:9671>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9671
--# expr-start 10378 '<FieldAccess for args at ast.py:9671>' Fld /tmp/lal-23.0.0/ada/ast.py:9671
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10378
Fld_1 := Fld.Node;
Get_Result := Get (Self, Fld_1, 0, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result := No_Entity_Base_Assoc;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Get_Result); 
   If_Result := As_Entity;
end if;
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 10379
   If_Result_5 := Fld_3;
else
--# expr-start 10380 '<FieldAccess for args at ast.py:9672>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9672
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10380
Var_Expr_1 := Fld_4;
if Var_Expr_1 /= No_Entity_Base_Assoc_List then
   --# scope-start
Saved := Var_Expr_1; 
Fld_5 := Saved.Node;
Get_Result_1 := Get (Self, Fld_5, 1, True); 
Is_Null_1 := Get_Result_1 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Base_Assoc;
else
Fld_6 := Saved.Info;
As_Entity_1 := (Info => Fld_6, Node => Get_Result_1); 
   If_Result_1 := As_Entity_1;
end if;
Scope_Result := If_Result_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Assoc;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Base_Assoc then
   --# scope-start
--# expr-start 10381 '<FieldAccess for assoc_expr at ast.py:9672>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9672
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_7 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 10381
Scope_Result_1 := Fld_7;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Entity_Expr;
end if;
   If_Result_5 := Result_Var_1;
end if;
--# expr-done 10382
Let_Result := If_Result_5; 
--# end
--# expr-done 10383
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Value_Expr;
--# end
--# property-start Pragma.associated_entity_names /tmp/lal-23.0.0/ada/ast.py:9676
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Associated_Entity_Names
  (Node : Bare_Pragma_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name_Array_Access
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Name_Array_Access;
            procedure Finalizer_Scope_781 with Inline_Always;
            procedure Finalizer_Scope_3125 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Var_Expr_1 : Internal_Entity_Base_Assoc;
Fld : Internal_Entity_Identifier;
Fld_1 : Symbol_Type;
Sym : Symbol_Type;
Is_Equal : Boolean;
Fld_2 : Internal_Entity_Identifier;
Fld_3 : Symbol_Type;
Sym_1 : Symbol_Type;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_4 : Internal_Entity_Identifier;
Fld_5 : Symbol_Type;
Sym_2 : Symbol_Type;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Fld_6 : Internal_Entity_Identifier;
Fld_7 : Symbol_Type;
Sym_3 : Symbol_Type;
Is_Equal_3 : Boolean;
If_Result_2 : Boolean;
Fld_8 : Internal_Entity_Base_Assoc_List;
Fld_9 : Bare_Base_Assoc_List;
Fld_10 : Internal_Entity_Info;
Get_Result : Bare_Base_Assoc;
As_Entity : Internal_Entity_Base_Assoc;
Is_Null : Boolean;
If_Result_3 : Internal_Entity_Base_Assoc;
Fld_11 : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Singleton : Internal_Entity_Name_Array_Access;
Fld_12 : Internal_Entity_Identifier;
Sym_4 : Symbol_Type;
Fld_13 : Boolean;
Fld_14 : Internal_Entity_Base_Assoc_List;
Fld_15 : Bare_Base_Assoc_List;
Fld_16 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity_Base_Assoc;
Is_Null_1 : Boolean;
If_Result_4 : Internal_Entity_Base_Assoc;
Fld_17 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Item_317 : Internal_Entity_Base_Assoc;
Bare_Item_317 : Bare_Base_Assoc;
Map_Result : Internal_Entity_Name_Array_Access;
Fld_18 : Internal_Entity_Identifier;
Fld_19 : Symbol_Type;
Sym_5 : Symbol_Type;
Is_Equal_4 : Boolean;
Fld_20 : Internal_Entity_Identifier;
Fld_21 : Symbol_Type;
Sym_6 : Symbol_Type;
Is_Equal_5 : Boolean;
If_Result_5 : Boolean;
Fld_22 : Internal_Entity_Identifier;
Fld_23 : Symbol_Type;
Sym_7 : Symbol_Type;
Is_Equal_6 : Boolean;
If_Result_6 : Boolean;
Fld_24 : Internal_Entity_Identifier;
Fld_25 : Symbol_Type;
Sym_8 : Symbol_Type;
Is_Equal_7 : Boolean;
If_Result_7 : Boolean;
Fld_26 : Internal_Entity_Identifier;
Fld_27 : Symbol_Type;
Sym_9 : Symbol_Type;
Is_Equal_8 : Boolean;
If_Result_8 : Boolean;
Fld_28 : Internal_Entity_Identifier;
Fld_29 : Symbol_Type;
Sym_10 : Symbol_Type;
Is_Equal_9 : Boolean;
If_Result_9 : Boolean;
Fld_30 : Internal_Entity_Identifier;
Fld_31 : Symbol_Type;
Sym_11 : Symbol_Type;
Is_Equal_10 : Boolean;
If_Result_10 : Boolean;
Fld_32 : Internal_Entity_Identifier;
Fld_33 : Symbol_Type;
Sym_12 : Symbol_Type;
Is_Equal_11 : Boolean;
If_Result_11 : Boolean;
Fld_34 : Internal_Entity_Identifier;
Fld_35 : Symbol_Type;
Sym_13 : Symbol_Type;
Is_Equal_12 : Boolean;
If_Result_12 : Boolean;
Fld_36 : Internal_Entity_Identifier;
Fld_37 : Symbol_Type;
Sym_14 : Symbol_Type;
Is_Equal_13 : Boolean;
If_Result_13 : Boolean;
Fld_38 : Internal_Entity_Identifier;
Fld_39 : Symbol_Type;
Sym_15 : Symbol_Type;
Is_Equal_14 : Boolean;
If_Result_14 : Boolean;
Fld_40 : Internal_Entity_Identifier;
Fld_41 : Symbol_Type;
Sym_16 : Symbol_Type;
Is_Equal_15 : Boolean;
If_Result_15 : Boolean;
Fld_42 : Internal_Entity_Identifier;
Fld_43 : Symbol_Type;
Sym_17 : Symbol_Type;
Is_Equal_16 : Boolean;
If_Result_16 : Boolean;
Fld_44 : Internal_Entity_Identifier;
Fld_45 : Symbol_Type;
Sym_18 : Symbol_Type;
Is_Equal_17 : Boolean;
If_Result_17 : Boolean;
Fld_46 : Internal_Entity_Identifier;
Fld_47 : Symbol_Type;
Sym_19 : Symbol_Type;
Is_Equal_18 : Boolean;
If_Result_18 : Boolean;
Fld_48 : Internal_Entity_Identifier;
Fld_49 : Symbol_Type;
Sym_20 : Symbol_Type;
Is_Equal_19 : Boolean;
If_Result_19 : Boolean;
Fld_50 : Internal_Entity_Base_Assoc_List;
Fld_51 : Bare_Base_Assoc_List;
Fld_52 : Internal_Entity_Info;
Get_Result_1 : Bare_Base_Assoc;
As_Entity_2 : Internal_Entity_Base_Assoc;
Is_Null_2 : Boolean;
If_Result_20 : Internal_Entity_Base_Assoc;
Fld_53 : Internal_Entity_Expr;
Scope_Result : Internal_Entity_Expr;
Result_Var : Internal_Entity_Expr;
Cast_Result_2 : Internal_Entity_Name;
Singleton_1 : Internal_Entity_Name_Array_Access;
Scope_Result_1 : Internal_Entity_Name_Array_Access;
Result_Var_1 : Internal_Entity_Name_Array_Access;
If_Result_21 : Internal_Entity_Name_Array_Access;
If_Result_22 : Internal_Entity_Name_Array_Access;
If_Result_23 : Internal_Entity_Name_Array_Access;
Let_Result : Internal_Entity_Name_Array_Access;
            procedure Finalizer_Scope_781 is
            begin
                     Dec_Ref (Singleton);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (If_Result_21);
                     Dec_Ref (If_Result_22);
                     Dec_Ref (If_Result_23);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_781;
            procedure Finalizer_Scope_3125 is
            begin
                     Dec_Ref (Singleton_1);
            end Finalizer_Scope_3125;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10478 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10477 '<Cond at ast.py:9677>' If_Result_23 /tmp/lal-23.0.0/ada/ast.py:9677
--# expr-start 10387 '<Eq at ast.py:9678>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10385 '<FieldAccess for name_symbol at ast.py:9678>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10384 '<FieldAccess for id at ast.py:9678>' Fld /tmp/lal-23.0.0/ada/ast.py:9678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10384
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld.Node);
--# end
--# expr-done 10385
--# expr-start 10386 '<Symbol Import at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Import); 
--# expr-done 10386
Is_Equal := Fld_1 = Sym; 
--# expr-done 10387
if Is_Equal then
   If_Result := True;
else
   --# expr-start 10391 '<Eq at ast.py:9678>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10389 '<FieldAccess for name_symbol at ast.py:9678>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10388 '<FieldAccess for id at ast.py:9678>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10388
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_2.Node);
--# end
--# expr-done 10389
--# expr-start 10390 '<Symbol Export at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Export); 
--# expr-done 10390
Is_Equal_1 := Fld_3 = Sym_1; 
--# expr-done 10391
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 10395 '<Eq at ast.py:9678>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10393 '<FieldAccess for name_symbol at ast.py:9678>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10392 '<FieldAccess for id at ast.py:9678>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10392
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_5 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_4.Node);
--# end
--# expr-done 10393
--# expr-start 10394 '<Symbol Interface at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Interface); 
--# expr-done 10394
Is_Equal_2 := Fld_5 = Sym_2; 
--# expr-done 10395
   If_Result_1 := Is_Equal_2;
end if;
if If_Result_1 then
   If_Result_2 := True;
else
   --# expr-start 10399 '<Eq at ast.py:9678>' Is_Equal_3 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10397 '<FieldAccess for name_symbol at ast.py:9678>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9678
--# expr-start 10396 '<FieldAccess for id at ast.py:9678>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9678
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10396
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_7 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_6.Node);
--# end
--# expr-done 10397
--# expr-start 10398 '<Symbol Convention at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Convention); 
--# expr-done 10398
Is_Equal_3 := Fld_7 = Sym_3; 
--# expr-done 10399
   If_Result_2 := Is_Equal_3;
end if;
if If_Result_2 then
   --# expr-start 10402 '<Cast to Name at ast.py:9681>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9681
--# expr-start 10401 '<FieldAccess for assoc_expr at ast.py:9681>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9681
--# expr-start 10400 '<FieldAccess for args at ast.py:9681>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9681
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10400
Fld_9 := Fld_8.Node;
Get_Result := Get (Self, Fld_9, 1, True); 
Is_Null := Get_Result = null; 
if Is_Null then
   If_Result_3 := No_Entity_Base_Assoc;
else
Fld_10 := Fld_8.Info;
As_Entity := (Info => Fld_10, Node => Get_Result); 
   If_Result_3 := As_Entity;
end if;
      if If_Result_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_11 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => If_Result_3.Node, E_Info => If_Result_3.Info);
--# end
--# expr-done 10401
   if Fld_11.Node = null
      or else Fld_11.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Fld_11.Node,
         Info => Fld_11.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 10402
                Singleton := Create_Internal_Entity_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Cast_Result;
   If_Result_23 := Singleton;
else
--# expr-start 10405 '<FieldAccess for name_is at ast.py:9683>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9683
--# expr-start 10403 '<FieldAccess for id at ast.py:9683>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9683
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10403
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10404 '<Symbol Inline at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Inline); 
--# expr-done 10404
--# property-call-start Name.name_is
Fld_13 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_12.Node, Sym => Sym_4);
--# end
--# expr-done 10405
if Fld_13 then
   --# expr-start 10409 '<Map at ast.py:9684>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9684
   --# expr-start 10406 '<FieldAccess for args at ast.py:9684>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:9684
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10406
Fld_15 := Fld_14.Node;
      declare
         Map_Result_Vec : Internal_Entity_Name_Vectors.Vector;
      begin
      if Fld_15 = null then
      Map_Result := Create_Internal_Entity_Name_Array (0);
      else
      declare
         Collection : constant Bare_Base_Assoc_List := Fld_15;
      begin
         for Untyped_Item_317 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_317 := Untyped_Item_317; 
Is_Null_1 := Bare_Item_317 = null; 
if Is_Null_1 then
   If_Result_4 := No_Entity_Base_Assoc;
else
Fld_16 := Fld_14.Info;
As_Entity_1 := (Info => Fld_16, Node => Bare_Item_317); 
   If_Result_4 := As_Entity_1;
end if;
                  Item_317 := If_Result_4; 
   --# scope-start
               --# bind a Item_317
      --# expr-start 10408 '<Cast to Name at ast.py:9684>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9684
--# expr-start 10407 '<FieldAccess for assoc_expr at ast.py:9684>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:9684
      if Item_317.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_17 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Item_317.Node, E_Info => Item_317.Info);
--# end
--# expr-done 10407
   if Fld_17.Node = null
      or else Fld_17.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Fld_17.Node,
         Info => Fld_17.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 10408
         declare
            Item_To_Append : constant Internal_Entity_Name := Cast_Result_1;
         begin
            Internal_Entity_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Name_Array
           (Items_Count => Natural (Internal_Entity_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10409
   If_Result_22 := Map_Result;
else
--# expr-start 10413 '<Eq at ast.py:9686>' Is_Equal_4 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10411 '<FieldAccess for name_symbol at ast.py:9686>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10410 '<FieldAccess for id at ast.py:9686>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10410
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_19 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_18.Node);
--# end
--# expr-done 10411
--# expr-start 10412 '<Symbol Pack at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pack); 
--# expr-done 10412
Is_Equal_4 := Fld_19 = Sym_5; 
--# expr-done 10413
if Is_Equal_4 then
   If_Result_5 := True;
else
   --# expr-start 10417 '<Eq at ast.py:9686>' Is_Equal_5 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10415 '<FieldAccess for name_symbol at ast.py:9686>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10414 '<FieldAccess for id at ast.py:9686>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10414
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_21 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_20.Node);
--# end
--# expr-done 10415
--# expr-start 10416 '<Symbol Pure at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pure); 
--# expr-done 10416
Is_Equal_5 := Fld_21 = Sym_6; 
--# expr-done 10417
   If_Result_5 := Is_Equal_5;
end if;
if If_Result_5 then
   If_Result_6 := True;
else
   --# expr-start 10421 '<Eq at ast.py:9686>' Is_Equal_6 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10419 '<FieldAccess for name_symbol at ast.py:9686>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10418 '<FieldAccess for id at ast.py:9686>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_22 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10418
      if Fld_22.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_23 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_22.Node);
--# end
--# expr-done 10419
--# expr-start 10420 '<Symbol Preelaborate at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Preelaborate); 
--# expr-done 10420
Is_Equal_6 := Fld_23 = Sym_7; 
--# expr-done 10421
   If_Result_6 := Is_Equal_6;
end if;
if If_Result_6 then
   If_Result_7 := True;
else
   --# expr-start 10425 '<Eq at ast.py:9686>' Is_Equal_7 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10423 '<FieldAccess for name_symbol at ast.py:9686>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10422 '<FieldAccess for id at ast.py:9686>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_24 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10422
      if Fld_24.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_25 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_24.Node);
--# end
--# expr-done 10423
--# expr-start 10424 '<Symbol Elaborate_Body at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Elaborate_Body); 
--# expr-done 10424
Is_Equal_7 := Fld_25 = Sym_8; 
--# expr-done 10425
   If_Result_7 := Is_Equal_7;
end if;
if If_Result_7 then
   If_Result_8 := True;
else
   --# expr-start 10429 '<Eq at ast.py:9686>' Is_Equal_8 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10427 '<FieldAccess for name_symbol at ast.py:9686>' Fld_27 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10426 '<FieldAccess for id at ast.py:9686>' Fld_26 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_26 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10426
      if Fld_26.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_27 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_26.Node);
--# end
--# expr-done 10427
--# expr-start 10428 '<Symbol Volatile at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Volatile); 
--# expr-done 10428
Is_Equal_8 := Fld_27 = Sym_9; 
--# expr-done 10429
   If_Result_8 := Is_Equal_8;
end if;
if If_Result_8 then
   If_Result_9 := True;
else
   --# expr-start 10433 '<Eq at ast.py:9686>' Is_Equal_9 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10431 '<FieldAccess for name_symbol at ast.py:9686>' Fld_29 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10430 '<FieldAccess for id at ast.py:9686>' Fld_28 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_28 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10430
      if Fld_28.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_29 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_28.Node);
--# end
--# expr-done 10431
--# expr-start 10432 '<Symbol Volatile_Components at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Volatile_Components); 
--# expr-done 10432
Is_Equal_9 := Fld_29 = Sym_10; 
--# expr-done 10433
   If_Result_9 := Is_Equal_9;
end if;
if If_Result_9 then
   If_Result_10 := True;
else
   --# expr-start 10437 '<Eq at ast.py:9686>' Is_Equal_10 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10435 '<FieldAccess for name_symbol at ast.py:9686>' Fld_31 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10434 '<FieldAccess for id at ast.py:9686>' Fld_30 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_30 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10434
      if Fld_30.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_31 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_30.Node);
--# end
--# expr-done 10435
--# expr-start 10436 '<Symbol Unchecked_Union at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Unchecked_Union); 
--# expr-done 10436
Is_Equal_10 := Fld_31 = Sym_11; 
--# expr-done 10437
   If_Result_10 := Is_Equal_10;
end if;
if If_Result_10 then
   If_Result_11 := True;
else
   --# expr-start 10441 '<Eq at ast.py:9686>' Is_Equal_11 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10439 '<FieldAccess for name_symbol at ast.py:9686>' Fld_33 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10438 '<FieldAccess for id at ast.py:9686>' Fld_32 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_32 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10438
      if Fld_32.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_33 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_32.Node);
--# end
--# expr-done 10439
--# expr-start 10440 '<Symbol Atomic at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Atomic); 
--# expr-done 10440
Is_Equal_11 := Fld_33 = Sym_12; 
--# expr-done 10441
   If_Result_11 := Is_Equal_11;
end if;
if If_Result_11 then
   If_Result_12 := True;
else
   --# expr-start 10445 '<Eq at ast.py:9686>' Is_Equal_12 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10443 '<FieldAccess for name_symbol at ast.py:9686>' Fld_35 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10442 '<FieldAccess for id at ast.py:9686>' Fld_34 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_34 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10442
      if Fld_34.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_35 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_34.Node);
--# end
--# expr-done 10443
--# expr-start 10444 '<Symbol Atomic_Components at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Atomic_Components); 
--# expr-done 10444
Is_Equal_12 := Fld_35 = Sym_13; 
--# expr-done 10445
   If_Result_12 := Is_Equal_12;
end if;
if If_Result_12 then
   If_Result_13 := True;
else
   --# expr-start 10449 '<Eq at ast.py:9686>' Is_Equal_13 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10447 '<FieldAccess for name_symbol at ast.py:9686>' Fld_37 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10446 '<FieldAccess for id at ast.py:9686>' Fld_36 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_36 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10446
      if Fld_36.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_37 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_36.Node);
--# end
--# expr-done 10447
--# expr-start 10448 '<Symbol No_Return at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_No_Return); 
--# expr-done 10448
Is_Equal_13 := Fld_37 = Sym_14; 
--# expr-done 10449
   If_Result_13 := Is_Equal_13;
end if;
if If_Result_13 then
   If_Result_14 := True;
else
   --# expr-start 10453 '<Eq at ast.py:9686>' Is_Equal_14 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10451 '<FieldAccess for name_symbol at ast.py:9686>' Fld_39 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10450 '<FieldAccess for id at ast.py:9686>' Fld_38 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_38 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10450
      if Fld_38.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_39 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_38.Node);
--# end
--# expr-done 10451
--# expr-start 10452 '<Symbol Discard_Names at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Discard_Names); 
--# expr-done 10452
Is_Equal_14 := Fld_39 = Sym_15; 
--# expr-done 10453
   If_Result_14 := Is_Equal_14;
end if;
if If_Result_14 then
   If_Result_15 := True;
else
   --# expr-start 10457 '<Eq at ast.py:9686>' Is_Equal_15 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10455 '<FieldAccess for name_symbol at ast.py:9686>' Fld_41 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10454 '<FieldAccess for id at ast.py:9686>' Fld_40 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_40 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10454
      if Fld_40.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_41 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_40.Node);
--# end
--# expr-done 10455
--# expr-start 10456 '<Symbol Independent at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Independent); 
--# expr-done 10456
Is_Equal_15 := Fld_41 = Sym_16; 
--# expr-done 10457
   If_Result_15 := Is_Equal_15;
end if;
if If_Result_15 then
   If_Result_16 := True;
else
   --# expr-start 10461 '<Eq at ast.py:9686>' Is_Equal_16 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10459 '<FieldAccess for name_symbol at ast.py:9686>' Fld_43 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10458 '<FieldAccess for id at ast.py:9686>' Fld_42 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_42 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10458
      if Fld_42.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_43 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_42.Node);
--# end
--# expr-done 10459
--# expr-start 10460 '<Symbol Independent_Components at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Independent_Components); 
--# expr-done 10460
Is_Equal_16 := Fld_43 = Sym_17; 
--# expr-done 10461
   If_Result_16 := Is_Equal_16;
end if;
if If_Result_16 then
   If_Result_17 := True;
else
   --# expr-start 10465 '<Eq at ast.py:9686>' Is_Equal_17 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10463 '<FieldAccess for name_symbol at ast.py:9686>' Fld_45 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10462 '<FieldAccess for id at ast.py:9686>' Fld_44 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_44 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10462
      if Fld_44.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_45 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_44.Node);
--# end
--# expr-done 10463
--# expr-start 10464 '<Symbol Asynchronous at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asynchronous); 
--# expr-done 10464
Is_Equal_17 := Fld_45 = Sym_18; 
--# expr-done 10465
   If_Result_17 := Is_Equal_17;
end if;
if If_Result_17 then
   If_Result_18 := True;
else
   --# expr-start 10469 '<Eq at ast.py:9686>' Is_Equal_18 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10467 '<FieldAccess for name_symbol at ast.py:9686>' Fld_47 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10466 '<FieldAccess for id at ast.py:9686>' Fld_46 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_46 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10466
      if Fld_46.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_47 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_46.Node);
--# end
--# expr-done 10467
--# expr-start 10468 '<Symbol Interrupt_Handler at ???>' Sym_19 None
Sym_19 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Interrupt_Handler); 
--# expr-done 10468
Is_Equal_18 := Fld_47 = Sym_19; 
--# expr-done 10469
   If_Result_18 := Is_Equal_18;
end if;
if If_Result_18 then
   If_Result_19 := True;
else
   --# expr-start 10473 '<Eq at ast.py:9686>' Is_Equal_19 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10471 '<FieldAccess for name_symbol at ast.py:9686>' Fld_49 /tmp/lal-23.0.0/ada/ast.py:9686
--# expr-start 10470 '<FieldAccess for id at ast.py:9686>' Fld_48 /tmp/lal-23.0.0/ada/ast.py:9686
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_48 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10470
      if Fld_48.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_49 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_48.Node);
--# end
--# expr-done 10471
--# expr-start 10472 '<Symbol Attach_Handler at ???>' Sym_20 None
Sym_20 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Attach_Handler); 
--# expr-done 10472
Is_Equal_19 := Fld_49 = Sym_20; 
--# expr-done 10473
   If_Result_19 := Is_Equal_19;
end if;
if If_Result_19 then
--# expr-start 10476 '<Cast to Name at ast.py:9693>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:9693
--# expr-start 10474 '<FieldAccess for args at ast.py:9693>' Fld_50 /tmp/lal-23.0.0/ada/ast.py:9693
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_50 := Create_Internal_Entity_Base_Assoc_List (Node => Ent.Node.Pragma_Node_F_Args, Info => Ent.Info);
--# expr-done 10474
Fld_51 := Fld_50.Node;
Get_Result_1 := Get (Self, Fld_51, 0, True); 
Is_Null_2 := Get_Result_1 = null; 
if Is_Null_2 then
   If_Result_20 := No_Entity_Base_Assoc;
else
Fld_52 := Fld_50.Info;
As_Entity_2 := (Info => Fld_52, Node => Get_Result_1); 
   If_Result_20 := As_Entity_2;
end if;
Var_Expr_1 := If_Result_20;
if Var_Expr_1 /= No_Entity_Base_Assoc then
   --# scope-start
--# expr-start 10475 '<FieldAccess for assoc_expr at ast.py:9693>' Fld_53 /tmp/lal-23.0.0/ada/ast.py:9693
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseAssoc.assoc_expr'
Fld_53 := Libadalang.Implementation.Dispatcher_Base_Assoc_P_Assoc_Expr (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 10475
Scope_Result := Fld_53;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Expr;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Name
   then
      Cast_Result_2 := Create_Internal_Entity_Name
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result_2 := No_Entity_Name;
   end if;
--# expr-done 10476
Var_Expr := Cast_Result_2;
if Var_Expr /= No_Entity_Name then
   --# scope-start
                Singleton_1 := Create_Internal_Entity_Name_Array (Items_Count => 1);
                Singleton_1.Items (1) := Var_Expr;
Scope_Result_1 := Singleton_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3125;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Name_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
   If_Result_21 := Result_Var_1;
else
   If_Result_21 := No_Internal_Entity_Name_Array_Type;
end if;
      Inc_Ref (If_Result_21);
   If_Result_22 := If_Result_21;
end if;
      Inc_Ref (If_Result_22);
   If_Result_23 := If_Result_22;
end if;
      Inc_Ref (If_Result_23);
--# expr-done 10477
Let_Result := If_Result_23; Inc_Ref (Let_Result);
--# end
--# expr-done 10478
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_781;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_781;
               Finalizer_Scope_3125;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Associated_Entity_Names;
--# end
--# property-start Pragma.associated_entities_helper /tmp/lal-23.0.0/ada/ast.py:9699
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Associated_Entities_Helper
  (Node : Bare_Pragma_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_782 with Inline_Always;
            procedure Finalizer_Scope_2956 with Inline_Always;
            procedure Finalizer_Scope_2957 with Inline_Always;
            procedure Finalizer_Scope_2958 with Inline_Always;
      Var_Expr : Internal_Entity;
Fld : Internal_Entity_Name_Array_Access;
Fld_1 : Internal_Entity;
Fld_2 : Lexical_Env := Empty_Env;
Fld_3 : Symbol_Type;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Defining_Name_Array_Access;
Fld_6 : Symbol_Type;
Fld_7 : Boolean;
Find_Result : Internal_Entity_Defining_Name;
Map_Result : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Fld_8 : Internal_Unit;
Fld_9 : Internal_Unit;
Is_Equal : Boolean;
Fld_10 : Bare_Defining_Name;
Node_Comp : Boolean;
If_Result : Boolean;
Map_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Map_Result_2 : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_782 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_782;
            procedure Finalizer_Scope_2956 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Map_Result_1);
            end Finalizer_Scope_2956;
            procedure Finalizer_Scope_2957 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_2957;
            procedure Finalizer_Scope_2958 is
            begin
                     Dec_Ref (Fld_5);
            end Finalizer_Scope_2958;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10498 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10497 '<Mapcat at ast.py:9700>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:9700
   --# expr-start 10479 '<FieldAccess for associated_entity_names at ast.py:9700>' Fld /tmp/lal-23.0.0/ada/ast.py:9700
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.associated_entity_names
Fld := Libadalang.Implementation.Pragma_Node_P_Associated_Entity_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10479
      declare
         Map_Result_2_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Name_Array_Access := Fld;
      begin
         for Item_318 of
               Collection.Items
         loop
   --# scope-start
               --# bind name Item_318
      --# expr-start 10496 '<Filter at ast.py:9721>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:9721
--# expr-start 10480 '<FieldAccess for semantic_parent at ast.py:9704>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9704
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.semantic_parent
Fld_1 := Libadalang.Implementation.Ada_Node_P_Semantic_Parent (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10480
Var_Expr := Fld_1;
if Var_Expr /= No_Entity then
   --# scope-start
   --# bind parent Var_Expr
--# expr-start 10490 '<Map at ast.py:9711>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9711
   --# expr-start 10483 '<EnvGet at ast.py:9706>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:9706
--# expr-start 10481 '<FieldAccess for children_env at ast.py:9706>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9706
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Children_Env (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# expr-done 10481
--# expr-start 10482 '<FieldAccess for name_symbol at ast.py:9707>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9707
      if Item_318.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_3 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Item_318.Node);
--# end
--# expr-done 10482
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld_2, Key => Fld_3, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => False, Nocat => True))); 
--# expr-done 10483
      declare
         Map_Result_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_320 of
               Collection.Items
         loop
   --# scope-start
               --# bind node Item_320
      --# expr-start 10489 '<Find at ast.py:9714>' Find_Result /tmp/lal-23.0.0/ada/ast.py:9714
   --# expr-start 10486 '<FieldAccess for defining_names at ast.py:9714>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9714
--# expr-start 10485 '<FieldAccess for wrap_public_reference at ast.py:9713>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9713
--# expr-start 10484 '<Cast to BasicDecl at ast.py:9713>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9713
Cast_Expr := Item_320; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 10484
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.wrap_public_reference
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Wrap_Public_Reference (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 10485
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_names'
Fld_5 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Names (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 10486
      Find_Result := No_Entity_Defining_Name;
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Fld_5;
      begin
         for Item_321 of
               Collection.Items
         loop
   --# scope-start
               --# bind dn Item_321
      --# expr-start 10488 '<FieldAccess for name_is at ast.py:9715>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9715
      if Item_321.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10487 '<FieldAccess for name_symbol at ast.py:9715>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9715
      if Item_318.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_6 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Item_318.Node);
--# end
--# expr-done 10487
--# property-call-start Name.name_is
Fld_7 := Libadalang.Implementation.Name_P_Name_Is (Node => Item_321.Node, Sym => Fld_6);
--# end
--# expr-done 10488
      if Fld_7 then
         Find_Result := Item_321;
      end if;
   --# end
               exit when Fld_7;
         end loop;
      end;
--# expr-done 10489
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Find_Result;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2958;
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10490
Scope_Result := Map_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2957;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
      declare
         Map_Result_1_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Defining_Name_Array_Access := Result_Var;
      begin
         for Item_319 of
               Collection.Items
         loop
   --# scope-start
               --# bind ent Item_319
--# expr-start 10493 '<Eq at ast.py:9721>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9721
--# expr-start 10491 '<FieldAccess for unit at ast.py:9721>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9721
      if Item_319.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Unit (Node => Item_319.Node);
--# expr-done 10491
--# expr-start 10492 '<FieldAccess for unit at ast.py:9721>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9721
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Unit (Node => Self);
--# expr-done 10492
Is_Equal := Fld_8 = Fld_9; 
--# expr-done 10493
if Is_Equal then
   --# expr-start 10495 '<OrderingTest '"'"'lt'"'"' at ast.py:9721>' Node_Comp /tmp/lal-23.0.0/ada/ast.py:9721
--# expr-start 10494 '<FieldAccess for node at ast.py:9721>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9721
Fld_10 := Item_319.Node;
--# expr-done 10494
Node_Comp := Compare (Self, Fld_10, Self, Less_Than); 
--# expr-done 10495
   If_Result := Node_Comp;
else
   If_Result := False;
end if;
         if If_Result then
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Item_319;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 10496
         for Item_To_Append of
               Map_Result_1.Items
         loop
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_2956;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 10497
Let_Result := Map_Result_2; Inc_Ref (Let_Result);
--# end
--# expr-done 10498
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_782;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_782;
               Finalizer_Scope_2956;
               Finalizer_Scope_2957;
               Finalizer_Scope_2958;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Associated_Entities_Helper;
--# end
--# property-start Pragma.associated_entities /tmp/lal-23.0.0/ada/ast.py:9725
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Associated_Entities
  (Node : Bare_Pragma_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Defining_Name_Array_Access
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Pragma_Node :=
     Internal_Entity_Pragma_Node'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_783 with Inline_Always;
            procedure Finalizer_Scope_2953 with Inline_Always;
            procedure Finalizer_Scope_2955 with Inline_Always;
            procedure Finalizer_Scope_2961 with Inline_Always;
            procedure Finalizer_Scope_2962 with Inline_Always;
            procedure Finalizer_Scope_2963 with Inline_Always;
            procedure Finalizer_Scope_2965 with Inline_Always;
            procedure Finalizer_Scope_2966 with Inline_Always;
            procedure Finalizer_Scope_2967 with Inline_Always;
      Block_Var : Internal_Entity_Defining_Name_Array_Access;
Block_Var_1 : Internal_Entity_Basic_Decl;
Var_Expr : Bare_Compilation_Unit;
Var_Expr_1 : Internal_Entity_Name_Array_Access;
Var_Expr_2 : Internal_Entity_Basic_Decl_Array_Access;
Var_Expr_3 : Bare_Declarative_Part;
Var_Expr_4 : Internal_Entity_Basic_Decl;
Var_Expr_5 : Bare_Ada_Node_Array_Access;
P : Internal_Entity_Defining_Name_Array_Access;
Var_Expr_6 : Internal_Entity_Defining_Name_Array_Access;
Var_Expr_7 : Internal_Entity_Basic_Decl;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Cast_Result : Bare_Compilation_Unit;
Fld_2 : Bare_Ada_Node;
Cast_Result_1 : Bare_Library_Item;
Fld_3 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Defining_Name;
Singleton : Internal_Entity_Defining_Name_Array_Access;
Scope_Result : Internal_Entity_Defining_Name_Array_Access;
Result_Var : Internal_Entity_Defining_Name_Array_Access;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result_2 : Bare_Basic_Decl;
As_Entity_1 : Internal_Entity_Basic_Decl;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity_Basic_Decl;
Fld_5 : Internal_Entity_Name_Array_Access;
Fld_6 : Internal_Entity_Defining_Name_Array_Access;
Scope_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Result_Var_1 : Internal_Entity_Defining_Name_Array_Access;
Fld_7 : Internal_Entity_Defining_Name;
Singleton_1 : Internal_Entity_Defining_Name_Array_Access;
Len : Integer;
Is_Equal : Boolean;
Get_Result : Internal_Entity_Name;
Fld_8 : Internal_Entity_Basic_Decl;
Cast_Result_3 : Internal_Entity;
Cast_Expr : Internal_Entity_Basic_Decl;
Cast_Result_4 : Internal_Entity;
Is_Equiv : Boolean;
If_Result_2 : Boolean;
If_Result_3 : Internal_Entity_Defining_Name_Array_Access;
Scope_Result_2 : Internal_Entity_Defining_Name_Array_Access;
Result_Var_2 : Internal_Entity_Defining_Name_Array_Access;
Is_Equal_1 : Boolean;
Not_Val : Boolean;
If_Result_4 : Internal_Entity_Defining_Name_Array_Access;
Let_Result : Internal_Entity_Defining_Name_Array_Access;
Scope_Result_3 : Internal_Entity_Defining_Name_Array_Access;
Fld_9 : Bare_Declarative_Part;
Fld_10 : Bare_Ada_Node_List;
Item_324 : Bare_Ada_Node;
Is_A_1 : Boolean;
Node_Comp : Boolean;
If_Result_5 : Boolean;
Map_Result : Bare_Ada_Node_Array_Access;
Len_1 : Integer;
Arith_Result : Integer;
Get_Result_1 : Bare_Ada_Node;
Scope_Result_4 : Bare_Ada_Node;
Result_Var_3 : Bare_Ada_Node;
Cast_Result_5 : Bare_Basic_Decl;
As_Entity_2 : Internal_Entity_Basic_Decl;
Is_Null_2 : Boolean;
If_Result_6 : Internal_Entity_Basic_Decl;
Singleton_2 : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result_5 : Internal_Entity_Basic_Decl_Array_Access;
Result_Var_4 : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result_6 : Internal_Entity_Basic_Decl_Array_Access;
Result_Var_5 : Internal_Entity_Basic_Decl_Array_Access;
Scope_Result_7 : Internal_Entity_Basic_Decl_Array_Access;
Singleton_3 : Internal_Entity_Basic_Decl_Array_Access;
Result_Var_6 : Internal_Entity_Basic_Decl_Array_Access;
Singleton_4 : Internal_Entity_Basic_Decl_Array_Access;
Fld_11 : Internal_Entity_Identifier;
Fld_12 : Symbol_Type;
Fld_13 : Boolean;
If_Result_7 : Internal_Entity_Basic_Decl_Array_Access;
Fld_14 : Internal_Entity_Defining_Name;
Map_Result_1 : Internal_Entity_Defining_Name_Array_Access;
Result_Var_7 : Internal_Entity_Defining_Name_Array_Access;
Let_Result_1 : Internal_Entity_Defining_Name_Array_Access;
            procedure Finalizer_Scope_783 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Node_Parents);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Scope_Result_6);
                     Dec_Ref (Result_Var_5);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (Singleton_3);
                     Dec_Ref (Result_Var_6);
                     Dec_Ref (Singleton_4);
                     Dec_Ref (If_Result_7);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Result_Var_7);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_783;
            procedure Finalizer_Scope_2953 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2953;
            procedure Finalizer_Scope_2955 is
            begin
                     Dec_Ref (Var_Expr_1);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (P);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (If_Result_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_2955;
            procedure Finalizer_Scope_2961 is
            begin
                     Dec_Ref (Var_Expr_6);
            end Finalizer_Scope_2961;
            procedure Finalizer_Scope_2962 is
            begin
                     Dec_Ref (Singleton_1);
                     Dec_Ref (If_Result_3);
            end Finalizer_Scope_2962;
            procedure Finalizer_Scope_2963 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Result_Var_4);
            end Finalizer_Scope_2963;
            procedure Finalizer_Scope_2965 is
            begin
                     Dec_Ref (Var_Expr_5);
            end Finalizer_Scope_2965;
            procedure Finalizer_Scope_2966 is
            begin
                     Dec_Ref (Singleton_2);
            end Finalizer_Scope_2966;
            procedure Finalizer_Scope_2967 is
            begin
                     Dec_Ref (Var_Expr_2);
            end Finalizer_Scope_2967;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10541 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 10501 '<Cast to CompilationUnit at ast.py:9730>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9730
--# expr-start 10500 '<parent at ast.py:9730>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9730
--# expr-start 10499 '<parent at ast.py:9730>' Fld /tmp/lal-23.0.0/ada/ast.py:9730
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 10499
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 10500
   if Fld_1 = null
      or else Fld_1.Kind in Ada_Compilation_Unit_Range
   then
      Cast_Result := Fld_1;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 10501
Var_Expr := Cast_Result;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind cu Var_Expr
--# expr-start 10506 '<FieldAccess for defining_name at ast.py:9732>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9732
--# expr-start 10505 '<as_entity at ast.py:9732>' If_Result /tmp/lal-23.0.0/ada/ast.py:9732
--# expr-start 10504 '<FieldAccess for item at ast.py:9732>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9732
--# expr-start 10503 '<Cast to LibraryItem at ast.py:9731>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9731
--# expr-start 10502 '<FieldAccess for body at ast.py:9731>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9731
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Var_Expr.Compilation_Unit_F_Body;
--# expr-done 10502
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Library_Item_Range
   then
      Cast_Result_1 := Fld_2;
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 10503
      if Cast_Result_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Cast_Result_1.Library_Item_F_Item;
--# expr-done 10504
Is_Null := Fld_3 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => E_Info, Node => Fld_3); 
   If_Result := As_Entity;
end if;
--# expr-done 10505
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => If_Result.Node, E_Info => If_Result.Info);
--# end
--# expr-done 10506
                Singleton := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_4;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2953;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (Result_Var);
Block_Var := Result_Var; Inc_Ref (Block_Var);
--# bind top_level_decl Block_Var
--# expr-start 10511 '<as_entity at ast.py:9738>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:9738
--# expr-start 10510 '<Cast to BasicDecl at ast.py:9738>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:9738
--# expr-start 10509 '<Find at ast.py:9736>' Find_Result /tmp/lal-23.0.0/ada/ast.py:9736
   --# expr-start 10507 '<FieldAccess for parents at ast.py:9736>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:9736
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 10507
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_322 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_322
      --# expr-start 10508 '<IsA BasicDecl at ast.py:9737>' Is_A /tmp/lal-23.0.0/ada/ast.py:9737
Is_A := Item_322 /= null 
and then Item_322.Kind in Ada_Basic_Decl; 
--# expr-done 10508
      if Is_A then
         Find_Result := Item_322;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 10509
   if Find_Result = null
      or else Find_Result.Kind in Ada_Basic_Decl
   then
      Cast_Result_2 := Find_Result;
   else
         Cast_Result_2 := No_Bare_Ada_Node;
   end if;
--# expr-done 10510
Is_Null_1 := Cast_Result_2 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity_Basic_Decl;
else
As_Entity_1 := (Info => E_Info, Node => Cast_Result_2); 
   If_Result_1 := As_Entity_1;
end if;
--# expr-done 10511
Block_Var_1 := If_Result_1; 
--# bind enclosing_program_unit Block_Var_1
--# expr-start 10512 '<FieldAccess for associated_entity_names at ast.py:9751>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9751
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.associated_entity_names
Fld_5 := Libadalang.Implementation.Pragma_Node_P_Associated_Entity_Names (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10512
Var_Expr_1 := Fld_5;
      Inc_Ref (Var_Expr_1);
if Var_Expr_1 /= No_Internal_Entity_Name_Array_Type then
   --# scope-start
   --# bind names Var_Expr_1
--# expr-start 10524 '<Let at ast.py:9752>' Let_Result /tmp/lal-23.0.0/ada/ast.py:9752
--# scope-start
--# expr-start 10513 '<FieldAccess for associated_entities_helper at ast.py:9753>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9753
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.associated_entities_helper
Fld_6 := Libadalang.Implementation.Pragma_Node_P_Associated_Entities_Helper (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10513
Var_Expr_6 := Fld_6;
      Inc_Ref (Var_Expr_6);
if Var_Expr_6 /= No_Internal_Entity_Defining_Name_Array_Type then
   --# scope-start
   --# bind e Var_Expr_6
Scope_Result_1 := Var_Expr_6;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2961;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Block_Var;
end if;
      Inc_Ref (Result_Var_1);
P := Result_Var_1; Inc_Ref (P);
--# bind p P
--# expr-start 10523 '<If at ast.py:9754>' If_Result_4 /tmp/lal-23.0.0/ada/ast.py:9754
--# expr-start 10515 '<Not at ast.py:9755>' Not_Val /tmp/lal-23.0.0/ada/ast.py:9755
--# expr-start 10514 '<Eq at ast.py:9755>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:9755
Is_Equal_1 := Equivalent (P, No_Internal_Entity_Defining_Name_Array_Type); 
--# expr-done 10514
Not_Val := not (Is_Equal_1); 
--# expr-done 10515
if Not_Val then
   If_Result_4 := P;
else
Var_Expr_7 := Block_Var_1;
if Var_Expr_7 /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind epu Var_Expr_7
--# expr-start 10522 '<If at ast.py:9757>' If_Result_3 /tmp/lal-23.0.0/ada/ast.py:9757
--# expr-start 10517 '<Eq at ast.py:9759>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:9759
--# expr-start 10516 '<length at ast.py:9759>' Len /tmp/lal-23.0.0/ada/ast.py:9759
Len := Length (Var_Expr_1); 
--# expr-done 10516
Is_Equal := Len = 1; 
--# expr-done 10517
if Is_Equal then
   --# expr-start 10520 '<Eq at ast.py:9760>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:9760
--# expr-start 10519 '<FieldAccess for referenced_decl at ast.py:9760>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9760
--# expr-start 10518 '<at at ast.py:9760>' Get_Result /tmp/lal-23.0.0/ada/ast.py:9760
Get_Result := Get (Self, Var_Expr_1, 0, True); 
--# expr-done 10518
      if Get_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.referenced_decl
Fld_8 := Libadalang.Implementation.Name_P_Referenced_Decl (Node => Get_Result.Node, Imprecise_Fallback => False, E_Info => Get_Result.Info);
--# end
--# expr-done 10519
      Cast_Result_3 := Create_Internal_Entity
        (Node => Fld_8.Node,
         Info => Fld_8.Info);
Cast_Expr := Var_Expr_7; 
      Cast_Result_4 := Create_Internal_Entity
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
Is_Equiv := Equivalent (Cast_Result_3, Cast_Result_4); 
--# expr-done 10520
   If_Result_2 := Is_Equiv;
else
   If_Result_2 := False;
end if;
if If_Result_2 then
   --# expr-start 10521 '<FieldAccess for defining_name at ast.py:9762>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9762
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_7 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Var_Expr_7.Node, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 10521
                Singleton_1 := Create_Internal_Entity_Defining_Name_Array (Items_Count => 1);
                Singleton_1.Items (1) := Fld_7;
   If_Result_3 := Singleton_1;
else
   If_Result_3 := No_Internal_Entity_Defining_Name_Array_Type;
end if;
      Inc_Ref (If_Result_3);
--# expr-done 10522
Scope_Result_2 := If_Result_3;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2962;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Block_Var;
end if;
      Inc_Ref (Result_Var_2);
   If_Result_4 := Result_Var_2;
end if;
      Inc_Ref (If_Result_4);
--# expr-done 10523
Let_Result := If_Result_4; Inc_Ref (Let_Result);
--# end
--# expr-done 10524
Scope_Result_3 := Let_Result;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2955;
   Result_Var_7 := Scope_Result_3;
else
   --# expr-start 10540 '<Map at ast.py:9786>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:9786
   --# expr-start 10538 '<If at ast.py:9767>' If_Result_7 /tmp/lal-23.0.0/ada/ast.py:9767
--# expr-start 10527 '<FieldAccess for is_contract_aspect at ast.py:9769>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:9769
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10526 '<FieldAccess for name_symbol at ast.py:9769>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:9769
--# expr-start 10525 '<FieldAccess for id at ast.py:9769>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9769
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Identifier (Node => Ent.Node.Pragma_Node_F_Id, Info => Ent.Info);
--# expr-done 10525
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.name_symbol'
Fld_12 := Libadalang.Implementation.Dispatcher_Name_P_Name_Symbol (Node => Fld_11.Node);
--# end
--# expr-done 10526
--# property-call-start AdaNode.is_contract_aspect
Fld_13 := Libadalang.Implementation.Ada_Node_P_Is_Contract_Aspect (Node => Self, Name => Fld_12);
--# end
--# expr-done 10527
if Fld_13 then
--# expr-start 10528 '<FieldAccess for declarative_scope at ast.py:9773>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9773
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.declarative_scope
Fld_9 := Libadalang.Implementation.Ada_Node_P_Declarative_Scope (Node => Ent.Node);
--# end
--# expr-done 10528
Var_Expr_3 := Fld_9;
if Var_Expr_3 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind decl_scope Var_Expr_3
--# expr-start 10537 '<as_entity at ast.py:9778>' If_Result_6 /tmp/lal-23.0.0/ada/ast.py:9778
--# expr-start 10536 '<Cast to BasicDecl at ast.py:9778>' Cast_Result_5 /tmp/lal-23.0.0/ada/ast.py:9778
--# expr-start 10532 '<Filter at ast.py:9774>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9774
   --# expr-start 10529 '<FieldAccess for decls at ast.py:9774>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9774
      if Var_Expr_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Var_Expr_3.Declarative_Part_F_Decls;
--# expr-done 10529
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld_10 = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Ada_Node_List := Fld_10;
      begin
         for Untyped_Item_324 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_324 := Untyped_Item_324; 
   --# scope-start
               --# bind decl Item_324
--# expr-start 10530 '<IsA BasicDecl at ast.py:9775>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:9775
Is_A_1 := Item_324 /= null 
and then Item_324.Kind in Ada_Basic_Decl; 
--# expr-done 10530
if Is_A_1 then
   --# expr-start 10531 '<OrderingTest '"'"'gt'"'"' at ast.py:9775>' Node_Comp /tmp/lal-23.0.0/ada/ast.py:9775
Node_Comp := Compare (Self, Self, Item_324, Greater_Than); 
--# expr-done 10531
   If_Result_5 := Node_Comp;
else
   If_Result_5 := False;
end if;
         if If_Result_5 then
         declare
            Item_To_Append : constant Bare_Ada_Node := Item_324;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10532
Var_Expr_5 := Map_Result;
      Inc_Ref (Var_Expr_5);
if Var_Expr_5 /= No_Bare_Ada_Node_Array_Type then
   --# scope-start
   --# bind decls Var_Expr_5
--# expr-start 10535 '<at at ast.py:9777>' Get_Result_1 /tmp/lal-23.0.0/ada/ast.py:9777
--# expr-start 10534 '<Arithmetic - at ast.py:9777>' Arith_Result /tmp/lal-23.0.0/ada/ast.py:9777
--# expr-start 10533 '<length at ast.py:9777>' Len_1 /tmp/lal-23.0.0/ada/ast.py:9777
Len_1 := Length (Var_Expr_5); 
--# expr-done 10533
Arith_Result := (Len_1 - 1); 
--# expr-done 10534
Get_Result_1 := Get (Self, Var_Expr_5, Arith_Result, True); 
--# expr-done 10535
Scope_Result_4 := Get_Result_1;
   --# end
      Finalizer_Scope_2965;
   Result_Var_3 := Scope_Result_4;
else
   Result_Var_3 := No_Bare_Ada_Node;
end if;
   if Result_Var_3 = null
      or else Result_Var_3.Kind in Ada_Basic_Decl
   then
      Cast_Result_5 := Result_Var_3;
   else
         Cast_Result_5 := No_Bare_Ada_Node;
   end if;
--# expr-done 10536
Is_Null_2 := Cast_Result_5 = null; 
if Is_Null_2 then
   If_Result_6 := No_Entity_Basic_Decl;
else
As_Entity_2 := (Info => E_Info, Node => Cast_Result_5); 
   If_Result_6 := As_Entity_2;
end if;
--# expr-done 10537
Var_Expr_4 := If_Result_6;
if Var_Expr_4 /= No_Entity_Basic_Decl then
   --# scope-start
                Singleton_2 := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton_2.Items (1) := Var_Expr_4;
Scope_Result_5 := Singleton_2;
   Inc_Ref (Scope_Result_5);
   --# end
      Finalizer_Scope_2966;
   Result_Var_4 := Scope_Result_5;
else
   Result_Var_4 := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_4);
Scope_Result_6 := Result_Var_4;
   Inc_Ref (Scope_Result_6);
   --# end
      Finalizer_Scope_2963;
   Result_Var_5 := Scope_Result_6;
else
   Result_Var_5 := No_Internal_Entity_Basic_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_5);
Var_Expr_2 := Result_Var_5;
      Inc_Ref (Var_Expr_2);
if Var_Expr_2 /= No_Internal_Entity_Basic_Decl_Array_Type then
   --# scope-start
   --# bind e Var_Expr_2
Scope_Result_7 := Var_Expr_2;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_2967;
   Result_Var_6 := Scope_Result_7;
else
                Singleton_3 := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton_3.Items (1) := Block_Var_1;
   Result_Var_6 := Singleton_3;
end if;
      Inc_Ref (Result_Var_6);
   If_Result_7 := Result_Var_6;
else
                Singleton_4 := Create_Internal_Entity_Basic_Decl_Array (Items_Count => 1);
                Singleton_4.Items (1) := Block_Var_1;
   If_Result_7 := Singleton_4;
end if;
      Inc_Ref (If_Result_7);
--# expr-done 10538
      declare
         Map_Result_1_Vec : Internal_Entity_Defining_Name_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Basic_Decl_Array_Access := If_Result_7;
      begin
         for Item_323 of
               Collection.Items
         loop
   --# scope-start
               --# bind bd Item_323
      --# expr-start 10539 '<FieldAccess for defining_name at ast.py:9786>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:9786
      if Item_323.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_14 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Item_323.Node, E_Info => Item_323.Info);
--# end
--# expr-done 10539
         declare
            Item_To_Append : constant Internal_Entity_Defining_Name := Fld_14;
         begin
            Internal_Entity_Defining_Name_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result_1 := Create_Internal_Entity_Defining_Name_Array
           (Items_Count => Natural (Internal_Entity_Defining_Name_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Defining_Name_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Defining_Name_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Defining_Name_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 10540
   Result_Var_7 := Map_Result_1;
end if;
      Inc_Ref (Result_Var_7);
Let_Result_1 := Result_Var_7; Inc_Ref (Let_Result_1);
--# end
--# expr-done 10541
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_783;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_783;
               Finalizer_Scope_2953;
               Finalizer_Scope_2955;
               Finalizer_Scope_2961;
               Finalizer_Scope_2962;
               Finalizer_Scope_2963;
               Finalizer_Scope_2965;
               Finalizer_Scope_2966;
               Finalizer_Scope_2967;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Associated_Entities;
--# end
--# property-start Pragma.initial_env /tmp/lal-23.0.0/ada/ast.py:9790
pragma Warnings (Off, "is not referenced");
 function Pragma_Node_P_Initial_Env
  (Node : Bare_Pragma_Node
  )
   return Internal_Designated_Env
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_784 with Inline_Always;
      Sym : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
If_Result : Internal_Designated_Env := No_Designated_Env;
Let_Result : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_784 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_784;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10549 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10548 '<If at ast.py:9795>' If_Result /tmp/lal-23.0.0/ada/ast.py:9795
--# expr-start 10544 '<IsA CompilationUnit at ast.py:9796>' Is_A /tmp/lal-23.0.0/ada/ast.py:9796
--# expr-start 10543 '<parent at ast.py:9796>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9796
--# expr-start 10542 '<parent at ast.py:9796>' Fld /tmp/lal-23.0.0/ada/ast.py:9796
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 10542
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 10543
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 10544
if Is_A then
   --# expr-start 10546 '<New DesignatedEnv at ast.py:9797>' New_Struct /tmp/lal-23.0.0/ada/ast.py:9797
--# expr-start 10545 '<Symbol Standard at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Standard); 
--# expr-done 10545
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Sym, Kind => Named_Env); 
--# expr-done 10546
   If_Result := New_Struct;
else
   --# expr-start 10547 '<New DesignatedEnv at ast.py:9798>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:9798
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 10547
   If_Result := New_Struct_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 10548
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 10549
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_784;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_784;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Pragma_Node_P_Initial_Env;
--# end
--# property-start Pragma._initial_env_36 /tmp/lal-23.0.0/ada/ast.py:9802
pragma Warnings (Off, "is not referenced");
 function Initial_Env_36
  (Node : Bare_Pragma_Node
  )
   return Internal_Designated_Env
is
   Self : Bare_Pragma_Node := Bare_Pragma_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1505 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1505 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1505;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10550 '<FieldAccess for initial_env at ast.py:9802>' Fld /tmp/lal-23.0.0/ada/ast.py:9802
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Pragma.initial_env
Fld := Libadalang.Implementation.Pragma_Node_P_Initial_Env (Node => Self);
--# end
--# expr-done 10550
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1505;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1505;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_36;
--# end
   --
   --  Primitives for Bare_Private_Node
   --
--# property-start '[dispatcher]Private.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Private_Node_P_As_Bool
  (Node : Bare_Private_Node
  )
   return Boolean
is
   Self : Bare_Private_Node := Bare_Private_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Private_Node (Self.Kind) is
               when Ada_Private_Absent =>
                  --# property-call-start Private.Absent.as_bool
                  Property_Result := Private_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Private_Present =>
                  --# property-call-start Private.Present.as_bool
                  Property_Result := Private_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Private_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Private_Absent
   --
--# property-start Private.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:4989
pragma Warnings (Off, "is not referenced");
 function Private_Absent_P_As_Bool
  (Node : Bare_Private_Absent
  )
   return Boolean
is
   Self : Bare_Private_Absent := Bare_Private_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Private_Present
   --
--# property-start Private.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:4989
pragma Warnings (Off, "is not referenced");
 function Private_Present_P_As_Bool
  (Node : Bare_Private_Present
  )
   return Boolean
is
   Self : Bare_Private_Present := Bare_Private_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Protected_Def
   --
      procedure Initialize_Fields_For_Protected_Def
        (Self : Bare_Protected_Def
         ; Protected_Def_F_Public_Part : Bare_Public_Part
         ; Protected_Def_F_Private_Part : Bare_Private_Part
         ; Protected_Def_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Protected_Def_F_Public_Part := Protected_Def_F_Public_Part;
            Self.Protected_Def_F_Private_Part := Protected_Def_F_Private_Part;
            Self.Protected_Def_F_End_Name := Protected_Def_F_End_Name;
      end Initialize_Fields_For_Protected_Def;
   function Protected_Def_F_Public_Part
     (Node : Bare_Protected_Def) return Bare_Public_Part
   is
   begin
         return Node.Protected_Def_F_Public_Part;
   end;
   function Protected_Def_F_Private_Part
     (Node : Bare_Protected_Def) return Bare_Private_Part
   is
   begin
         return Node.Protected_Def_F_Private_Part;
   end;
   function Protected_Def_F_End_Name
     (Node : Bare_Protected_Def) return Bare_End_Name
   is
   begin
         return Node.Protected_Def_F_End_Name;
   end;
   --
   --  Primitives for Bare_Protected_Node
   --
--# property-start '[dispatcher]Protected.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Protected_Node_P_As_Bool
  (Node : Bare_Protected_Node
  )
   return Boolean
is
   Self : Bare_Protected_Node := Bare_Protected_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Protected_Node (Self.Kind) is
               when Ada_Protected_Absent =>
                  --# property-call-start Protected.Absent.as_bool
                  Property_Result := Protected_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Protected_Present =>
                  --# property-call-start Protected.Present.as_bool
                  Property_Result := Protected_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Protected_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Protected_Absent
   --
--# property-start Protected.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5069
pragma Warnings (Off, "is not referenced");
 function Protected_Absent_P_As_Bool
  (Node : Bare_Protected_Absent
  )
   return Boolean
is
   Self : Bare_Protected_Absent := Bare_Protected_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Protected_Present
   --
--# property-start Protected.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5069
pragma Warnings (Off, "is not referenced");
 function Protected_Present_P_As_Bool
  (Node : Bare_Protected_Present
  )
   return Boolean
is
   Self : Bare_Protected_Present := Bare_Protected_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Protected_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Quantifier
   --
   --
   --  Primitives for Bare_Quantifier_All
   --
   --
   --  Primitives for Bare_Quantifier_Some
   --
   --
   --  Primitives for Bare_Range_Spec
   --
      procedure Initialize_Fields_For_Range_Spec
        (Self : Bare_Range_Spec
         ; Range_Spec_F_Range : Bare_Expr
        ) is
      begin
            Self.Range_Spec_F_Range := Range_Spec_F_Range;
      end Initialize_Fields_For_Range_Spec;
   function Range_Spec_F_Range
     (Node : Bare_Range_Spec) return Bare_Expr
   is
   begin
         return Node.Range_Spec_F_Range;
   end;
--# property-start RangeSpec.xref_stop_resolution /tmp/lal-23.0.0/ada/ast.py:20729
pragma Warnings (Off, "is not referenced");
 function Range_Spec_P_Xref_Stop_Resolution
  (Node : Bare_Range_Spec
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Range_Spec := Bare_Range_Spec (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Is_A : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10552 '<IsA ComponentClause at ast.py:20729>' Is_A /tmp/lal-23.0.0/ada/ast.py:20729
--# expr-start 10551 '<parent at ast.py:20729>' Fld /tmp/lal-23.0.0/ada/ast.py:20729
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 10551
Is_A := Fld /= null 
and then Fld.Kind in Ada_Component_Clause_Range; 
--# expr-done 10552
      Property_Result := Is_A;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Range_Spec_P_Xref_Stop_Resolution;
--# end
--# property-start RangeSpec.xref_equation /tmp/lal-23.0.0/ada/ast.py:20730
pragma Warnings (Off, "is not referenced");
 function Range_Spec_P_Xref_Equation
  (Node : Bare_Range_Spec
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Range_Spec := Bare_Range_Spec (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Range_Spec :=
     Internal_Entity_Range_Spec'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1456 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Fld_4 : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
True_Rel : Logic_Equation;
Fld_7 : Bare_Ada_Node;
Is_A : Boolean;
If_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
            procedure Finalizer_Scope_1456 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (True_Rel);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_1456;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10564 '<And at ast.py:20730>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:20730
--# expr-start 10554 '<FieldAccess for xref_equation at ast.py:20730>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20730
--# expr-start 10553 '<FieldAccess for range at ast.py:20730>' Fld /tmp/lal-23.0.0/ada/ast.py:20730
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Range_Spec_F_Range, Info => Ent.Info);
--# expr-done 10553
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10554
--# expr-start 10563 '<If at ast.py:20730>' If_Result /tmp/lal-23.0.0/ada/ast.py:20730
--# expr-start 10556 '<IsA ComponentClause, SignedIntTypeDef at ast.py:20733>' Is_A /tmp/lal-23.0.0/ada/ast.py:20733
--# expr-start 10555 '<parent at ast.py:20733>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:20733
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Parent; 
--# expr-done 10555
Is_A := Fld_7 /= null 
and then Fld_7.Kind in Ada_Component_Clause_Range | Ada_Signed_Int_Type_Def_Range; 
--# expr-done 10556
if Is_A then
   --# expr-start 10562 '<And at ast.py:20735>' And_Pred /tmp/lal-23.0.0/ada/ast.py:20735
--# expr-start 10559 '<FieldAccess for universal_int_bind at ast.py:20735>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20735
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10558 '<FieldAccess for expected_type_var at ast.py:20735>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20735
--# expr-start 10557 '<FieldAccess for range at ast.py:20735>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20735
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Range_Spec_F_Range;
--# expr-done 10557
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2);
--# expr-done 10558
--# property-call-start AdaNode.universal_int_bind
Fld_4 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Self, Type_Var => Fld_3, Origin => Origin);
--# end
--# expr-done 10559
--# expr-start 10561 '<FieldAccess for matches_expected_type at ast.py:20736>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:20736
--# expr-start 10560 '<FieldAccess for range at ast.py:20736>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:20736
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Range_Spec_F_Range, Info => Ent.Info);
--# expr-done 10560
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 10561
And_Pred := Create_And (Fld_4, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20735") else null)); 
--# expr-done 10562
   If_Result := And_Pred;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20738") else null)); 
   If_Result := True_Rel;
end if;
      Inc_Ref (If_Result);
--# expr-done 10563
And_Pred_1 := Create_And (Fld_1, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20730") else null)); 
--# expr-done 10564
      Property_Result := And_Pred_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1456;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1456;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Range_Spec_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Renaming_Clause
   --
      procedure Initialize_Fields_For_Renaming_Clause
        (Self : Bare_Renaming_Clause
         ; Renaming_Clause_F_Renamed_Object : Bare_Name
        ) is
      begin
            Self.Renaming_Clause_F_Renamed_Object := Renaming_Clause_F_Renamed_Object;
      end Initialize_Fields_For_Renaming_Clause;
   function Renaming_Clause_F_Renamed_Object
     (Node : Bare_Renaming_Clause) return Bare_Name
   is
   begin
         return Node.Renaming_Clause_F_Renamed_Object;
   end;
   --
   --  Primitives for Bare_Synthetic_Renaming_Clause
   --
      procedure Initialize_Fields_For_Synthetic_Renaming_Clause
        (Self : Bare_Synthetic_Renaming_Clause
         ; Renaming_Clause_F_Renamed_Object : Bare_Name
        ) is
      begin
            Initialize_Fields_For_Renaming_Clause
              (Self, Renaming_Clause_F_Renamed_Object);
      end Initialize_Fields_For_Synthetic_Renaming_Clause;
   --
   --  Primitives for Bare_Reverse_Node
   --
--# property-start '[dispatcher]Reverse.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Reverse_Node_P_As_Bool
  (Node : Bare_Reverse_Node
  )
   return Boolean
is
   Self : Bare_Reverse_Node := Bare_Reverse_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Reverse_Node (Self.Kind) is
               when Ada_Reverse_Absent =>
                  --# property-call-start Reverse.Absent.as_bool
                  Property_Result := Reverse_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Reverse_Present =>
                  --# property-call-start Reverse.Present.as_bool
                  Property_Result := Reverse_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Reverse_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Reverse_Absent
   --
--# property-start Reverse.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5037
pragma Warnings (Off, "is not referenced");
 function Reverse_Absent_P_As_Bool
  (Node : Bare_Reverse_Absent
  )
   return Boolean
is
   Self : Bare_Reverse_Absent := Bare_Reverse_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Reverse_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Reverse_Present
   --
--# property-start Reverse.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5037
pragma Warnings (Off, "is not referenced");
 function Reverse_Present_P_As_Bool
  (Node : Bare_Reverse_Present
  )
   return Boolean
is
   Self : Bare_Reverse_Present := Bare_Reverse_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Reverse_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Select_When_Part
   --
      procedure Initialize_Fields_For_Select_When_Part
        (Self : Bare_Select_When_Part
         ; Select_When_Part_F_Cond_Expr : Bare_Expr
         ; Select_When_Part_F_Stmts : Bare_Stmt_List
        ) is
      begin
            Self.Select_When_Part_F_Cond_Expr := Select_When_Part_F_Cond_Expr;
            Self.Select_When_Part_F_Stmts := Select_When_Part_F_Stmts;
      end Initialize_Fields_For_Select_When_Part;
   function Select_When_Part_F_Cond_Expr
     (Node : Bare_Select_When_Part) return Bare_Expr
   is
   begin
         return Node.Select_When_Part_F_Cond_Expr;
   end;
   function Select_When_Part_F_Stmts
     (Node : Bare_Select_When_Part) return Bare_Stmt_List
   is
   begin
         return Node.Select_When_Part_F_Stmts;
   end;
--# property-start SelectWhenPart.xref_equation /tmp/lal-23.0.0/ada/ast.py:20243
pragma Warnings (Off, "is not referenced");
 function Select_When_Part_P_Xref_Equation
  (Node : Bare_Select_When_Part
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Select_When_Part := Bare_Select_When_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Select_When_Part :=
     Internal_Entity_Select_When_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1424 with Inline_Always;
            procedure Finalizer_Scope_3126 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1424 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1424;
            procedure Finalizer_Scope_3126 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3126;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10573 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10565 '<FieldAccess for cond_expr at ast.py:20244>' Fld /tmp/lal-23.0.0/ada/ast.py:20244
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Select_When_Part_F_Cond_Expr, Info => Ent.Info);
--# expr-done 10565
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 10572 '<And at ast.py:20245>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:20245
--# expr-start 10570 '<And at ast.py:20245>' And_Pred /tmp/lal-23.0.0/ada/ast.py:20245
--# expr-start 10568 '<Bind at ast.py:20246>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:20246
--# expr-start 10566 '<FieldAccess for expected_type_var at ast.py:20246>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20246
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 10566
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10567 '<FieldAccess for bool_type at ast.py:20246>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20246
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10567
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20246") else null)); 
--# expr-done 10568
--# expr-start 10569 '<FieldAccess for sub_equation at ast.py:20247>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20247
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10569
And_Pred := Create_And (Bind_Result, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20245") else null)); 
--# expr-done 10570
--# expr-start 10571 '<FieldAccess for matches_expected_formal_prim_type at ast.py:20248>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20248
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_4 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 10571
And_Pred_1 := Create_And (And_Pred, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20245") else null)); 
--# expr-done 10572
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3126;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20250") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 10573
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1424;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1424;
               Finalizer_Scope_3126;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Select_When_Part_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Stmt
   --
--# property-start Stmt.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:19596
pragma Warnings (Off, "is not referenced");
 function Stmt_P_Xref_Entry_Point
  (Node : Bare_Stmt
  )
   return Boolean
is
   Self : Bare_Stmt := Bare_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Stmt_P_Xref_Entry_Point;
--# end
--# property-start Stmt.is_ghost_code /tmp/lal-23.0.0/ada/ast.py:19599
pragma Warnings (Off, "is not referenced");
 function Stmt_P_Is_Ghost_Code
  (Node : Bare_Stmt
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Stmt := Bare_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Stmt :=
     Internal_Entity_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Refd_Def;
Match_0 : Internal_Entity_Assign_Stmt;
Match_1 : Internal_Entity_Call_Stmt;
Match_2 : Internal_Entity_Stmt;
Var_Expr_2 : Internal_Entity_Defining_Name;
Fld : Internal_Entity_Basic_Decl;
Fld_1 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Fld_2 : Internal_Entity_Name;
Fld_3 : Internal_Refd_Def;
Fld_4 : Internal_Entity_Name;
Fld_5 : Internal_Refd_Def;
Match_Prefix : Internal_Entity_Stmt;
Cast_Result : Internal_Entity_Assign_Stmt;
Let_Result : Internal_Refd_Def;
Scope_Result_1 : Internal_Refd_Def;
Cast_Result_1 : Internal_Entity_Call_Stmt;
Let_Result_1 : Internal_Refd_Def;
Scope_Result_2 : Internal_Refd_Def;
Cast_Result_2 : Internal_Entity_Stmt;
Let_Result_2 : Internal_Refd_Def;
Scope_Result_3 : Internal_Refd_Def;
Match_Result : Internal_Refd_Def;
Fld_6 : Internal_Entity_Defining_Name;
Fld_7 : Boolean;
Scope_Result_4 : Boolean;
Result_Var_1 : Boolean;
Fld_8 : Ref_Result_Kind;
Is_Equal : Boolean;
If_Result : Boolean;
Scope_Result_5 : Boolean;
Result_Var_2 : Boolean;
If_Result_1 : Boolean;
Let_Result_3 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10586 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 10574 '<FieldAccess for parent_basic_decl at ast.py:19606>' Fld /tmp/lal-23.0.0/ada/ast.py:19606
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.parent_basic_decl
Fld := Libadalang.Implementation.Ada_Node_P_Parent_Basic_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10574
Var_Expr := Fld;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind bd Var_Expr
--# expr-start 10575 '<FieldAccess for is_ghost_code at ast.py:19607>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19607
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.is_ghost_code
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Is_Ghost_Code (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 10575
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
if Result_Var then
   If_Result_1 := True;
else
--# expr-start 10580 '<Match at ast.py:19612>' Match_Result /tmp/lal-23.0.0/ada/ast.py:19612
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Stmt (Match_Prefix.Node.Kind) is
         when Ada_Assign_Stmt =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Assign_Stmt
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind ass Match_0
--# expr-start 10577 '<FieldAccess for failsafe_referenced_def_name at ast.py:19613>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19613
--# expr-start 10576 '<FieldAccess for dest at ast.py:19613>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19613
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Match_0.Node.Assign_Stmt_F_Dest, Info => Match_0.Info);
--# expr-done 10576
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.failsafe_referenced_def_name
Fld_3 := Libadalang.Implementation.Name_P_Failsafe_Referenced_Def_Name (Node => Fld_2.Node, Imprecise_Fallback => False, E_Info => Fld_2.Info);
--# end
--# expr-done 10577
Let_Result := Fld_3; 
--# end
Scope_Result_1 := Let_Result;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Call_Stmt =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Call_Stmt
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind call Match_1
--# expr-start 10579 '<FieldAccess for failsafe_referenced_def_name at ast.py:19614>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19614
--# expr-start 10578 '<FieldAccess for call at ast.py:19614>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19614
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Name (Node => Match_1.Node.Call_Stmt_F_Call, Info => Match_1.Info);
--# expr-done 10578
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.failsafe_referenced_def_name
Fld_5 := Libadalang.Implementation.Name_P_Failsafe_Referenced_Def_Name (Node => Fld_4.Node, Imprecise_Fallback => False, E_Info => Fld_4.Info);
--# end
--# expr-done 10579
Let_Result_1 := Fld_5; 
--# end
Scope_Result_2 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_2; 
         when Ada_Accept_Stmt .. Ada_Abort_Stmt | Ada_Delay_Stmt .. Ada_Terminate_Alternative =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Stmt
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Refd_Def; 
--# end
Scope_Result_3 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_3; 
end case;
--# expr-done 10580
Var_Expr_1 := Match_Result;
if Var_Expr_1 /= No_Refd_Def then
   --# scope-start
   --# bind res Var_Expr_1
--# expr-start 10585 '<If at ast.py:19616>' If_Result /tmp/lal-23.0.0/ada/ast.py:19616
--# expr-start 10582 '<Eq at ast.py:19623>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19623
--# expr-start 10581 '<FieldAccess for kind at ast.py:19623>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19623
Fld_8 := Var_Expr_1.Kind;
--# expr-done 10581
Is_Equal := Fld_8 = Error; 
--# expr-done 10582
if Is_Equal then
   If_Result := raise Property_Error with "Name resolution error";
else
--# expr-start 10583 '<FieldAccess for def_name at ast.py:19625>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19625
Fld_6 := Var_Expr_1.Def_Name;
--# expr-done 10583
Var_Expr_2 := Fld_6;
if Var_Expr_2 /= No_Entity_Defining_Name then
   --# scope-start
--# expr-start 10584 '<FieldAccess for is_ghost_code at ast.py:19625>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19625
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start DefiningName.is_ghost_code
Fld_7 := Libadalang.Implementation.Defining_Name_P_Is_Ghost_Code (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 10584
Scope_Result_4 := Fld_7;
   --# end
   Result_Var_1 := Scope_Result_4;
else
   Result_Var_1 := False;
end if;
   If_Result := Result_Var_1;
end if;
--# expr-done 10585
Scope_Result_5 := If_Result;
   --# end
   Result_Var_2 := Scope_Result_5;
else
   Result_Var_2 := False;
end if;
   If_Result_1 := Result_Var_2;
end if;
Let_Result_3 := If_Result_1; 
--# end
--# expr-done 10586
      Property_Result := Let_Result_3;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Stmt_P_Is_Ghost_Code;
--# end
   --
   --  Primitives for Bare_Composite_Stmt
   --
   --
   --  Primitives for Bare_Accept_Stmt
   --
      procedure Accept_Stmt_Pre_Env_Actions
        (Self            : Bare_Accept_Stmt;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_158 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Accept_Stmt
        (Self : Bare_Accept_Stmt
         ; Accept_Stmt_F_Name : Bare_Identifier
         ; Accept_Stmt_F_Entry_Index_Expr : Bare_Expr
         ; Accept_Stmt_F_Params : Bare_Entry_Completion_Formal_Params
        ) is
      begin
            Self.Accept_Stmt_F_Name := Accept_Stmt_F_Name;
            Self.Accept_Stmt_F_Entry_Index_Expr := Accept_Stmt_F_Entry_Index_Expr;
            Self.Accept_Stmt_F_Params := Accept_Stmt_F_Params;
      end Initialize_Fields_For_Accept_Stmt;
   function Accept_Stmt_F_Name
     (Node : Bare_Accept_Stmt) return Bare_Identifier
   is
   begin
         return Node.Accept_Stmt_F_Name;
   end;
   function Accept_Stmt_F_Entry_Index_Expr
     (Node : Bare_Accept_Stmt) return Bare_Expr
   is
   begin
         return Node.Accept_Stmt_F_Entry_Index_Expr;
   end;
   function Accept_Stmt_F_Params
     (Node : Bare_Accept_Stmt) return Bare_Entry_Completion_Formal_Params
   is
   begin
         return Node.Accept_Stmt_F_Params;
   end;
--# property-start AcceptStmt.designated_entry /tmp/lal-23.0.0/ada/ast.py:20185
pragma Warnings (Off, "is not referenced");
 function Accept_Stmt_P_Designated_Entry
  (Node : Bare_Accept_Stmt
      ; Origin : Bare_Ada_Node
      ; Env : Lexical_Env
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Entry_Decl
is
   Self : Bare_Accept_Stmt := Bare_Accept_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Accept_Stmt :=
     Internal_Entity_Accept_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind env Env
   Property_Result : Internal_Entity_Entry_Decl;
            procedure Finalizer_Scope_1420 with Inline_Always;
      Var_Expr : Internal_Entity_Entry_Decl;
Fld : Internal_Entity_Identifier;
Fld_1 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Entry_Decl;
Fld_2 : Internal_Entity_Entry_Spec;
Fld_3 : Internal_Entity_Entry_Completion_Formal_Params;
Cast_Result_1 : Internal_Entity_Base_Formal_Param_Holder;
Fld_4 : Boolean;
Scope_Result : Boolean;
Result_Var : Boolean;
Find_Result : Internal_Entity;
Cast_Result_2 : Internal_Entity_Entry_Decl;
Let_Result : Internal_Entity_Entry_Decl;
            procedure Finalizer_Scope_1420 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1420;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10595 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10594 '<Cast to EntryDecl at ast.py:20190>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:20190
--# expr-start 10593 '<Find at ast.py:20186>' Find_Result /tmp/lal-23.0.0/ada/ast.py:20186
   --# expr-start 10588 '<FieldAccess for all_env_els_impl at ast.py:20186>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20186
--# expr-start 10587 '<FieldAccess for name at ast.py:20186>' Fld /tmp/lal-23.0.0/ada/ast.py:20186
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Accept_Stmt_F_Name, Info => Ent.Info);
--# expr-done 10587
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.all_env_els_impl'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_All_Env_Els_Impl (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10588
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_1;
      begin
         for Item_325 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_325
--# expr-start 10589 '<Cast to EntryDecl at ast.py:20187>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:20187
Cast_Expr := Item_325; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Entry_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Entry_Decl;
   end if;
--# expr-done 10589
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Entry_Decl then
   --# scope-start
   --# bind d Var_Expr
--# expr-start 10592 '<FieldAccess for match_formal_params at ast.py:20188>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20188
--# expr-start 10590 '<FieldAccess for spec at ast.py:20188>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20188
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Entry_Spec (Node => Var_Expr.Node.Entry_Decl_F_Spec, Info => Var_Expr.Info);
--# expr-done 10590
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10591 '<FieldAccess for params at ast.py:20188>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20188
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Entry_Completion_Formal_Params (Node => Ent.Node.Accept_Stmt_F_Params, Info => Ent.Info);
--# expr-done 10591
      Cast_Result_1 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
--# property-call-start BaseFormalParamHolder.match_formal_params
Fld_4 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Formal_Params (Node => Fld_2.Node, Other => Cast_Result_1, E_Info => Fld_2.Info);
--# end
--# expr-done 10592
Scope_Result := Fld_4;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := False;
end if;
      if Result_Var then
         Find_Result := Item_325;
      end if;
   --# end
               exit when Result_Var;
         end loop;
      end;
--# expr-done 10593
   if Find_Result.Node = null
      or else Find_Result.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Entry_Decl
        (Node => Find_Result.Node,
         Info => Find_Result.Info);
   else
         Cast_Result_2 := No_Entity_Entry_Decl;
   end if;
--# expr-done 10594
Let_Result := Cast_Result_2; 
--# end
--# expr-done 10595
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1420;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1420;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Accept_Stmt_P_Designated_Entry;
--# end
--# property-start AcceptStmt.corresponding_entry /tmp/lal-23.0.0/ada/ast.py:20194
pragma Warnings (Off, "is not referenced");
 function Accept_Stmt_P_Corresponding_Entry
  (Node : Bare_Accept_Stmt
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Entry_Decl
is
   Self : Bare_Accept_Stmt := Bare_Accept_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Accept_Stmt :=
     Internal_Entity_Accept_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Entry_Decl;
            procedure Finalizer_Scope_1421 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Entry_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Entry_Decl;
Let_Result : Internal_Entity_Entry_Decl;
            procedure Finalizer_Scope_1421 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_1421;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10599 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10598 '<bind at ast.py:20198>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:20198
--# expr-start 10596 '<FieldAccess for node_env at ast.py:20198>' Fld /tmp/lal-23.0.0/ada/ast.py:20198
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 10596
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 10597 '<FieldAccess for designated_entry at ast.py:20198>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20198
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AcceptStmt.designated_entry
Fld_1 := Libadalang.Implementation.Accept_Stmt_P_Designated_Entry (Node => Ent.Node, Origin => Origin, Env => Bound_Env, E_Info => Ent.Info);
--# end
--# expr-done 10597
Dyn_Var_Bind_Result := Fld_1; 
--# expr-done 10598
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 10599
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1421;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1421;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Accept_Stmt_P_Corresponding_Entry;
--# end
--# property-start AcceptStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20201
pragma Warnings (Off, "is not referenced");
 function Accept_Stmt_P_Xref_Equation
  (Node : Bare_Accept_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Accept_Stmt := Bare_Accept_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Accept_Stmt :=
     Internal_Entity_Accept_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1422 with Inline_Always;
            procedure Finalizer_Scope_3135 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Bare_Identifier;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Entry_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1422 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1422;
            procedure Finalizer_Scope_3135 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_3135;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10607 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10606 '<And at ast.py:20202>' And_Pred /tmp/lal-23.0.0/ada/ast.py:20202
--# expr-start 10603 '<Bind at ast.py:20203>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:20203
--# expr-start 10601 '<FieldAccess for ref_var at ast.py:20203>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20203
--# expr-start 10600 '<FieldAccess for name at ast.py:20203>' Fld /tmp/lal-23.0.0/ada/ast.py:20203
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Accept_Stmt_F_Name;
--# expr-done 10600
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 10601
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10602 '<FieldAccess for designated_entry at ast.py:20203>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20203
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AcceptStmt.designated_entry
Fld_2 := Libadalang.Implementation.Accept_Stmt_P_Designated_Entry (Node => Ent.Node, Origin => Origin, Env => Env, E_Info => Ent.Info);
--# end
--# expr-done 10602
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20203") else null)); 
--# expr-done 10603
--# expr-start 10604 '<FieldAccess for entry_index_expr at ast.py:20204>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20204
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Accept_Stmt_F_Entry_Index_Expr, Info => Ent.Info);
--# expr-done 10604
Var_Expr := Fld_3;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind e Var_Expr
--# expr-start 10605 '<FieldAccess for sub_equation at ast.py:20205>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20205
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10605
Scope_Result := Fld_4;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3135;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20206") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Bind_Result, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20202") else null)); 
--# expr-done 10606
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 10607
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1422;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1422;
               Finalizer_Scope_3135;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Accept_Stmt_P_Xref_Equation;
--# end
--# property-start AcceptStmt._env_trans_parent_158 /tmp/lal-23.0.0/ada/ast.py:20181
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_158
  (Node : Bare_Accept_Stmt
  )
   return Boolean
is
   Self : Bare_Accept_Stmt := Bare_Accept_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_158;
--# end
   --
   --  Primitives for Bare_Accept_Stmt_With_Stmts
   --
      procedure Initialize_Fields_For_Accept_Stmt_With_Stmts
        (Self : Bare_Accept_Stmt_With_Stmts
         ; Accept_Stmt_F_Name : Bare_Identifier
         ; Accept_Stmt_F_Entry_Index_Expr : Bare_Expr
         ; Accept_Stmt_F_Params : Bare_Entry_Completion_Formal_Params
         ; Accept_Stmt_With_Stmts_F_Stmts : Bare_Handled_Stmts
         ; Accept_Stmt_With_Stmts_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Accept_Stmt
              (Self, Accept_Stmt_F_Name, Accept_Stmt_F_Entry_Index_Expr, Accept_Stmt_F_Params);
            Self.Accept_Stmt_With_Stmts_F_Stmts := Accept_Stmt_With_Stmts_F_Stmts;
            Self.Accept_Stmt_With_Stmts_F_End_Name := Accept_Stmt_With_Stmts_F_End_Name;
      end Initialize_Fields_For_Accept_Stmt_With_Stmts;
   function Accept_Stmt_With_Stmts_F_Stmts
     (Node : Bare_Accept_Stmt_With_Stmts) return Bare_Handled_Stmts
   is
   begin
         return Node.Accept_Stmt_With_Stmts_F_Stmts;
   end;
   function Accept_Stmt_With_Stmts_F_End_Name
     (Node : Bare_Accept_Stmt_With_Stmts) return Bare_End_Name
   is
   begin
         return Node.Accept_Stmt_With_Stmts_F_End_Name;
   end;
   --
   --  Primitives for Bare_Base_Loop_Stmt
   --
      procedure Initialize_Fields_For_Base_Loop_Stmt
        (Self : Bare_Base_Loop_Stmt
         ; Base_Loop_Stmt_F_Spec : Bare_Loop_Spec
         ; Base_Loop_Stmt_F_Stmts : Bare_Stmt_List
         ; Base_Loop_Stmt_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Base_Loop_Stmt_F_Spec := Base_Loop_Stmt_F_Spec;
            Self.Base_Loop_Stmt_F_Stmts := Base_Loop_Stmt_F_Stmts;
            Self.Base_Loop_Stmt_F_End_Name := Base_Loop_Stmt_F_End_Name;
      end Initialize_Fields_For_Base_Loop_Stmt;
   function Base_Loop_Stmt_F_Spec
     (Node : Bare_Base_Loop_Stmt) return Bare_Loop_Spec
   is
   begin
         return Node.Base_Loop_Stmt_F_Spec;
   end;
   function Base_Loop_Stmt_F_Stmts
     (Node : Bare_Base_Loop_Stmt) return Bare_Stmt_List
   is
   begin
         return Node.Base_Loop_Stmt_F_Stmts;
   end;
   function Base_Loop_Stmt_F_End_Name
     (Node : Bare_Base_Loop_Stmt) return Bare_End_Name
   is
   begin
         return Node.Base_Loop_Stmt_F_End_Name;
   end;
--# property-start BaseLoopStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20020
pragma Warnings (Off, "is not referenced");
 function Base_Loop_Stmt_P_Xref_Equation
  (Node : Bare_Base_Loop_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Base_Loop_Stmt := Bare_Base_Loop_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Base_Loop_Stmt :=
     Internal_Entity_Base_Loop_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1412 with Inline_Always;
            procedure Finalizer_Scope_3136 with Inline_Always;
      Var_Expr : Internal_Entity_Loop_Spec;
Fld : Internal_Entity_Loop_Spec;
Fld_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1412 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1412;
            procedure Finalizer_Scope_3136 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_3136;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10610 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10608 '<FieldAccess for spec at ast.py:20021>' Fld /tmp/lal-23.0.0/ada/ast.py:20021
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Loop_Spec (Node => Ent.Node.Base_Loop_Stmt_F_Spec, Info => Ent.Info);
--# expr-done 10608
Var_Expr := Fld;
if Var_Expr /= No_Entity_Loop_Spec then
   --# scope-start
   --# bind s Var_Expr
--# expr-start 10609 '<FieldAccess for xref_equation at ast.py:20021>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20021
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10609
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3136;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20022") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 10610
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1412;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1412;
               Finalizer_Scope_3136;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Base_Loop_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_For_Loop_Stmt
   --
      procedure For_Loop_Stmt_Pre_Env_Actions
        (Self            : Bare_For_Loop_Stmt;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_155 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_For_Loop_Stmt
        (Self : Bare_For_Loop_Stmt
         ; Base_Loop_Stmt_F_Spec : Bare_Loop_Spec
         ; Base_Loop_Stmt_F_Stmts : Bare_Stmt_List
         ; Base_Loop_Stmt_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Base_Loop_Stmt
              (Self, Base_Loop_Stmt_F_Spec, Base_Loop_Stmt_F_Stmts, Base_Loop_Stmt_F_End_Name);
      end Initialize_Fields_For_For_Loop_Stmt;
--# property-start ForLoopStmt._env_trans_parent_155 /tmp/lal-23.0.0/ada/ast.py:20039
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_155
  (Node : Bare_For_Loop_Stmt
  )
   return Boolean
is
   Self : Bare_For_Loop_Stmt := Bare_For_Loop_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_155;
--# end
   --
   --  Primitives for Bare_Loop_Stmt
   --
      procedure Initialize_Fields_For_Loop_Stmt
        (Self : Bare_Loop_Stmt
         ; Base_Loop_Stmt_F_Spec : Bare_Loop_Spec
         ; Base_Loop_Stmt_F_Stmts : Bare_Stmt_List
         ; Base_Loop_Stmt_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Base_Loop_Stmt
              (Self, Base_Loop_Stmt_F_Spec, Base_Loop_Stmt_F_Stmts, Base_Loop_Stmt_F_End_Name);
      end Initialize_Fields_For_Loop_Stmt;
   --
   --  Primitives for Bare_While_Loop_Stmt
   --
      procedure Initialize_Fields_For_While_Loop_Stmt
        (Self : Bare_While_Loop_Stmt
         ; Base_Loop_Stmt_F_Spec : Bare_Loop_Spec
         ; Base_Loop_Stmt_F_Stmts : Bare_Stmt_List
         ; Base_Loop_Stmt_F_End_Name : Bare_End_Name
        ) is
      begin
            Initialize_Fields_For_Base_Loop_Stmt
              (Self, Base_Loop_Stmt_F_Spec, Base_Loop_Stmt_F_Stmts, Base_Loop_Stmt_F_End_Name);
      end Initialize_Fields_For_While_Loop_Stmt;
   --
   --  Primitives for Bare_Block_Stmt
   --
      procedure Block_Stmt_Pre_Env_Actions
        (Self            : Bare_Block_Stmt;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_156 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
--# property-start BlockStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20059
pragma Warnings (Off, "is not referenced");
 function Block_Stmt_P_Xref_Equation
  (Node : Bare_Block_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Block_Stmt := Bare_Block_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1413 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_1413 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_1413;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20059") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1413;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1413;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Block_Stmt_P_Xref_Equation;
--# end
--# property-start BlockStmt._env_trans_parent_156 /tmp/lal-23.0.0/ada/ast.py:20057
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_156
  (Node : Bare_Block_Stmt
  )
   return Boolean
is
   Self : Bare_Block_Stmt := Bare_Block_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_156;
--# end
   --
   --  Primitives for Bare_Begin_Block
   --
      procedure Initialize_Fields_For_Begin_Block
        (Self : Bare_Begin_Block
         ; Begin_Block_F_Stmts : Bare_Handled_Stmts
         ; Begin_Block_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Begin_Block_F_Stmts := Begin_Block_F_Stmts;
            Self.Begin_Block_F_End_Name := Begin_Block_F_End_Name;
      end Initialize_Fields_For_Begin_Block;
   function Begin_Block_F_Stmts
     (Node : Bare_Begin_Block) return Bare_Handled_Stmts
   is
   begin
         return Node.Begin_Block_F_Stmts;
   end;
   function Begin_Block_F_End_Name
     (Node : Bare_Begin_Block) return Bare_End_Name
   is
   begin
         return Node.Begin_Block_F_End_Name;
   end;
   --
   --  Primitives for Bare_Decl_Block
   --
      procedure Initialize_Fields_For_Decl_Block
        (Self : Bare_Decl_Block
         ; Decl_Block_F_Decls : Bare_Declarative_Part
         ; Decl_Block_F_Stmts : Bare_Handled_Stmts
         ; Decl_Block_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Decl_Block_F_Decls := Decl_Block_F_Decls;
            Self.Decl_Block_F_Stmts := Decl_Block_F_Stmts;
            Self.Decl_Block_F_End_Name := Decl_Block_F_End_Name;
      end Initialize_Fields_For_Decl_Block;
   function Decl_Block_F_Decls
     (Node : Bare_Decl_Block) return Bare_Declarative_Part
   is
   begin
         return Node.Decl_Block_F_Decls;
   end;
   function Decl_Block_F_Stmts
     (Node : Bare_Decl_Block) return Bare_Handled_Stmts
   is
   begin
         return Node.Decl_Block_F_Stmts;
   end;
   function Decl_Block_F_End_Name
     (Node : Bare_Decl_Block) return Bare_End_Name
   is
   begin
         return Node.Decl_Block_F_End_Name;
   end;
--# property-start DeclBlock.immediate_declarative_region /tmp/lal-23.0.0/ada/ast.py:20072
pragma Warnings (Off, "is not referenced");
 function Decl_Block_P_Immediate_Declarative_Region
  (Node : Bare_Decl_Block
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Decl_Block := Bare_Decl_Block (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Decl_Block :=
     Internal_Entity_Decl_Block'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_1414 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_1414 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1414;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10612 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10611 '<FieldAccess for children_env at ast.py:20073>' Fld /tmp/lal-23.0.0/ada/ast.py:20073
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 10611
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 10612
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1414;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1414;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Decl_Block_P_Immediate_Declarative_Region;
--# end
   --
   --  Primitives for Bare_Case_Stmt
   --
      procedure Initialize_Fields_For_Case_Stmt
        (Self : Bare_Case_Stmt
         ; Case_Stmt_F_Expr : Bare_Expr
         ; Case_Stmt_F_Pragmas : Bare_Pragma_Node_List
         ; Case_Stmt_F_Alternatives : Bare_Case_Stmt_Alternative_List
        ) is
      begin
            Self.Case_Stmt_F_Expr := Case_Stmt_F_Expr;
            Self.Case_Stmt_F_Pragmas := Case_Stmt_F_Pragmas;
            Self.Case_Stmt_F_Alternatives := Case_Stmt_F_Alternatives;
      end Initialize_Fields_For_Case_Stmt;
   function Case_Stmt_F_Expr
     (Node : Bare_Case_Stmt) return Bare_Expr
   is
   begin
         return Node.Case_Stmt_F_Expr;
   end;
   function Case_Stmt_F_Pragmas
     (Node : Bare_Case_Stmt) return Bare_Pragma_Node_List
   is
   begin
         return Node.Case_Stmt_F_Pragmas;
   end;
   function Case_Stmt_F_Alternatives
     (Node : Bare_Case_Stmt) return Bare_Case_Stmt_Alternative_List
   is
   begin
         return Node.Case_Stmt_F_Alternatives;
   end;
--# property-start CaseStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20110
pragma Warnings (Off, "is not referenced");
 function Case_Stmt_P_Xref_Equation
  (Node : Bare_Case_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Case_Stmt := Bare_Case_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Case_Stmt :=
     Internal_Entity_Case_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1416 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Pred : Logic_Equation;
Fld_4 : Bare_Expr;
Fld_5 : Logic_Var;
Pred_1 : Logic_Equation;
And_Pred : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1416 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Pred);
                     Dec_Ref (Pred_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1416;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10623 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10622 '<And at ast.py:20111>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:20111
--# expr-start 10614 '<FieldAccess for sub_equation at ast.py:20111>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20111
--# expr-start 10613 '<FieldAccess for expr at ast.py:20111>' Fld /tmp/lal-23.0.0/ada/ast.py:20111
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Case_Stmt_F_Expr, Info => Ent.Info);
--# expr-done 10613
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10614
--# expr-start 10621 '<And at ast.py:20115>' And_Pred /tmp/lal-23.0.0/ada/ast.py:20115
--# expr-start 10617 '<Predicate on AdaNode.is_not_null at ast.py:20115>' Pred /tmp/lal-23.0.0/ada/ast.py:20115
--# expr-start 10616 '<FieldAccess for type_var at ast.py:20115>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20115
--# expr-start 10615 '<FieldAccess for expr at ast.py:20115>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20115
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Case_Stmt_F_Expr;
--# expr-done 10615
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_2);
--# expr-done 10616
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Pred := Solver.Create_Predicate (Fld_3, Create_Ada_Node_P_Is_Not_Null_0_Predicate); 
--# expr-done 10617
--# expr-start 10620 '<Predicate on BaseTypeDecl.is_discrete_type at ast.py:20117>' Pred_1 /tmp/lal-23.0.0/ada/ast.py:20117
--# expr-start 10619 '<FieldAccess for type_var at ast.py:20117>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:20117
--# expr-start 10618 '<FieldAccess for expr at ast.py:20117>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:20117
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Case_Stmt_F_Expr;
--# expr-done 10618
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_4);
--# expr-done 10619
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Pred_1 := Solver.Create_Predicate (Fld_5, Create_Base_Type_Decl_P_Is_Discrete_Type_0_Predicate (Origin)); 
--# expr-done 10620
And_Pred := Create_And (Pred, Pred_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20115") else null)); 
--# expr-done 10621
And_Pred_1 := Create_And (Fld_1, And_Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20111") else null)); 
--# expr-done 10622
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10623
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1416;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1416;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Case_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Extended_Return_Stmt
   --
      procedure Extended_Return_Stmt_Pre_Env_Actions
        (Self            : Bare_Extended_Return_Stmt;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_157 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Extended_Return_Stmt
        (Self : Bare_Extended_Return_Stmt
         ; Extended_Return_Stmt_F_Decl : Bare_Extended_Return_Stmt_Object_Decl
         ; Extended_Return_Stmt_F_Stmts : Bare_Handled_Stmts
        ) is
      begin
            Self.Extended_Return_Stmt_F_Decl := Extended_Return_Stmt_F_Decl;
            Self.Extended_Return_Stmt_F_Stmts := Extended_Return_Stmt_F_Stmts;
      end Initialize_Fields_For_Extended_Return_Stmt;
   function Extended_Return_Stmt_F_Decl
     (Node : Bare_Extended_Return_Stmt) return Bare_Extended_Return_Stmt_Object_Decl
   is
   begin
         return Node.Extended_Return_Stmt_F_Decl;
   end;
   function Extended_Return_Stmt_F_Stmts
     (Node : Bare_Extended_Return_Stmt) return Bare_Handled_Stmts
   is
   begin
         return Node.Extended_Return_Stmt_F_Stmts;
   end;
--# property-start ExtendedReturnStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20094
pragma Warnings (Off, "is not referenced");
 function Extended_Return_Stmt_P_Xref_Equation
  (Node : Bare_Extended_Return_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Extended_Return_Stmt := Bare_Extended_Return_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1415 with Inline_Always;
      True_Rel : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1415 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1415;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10624 '<Block at ???>' Let_Result None
--# scope-start
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20095") else null)); 
Let_Result := True_Rel; Inc_Ref (Let_Result);
--# end
--# expr-done 10624
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1415;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1415;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Extended_Return_Stmt_P_Xref_Equation;
--# end
--# property-start ExtendedReturnStmt._env_trans_parent_157 /tmp/lal-23.0.0/ada/ast.py:20097
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_157
  (Node : Bare_Extended_Return_Stmt
  )
   return Boolean
is
   Self : Bare_Extended_Return_Stmt := Bare_Extended_Return_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_157;
--# end
   --
   --  Primitives for Bare_If_Stmt
   --
      procedure Initialize_Fields_For_If_Stmt
        (Self : Bare_If_Stmt
         ; If_Stmt_F_Cond_Expr : Bare_Expr
         ; If_Stmt_F_Then_Stmts : Bare_Stmt_List
         ; If_Stmt_F_Alternatives : Bare_Elsif_Stmt_Part_List
         ; If_Stmt_F_Else_Stmts : Bare_Stmt_List
        ) is
      begin
            Self.If_Stmt_F_Cond_Expr := If_Stmt_F_Cond_Expr;
            Self.If_Stmt_F_Then_Stmts := If_Stmt_F_Then_Stmts;
            Self.If_Stmt_F_Alternatives := If_Stmt_F_Alternatives;
            Self.If_Stmt_F_Else_Stmts := If_Stmt_F_Else_Stmts;
      end Initialize_Fields_For_If_Stmt;
   function If_Stmt_F_Cond_Expr
     (Node : Bare_If_Stmt) return Bare_Expr
   is
   begin
         return Node.If_Stmt_F_Cond_Expr;
   end;
   function If_Stmt_F_Then_Stmts
     (Node : Bare_If_Stmt) return Bare_Stmt_List
   is
   begin
         return Node.If_Stmt_F_Then_Stmts;
   end;
   function If_Stmt_F_Alternatives
     (Node : Bare_If_Stmt) return Bare_Elsif_Stmt_Part_List
   is
   begin
         return Node.If_Stmt_F_Alternatives;
   end;
   function If_Stmt_F_Else_Stmts
     (Node : Bare_If_Stmt) return Bare_Stmt_List
   is
   begin
         return Node.If_Stmt_F_Else_Stmts;
   end;
--# property-start IfStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19913
pragma Warnings (Off, "is not referenced");
 function If_Stmt_P_Xref_Equation
  (Node : Bare_If_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_If_Stmt := Bare_If_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_If_Stmt :=
     Internal_Entity_If_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1403 with Inline_Always;
      Fld : Bare_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Bare_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1403 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1403;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10635 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10634 '<And at ast.py:19915>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19915
--# expr-start 10631 '<And at ast.py:19915>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19915
--# expr-start 10628 '<Bind at ast.py:19915>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19915
--# expr-start 10626 '<FieldAccess for expected_type_var at ast.py:19915>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19915
--# expr-start 10625 '<FieldAccess for cond_expr at ast.py:19915>' Fld /tmp/lal-23.0.0/ada/ast.py:19915
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.If_Stmt_F_Cond_Expr;
--# expr-done 10625
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld);
--# expr-done 10626
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10627 '<FieldAccess for bool_type at ast.py:19915>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19915
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10627
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19915") else null)); 
--# expr-done 10628
--# expr-start 10630 '<FieldAccess for sub_equation at ast.py:19916>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19916
--# expr-start 10629 '<FieldAccess for cond_expr at ast.py:19916>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19916
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.If_Stmt_F_Cond_Expr, Info => Ent.Info);
--# expr-done 10629
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 10630
And_Pred := Create_And (Bind_Result, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19915") else null)); 
--# expr-done 10631
--# expr-start 10633 '<FieldAccess for matches_expected_formal_prim_type at ast.py:19917>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19917
--# expr-start 10632 '<FieldAccess for cond_expr at ast.py:19917>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19917
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.If_Stmt_F_Cond_Expr;
--# expr-done 10632
      if Fld_5 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Fld_5, Origin => Origin);
--# end
--# expr-done 10633
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19915") else null)); 
--# expr-done 10634
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10635
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1403;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1403;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end If_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Named_Stmt
   --
      procedure Named_Stmt_Pre_Env_Actions
        (Self            : Bare_Named_Stmt;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Resolver : constant Entity_Resolver :=
            null;
         Mapping : Internal_Env_Assoc :=
            Libadalang.Implementation.Env_Mappings_153 (Node => 
Self);
      begin
         Add_To_Env
           (Self,
            State,
            Mapping.Key,
            Mapping.Value,
            Mapping.Metadata,
            Resolver,
            Mapping.Dest_Env,
            DSL_Location => "ast.py:20002");
         Dec_Ref (Mapping.Dest_Env);
      end;
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_154 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Named_Stmt
        (Self : Bare_Named_Stmt
         ; Named_Stmt_F_Decl : Bare_Named_Stmt_Decl
         ; Named_Stmt_F_Stmt : Bare_Composite_Stmt
        ) is
      begin
            Self.Named_Stmt_F_Decl := Named_Stmt_F_Decl;
            Self.Named_Stmt_F_Stmt := Named_Stmt_F_Stmt;
      end Initialize_Fields_For_Named_Stmt;
   function Named_Stmt_F_Decl
     (Node : Bare_Named_Stmt) return Bare_Named_Stmt_Decl
   is
   begin
         return Node.Named_Stmt_F_Decl;
   end;
   function Named_Stmt_F_Stmt
     (Node : Bare_Named_Stmt) return Bare_Composite_Stmt
   is
   begin
         return Node.Named_Stmt_F_Stmt;
   end;
--# property-start NamedStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20006
pragma Warnings (Off, "is not referenced");
 function Named_Stmt_P_Xref_Equation
  (Node : Bare_Named_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Named_Stmt := Bare_Named_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1411 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_1411 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_1411;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20006") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1411;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1411;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Named_Stmt_P_Xref_Equation;
--# end
--# property-start NamedStmt._env_mappings_153 /tmp/lal-23.0.0/ada/ast.py:20002
pragma Warnings (Off, "is not referenced");
 function Env_Mappings_153
  (Node : Bare_Named_Stmt
  )
   return Internal_Env_Assoc
is
   Self : Bare_Named_Stmt := Bare_Named_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc;
            procedure Finalizer_Scope_1622 with Inline_Always;
      Fld : Bare_Named_Stmt_Decl;
Fld_1 : Symbol_Type;
Fld_2 : Bare_Named_Stmt_Decl;
New_Struct : Internal_Designated_Env := No_Designated_Env;
Cast_Result : Bare_Ada_Node;
New_Struct_1 : Internal_Env_Assoc := No_Env_Assoc;
            procedure Finalizer_Scope_1622 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
            end Finalizer_Scope_1622;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10640 '<New EnvAssoc at ast.py:20002>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:20002
--# expr-start 10636 '<New DesignatedEnv at ast.py:20002>' New_Struct /tmp/lal-23.0.0/ada/ast.py:20002
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 10636
--# expr-start 10638 '<FieldAccess for name_symbol at ast.py:20002>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20002
--# expr-start 10637 '<FieldAccess for decl at ast.py:20002>' Fld /tmp/lal-23.0.0/ada/ast.py:20002
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Named_Stmt_F_Decl;
--# expr-done 10637
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.name_symbol
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Name_Symbol (Node => Fld);
--# end
--# expr-done 10638
--# expr-start 10639 '<FieldAccess for decl at ast.py:20002>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20002
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Named_Stmt_F_Decl;
--# expr-done 10639
      Cast_Result := Fld_2;
Inc_Ref (New_Struct);
New_Struct_1 := (Dest_Env => New_Struct, Key => Fld_1, Metadata => No_Metadata, Value => Cast_Result); 
--# expr-done 10640
      Property_Result := New_Struct_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1622;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1622;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Mappings_153;
--# end
--# property-start NamedStmt._env_trans_parent_154 /tmp/lal-23.0.0/ada/ast.py:20001
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_154
  (Node : Bare_Named_Stmt
  )
   return Boolean
is
   Self : Bare_Named_Stmt := Bare_Named_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_154;
--# end
   --
   --  Primitives for Bare_Select_Stmt
   --
      procedure Initialize_Fields_For_Select_Stmt
        (Self : Bare_Select_Stmt
         ; Select_Stmt_F_Guards : Bare_Select_When_Part_List
         ; Select_Stmt_F_Else_Stmts : Bare_Stmt_List
         ; Select_Stmt_F_Abort_Stmts : Bare_Stmt_List
        ) is
      begin
            Self.Select_Stmt_F_Guards := Select_Stmt_F_Guards;
            Self.Select_Stmt_F_Else_Stmts := Select_Stmt_F_Else_Stmts;
            Self.Select_Stmt_F_Abort_Stmts := Select_Stmt_F_Abort_Stmts;
      end Initialize_Fields_For_Select_Stmt;
   function Select_Stmt_F_Guards
     (Node : Bare_Select_Stmt) return Bare_Select_When_Part_List
   is
   begin
         return Node.Select_Stmt_F_Guards;
   end;
   function Select_Stmt_F_Else_Stmts
     (Node : Bare_Select_Stmt) return Bare_Stmt_List
   is
   begin
         return Node.Select_Stmt_F_Else_Stmts;
   end;
   function Select_Stmt_F_Abort_Stmts
     (Node : Bare_Select_Stmt) return Bare_Stmt_List
   is
   begin
         return Node.Select_Stmt_F_Abort_Stmts;
   end;
--# property-start SelectStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:20230
pragma Warnings (Off, "is not referenced");
 function Select_Stmt_P_Xref_Equation
  (Node : Bare_Select_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Select_Stmt := Bare_Select_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Select_Stmt :=
     Internal_Entity_Select_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1423 with Inline_Always;
            procedure Finalizer_Scope_3137 with Inline_Always;
      Fld : Internal_Entity_Select_When_Part_List;
Fld_1 : Bare_Select_When_Part_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Select_When_Part;
Is_Null : Boolean;
If_Result : Internal_Entity_Select_When_Part;
Fld_3 : Logic_Equation;
Item_326 : Internal_Entity_Select_When_Part;
Bare_Item_326 : Bare_Select_When_Part;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1423 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1423;
            procedure Finalizer_Scope_3137 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3137;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10645 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10644 '<LogicAll at ast.py:20231>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:20231
--# expr-start 10643 '<Map at ast.py:20231>' Map_Result /tmp/lal-23.0.0/ada/ast.py:20231
   --# expr-start 10641 '<FieldAccess for guards at ast.py:20231>' Fld /tmp/lal-23.0.0/ada/ast.py:20231
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Select_When_Part_List (Node => Ent.Node.Select_Stmt_F_Guards, Info => Ent.Info);
--# expr-done 10641
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Select_When_Part_List := Fld_1;
      begin
         for Untyped_Item_326 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_326 := Untyped_Item_326; 
Is_Null := Bare_Item_326 = null; 
if Is_Null then
   If_Result := No_Entity_Select_When_Part;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_326); 
   If_Result := As_Entity;
end if;
                  Item_326 := If_Result; 
   --# scope-start
               --# bind wp Item_326
      --# expr-start 10642 '<FieldAccess for sub_equation at ast.py:20231>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:20231
      if Item_326.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_326.Node, Env => Env, Origin => Origin, E_Info => Item_326.Info);
--# end
--# expr-done 10642
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3137;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10643
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20231") else null)); 
--# expr-done 10644
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 10645
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1423;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1423;
               Finalizer_Scope_3137;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Select_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Error_Stmt
   --
   --
   --  Primitives for Bare_Simple_Stmt
   --
   --
   --  Primitives for Bare_Abort_Stmt
   --
      procedure Initialize_Fields_For_Abort_Stmt
        (Self : Bare_Abort_Stmt
         ; Abort_Stmt_F_Names : Bare_Name_List
        ) is
      begin
            Self.Abort_Stmt_F_Names := Abort_Stmt_F_Names;
      end Initialize_Fields_For_Abort_Stmt;
   function Abort_Stmt_F_Names
     (Node : Bare_Abort_Stmt) return Bare_Name_List
   is
   begin
         return Node.Abort_Stmt_F_Names;
   end;
--# property-start AbortStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19849
pragma Warnings (Off, "is not referenced");
 function Abort_Stmt_P_Xref_Equation
  (Node : Bare_Abort_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Abort_Stmt := Bare_Abort_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Abort_Stmt :=
     Internal_Entity_Abort_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1400 with Inline_Always;
            procedure Finalizer_Scope_3138 with Inline_Always;
      Fld : Internal_Entity_Name_List;
Fld_1 : Bare_Name_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Fld_4 : Logic_Var;
Pred : Logic_Equation;
And_Pred : Logic_Equation;
Item_327 : Internal_Entity_Name;
Bare_Item_327 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1400 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1400;
            procedure Finalizer_Scope_3138 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Pred);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_3138;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10653 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10652 '<LogicAll at ast.py:19850>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:19850
--# expr-start 10651 '<Map at ast.py:19850>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19850
   --# expr-start 10646 '<FieldAccess for names at ast.py:19850>' Fld /tmp/lal-23.0.0/ada/ast.py:19850
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name_List (Node => Ent.Node.Abort_Stmt_F_Names, Info => Ent.Info);
--# expr-done 10646
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld_1;
      begin
         for Untyped_Item_327 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_327 := Untyped_Item_327; 
Is_Null := Bare_Item_327 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_327); 
   If_Result := As_Entity;
end if;
                  Item_327 := If_Result; 
   --# scope-start
               --# bind name Item_327
      --# expr-start 10650 '<And at ast.py:19852>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19852
--# expr-start 10647 '<FieldAccess for sub_equation at ast.py:19852>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19852
      if Item_327.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Item_327.Node, Env => Env, Origin => Origin, E_Info => Item_327.Info);
--# end
--# expr-done 10647
--# expr-start 10649 '<Predicate on BaseTypeDecl.is_task_type at ast.py:19852>' Pred /tmp/lal-23.0.0/ada/ast.py:19852
--# expr-start 10648 '<FieldAccess for type_var at ast.py:19853>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19853
      if Item_327.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Item_327.Node);
--# expr-done 10648
Fld_4.Value := No_Entity;
Entity_Vars.Reset (Fld_4);
Pred := Solver.Create_Predicate (Fld_4, Create_Base_Type_Decl_P_Is_Task_Type_0_Predicate); 
--# expr-done 10649
And_Pred := Create_And (Fld_3, Pred, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19852") else null)); 
--# expr-done 10650
         declare
            Item_To_Append : constant Logic_Equation := And_Pred;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3138;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10651
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19850") else null)); 
--# expr-done 10652
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 10653
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1400;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1400;
               Finalizer_Scope_3138;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Abort_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Assign_Stmt
   --
      procedure Initialize_Fields_For_Assign_Stmt
        (Self : Bare_Assign_Stmt
         ; Assign_Stmt_F_Dest : Bare_Name
         ; Assign_Stmt_F_Expr : Bare_Expr
        ) is
      begin
            Self.Assign_Stmt_F_Dest := Assign_Stmt_F_Dest;
            Self.Assign_Stmt_F_Expr := Assign_Stmt_F_Expr;
      end Initialize_Fields_For_Assign_Stmt;
   function Assign_Stmt_F_Dest
     (Node : Bare_Assign_Stmt) return Bare_Name
   is
   begin
         return Node.Assign_Stmt_F_Dest;
   end;
   function Assign_Stmt_F_Expr
     (Node : Bare_Assign_Stmt) return Bare_Expr
   is
   begin
         return Node.Assign_Stmt_F_Expr;
   end;
--# property-start AssignStmt.complete_item_weight /tmp/lal-23.0.0/ada/ast.py:19691
pragma Warnings (Off, "is not referenced");
 function Assign_Stmt_P_Complete_Item_Weight
  (Node : Bare_Assign_Stmt
      ; Item : Internal_Entity_Basic_Decl
      ; Origin : Bare_Ada_Node
  )
   return Integer
is
   Self : Bare_Assign_Stmt := Bare_Assign_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind item Item
   --# bind origin Origin
   Property_Result : Integer;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Scope_Result : Integer;
Result_Var : Integer;
Let_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10655 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10654 '<FieldAccess for expr_type at ast.py:19693>' Fld /tmp/lal-23.0.0/ada/ast.py:19693
      if Item.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.expr_type'
Fld := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Expr_Type (Node => Item.Node, Origin => Origin, E_Info => Item.Info);
--# end
--# expr-done 10654
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind _ Var_Expr
Scope_Result := 100;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := 0;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 10655
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Assign_Stmt_P_Complete_Item_Weight;
--# end
--# property-start AssignStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19699
pragma Warnings (Off, "is not referenced");
 function Assign_Stmt_P_Xref_Equation
  (Node : Bare_Assign_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Assign_Stmt := Bare_Assign_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Assign_Stmt :=
     Internal_Entity_Assign_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1393 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Fld_4 : Bare_Expr;
Fld_5 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Fld_6 : Internal_Entity_Expr;
Fld_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_8 : Bare_Expr;
Fld_9 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1393 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1393;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10670 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10669 '<And at ast.py:19701>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:19701
--# expr-start 10666 '<And at ast.py:19701>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19701
--# expr-start 10663 '<And at ast.py:19701>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19701
--# expr-start 10657 '<FieldAccess for sub_equation at ast.py:19701>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19701
--# expr-start 10656 '<FieldAccess for dest at ast.py:19701>' Fld /tmp/lal-23.0.0/ada/ast.py:19701
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Assign_Stmt_F_Dest, Info => Ent.Info);
--# expr-done 10656
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10657
--# expr-start 10662 '<Bind at ast.py:19702>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19702
--# expr-start 10659 '<FieldAccess for type_var at ast.py:19702>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19702
--# expr-start 10658 '<FieldAccess for dest at ast.py:19702>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19702
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Assign_Stmt_F_Dest;
--# expr-done 10658
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_2);
--# expr-done 10659
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 10661 '<FieldAccess for expected_type_var at ast.py:19702>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19702
--# expr-start 10660 '<FieldAccess for expr at ast.py:19702>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19702
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Assign_Stmt_F_Expr;
--# expr-done 10660
      if Fld_4 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_4);
--# expr-done 10661
Fld_5.Value := No_Entity;
Entity_Vars.Reset (Fld_5);
Bind_Result := Solver.Create_Propagate (Fld_3, Fld_5, Logic_Functor_629'(Ref_Count => 1, Cache_Set => False, Cache_Key => <>, Cache_Value => <>, Origin => Origin), Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19702") else null)); 
--# expr-done 10662
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19701") else null)); 
--# expr-done 10663
--# expr-start 10665 '<FieldAccess for sub_equation at ast.py:19704>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19704
--# expr-start 10664 '<FieldAccess for expr at ast.py:19704>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19704
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Create_Internal_Entity_Expr (Node => Ent.Node.Assign_Stmt_F_Expr, Info => Ent.Info);
--# expr-done 10664
      if Fld_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_7 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_6.Node, Env => Env, Origin => Origin, E_Info => Fld_6.Info);
--# end
--# expr-done 10665
And_Pred_1 := Create_And (And_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19701") else null)); 
--# expr-done 10666
--# expr-start 10668 '<FieldAccess for matches_expected_assign_type at ast.py:19705>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:19705
--# expr-start 10667 '<FieldAccess for expr at ast.py:19705>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19705
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Self.Assign_Stmt_F_Expr;
--# expr-done 10667
      if Fld_8 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_9 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Fld_8, Origin => Origin);
--# end
--# expr-done 10668
And_Pred_2 := Create_And (And_Pred_1, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19701") else null)); 
--# expr-done 10669
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 10670
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1393;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1393;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Assign_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Call_Stmt
   --
      procedure Initialize_Fields_For_Call_Stmt
        (Self : Bare_Call_Stmt
         ; Call_Stmt_F_Call : Bare_Name
        ) is
      begin
            Self.Call_Stmt_F_Call := Call_Stmt_F_Call;
      end Initialize_Fields_For_Call_Stmt;
   function Call_Stmt_F_Call
     (Node : Bare_Call_Stmt) return Bare_Name
   is
   begin
         return Node.Call_Stmt_F_Call;
   end;
--# property-start CallStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19663
pragma Warnings (Off, "is not referenced");
 function Call_Stmt_P_Xref_Equation
  (Node : Bare_Call_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Call_Stmt := Bare_Call_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Call_Stmt :=
     Internal_Entity_Call_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1390 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Bare_Name;
Fld_3 : Logic_Var;
Bind_Result : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1390 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1390;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10677 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10676 '<And at ast.py:19665>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19665
--# expr-start 10672 '<FieldAccess for sub_equation at ast.py:19665>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19665
--# expr-start 10671 '<FieldAccess for call at ast.py:19665>' Fld /tmp/lal-23.0.0/ada/ast.py:19665
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Call_Stmt_F_Call, Info => Ent.Info);
--# expr-done 10671
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10672
--# expr-start 10675 '<Bind at ast.py:19668>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19668
--# expr-start 10674 '<FieldAccess for type_var at ast.py:19668>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19668
--# expr-start 10673 '<FieldAccess for call at ast.py:19668>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19668
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Call_Stmt_F_Call;
--# expr-done 10673
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Type_Var (Node => Fld_2);
--# expr-done 10674
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
Bind_Result := Solver.Create_Assign (Fld_3, No_Entity, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19668") else null)); 
--# expr-done 10675
And_Pred := Create_And (Fld_1, Bind_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19665") else null)); 
--# expr-done 10676
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 10677
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1390;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1390;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Call_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Delay_Stmt
   --
      procedure Initialize_Fields_For_Delay_Stmt
        (Self : Bare_Delay_Stmt
         ; Delay_Stmt_F_Has_Until : Bare_Until_Node
         ; Delay_Stmt_F_Expr : Bare_Expr
        ) is
      begin
            Self.Delay_Stmt_F_Has_Until := Delay_Stmt_F_Has_Until;
            Self.Delay_Stmt_F_Expr := Delay_Stmt_F_Expr;
      end Initialize_Fields_For_Delay_Stmt;
   function Delay_Stmt_F_Has_Until
     (Node : Bare_Delay_Stmt) return Bare_Until_Node
   is
   begin
         return Node.Delay_Stmt_F_Has_Until;
   end;
   function Delay_Stmt_F_Expr
     (Node : Bare_Delay_Stmt) return Bare_Expr
   is
   begin
         return Node.Delay_Stmt_F_Expr;
   end;
--# property-start DelayStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19866
pragma Warnings (Off, "is not referenced");
 function Delay_Stmt_P_Xref_Equation
  (Node : Bare_Delay_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Delay_Stmt := Bare_Delay_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Delay_Stmt :=
     Internal_Entity_Delay_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1401 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
True_Rel : Logic_Equation;
Fld_2 : Bare_Expr;
Fld_3 : Logic_Var;
Sym : Symbol_Type;
Fld_4 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Bare_Until_Node;
Fld_8 : Boolean;
If_Result : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1401 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (If_Result);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1401;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10692 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10691 '<And at ast.py:19867>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19867
--# expr-start 10679 '<FieldAccess for sub_equation at ast.py:19867>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19867
--# expr-start 10678 '<FieldAccess for expr at ast.py:19867>' Fld /tmp/lal-23.0.0/ada/ast.py:19867
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Delay_Stmt_F_Expr, Info => Ent.Info);
--# expr-done 10678
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10679
--# expr-start 10690 '<If at ast.py:19867>' If_Result /tmp/lal-23.0.0/ada/ast.py:19867
--# expr-start 10681 '<FieldAccess for as_bool at ast.py:19868>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19868
--# expr-start 10680 '<FieldAccess for has_until at ast.py:19868>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19868
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Self.Delay_Stmt_F_Has_Until;
--# expr-done 10680
      if Fld_7 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Until.as_bool'
Fld_8 := Libadalang.Implementation.Dispatcher_Until_Node_P_As_Bool (Node => Fld_7);
--# end
--# expr-done 10681
if Fld_8 then
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19869") else null)); 
   If_Result := True_Rel;
else
   --# expr-start 10689 '<And at ast.py:19870>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19870
--# expr-start 10686 '<Bind at ast.py:19870>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19870
--# expr-start 10683 '<FieldAccess for expected_type_var at ast.py:19870>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19870
--# expr-start 10682 '<FieldAccess for expr at ast.py:19870>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19870
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Delay_Stmt_F_Expr;
--# expr-done 10682
      if Fld_2 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_2);
--# expr-done 10683
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 10685 '<FieldAccess for std_entity at ast.py:19870>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19870
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10684 '<Symbol Duration at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Duration); 
--# expr-done 10684
--# property-call-start AdaNode.std_entity
Fld_4 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 10685
Bind_Result := Solver.Create_Assign (Fld_3, Fld_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19870") else null)); 
--# expr-done 10686
--# expr-start 10688 '<FieldAccess for matches_expected_type at ast.py:19871>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19871
--# expr-start 10687 '<FieldAccess for expr at ast.py:19871>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19871
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Delay_Stmt_F_Expr, Info => Ent.Info);
--# expr-done 10687
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 10688
And_Pred := Create_And (Bind_Result, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19870") else null)); 
--# expr-done 10689
   If_Result := And_Pred;
end if;
      Inc_Ref (If_Result);
--# expr-done 10690
And_Pred_1 := Create_And (Fld_1, If_Result, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19867") else null)); 
--# expr-done 10691
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10692
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1401;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1401;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Delay_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Exit_Stmt
   --
      procedure Initialize_Fields_For_Exit_Stmt
        (Self : Bare_Exit_Stmt
         ; Exit_Stmt_F_Loop_Name : Bare_Name
         ; Exit_Stmt_F_Cond_Expr : Bare_Expr
        ) is
      begin
            Self.Exit_Stmt_F_Loop_Name := Exit_Stmt_F_Loop_Name;
            Self.Exit_Stmt_F_Cond_Expr := Exit_Stmt_F_Cond_Expr;
      end Initialize_Fields_For_Exit_Stmt;
   function Exit_Stmt_F_Loop_Name
     (Node : Bare_Exit_Stmt) return Bare_Name
   is
   begin
         return Node.Exit_Stmt_F_Loop_Name;
   end;
   function Exit_Stmt_F_Cond_Expr
     (Node : Bare_Exit_Stmt) return Bare_Expr
   is
   begin
         return Node.Exit_Stmt_F_Cond_Expr;
   end;
--# property-start ExitStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19730
pragma Warnings (Off, "is not referenced");
 function Exit_Stmt_P_Xref_Equation
  (Node : Bare_Exit_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Exit_Stmt := Bare_Exit_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Exit_Stmt :=
     Internal_Entity_Exit_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1395 with Inline_Always;
            procedure Finalizer_Scope_3140 with Inline_Always;
            procedure Finalizer_Scope_3141 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Var_Expr_1 : Internal_Entity_Name;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_4 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Fld_5 : Internal_Entity_Name;
Fld_6 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1395 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1395;
            procedure Finalizer_Scope_3140 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3140;
            procedure Finalizer_Scope_3141 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_3141;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10704 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10703 '<And at ast.py:19731>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:19731
--# expr-start 10693 '<FieldAccess for cond_expr at ast.py:19732>' Fld /tmp/lal-23.0.0/ada/ast.py:19732
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Exit_Stmt_F_Cond_Expr, Info => Ent.Info);
--# expr-done 10693
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind cond Var_Expr
--# expr-start 10700 '<And at ast.py:19734>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19734
--# expr-start 10698 '<And at ast.py:19734>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19734
--# expr-start 10696 '<Bind at ast.py:19734>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19734
--# expr-start 10694 '<FieldAccess for expected_type_var at ast.py:19734>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19734
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 10694
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10695 '<FieldAccess for bool_type at ast.py:19734>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19734
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_2 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 10695
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19734") else null)); 
--# expr-done 10696
--# expr-start 10697 '<FieldAccess for sub_equation at ast.py:19735>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19735
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10697
And_Pred := Create_And (Bind_Result, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19734") else null)); 
--# expr-done 10698
--# expr-start 10699 '<FieldAccess for matches_expected_formal_prim_type at ast.py:19736>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19736
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_formal_prim_type
Fld_4 := Libadalang.Implementation.Expr_P_Matches_Expected_Formal_Prim_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 10699
And_Pred_1 := Create_And (And_Pred, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19734") else null)); 
--# expr-done 10700
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3140;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19737") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
--# expr-start 10701 '<FieldAccess for loop_name at ast.py:19740>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19740
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Name (Node => Ent.Node.Exit_Stmt_F_Loop_Name, Info => Ent.Info);
--# expr-done 10701
Var_Expr_1 := Fld_5;
if Var_Expr_1 /= No_Entity_Name then
   --# scope-start
   --# bind ln Var_Expr_1
--# expr-start 10702 '<FieldAccess for xref_no_overloading at ast.py:19741>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19741
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_6 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Var_Expr_1.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 10702
Scope_Result_1 := Fld_6;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3141;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19742") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_2 := Create_And (Result_Var, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19731") else null)); 
--# expr-done 10703
Let_Result := And_Pred_2; Inc_Ref (Let_Result);
--# end
--# expr-done 10704
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1395;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1395;
               Finalizer_Scope_3140;
               Finalizer_Scope_3141;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Exit_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Goto_Stmt
   --
      procedure Initialize_Fields_For_Goto_Stmt
        (Self : Bare_Goto_Stmt
         ; Goto_Stmt_F_Label_Name : Bare_Name
        ) is
      begin
            Self.Goto_Stmt_F_Label_Name := Goto_Stmt_F_Label_Name;
      end Initialize_Fields_For_Goto_Stmt;
   function Goto_Stmt_F_Label_Name
     (Node : Bare_Goto_Stmt) return Bare_Name
   is
   begin
         return Node.Goto_Stmt_F_Label_Name;
   end;
--# property-start GotoStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19717
pragma Warnings (Off, "is not referenced");
 function Goto_Stmt_P_Xref_Equation
  (Node : Bare_Goto_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Goto_Stmt := Bare_Goto_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Goto_Stmt :=
     Internal_Entity_Goto_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1394 with Inline_Always;
      Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1394 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1394;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10707 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10706 '<FieldAccess for xref_no_overloading at ast.py:19718>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19718
--# expr-start 10705 '<FieldAccess for label_name at ast.py:19718>' Fld /tmp/lal-23.0.0/ada/ast.py:19718
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Goto_Stmt_F_Label_Name, Info => Ent.Info);
--# expr-done 10705
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_1 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Fld.Node, Sequential => False, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 10706
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10707
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1394;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1394;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Goto_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Label
   --
      procedure Initialize_Fields_For_Label
        (Self : Bare_Label
         ; Label_F_Decl : Bare_Label_Decl
        ) is
      begin
            Self.Label_F_Decl := Label_F_Decl;
      end Initialize_Fields_For_Label;
   function Label_F_Decl
     (Node : Bare_Label) return Bare_Label_Decl
   is
   begin
         return Node.Label_F_Decl;
   end;
--# property-start Label.xref_equation /tmp/lal-23.0.0/ada/ast.py:19961
pragma Warnings (Off, "is not referenced");
 function Label_P_Xref_Equation
  (Node : Bare_Label
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Label := Bare_Label (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1407 with Inline_Always;
      True_Rel : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1407 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1407;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10708 '<Block at ???>' Let_Result None
--# scope-start
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19962") else null)); 
Let_Result := True_Rel; Inc_Ref (Let_Result);
--# end
--# expr-done 10708
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1407;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1407;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Label_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Null_Stmt
   --
--# property-start NullStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19678
pragma Warnings (Off, "is not referenced");
 function Null_Stmt_P_Xref_Equation
  (Node : Bare_Null_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Null_Stmt := Bare_Null_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1391 with Inline_Always;
      True_Rel : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1391 is
            begin
                     Dec_Ref (True_Rel);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1391;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10709 '<Block at ???>' Let_Result None
--# scope-start
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19679") else null)); 
Let_Result := True_Rel; Inc_Ref (Let_Result);
--# end
--# expr-done 10709
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1391;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1391;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Null_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Raise_Stmt
   --
      procedure Initialize_Fields_For_Raise_Stmt
        (Self : Bare_Raise_Stmt
         ; Raise_Stmt_F_Exception_Name : Bare_Name
         ; Raise_Stmt_F_Error_Message : Bare_Expr
        ) is
      begin
            Self.Raise_Stmt_F_Exception_Name := Raise_Stmt_F_Exception_Name;
            Self.Raise_Stmt_F_Error_Message := Raise_Stmt_F_Error_Message;
      end Initialize_Fields_For_Raise_Stmt;
   function Raise_Stmt_F_Exception_Name
     (Node : Bare_Raise_Stmt) return Bare_Name
   is
   begin
         return Node.Raise_Stmt_F_Exception_Name;
   end;
   function Raise_Stmt_F_Error_Message
     (Node : Bare_Raise_Stmt) return Bare_Expr
   is
   begin
         return Node.Raise_Stmt_F_Error_Message;
   end;
--# property-start RaiseStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19884
pragma Warnings (Off, "is not referenced");
 function Raise_Stmt_P_Xref_Equation
  (Node : Bare_Raise_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Raise_Stmt := Bare_Raise_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Raise_Stmt :=
     Internal_Entity_Raise_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1402 with Inline_Always;
            procedure Finalizer_Scope_3142 with Inline_Always;
            procedure Finalizer_Scope_3143 with Inline_Always;
      Var_Expr : Internal_Entity_Name;
Var_Expr_1 : Internal_Entity_Expr;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Logic_Var;
Sym : Symbol_Type;
Fld_4 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_5 : Logic_Equation;
And_Pred : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1402 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1402;
            procedure Finalizer_Scope_3142 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_3142;
            procedure Finalizer_Scope_3143 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_5);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_3143;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10720 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10719 '<And at ast.py:19885>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19885
--# expr-start 10710 '<FieldAccess for exception_name at ast.py:19886>' Fld /tmp/lal-23.0.0/ada/ast.py:19886
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Raise_Stmt_F_Exception_Name, Info => Ent.Info);
--# expr-done 10710
Var_Expr := Fld;
if Var_Expr /= No_Entity_Name then
   --# scope-start
   --# bind en Var_Expr
--# expr-start 10711 '<FieldAccess for sub_equation at ast.py:19887>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19887
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10711
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3142;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19888") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
--# expr-start 10712 '<FieldAccess for error_message at ast.py:19890>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19890
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Ent.Node.Raise_Stmt_F_Error_Message, Info => Ent.Info);
--# expr-done 10712
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity_Expr then
   --# scope-start
   --# bind er Var_Expr_1
--# expr-start 10718 '<And at ast.py:19891>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19891
--# expr-start 10716 '<Bind at ast.py:19894>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19894
--# expr-start 10713 '<FieldAccess for expected_type_var at ast.py:19894>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19894
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr_1.Node);
--# expr-done 10713
Fld_3.Value := No_Entity;
Entity_Vars.Reset (Fld_3);
--# expr-start 10715 '<FieldAccess for std_entity at ast.py:19894>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19894
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10714 '<Symbol String at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 10714
--# property-call-start AdaNode.std_entity
Fld_4 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym);
--# end
--# expr-done 10715
Bind_Result := Solver.Create_Assign (Fld_3, Fld_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19894") else null)); 
--# expr-done 10716
--# expr-start 10717 '<FieldAccess for sub_equation at ast.py:19895>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19895
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr_1.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 10717
And_Pred := Create_And (Bind_Result, Fld_5, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19891") else null)); 
--# expr-done 10718
Scope_Result_1 := And_Pred;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3143;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19897") else null)); 
   Result_Var_1 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_1);
And_Pred_1 := Create_And (Result_Var, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19885") else null)); 
--# expr-done 10719
Let_Result := And_Pred_1; Inc_Ref (Let_Result);
--# end
--# expr-done 10720
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1402;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1402;
               Finalizer_Scope_3142;
               Finalizer_Scope_3143;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Raise_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Requeue_Stmt
   --
      procedure Initialize_Fields_For_Requeue_Stmt
        (Self : Bare_Requeue_Stmt
         ; Requeue_Stmt_F_Call_Name : Bare_Name
         ; Requeue_Stmt_F_Has_Abort : Bare_Abort_Node
        ) is
      begin
            Self.Requeue_Stmt_F_Call_Name := Requeue_Stmt_F_Call_Name;
            Self.Requeue_Stmt_F_Has_Abort := Requeue_Stmt_F_Has_Abort;
      end Initialize_Fields_For_Requeue_Stmt;
   function Requeue_Stmt_F_Call_Name
     (Node : Bare_Requeue_Stmt) return Bare_Name
   is
   begin
         return Node.Requeue_Stmt_F_Call_Name;
   end;
   function Requeue_Stmt_F_Has_Abort
     (Node : Bare_Requeue_Stmt) return Bare_Abort_Node
   is
   begin
         return Node.Requeue_Stmt_F_Has_Abort;
   end;
--# property-start RequeueStmt.innermost_entry_or_accept_stmt_params /tmp/lal-23.0.0/ada/ast.py:19779
pragma Warnings (Off, "is not referenced");
 function Requeue_Stmt_P_Innermost_Entry_Or_Accept_Stmt_Params
  (Node : Bare_Requeue_Stmt
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Holder
is
   Self : Bare_Requeue_Stmt := Bare_Requeue_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Requeue_Stmt :=
     Internal_Entity_Requeue_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Formal_Param_Holder;
            procedure Finalizer_Scope_1398 with Inline_Always;
      Match_0 : Internal_Entity_Accept_Stmt_With_Stmts;
Match_1 : Internal_Entity_Entry_Body;
Match_2 : Internal_Entity;
Fld : Internal_Entity_Array_Access;
Is_A : Boolean;
Find_Result : Internal_Entity;
Fld_1 : Internal_Entity_Entry_Completion_Formal_Params;
Fld_2 : Internal_Entity_Entry_Completion_Formal_Params;
Match_Prefix : Internal_Entity;
Cast_Result : Internal_Entity_Accept_Stmt_With_Stmts;
Let_Result : Internal_Entity_Entry_Completion_Formal_Params;
Scope_Result : Internal_Entity_Entry_Completion_Formal_Params;
Cast_Result_1 : Internal_Entity_Entry_Body;
Let_Result_1 : Internal_Entity_Entry_Completion_Formal_Params;
Scope_Result_1 : Internal_Entity_Entry_Completion_Formal_Params;
Cast_Result_2 : Internal_Entity;
Let_Result_2 : Internal_Entity_Entry_Completion_Formal_Params;
Scope_Result_2 : Internal_Entity_Entry_Completion_Formal_Params;
Match_Result : Internal_Entity_Entry_Completion_Formal_Params;
Cast_Result_3 : Internal_Entity_Base_Formal_Param_Holder;
            procedure Finalizer_Scope_1398 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1398;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10727 '<Cast to BaseFormalParamHolder.entity at ast.py:19786>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:19786
--# expr-start 10726 '<Match at ast.py:19782>' Match_Result /tmp/lal-23.0.0/ada/ast.py:19782
--# expr-start 10723 '<Find at ast.py:19780>' Find_Result /tmp/lal-23.0.0/ada/ast.py:19780
   --# expr-start 10721 '<FieldAccess for parents at ast.py:19780>' Fld /tmp/lal-23.0.0/ada/ast.py:19780
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parents (Node => Ent.Node, With_Self => True, E_Info => Ent.Info);
--# expr-done 10721
      Find_Result := No_Entity;
      declare
         Collection : constant Internal_Entity_Array_Access := Fld;
      begin
         for Item_328 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_328
      --# expr-start 10722 '<IsA AcceptStmtWithStmts, EntryBody at ast.py:19781>' Is_A /tmp/lal-23.0.0/ada/ast.py:19781
Is_A := Item_328.Node /= null 
and then Item_328.Node.Kind in Ada_Accept_Stmt_With_Stmts_Range | Ada_Entry_Body_Range; 
--# expr-done 10722
      if Is_A then
         Find_Result := Item_328;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 10723
      if Find_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Find_Result; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Accept_Stmt_With_Stmts =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Accept_Stmt_With_Stmts
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind a Match_0
--# expr-start 10724 '<FieldAccess for params at ast.py:19783>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19783
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Entry_Completion_Formal_Params (Node => Match_0.Node.Accept_Stmt_F_Params, Info => Match_0.Info);
--# expr-done 10724
Let_Result := Fld_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Entry_Body =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Entry_Body
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind b Match_1
--# expr-start 10725 '<FieldAccess for params at ast.py:19784>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19784
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Entry_Completion_Formal_Params (Node => Match_1.Node.Entry_Body_F_Params, Info => Match_1.Info);
--# expr-done 10725
Let_Result_1 := Fld_2; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Task_Body_Stub | Ada_Package_Body .. Ada_Accept_Stmt | Ada_For_Loop_Stmt .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := No_Entity_Entry_Completion_Formal_Params; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 10726
      Cast_Result_3 := Create_Internal_Entity_Base_Formal_Param_Holder
        (Node => Match_Result.Node,
         Info => Match_Result.Info);
--# expr-done 10727
      Property_Result := Cast_Result_3;
   --# end
      Finalizer_Scope_1398;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1398;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Requeue_Stmt_P_Innermost_Entry_Or_Accept_Stmt_Params;
--# end
--# property-start RequeueStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19790
pragma Warnings (Off, "is not referenced");
 function Requeue_Stmt_P_Xref_Equation
  (Node : Bare_Requeue_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Requeue_Stmt := Bare_Requeue_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Requeue_Stmt :=
     Internal_Entity_Requeue_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1399 with Inline_Always;
            procedure Finalizer_Scope_3152 with Inline_Always;
            procedure Finalizer_Scope_3159 with Inline_Always;
            procedure Finalizer_Scope_3160 with Inline_Always;
      Block_Var : Internal_Entity_Call_Expr;
Block_Var_1 : Internal_Entity_Name;
Block_Var_2 : Internal_Entity_Array_Access;
Var_Expr : Internal_Entity_Call_Expr;
Var_Expr_1 : Internal_Entity_Entry_Decl;
Var_Expr_2 : Internal_Entity_Base_Subp_Spec;
Fam_Type : Internal_Entity_Base_Type_Decl;
First_Param : Internal_Entity_Expr;
Var_Expr_3 : Internal_Entity_Subtype_Indication;
Var_Expr_4 : Internal_Entity_Entry_Decl;
Var_Expr_5 : Internal_Entity_Basic_Assoc;
Var_Expr_6 : Internal_Entity_Call_Expr;
Var_Expr_7 : Internal_Entity_Expr;
Var_Expr_8 : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Name;
Cast_Result : Internal_Entity_Call_Expr;
Fld_1 : Internal_Entity_Name;
Scope_Result : Internal_Entity_Name;
Fld_2 : Internal_Entity_Name;
Result_Var : Internal_Entity_Name;
Fld_3 : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result_1 : Internal_Entity_Entry_Decl;
Fld_4 : Internal_Entity_Base_Subp_Spec;
Fld_5 : Integer;
Is_Equal : Boolean;
Fld_6 : Internal_Entity_Type_Expr;
Is_Null : Boolean;
If_Result : Boolean;
Scope_Result_1 : Boolean;
Result_Var_1 : Boolean;
Fld_7 : Internal_Entity_Entry_Spec;
Fld_8 : Internal_Entity_Base_Formal_Param_Holder;
Fld_9 : Boolean;
If_Result_1 : Boolean;
Scope_Result_2 : Boolean;
Result_Var_2 : Boolean;
Map_Result : Internal_Entity_Array_Access;
Fld_10 : Logic_Equation;
Cast_Expr_1 : Internal_Entity;
Cast_Result_2 : Internal_Entity_Entry_Decl;
Fld_11 : Internal_Entity_Entry_Spec;
Fld_12 : Internal_Entity;
Scope_Result_3 : Internal_Entity;
Result_Var_3 : Internal_Entity;
Cast_Result_3 : Internal_Entity_Subtype_Indication;
Fld_13 : Internal_Entity_Base_Type_Decl;
Scope_Result_4 : Internal_Entity_Base_Type_Decl;
Result_Var_4 : Internal_Entity_Base_Type_Decl;
Fld_14 : Internal_Entity_Assoc_List;
Scope_Result_5 : Internal_Entity_Assoc_List;
Result_Var_5 : Internal_Entity_Assoc_List;
Fld_15 : Bare_Assoc_List;
Fld_16 : Internal_Entity_Info;
As_Entity : Internal_Entity_Basic_Assoc;
Is_Null_1 : Boolean;
If_Result_2 : Internal_Entity_Basic_Assoc;
Item_363 : Internal_Entity_Basic_Assoc;
Bare_Item_363 : Bare_Basic_Assoc;
Map_Result_1 : Internal_Entity_Basic_Assoc_Array_Access;
Get_Result : Internal_Entity_Basic_Assoc;
Fld_17 : Internal_Entity_Expr;
Scope_Result_6 : Internal_Entity_Expr;
Result_Var_6 : Internal_Entity_Expr;
Fld_18 : Logic_Equation;
Fld_19 : Logic_Var;
Cast_Expr_2 : Internal_Entity_Base_Type_Decl;
Cast_Result_4 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_20 : Logic_Equation;
And_Pred : Logic_Equation;
Scope_Result_7 : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result_8 : Logic_Equation;
True_Rel_1 : Logic_Equation;
Result_Var_8 : Logic_Equation;
Let_Result : Logic_Equation;
Map_Result_2 : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred_2 : Logic_Equation;
Let_Result_1 : Logic_Equation;
            procedure Finalizer_Scope_1399 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Map_Result_2);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_1399;
            procedure Finalizer_Scope_3152 is
            begin
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Scope_Result_8);
                     Dec_Ref (True_Rel_1);
                     Dec_Ref (Result_Var_8);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_3152;
            procedure Finalizer_Scope_3159 is
            begin
                     Dec_Ref (Fld_18);
                     Dec_Ref (Scope_Result_7);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var_7);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3159;
            procedure Finalizer_Scope_3160 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_20);
                     Dec_Ref (And_Pred);
            end Finalizer_Scope_3160;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10763 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 10729 '<Cast to CallExpr at ast.py:19791>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19791
--# expr-start 10728 '<FieldAccess for call_name at ast.py:19791>' Fld /tmp/lal-23.0.0/ada/ast.py:19791
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Requeue_Stmt_F_Call_Name, Info => Ent.Info);
--# expr-done 10728
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Call_Expr_Range
   then
      Cast_Result := Create_Internal_Entity_Call_Expr
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Call_Expr;
   end if;
--# expr-done 10729
Block_Var := Cast_Result; 
--# bind ce Block_Var
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Call_Expr then
   --# scope-start
   --# bind ce Var_Expr
--# expr-start 10730 '<FieldAccess for name at ast.py:19792>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19792
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Var_Expr.Node.Call_Expr_F_Name, Info => Var_Expr.Info);
--# expr-done 10730
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 10731 '<FieldAccess for call_name at ast.py:19793>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19793
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Name (Node => Ent.Node.Requeue_Stmt_F_Call_Name, Info => Ent.Info);
--# expr-done 10731
   Result_Var := Fld_2;
end if;
Block_Var_1 := Result_Var; 
--# bind name Block_Var_1
--# expr-start 10742 '<Filter at ast.py:19795>' Map_Result /tmp/lal-23.0.0/ada/ast.py:19795
   --# expr-start 10732 '<FieldAccess for all_env_elements_internal at ast.py:19795>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19795
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.all_env_elements_internal
Fld_3 := Libadalang.Implementation.Name_P_All_Env_Elements_Internal (Node => Block_Var_1.Node, E_Info => Block_Var_1.Info);
--# end
--# expr-done 10732
      declare
         Map_Result_Vec : Internal_Entity_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Fld_3;
      begin
         for Item_329 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_329
--# expr-start 10733 '<Cast to EntryDecl at ast.py:19798>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:19798
Cast_Expr := Item_329; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Entry_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result_1 := No_Entity_Entry_Decl;
   end if;
--# expr-done 10733
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Entity_Entry_Decl then
   --# scope-start
   --# bind e Var_Expr_1
--# expr-start 10734 '<FieldAccess for subp_spec_or_null at ast.py:19800>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19800
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.subp_spec_or_null
Fld_4 := Libadalang.Implementation.Basic_Decl_P_Subp_Spec_Or_Null (Node => Var_Expr_1.Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 10734
Var_Expr_2 := Fld_4;
if Var_Expr_2 /= No_Entity_Base_Subp_Spec then
   --# scope-start
   --# bind ss Var_Expr_2
--# expr-start 10736 '<Eq at ast.py:19801>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:19801
--# expr-start 10735 '<FieldAccess for nb_max_params at ast.py:19801>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19801
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseFormalParamHolder.nb_max_params
Fld_5 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Nb_Max_Params (Node => Var_Expr_2.Node);
--# end
--# expr-done 10735
Is_Equal := Fld_5 = 0; 
--# expr-done 10736
if Is_Equal then
   --# expr-start 10738 '<IsNull at ast.py:19802>' Is_Null /tmp/lal-23.0.0/ada/ast.py:19802
--# expr-start 10737 '<FieldAccess for returns at ast.py:19802>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19802
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_6 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Var_Expr_2.Node, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 10737
Is_Null := Fld_6.Node = null; 
--# expr-done 10738
   If_Result := Is_Null;
else
   If_Result := False;
end if;
Scope_Result_1 := If_Result;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := False;
end if;
if Result_Var_1 then
   If_Result_1 := True;
else
   --# expr-start 10741 '<FieldAccess for match_formal_params at ast.py:19805>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:19805
--# expr-start 10739 '<FieldAccess for spec at ast.py:19805>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19805
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Entry_Spec (Node => Var_Expr_1.Node.Entry_Decl_F_Spec, Info => Var_Expr_1.Info);
--# expr-done 10739
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10740 '<FieldAccess for innermost_entry_or_accept_stmt_params at ast.py:19806>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:19806
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start RequeueStmt.innermost_entry_or_accept_stmt_params
Fld_8 := Libadalang.Implementation.Requeue_Stmt_P_Innermost_Entry_Or_Accept_Stmt_Params (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10740
--# property-call-start BaseFormalParamHolder.match_formal_params
Fld_9 := Libadalang.Implementation.Base_Formal_Param_Holder_P_Match_Formal_Params (Node => Fld_7.Node, Other => Fld_8, E_Info => Fld_7.Info);
--# end
--# expr-done 10741
   If_Result_1 := Fld_9;
end if;
Scope_Result_2 := If_Result_1;
   --# end
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := False;
end if;
         if Result_Var_2 then
         declare
            Item_To_Append : constant Internal_Entity := Item_329;
         begin
            Internal_Entity_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
         end if;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Entity_Array
           (Items_Count => Natural (Internal_Entity_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10742
Block_Var_2 := Map_Result; Inc_Ref (Block_Var_2);
--# bind entries Block_Var_2
--# expr-start 10762 '<And at ast.py:19811>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:19811
--# expr-start 10743 '<FieldAccess for xref_no_overloading at ast.py:19814>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:19814
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_10 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Block_Var_1.Node, Env => Env, Origin => Origin, E_Info => Block_Var_1.Info);
--# end
--# expr-done 10743
--# expr-start 10761 '<LogicAny at ast.py:19817>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:19817
--# expr-start 10760 '<Map at ast.py:19817>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:19817
      declare
         Map_Result_2_Vec : Logic_Equation_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Block_Var_2;
      begin
         for Item_330 of
               Collection.Items
         loop
   --# scope-start
               --# bind e Item_330
      --# expr-start 10759 '<Let at ast.py:19817>' Let_Result /tmp/lal-23.0.0/ada/ast.py:19817
--# scope-start
--# expr-start 10747 '<Cast to SubtypeIndication at ast.py:19822>' Cast_Result_3 /tmp/lal-23.0.0/ada/ast.py:19822
--# expr-start 10744 '<Cast to EntryDecl at ast.py:19821>' Cast_Result_2 /tmp/lal-23.0.0/ada/ast.py:19821
Cast_Expr_1 := Item_330; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Entry_Decl_Range
   then
      Cast_Result_2 := Create_Internal_Entity_Entry_Decl
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_2 := No_Entity_Entry_Decl;
   end if;
--# expr-done 10744
Var_Expr_4 := Cast_Result_2;
if Var_Expr_4 /= No_Entity_Entry_Decl then
   --# scope-start
--# expr-start 10746 '<FieldAccess for family_type at ast.py:19821>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:19821
--# expr-start 10745 '<FieldAccess for spec at ast.py:19821>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:19821
      if Var_Expr_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Entry_Spec (Node => Var_Expr_4.Node.Entry_Decl_F_Spec, Info => Var_Expr_4.Info);
--# expr-done 10745
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity (Node => Fld_11.Node.Entry_Spec_F_Family_Type, Info => Fld_11.Info);
--# expr-done 10746
Scope_Result_3 := Fld_12;
   --# end
   Result_Var_3 := Scope_Result_3;
else
   Result_Var_3 := No_Entity;
end if;
   if Result_Var_3.Node = null
      or else Result_Var_3.Node.Kind in Ada_Subtype_Indication_Range
   then
      Cast_Result_3 := Create_Internal_Entity_Subtype_Indication
        (Node => Result_Var_3.Node,
         Info => Result_Var_3.Info);
   else
         Cast_Result_3 := No_Entity_Subtype_Indication;
   end if;
--# expr-done 10747
Var_Expr_3 := Cast_Result_3;
if Var_Expr_3 /= No_Entity_Subtype_Indication then
   --# scope-start
--# expr-start 10748 '<FieldAccess for designated_type at ast.py:19822>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:19822
      if Var_Expr_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_13 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Var_Expr_3.Node, Origin => Origin, E_Info => Var_Expr_3.Info);
--# end
--# expr-done 10748
Scope_Result_4 := Fld_13;
   --# end
   Result_Var_4 := Scope_Result_4;
else
   Result_Var_4 := No_Entity_Base_Type_Decl;
end if;
Fam_Type := Result_Var_4; 
--# bind fam_type Fam_Type
--# expr-start 10751 '<at at ast.py:19826>' Get_Result /tmp/lal-23.0.0/ada/ast.py:19826
--# expr-start 10750 '<TakeWhile at ???>' Map_Result_1 None
Var_Expr_6 := Block_Var;
if Var_Expr_6 /= No_Entity_Call_Expr then
   --# scope-start
--# expr-start 10749 '<FieldAccess for params at ast.py:19826>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:19826
      if Var_Expr_6.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CallExpr.params
Fld_14 := Libadalang.Implementation.Call_Expr_P_Params (Node => Var_Expr_6.Node, E_Info => Var_Expr_6.Info);
--# end
--# expr-done 10749
Scope_Result_5 := Fld_14;
   --# end
   Result_Var_5 := Scope_Result_5;
else
   Result_Var_5 := No_Entity_Assoc_List;
end if;
Fld_15 := Result_Var_5.Node;
      declare
         Map_Result_1_Vec : Internal_Entity_Basic_Assoc_Vectors.Vector;
      begin
      if Fld_15 = null then
      Map_Result_1 := Create_Internal_Entity_Basic_Assoc_Array (0);
      else
      declare
         Collection : constant Bare_Assoc_List := Fld_15;
      begin
         for Untyped_Item_363 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_363 := Untyped_Item_363; 
Is_Null_1 := Bare_Item_363 = null; 
if Is_Null_1 then
   If_Result_2 := No_Entity_Basic_Assoc;
else
Fld_16 := Result_Var_5.Info;
As_Entity := (Info => Fld_16, Node => Bare_Item_363); 
   If_Result_2 := As_Entity;
end if;
                  Item_363 := If_Result_2; 
   --# scope-start
         declare
            Item_To_Append : constant Internal_Entity_Basic_Assoc := Item_363;
         begin
            Internal_Entity_Basic_Assoc_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Internal_Entity_Basic_Assoc_Array
           (Items_Count => Natural (Internal_Entity_Basic_Assoc_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Entity_Basic_Assoc_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Entity_Basic_Assoc_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Entity_Basic_Assoc_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 10750
Get_Result := Get (Self, Map_Result_1, 0, True); 
--# expr-done 10751
Var_Expr_5 := Get_Result;
if Var_Expr_5 /= No_Entity_Basic_Assoc then
   --# scope-start
--# expr-start 10752 '<FieldAccess for expr at ast.py:19826>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:19826
      if Var_Expr_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_17 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Var_Expr_5.Node, E_Info => Var_Expr_5.Info);
--# end
--# expr-done 10752
Scope_Result_6 := Fld_17;
   --# end
   Result_Var_6 := Scope_Result_6;
else
   Result_Var_6 := No_Entity_Expr;
end if;
First_Param := Result_Var_6; 
--# bind first_param First_Param
Var_Expr_7 := First_Param;
if Var_Expr_7 /= No_Entity_Expr then
   --# scope-start
   --# bind p Var_Expr_7
--# expr-start 10758 '<And at ast.py:19829>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19829
--# expr-start 10753 '<FieldAccess for sub_equation at ast.py:19829>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:19829
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_18 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr_7.Node, Env => Env, Origin => Origin, E_Info => Var_Expr_7.Info);
--# end
--# expr-done 10753
Var_Expr_8 := Fam_Type;
if Var_Expr_8 /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind eft Var_Expr_8
--# expr-start 10757 '<And at ast.py:19831>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19831
--# expr-start 10755 '<Bind at ast.py:19831>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19831
--# expr-start 10754 '<FieldAccess for expected_type_var at ast.py:19831>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:19831
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_19 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr_7.Node);
--# expr-done 10754
Fld_19.Value := No_Entity;
Entity_Vars.Reset (Fld_19);
Cast_Expr_2 := Var_Expr_8; 
      Cast_Result_4 := Create_Internal_Entity
        (Node => Cast_Expr_2.Node,
         Info => Cast_Expr_2.Info);
Bind_Result := Solver.Create_Assign (Fld_19, Cast_Result_4, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19831") else null)); 
--# expr-done 10755
--# expr-start 10756 '<FieldAccess for matches_expected_type at ast.py:19832>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:19832
      if Var_Expr_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_20 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Var_Expr_7.Node, Origin => Origin);
--# end
--# expr-done 10756
And_Pred := Create_And (Bind_Result, Fld_20, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19831") else null)); 
--# expr-done 10757
Scope_Result_7 := And_Pred;
   Inc_Ref (Scope_Result_7);
   --# end
      Finalizer_Scope_3160;
   Result_Var_7 := Scope_Result_7;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19833") else null)); 
   Result_Var_7 := True_Rel;
end if;
      Inc_Ref (Result_Var_7);
And_Pred_1 := Create_And (Fld_18, Result_Var_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19829") else null)); 
--# expr-done 10758
Scope_Result_8 := And_Pred_1;
   Inc_Ref (Scope_Result_8);
   --# end
      Finalizer_Scope_3159;
   Result_Var_8 := Scope_Result_8;
else
   True_Rel_1 := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19835") else null)); 
   Result_Var_8 := True_Rel_1;
end if;
      Inc_Ref (Result_Var_8);
Let_Result := Result_Var_8; Inc_Ref (Let_Result);
--# end
--# expr-done 10759
         declare
            Item_To_Append : constant Logic_Equation := Let_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3152;
         end loop;
      end;
         Map_Result_2 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_2_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 10760
Logic_Boolean_Op := Solver.Create_Any (Relation_Array (Map_Result_2.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19817") else null)); 
--# expr-done 10761
And_Pred_2 := Create_And (Fld_10, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19811") else null)); 
--# expr-done 10762
Let_Result_1 := And_Pred_2; Inc_Ref (Let_Result_1);
--# end
--# expr-done 10763
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1399;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1399;
               Finalizer_Scope_3152;
               Finalizer_Scope_3159;
               Finalizer_Scope_3160;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Requeue_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Return_Stmt
   --
      procedure Initialize_Fields_For_Return_Stmt
        (Self : Bare_Return_Stmt
         ; Return_Stmt_F_Return_Expr : Bare_Expr
        ) is
      begin
            Self.Return_Stmt_F_Return_Expr := Return_Stmt_F_Return_Expr;
      end Initialize_Fields_For_Return_Stmt;
   function Return_Stmt_F_Return_Expr
     (Node : Bare_Return_Stmt) return Bare_Expr
   is
   begin
         return Node.Return_Stmt_F_Return_Expr;
   end;
--# property-start ReturnStmt.subp /tmp/lal-23.0.0/ada/ast.py:19754
pragma Warnings (Off, "is not referenced");
 function Return_Stmt_P_Subp
  (Node : Bare_Return_Stmt
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Subp_Body
is
   Self : Bare_Return_Stmt := Bare_Return_Stmt (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Subp_Body;
            procedure Finalizer_Scope_1396 with Inline_Always;
      Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Subp_Body;
As_Entity : Internal_Entity_Subp_Body;
Is_Null : Boolean;
If_Result : Internal_Entity_Subp_Body;
            procedure Finalizer_Scope_1396 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_1396;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 10768 '<as_entity at ast.py:19755>' If_Result /tmp/lal-23.0.0/ada/ast.py:19755
--# expr-start 10767 '<Cast to SubpBody at ast.py:19755>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:19755
--# expr-start 10766 '<Find at ast.py:19755>' Find_Result /tmp/lal-23.0.0/ada/ast.py:19755
   --# expr-start 10764 '<FieldAccess for parents at ast.py:19755>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:19755
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Self, True); 
--# expr-done 10764
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_331 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_331
      --# expr-start 10765 '<IsA SubpBody at ast.py:19755>' Is_A /tmp/lal-23.0.0/ada/ast.py:19755
Is_A := Item_331 /= null 
and then Item_331.Kind in Ada_Subp_Body_Range; 
--# expr-done 10765
      if Is_A then
         Find_Result := Item_331;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 10766
   if Find_Result = null
      or else Find_Result.Kind in Ada_Subp_Body_Range
   then
      Cast_Result := Find_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 10767
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Subp_Body;
else
As_Entity := (Info => E_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 10768
      Property_Result := If_Result;
   --# end
      Finalizer_Scope_1396;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1396;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Return_Stmt_P_Subp;
--# end
--# property-start ReturnStmt.xref_equation /tmp/lal-23.0.0/ada/ast.py:19760
pragma Warnings (Off, "is not referenced");
 function Return_Stmt_P_Xref_Equation
  (Node : Bare_Return_Stmt
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Return_Stmt := Bare_Return_Stmt (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Return_Stmt :=
     Internal_Entity_Return_Stmt'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1397 with Inline_Always;
            procedure Finalizer_Scope_3162 with Inline_Always;
      Var_Expr : Internal_Entity_Expr;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Subp_Body;
Fld_3 : Internal_Entity_Subp_Spec;
Fld_4 : Internal_Entity_Type_Expr;
Fld_5 : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_6 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_7 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1397 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1397;
            procedure Finalizer_Scope_3162 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_7);
                     Dec_Ref (And_Pred_1);
            end Finalizer_Scope_3162;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10780 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10769 '<FieldAccess for return_expr at ast.py:19761>' Fld /tmp/lal-23.0.0/ada/ast.py:19761
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Return_Stmt_F_Return_Expr, Info => Ent.Info);
--# expr-done 10769
Var_Expr := Fld;
if Var_Expr /= No_Entity_Expr then
   --# scope-start
   --# bind rexpr Var_Expr
--# expr-start 10779 '<And at ast.py:19763>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:19763
--# expr-start 10777 '<And at ast.py:19763>' And_Pred /tmp/lal-23.0.0/ada/ast.py:19763
--# expr-start 10775 '<Bind at ast.py:19763>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:19763
--# expr-start 10770 '<FieldAccess for expected_type_var at ast.py:19763>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:19763
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Var_Expr.Node);
--# expr-done 10770
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10774 '<FieldAccess for designated_type at ast.py:19764>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:19764
--# expr-start 10773 '<FieldAccess for returns at ast.py:19764>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:19764
--# expr-start 10772 '<FieldAccess for subp_spec at ast.py:19764>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:19764
--# expr-start 10771 '<FieldAccess for subp at ast.py:19764>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:19764
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ReturnStmt.subp
Fld_2 := Libadalang.Implementation.Return_Stmt_P_Subp (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 10771
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Subp_Spec (Node => Fld_2.Node.Base_Subp_Body_F_Subp_Spec, Info => Fld_2.Info);
--# expr-done 10772
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseSubpSpec.returns'
Fld_4 := Libadalang.Implementation.Dispatcher_Base_Subp_Spec_P_Returns (Node => Fld_3.Node, E_Info => Fld_3.Info);
--# end
--# expr-done 10773
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_5 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_4.Node, Origin => Origin, E_Info => Fld_4.Info);
--# end
--# expr-done 10774
      Cast_Result := Create_Internal_Entity
        (Node => Fld_5.Node,
         Info => Fld_5.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19763") else null)); 
--# expr-done 10775
--# expr-start 10776 '<FieldAccess for sub_equation at ast.py:19765>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:19765
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_6 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 10776
And_Pred := Create_And (Bind_Result, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19763") else null)); 
--# expr-done 10777
--# expr-start 10778 '<FieldAccess for matches_expected_assign_type at ast.py:19766>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:19766
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_assign_type
Fld_7 := Libadalang.Implementation.Expr_P_Matches_Expected_Assign_Type (Node => Var_Expr.Node, Origin => Origin);
--# end
--# expr-done 10778
And_Pred_1 := Create_And (And_Pred, Fld_7, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19763") else null)); 
--# expr-done 10779
Scope_Result := And_Pred_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3162;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:19767") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
Let_Result := Result_Var; Inc_Ref (Let_Result);
--# end
--# expr-done 10780
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1397;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1397;
               Finalizer_Scope_3162;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Return_Stmt_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Terminate_Alternative
   --
--# property-start TerminateAlternative.xref_equation /tmp/lal-23.0.0/ada/ast.py:20259
pragma Warnings (Off, "is not referenced");
 function Terminate_Alternative_P_Xref_Equation
  (Node : Bare_Terminate_Alternative
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Terminate_Alternative := Bare_Terminate_Alternative (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1425 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_1425 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_1425;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20259") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1425;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1425;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Terminate_Alternative_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Subp_Kind
   --
   --
   --  Primitives for Bare_Subp_Kind_Function
   --
   --
   --  Primitives for Bare_Subp_Kind_Procedure
   --
   --
   --  Primitives for Bare_Subunit
   --
      procedure Initialize_Fields_For_Subunit
        (Self : Bare_Subunit
         ; Subunit_F_Name : Bare_Name
         ; Subunit_F_Body : Bare_Body_Node
        ) is
      begin
            Self.Subunit_F_Name := Subunit_F_Name;
            Self.Subunit_F_Body := Subunit_F_Body;
      end Initialize_Fields_For_Subunit;
   function Subunit_F_Name
     (Node : Bare_Subunit) return Bare_Name
   is
   begin
         return Node.Subunit_F_Name;
   end;
   function Subunit_F_Body
     (Node : Bare_Subunit) return Bare_Body_Node
   is
   begin
         return Node.Subunit_F_Body;
   end;
--# property-start Subunit.root_unit /tmp/lal-23.0.0/ada/ast.py:20592
pragma Warnings (Off, "is not referenced");
 function Subunit_P_Root_Unit
  (Node : Bare_Subunit
  )
   return Internal_Entity_Compilation_Unit
is
   Self : Bare_Subunit := Bare_Subunit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Compilation_Unit;
            procedure Finalizer_Scope_1445 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Symbol_Type_Array_Access;
Fld_2 : Bare_Compilation_Unit;
As_Entity : Internal_Entity_Compilation_Unit;
Is_Null : Boolean;
If_Result : Internal_Entity_Compilation_Unit;
Let_Result : Internal_Entity_Compilation_Unit;
            procedure Finalizer_Scope_1445 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_1445;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10785 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10784 '<as_bare_entity at ast.py:20601>' If_Result /tmp/lal-23.0.0/ada/ast.py:20601
--# expr-start 10783 '<FieldAccess for designated_compilation_unit at ast.py:20596>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20596
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10782 '<FieldAccess for as_symbol_array at ast.py:20597>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20597
--# expr-start 10781 '<FieldAccess for name at ast.py:20597>' Fld /tmp/lal-23.0.0/ada/ast.py:20597
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Subunit_F_Name;
--# expr-done 10781
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld);
--# end
--# expr-done 10782
--# property-call-start AdaNode.designated_compilation_unit
Fld_2 := Libadalang.Implementation.Ada_Node_P_Designated_Compilation_Unit (Node => Self, Name => Fld_1, Kind => Unit_Body, Load_If_Needed => True, Not_Found_Is_Error => True);
--# end
--# expr-done 10783
Is_Null := Fld_2 = null; 
if Is_Null then
   If_Result := No_Entity_Compilation_Unit;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_2); 
   If_Result := As_Entity;
end if;
--# expr-done 10784
Let_Result := If_Result; 
--# end
--# expr-done 10785
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1445;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1445;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subunit_P_Root_Unit;
--# end
--# property-start Subunit.env_hook_subunit /tmp/lal-23.0.0/ada/ast.py:20604
pragma Warnings (Off, "is not referenced");
 function Subunit_P_Env_Hook_Subunit
  (Node : Bare_Subunit
  )
   return Boolean
is
   Self : Bare_Subunit := Bare_Subunit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Block_Var : Internal_Entity_Compilation_Unit;
Fld : Internal_Entity_Compilation_Unit;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10787 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10786 '<FieldAccess for root_unit at ast.py:20610>' Fld /tmp/lal-23.0.0/ada/ast.py:20610
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.root_unit
Fld := Libadalang.Implementation.Subunit_P_Root_Unit (Node => Self);
--# end
--# expr-done 10786
Block_Var := Fld; 
Let_Result := False; 
--# end
--# expr-done 10787
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subunit_P_Env_Hook_Subunit;
--# end
--# property-start Subunit.body_root /tmp/lal-23.0.0/ada/ast.py:20614
pragma Warnings (Off, "is not referenced");
 function Subunit_P_Body_Root
  (Node : Bare_Subunit
  )
   return Internal_Entity_Basic_Decl
is
   Self : Bare_Subunit := Bare_Subunit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Basic_Decl;
      Fld : Internal_Entity_Compilation_Unit;
Fld_1 : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Let_Result : Internal_Entity_Basic_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10791 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10790 '<as_bare_entity at ast.py:20618>' If_Result /tmp/lal-23.0.0/ada/ast.py:20618
--# expr-start 10789 '<FieldAccess for decl at ast.py:20618>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20618
--# expr-start 10788 '<FieldAccess for root_unit at ast.py:20618>' Fld /tmp/lal-23.0.0/ada/ast.py:20618
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.root_unit
Fld := Libadalang.Implementation.Subunit_P_Root_Unit (Node => Self);
--# end
--# expr-done 10788
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_1 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Fld.Node);
--# end
--# expr-done 10789
Is_Null := Fld_1 = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Fld_1); 
   If_Result := As_Entity;
end if;
--# expr-done 10790
Let_Result := If_Result; 
--# end
--# expr-done 10791
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subunit_P_Body_Root;
--# end
--# property-start Subunit.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:20620
pragma Warnings (Off, "is not referenced");
 function Subunit_P_Xref_Entry_Point
  (Node : Bare_Subunit
  )
   return Boolean
is
   Self : Bare_Subunit := Bare_Subunit (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subunit_P_Xref_Entry_Point;
--# end
--# property-start Subunit.xref_equation /tmp/lal-23.0.0/ada/ast.py:20621
pragma Warnings (Off, "is not referenced");
 function Subunit_P_Xref_Equation
  (Node : Bare_Subunit
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Subunit := Bare_Subunit (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subunit :=
     Internal_Entity_Subunit'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1449 with Inline_Always;
      Fld : Bare_Name;
Fld_1 : Logic_Var;
Fld_2 : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
            procedure Finalizer_Scope_1449 is
            begin
                     Dec_Ref (Bind_Result);
            end Finalizer_Scope_1449;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10795 '<Bind at ast.py:20621>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:20621
--# expr-start 10793 '<FieldAccess for ref_var at ast.py:20621>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20621
--# expr-start 10792 '<FieldAccess for name at ast.py:20621>' Fld /tmp/lal-23.0.0/ada/ast.py:20621
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Subunit_F_Name;
--# expr-done 10792
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld_1 := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Fld);
--# end
--# expr-done 10793
Fld_1.Value := No_Entity;
Entity_Vars.Reset (Fld_1);
--# expr-start 10794 '<FieldAccess for body_root at ast.py:20621>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:20621
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Subunit.body_root
Fld_2 := Libadalang.Implementation.Subunit_P_Body_Root (Node => Ent.Node);
--# end
--# expr-done 10794
      Cast_Result := Create_Internal_Entity
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
Bind_Result := Solver.Create_Assign (Fld_1, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:20621") else null)); 
--# expr-done 10795
      Property_Result := Bind_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1449;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1449;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subunit_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Synchronized_Node
   --
--# property-start '[dispatcher]Synchronized.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Synchronized_Node_P_As_Bool
  (Node : Bare_Synchronized_Node
  )
   return Boolean
is
   Self : Bare_Synchronized_Node := Bare_Synchronized_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Synchronized_Node (Self.Kind) is
               when Ada_Synchronized_Absent =>
                  --# property-call-start Synchronized.Absent.as_bool
                  Property_Result := Synchronized_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Synchronized_Present =>
                  --# property-call-start Synchronized.Present.as_bool
                  Property_Result := Synchronized_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Synchronized_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Synchronized_Absent
   --
--# property-start Synchronized.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5061
pragma Warnings (Off, "is not referenced");
 function Synchronized_Absent_P_As_Bool
  (Node : Bare_Synchronized_Absent
  )
   return Boolean
is
   Self : Bare_Synchronized_Absent := Bare_Synchronized_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synchronized_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Synchronized_Present
   --
--# property-start Synchronized.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5061
pragma Warnings (Off, "is not referenced");
 function Synchronized_Present_P_As_Bool
  (Node : Bare_Synchronized_Present
  )
   return Boolean
is
   Self : Bare_Synchronized_Present := Bare_Synchronized_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synchronized_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Tagged_Node
   --
--# property-start '[dispatcher]Tagged.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Tagged_Node_P_As_Bool
  (Node : Bare_Tagged_Node
  )
   return Boolean
is
   Self : Bare_Tagged_Node := Bare_Tagged_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Tagged_Node (Self.Kind) is
               when Ada_Tagged_Absent =>
                  --# property-call-start Tagged.Absent.as_bool
                  Property_Result := Tagged_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Tagged_Present =>
                  --# property-call-start Tagged.Present.as_bool
                  Property_Result := Tagged_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Tagged_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Tagged_Absent
   --
--# property-start Tagged.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:4965
pragma Warnings (Off, "is not referenced");
 function Tagged_Absent_P_As_Bool
  (Node : Bare_Tagged_Absent
  )
   return Boolean
is
   Self : Bare_Tagged_Absent := Bare_Tagged_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Tagged_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Tagged_Present
   --
--# property-start Tagged.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:4965
pragma Warnings (Off, "is not referenced");
 function Tagged_Present_P_As_Bool
  (Node : Bare_Tagged_Present
  )
   return Boolean
is
   Self : Bare_Tagged_Present := Bare_Tagged_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Tagged_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Task_Def
   --
      procedure Initialize_Fields_For_Task_Def
        (Self : Bare_Task_Def
         ; Task_Def_F_Interfaces : Bare_Parent_List
         ; Task_Def_F_Public_Part : Bare_Public_Part
         ; Task_Def_F_Private_Part : Bare_Private_Part
         ; Task_Def_F_End_Name : Bare_End_Name
        ) is
      begin
            Self.Task_Def_F_Interfaces := Task_Def_F_Interfaces;
            Self.Task_Def_F_Public_Part := Task_Def_F_Public_Part;
            Self.Task_Def_F_Private_Part := Task_Def_F_Private_Part;
            Self.Task_Def_F_End_Name := Task_Def_F_End_Name;
      end Initialize_Fields_For_Task_Def;
   function Task_Def_F_Interfaces
     (Node : Bare_Task_Def) return Bare_Parent_List
   is
   begin
         return Node.Task_Def_F_Interfaces;
   end;
   function Task_Def_F_Public_Part
     (Node : Bare_Task_Def) return Bare_Public_Part
   is
   begin
         return Node.Task_Def_F_Public_Part;
   end;
   function Task_Def_F_Private_Part
     (Node : Bare_Task_Def) return Bare_Private_Part
   is
   begin
         return Node.Task_Def_F_Private_Part;
   end;
   function Task_Def_F_End_Name
     (Node : Bare_Task_Def) return Bare_End_Name
   is
   begin
         return Node.Task_Def_F_End_Name;
   end;
--# property-start TaskDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8602
pragma Warnings (Off, "is not referenced");
 function Task_Def_P_Xref_Equation
  (Node : Bare_Task_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Task_Def := Bare_Task_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Task_Def :=
     Internal_Entity_Task_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_698 with Inline_Always;
            procedure Finalizer_Scope_3163 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Item_332 : Internal_Entity_Name;
Bare_Item_332 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_698 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_698;
            procedure Finalizer_Scope_3163 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3163;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10800 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10799 '<LogicAll at ast.py:8603>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8603
--# expr-start 10798 '<Map at ast.py:8603>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8603
   --# expr-start 10796 '<FieldAccess for interfaces at ast.py:8603>' Fld /tmp/lal-23.0.0/ada/ast.py:8603
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Task_Def_F_Interfaces, Info => Ent.Info);
--# expr-done 10796
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_332 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_332 := Untyped_Item_332; 
Is_Null := Bare_Item_332 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_332); 
   If_Result := As_Entity;
end if;
                  Item_332 := If_Result; 
   --# scope-start
               --# bind ifc Item_332
      --# expr-start 10797 '<FieldAccess for xref_equation at ast.py:8603>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8603
      if Item_332.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Item_332.Node, Env => Env, Origin => Origin, E_Info => Item_332.Info);
--# end
--# expr-done 10797
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3163;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 10798
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8603") else null)); 
--# expr-done 10799
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 10800
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_698;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_698;
               Finalizer_Scope_3163;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Task_Def_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Type_Attributes_Repository
   --
      procedure Initialize_Fields_For_Type_Attributes_Repository
        (Self : Bare_Type_Attributes_Repository
        ) is
      begin
      Self.Type_Attributes_Repository_Base_Type := No_Bare_Ada_Node;
      Self.Lf_Present_Base_Type_Expr := False;
      Self.Lf_Stg_Base_Type_Expr := No_Bare_Ada_Node;
      Self.Lf_Present_Universal_Int_Type_Expr := False;
      Self.Lf_Stg_Universal_Int_Type_Expr := No_Bare_Ada_Node;
      Self.Lf_Present_Base_Type_Param := False;
      Self.Lf_Stg_Base_Type_Param := No_Bare_Ada_Node;
      Self.Lf_Present_Universal_Int_Param := False;
      Self.Lf_Stg_Universal_Int_Param := No_Bare_Ada_Node;
      Self.Lf_Present_Universal_Real_Param := False;
      Self.Lf_Stg_Universal_Real_Param := No_Bare_Ada_Node;
      Self.Lf_Present_Root_Stream_Param := False;
      Self.Lf_Stg_Root_Stream_Param := No_Bare_Ada_Node;
      Self.Lf_Present_Succ := False;
      Self.Lf_Stg_Succ := No_Bare_Ada_Node;
      Self.Lf_Present_Pred := False;
      Self.Lf_Stg_Pred := No_Bare_Ada_Node;
      Self.Lf_Present_Min := False;
      Self.Lf_Stg_Min := No_Bare_Ada_Node;
      Self.Lf_Present_Max := False;
      Self.Lf_Stg_Max := No_Bare_Ada_Node;
      Self.Lf_Present_Rounding := False;
      Self.Lf_Stg_Rounding := No_Bare_Ada_Node;
      Self.Lf_Present_Ceiling := False;
      Self.Lf_Stg_Ceiling := No_Bare_Ada_Node;
      Self.Lf_Present_Floor := False;
      Self.Lf_Stg_Floor := No_Bare_Ada_Node;
      Self.Lf_Present_Truncation := False;
      Self.Lf_Stg_Truncation := No_Bare_Ada_Node;
      Self.Lf_Present_Machine := False;
      Self.Lf_Stg_Machine := No_Bare_Ada_Node;
      Self.Lf_Present_Machine_Rounding := False;
      Self.Lf_Stg_Machine_Rounding := No_Bare_Ada_Node;
      Self.Lf_Present_Fraction := False;
      Self.Lf_Stg_Fraction := No_Bare_Ada_Node;
      Self.Lf_Present_Exponent := False;
      Self.Lf_Stg_Exponent := No_Bare_Ada_Node;
      Self.Lf_Present_Copy_Sign := False;
      Self.Lf_Stg_Copy_Sign := No_Bare_Ada_Node;
      Self.Lf_Present_Remainder := False;
      Self.Lf_Stg_Remainder := No_Bare_Ada_Node;
      Self.Lf_Present_Adjacent := False;
      Self.Lf_Stg_Adjacent := No_Bare_Ada_Node;
      Self.Lf_Present_Scaling := False;
      Self.Lf_Stg_Scaling := No_Bare_Ada_Node;
      Self.Lf_Present_Compose := False;
      Self.Lf_Stg_Compose := No_Bare_Ada_Node;
      Self.Lf_Present_Mod := False;
      Self.Lf_Stg_Mod := No_Bare_Ada_Node;
      Self.Lf_Present_Value := False;
      Self.Lf_Stg_Value := No_Bare_Ada_Node;
      Self.Lf_Present_Wide_Value := False;
      Self.Lf_Stg_Wide_Value := No_Bare_Ada_Node;
      Self.Lf_Present_Wide_Wide_Value := False;
      Self.Lf_Stg_Wide_Wide_Value := No_Bare_Ada_Node;
      Self.Lf_Present_Fixed_Value := False;
      Self.Lf_Stg_Fixed_Value := No_Bare_Ada_Node;
      Self.Lf_Present_Integer_Value := False;
      Self.Lf_Stg_Integer_Value := No_Bare_Ada_Node;
      Self.Lf_Present_Pos := False;
      Self.Lf_Stg_Pos := No_Bare_Ada_Node;
      Self.Lf_Present_Val_Attr := False;
      Self.Lf_Stg_Val_Attr := No_Bare_Ada_Node;
      Self.Lf_Present_Enum_Rep := False;
      Self.Lf_Stg_Enum_Rep := No_Bare_Ada_Node;
      Self.Lf_Present_Enum_Val := False;
      Self.Lf_Stg_Enum_Val := No_Bare_Ada_Node;
      Self.Lf_Present_Read := False;
      Self.Lf_Stg_Read := No_Bare_Ada_Node;
      Self.Lf_Present_Write := False;
      Self.Lf_Stg_Write := No_Bare_Ada_Node;
      Self.Lf_Present_Input := False;
      Self.Lf_Stg_Input := No_Bare_Ada_Node;
      Self.Lf_Present_Output := False;
      Self.Lf_Stg_Output := No_Bare_Ada_Node;
      Self.Lf_Present_Image := False;
      Self.Lf_Stg_Image := No_Bare_Ada_Node;
      Self.Lf_Present_Wide_Image := False;
      Self.Lf_Stg_Wide_Image := No_Bare_Ada_Node;
      Self.Lf_Present_Wide_Wide_Image := False;
      Self.Lf_Stg_Wide_Wide_Image := No_Bare_Ada_Node;
      Self.Lf_Present_Put_Image := False;
      Self.Lf_Stg_Put_Image := No_Bare_Ada_Node;
      Self.Lf_Present_Asm_Input := False;
      Self.Lf_Stg_Asm_Input := No_Bare_Ada_Node;
      Self.Lf_Present_Asm_Output := False;
      Self.Lf_Stg_Asm_Output := No_Bare_Ada_Node;
      end Initialize_Fields_For_Type_Attributes_Repository;
--# property-start TypeAttributesRepository.base_type_expr /tmp/lal-23.0.0/ada/ast.py:5193
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Base_Type_Expr
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Synthetic_Type_Expr
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Synthetic_Type_Expr;
      Fld : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Let_Result : Bare_Synthetic_Type_Expr;
begin
   --# property-body-start
      if Self.Lf_Present_Base_Type_Expr then
         Property_Result := Self.Lf_Stg_Base_Type_Expr;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10803 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10802 '<New SyntheticTypeExpr at ast.py:5194>' New_Node /tmp/lal-23.0.0/ada/ast.py:5194
--# expr-start 10801 '<FieldAccess for base_type at ast.py:5194>' Fld /tmp/lal-23.0.0/ada/ast.py:5194
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Type_Attributes_Repository_Base_Type;
--# expr-done 10801
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld);
--# expr-done 10802
Let_Result := New_Node; 
--# end
--# expr-done 10803
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Base_Type_Expr := True;
      Self.Lf_Stg_Base_Type_Expr := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Base_Type_Expr;
--# end
--# property-start TypeAttributesRepository.universal_int_type_expr /tmp/lal-23.0.0/ada/ast.py:5197
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Universal_Int_Type_Expr
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Synthetic_Type_Expr
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Synthetic_Type_Expr;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Let_Result : Bare_Synthetic_Type_Expr;
begin
   --# property-body-start
      if Self.Lf_Present_Universal_Int_Type_Expr then
         Property_Result := Self.Lf_Stg_Universal_Int_Type_Expr;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10808 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10807 '<New SyntheticTypeExpr at ast.py:5198>' New_Node /tmp/lal-23.0.0/ada/ast.py:5198
--# expr-start 10806 '<FieldAccess for node at ast.py:5199>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5199
--# expr-start 10805 '<Cast to BaseTypeDecl at ast.py:5199>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5199
--# expr-start 10804 '<FieldAccess for universal_int_type at ast.py:5199>' Fld /tmp/lal-23.0.0/ada/ast.py:5199
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_int_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Int_Type (Node => Self);
--# end
--# expr-done 10804
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 10805
Fld_1 := Cast_Result.Node;
--# expr-done 10806
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_1);
--# expr-done 10807
Let_Result := New_Node; 
--# end
--# expr-done 10808
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Universal_Int_Type_Expr := True;
      Self.Lf_Stg_Universal_Int_Type_Expr := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Universal_Int_Type_Expr;
--# end
--# property-start TypeAttributesRepository.base_type_param /tmp/lal-23.0.0/ada/ast.py:5204
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Base_Type_Param
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Synthetic_Formal_Param_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Synthetic_Formal_Param_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Formal_Param_Decl;
Let_Result : Bare_Synthetic_Formal_Param_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Base_Type_Param then
         Property_Result := Self.Lf_Stg_Base_Type_Param;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10812 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10811 '<New SyntheticFormalParamDecl at ast.py:5205>' New_Node /tmp/lal-23.0.0/ada/ast.py:5205
--# expr-start 10809 '<FieldAccess for base_type_expr at ast.py:5207>' Fld /tmp/lal-23.0.0/ada/ast.py:5207
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10809
      Cast_Result := Fld;
--# expr-start 10810 '<Symbol Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value); 
--# expr-done 10810
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result);
      New_Node.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym;
--# expr-done 10811
Let_Result := New_Node; 
--# end
--# expr-done 10812
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Base_Type_Param := True;
      Self.Lf_Stg_Base_Type_Param := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Base_Type_Param;
--# end
--# property-start TypeAttributesRepository.universal_int_param /tmp/lal-23.0.0/ada/ast.py:5212
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Universal_Int_Param
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Synthetic_Formal_Param_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Synthetic_Formal_Param_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Formal_Param_Decl;
Let_Result : Bare_Synthetic_Formal_Param_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Universal_Int_Param then
         Property_Result := Self.Lf_Stg_Universal_Int_Param;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10816 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10815 '<New SyntheticFormalParamDecl at ast.py:5213>' New_Node /tmp/lal-23.0.0/ada/ast.py:5213
--# expr-start 10813 '<FieldAccess for universal_int_type_expr at ast.py:5215>' Fld /tmp/lal-23.0.0/ada/ast.py:5215
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_type_expr
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Type_Expr (Node => Self);
--# end
--# expr-done 10813
      Cast_Result := Fld;
--# expr-start 10814 '<Symbol Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value); 
--# expr-done 10814
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result);
      New_Node.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym;
--# expr-done 10815
Let_Result := New_Node; 
--# end
--# expr-done 10816
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Universal_Int_Param := True;
      Self.Lf_Stg_Universal_Int_Param := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Universal_Int_Param;
--# end
--# property-start TypeAttributesRepository.universal_real_param /tmp/lal-23.0.0/ada/ast.py:5220
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Universal_Real_Param
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Synthetic_Formal_Param_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Synthetic_Formal_Param_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Let_Result : Bare_Synthetic_Formal_Param_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Universal_Real_Param then
         Property_Result := Self.Lf_Stg_Universal_Real_Param;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10823 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10822 '<New SyntheticFormalParamDecl at ast.py:5221>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5221
--# expr-start 10820 '<New SyntheticTypeExpr at ast.py:5223>' New_Node /tmp/lal-23.0.0/ada/ast.py:5223
--# expr-start 10819 '<FieldAccess for node at ast.py:5224>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5224
--# expr-start 10818 '<Cast to BaseTypeDecl at ast.py:5224>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5224
--# expr-start 10817 '<FieldAccess for universal_real_type at ast.py:5224>' Fld /tmp/lal-23.0.0/ada/ast.py:5224
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.universal_real_type
Fld := Libadalang.Implementation.Ada_Node_P_Universal_Real_Type (Node => Self);
--# end
--# expr-done 10817
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 10818
Fld_1 := Cast_Result.Node;
--# expr-done 10819
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_1);
--# expr-done 10820
      Cast_Result_1 := New_Node;
--# expr-start 10821 '<Symbol Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value); 
--# expr-done 10821
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_1);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym;
--# expr-done 10822
Let_Result := New_Node_1; 
--# end
--# expr-done 10823
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Universal_Real_Param := True;
      Self.Lf_Stg_Universal_Real_Param := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Universal_Real_Param;
--# end
--# property-start TypeAttributesRepository.root_stream_param /tmp/lal-23.0.0/ada/ast.py:5230
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Root_Stream_Param
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Synthetic_Formal_Param_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Synthetic_Formal_Param_Decl;
      Sym : Symbol_Type;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Let_Result : Bare_Synthetic_Formal_Param_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Root_Stream_Param then
         Property_Result := Self.Lf_Stg_Root_Stream_Param;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 10830 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10829 '<New SyntheticFormalParamDecl at ast.py:5231>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5231
--# expr-start 10827 '<New SyntheticTypeExpr at ast.py:5233>' New_Node /tmp/lal-23.0.0/ada/ast.py:5233
--# expr-start 10826 '<FieldAccess for node at ast.py:5234>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5234
--# expr-start 10825 '<FieldAccess for anonymous_access_type at ast.py:5234>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5234
--# expr-start 10824 '<FieldAccess for root_stream_type at ast.py:5234>' Fld /tmp/lal-23.0.0/ada/ast.py:5234
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_stream_type
Fld := Libadalang.Implementation.Ada_Node_P_Root_Stream_Type (Node => Self);
--# end
--# expr-done 10824
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.anonymous_access_type
Fld_1 := Libadalang.Implementation.Base_Type_Decl_P_Anonymous_Access_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 10825
Fld_2 := Fld_1.Node;
--# expr-done 10826
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_2);
--# expr-done 10827
      Cast_Result := New_Node;
--# expr-start 10828 '<Symbol S at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_S); 
--# expr-done 10828
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym;
--# expr-done 10829
Let_Result := New_Node_1; 
--# end
--# expr-done 10830
      Property_Result := Let_Result;
   --# end
      Self.Lf_Present_Root_Stream_Param := True;
      Self.Lf_Stg_Root_Stream_Param := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Root_Stream_Param;
--# end
--# property-start TypeAttributesRepository.succ /tmp/lal-23.0.0/ada/ast.py:5239
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Succ
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Succ then
         Property_Result := Self.Lf_Stg_Succ;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10836 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10835 '<New SyntheticSubpDecl at ast.py:5240>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5240
--# expr-start 10834 '<New SyntheticUnarySpec at ast.py:5240>' New_Node /tmp/lal-23.0.0/ada/ast.py:5240
--# expr-start 10831 '<FieldAccess for base_type_expr at ast.py:5243>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5243
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10831
--# expr-start 10832 '<FieldAccess for base_type_param at ast.py:5242>' Fld /tmp/lal-23.0.0/ada/ast.py:5242
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10832
--# expr-start 10833 '<Symbol Succ at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Succ); 
--# expr-done 10833
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10834
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10835
Let_Result := New_Node_1; 
--# end
--# expr-done 10836
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Succ := True;
      Self.Lf_Stg_Succ := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Succ;
--# end
--# property-start TypeAttributesRepository.pred /tmp/lal-23.0.0/ada/ast.py:5247
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Pred
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Pred then
         Property_Result := Self.Lf_Stg_Pred;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10842 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10841 '<New SyntheticSubpDecl at ast.py:5248>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5248
--# expr-start 10840 '<New SyntheticUnarySpec at ast.py:5248>' New_Node /tmp/lal-23.0.0/ada/ast.py:5248
--# expr-start 10837 '<FieldAccess for base_type_expr at ast.py:5251>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5251
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10837
--# expr-start 10838 '<FieldAccess for base_type_param at ast.py:5250>' Fld /tmp/lal-23.0.0/ada/ast.py:5250
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10838
--# expr-start 10839 '<Symbol Pred at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pred); 
--# expr-done 10839
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10840
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10841
Let_Result := New_Node_1; 
--# end
--# expr-done 10842
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Pred := True;
      Self.Lf_Stg_Pred := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Pred;
--# end
--# property-start TypeAttributesRepository.min /tmp/lal-23.0.0/ada/ast.py:5255
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Min
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Min then
         Property_Result := Self.Lf_Stg_Min;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10849 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10848 '<New SyntheticSubpDecl at ast.py:5256>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5256
--# expr-start 10847 '<New SyntheticBinarySpec at ast.py:5256>' New_Node /tmp/lal-23.0.0/ada/ast.py:5256
--# expr-start 10843 '<FieldAccess for base_type_param at ast.py:5258>' Fld /tmp/lal-23.0.0/ada/ast.py:5258
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10843
--# expr-start 10844 '<FieldAccess for base_type_expr at ast.py:5260>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5260
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10844
      Cast_Result := Fld_2;
--# expr-start 10845 '<FieldAccess for base_type_param at ast.py:5259>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5259
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10845
--# expr-start 10846 '<Symbol Min at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Min); 
--# expr-done 10846
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10847
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10848
Let_Result := New_Node_1; 
--# end
--# expr-done 10849
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Min := True;
      Self.Lf_Stg_Min := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Min;
--# end
--# property-start TypeAttributesRepository.max /tmp/lal-23.0.0/ada/ast.py:5264
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Max
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Max then
         Property_Result := Self.Lf_Stg_Max;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10856 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10855 '<New SyntheticSubpDecl at ast.py:5265>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5265
--# expr-start 10854 '<New SyntheticBinarySpec at ast.py:5265>' New_Node /tmp/lal-23.0.0/ada/ast.py:5265
--# expr-start 10850 '<FieldAccess for base_type_param at ast.py:5267>' Fld /tmp/lal-23.0.0/ada/ast.py:5267
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10850
--# expr-start 10851 '<FieldAccess for base_type_expr at ast.py:5269>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5269
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10851
      Cast_Result := Fld_2;
--# expr-start 10852 '<FieldAccess for base_type_param at ast.py:5268>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5268
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10852
--# expr-start 10853 '<Symbol Max at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Max); 
--# expr-done 10853
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10854
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10855
Let_Result := New_Node_1; 
--# end
--# expr-done 10856
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Max := True;
      Self.Lf_Stg_Max := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Max;
--# end
--# property-start TypeAttributesRepository.rounding /tmp/lal-23.0.0/ada/ast.py:5273
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Rounding
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Rounding then
         Property_Result := Self.Lf_Stg_Rounding;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10862 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10861 '<New SyntheticSubpDecl at ast.py:5274>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5274
--# expr-start 10860 '<New SyntheticUnarySpec at ast.py:5274>' New_Node /tmp/lal-23.0.0/ada/ast.py:5274
--# expr-start 10857 '<FieldAccess for base_type_expr at ast.py:5277>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5277
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10857
--# expr-start 10858 '<FieldAccess for base_type_param at ast.py:5276>' Fld /tmp/lal-23.0.0/ada/ast.py:5276
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10858
--# expr-start 10859 '<Symbol Rounding at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rounding); 
--# expr-done 10859
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10860
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10861
Let_Result := New_Node_1; 
--# end
--# expr-done 10862
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Rounding := True;
      Self.Lf_Stg_Rounding := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Rounding;
--# end
--# property-start TypeAttributesRepository.ceiling /tmp/lal-23.0.0/ada/ast.py:5281
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Ceiling
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Ceiling then
         Property_Result := Self.Lf_Stg_Ceiling;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10868 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10867 '<New SyntheticSubpDecl at ast.py:5282>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5282
--# expr-start 10866 '<New SyntheticUnarySpec at ast.py:5282>' New_Node /tmp/lal-23.0.0/ada/ast.py:5282
--# expr-start 10863 '<FieldAccess for base_type_expr at ast.py:5285>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5285
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10863
--# expr-start 10864 '<FieldAccess for base_type_param at ast.py:5284>' Fld /tmp/lal-23.0.0/ada/ast.py:5284
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10864
--# expr-start 10865 '<Symbol Ceiling at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Ceiling); 
--# expr-done 10865
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10866
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10867
Let_Result := New_Node_1; 
--# end
--# expr-done 10868
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Ceiling := True;
      Self.Lf_Stg_Ceiling := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Ceiling;
--# end
--# property-start TypeAttributesRepository.floor /tmp/lal-23.0.0/ada/ast.py:5289
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Floor
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Floor then
         Property_Result := Self.Lf_Stg_Floor;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10874 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10873 '<New SyntheticSubpDecl at ast.py:5290>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5290
--# expr-start 10872 '<New SyntheticUnarySpec at ast.py:5290>' New_Node /tmp/lal-23.0.0/ada/ast.py:5290
--# expr-start 10869 '<FieldAccess for base_type_expr at ast.py:5293>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5293
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10869
--# expr-start 10870 '<FieldAccess for base_type_param at ast.py:5292>' Fld /tmp/lal-23.0.0/ada/ast.py:5292
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10870
--# expr-start 10871 '<Symbol Floor at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Floor); 
--# expr-done 10871
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10872
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10873
Let_Result := New_Node_1; 
--# end
--# expr-done 10874
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Floor := True;
      Self.Lf_Stg_Floor := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Floor;
--# end
--# property-start TypeAttributesRepository.truncation /tmp/lal-23.0.0/ada/ast.py:5297
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Truncation
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Truncation then
         Property_Result := Self.Lf_Stg_Truncation;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10880 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10879 '<New SyntheticSubpDecl at ast.py:5298>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5298
--# expr-start 10878 '<New SyntheticUnarySpec at ast.py:5298>' New_Node /tmp/lal-23.0.0/ada/ast.py:5298
--# expr-start 10875 '<FieldAccess for base_type_expr at ast.py:5301>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5301
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10875
--# expr-start 10876 '<FieldAccess for base_type_param at ast.py:5300>' Fld /tmp/lal-23.0.0/ada/ast.py:5300
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10876
--# expr-start 10877 '<Symbol Truncation at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Truncation); 
--# expr-done 10877
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10878
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10879
Let_Result := New_Node_1; 
--# end
--# expr-done 10880
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Truncation := True;
      Self.Lf_Stg_Truncation := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Truncation;
--# end
--# property-start TypeAttributesRepository.machine /tmp/lal-23.0.0/ada/ast.py:5305
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Machine
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Machine then
         Property_Result := Self.Lf_Stg_Machine;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10886 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10885 '<New SyntheticSubpDecl at ast.py:5306>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5306
--# expr-start 10884 '<New SyntheticUnarySpec at ast.py:5306>' New_Node /tmp/lal-23.0.0/ada/ast.py:5306
--# expr-start 10881 '<FieldAccess for base_type_expr at ast.py:5309>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5309
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10881
--# expr-start 10882 '<FieldAccess for base_type_param at ast.py:5308>' Fld /tmp/lal-23.0.0/ada/ast.py:5308
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10882
--# expr-start 10883 '<Symbol Machine at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine); 
--# expr-done 10883
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10884
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10885
Let_Result := New_Node_1; 
--# end
--# expr-done 10886
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Machine := True;
      Self.Lf_Stg_Machine := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Machine;
--# end
--# property-start TypeAttributesRepository.machine_rounding /tmp/lal-23.0.0/ada/ast.py:5313
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Machine_Rounding
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Machine_Rounding then
         Property_Result := Self.Lf_Stg_Machine_Rounding;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10892 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10891 '<New SyntheticSubpDecl at ast.py:5314>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5314
--# expr-start 10890 '<New SyntheticUnarySpec at ast.py:5314>' New_Node /tmp/lal-23.0.0/ada/ast.py:5314
--# expr-start 10887 '<FieldAccess for base_type_expr at ast.py:5317>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5317
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10887
--# expr-start 10888 '<FieldAccess for base_type_param at ast.py:5316>' Fld /tmp/lal-23.0.0/ada/ast.py:5316
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10888
--# expr-start 10889 '<Symbol Machine_Rounding at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Rounding); 
--# expr-done 10889
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10890
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10891
Let_Result := New_Node_1; 
--# end
--# expr-done 10892
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Machine_Rounding := True;
      Self.Lf_Stg_Machine_Rounding := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Machine_Rounding;
--# end
--# property-start TypeAttributesRepository.fraction /tmp/lal-23.0.0/ada/ast.py:5321
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Fraction
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Fraction then
         Property_Result := Self.Lf_Stg_Fraction;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10898 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10897 '<New SyntheticSubpDecl at ast.py:5322>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5322
--# expr-start 10896 '<New SyntheticUnarySpec at ast.py:5322>' New_Node /tmp/lal-23.0.0/ada/ast.py:5322
--# expr-start 10893 '<FieldAccess for base_type_expr at ast.py:5325>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5325
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10893
--# expr-start 10894 '<FieldAccess for base_type_param at ast.py:5324>' Fld /tmp/lal-23.0.0/ada/ast.py:5324
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10894
--# expr-start 10895 '<Symbol Fraction at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fraction); 
--# expr-done 10895
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10896
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10897
Let_Result := New_Node_1; 
--# end
--# expr-done 10898
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Fraction := True;
      Self.Lf_Stg_Fraction := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Fraction;
--# end
--# property-start TypeAttributesRepository.exponent /tmp/lal-23.0.0/ada/ast.py:5329
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Exponent
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Exponent then
         Property_Result := Self.Lf_Stg_Exponent;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10904 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10903 '<New SyntheticSubpDecl at ast.py:5330>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5330
--# expr-start 10902 '<New SyntheticUnarySpec at ast.py:5330>' New_Node /tmp/lal-23.0.0/ada/ast.py:5330
--# expr-start 10899 '<FieldAccess for universal_int_type_expr at ast.py:5333>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5333
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Type_Expr (Node => Self);
--# end
--# expr-done 10899
--# expr-start 10900 '<FieldAccess for base_type_param at ast.py:5332>' Fld /tmp/lal-23.0.0/ada/ast.py:5332
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10900
--# expr-start 10901 '<Symbol Exponent at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Exponent); 
--# expr-done 10901
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10902
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10903
Let_Result := New_Node_1; 
--# end
--# expr-done 10904
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Exponent := True;
      Self.Lf_Stg_Exponent := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Exponent;
--# end
--# property-start TypeAttributesRepository.copy_sign /tmp/lal-23.0.0/ada/ast.py:5337
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Copy_Sign
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Copy_Sign then
         Property_Result := Self.Lf_Stg_Copy_Sign;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10911 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10910 '<New SyntheticSubpDecl at ast.py:5338>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5338
--# expr-start 10909 '<New SyntheticBinarySpec at ast.py:5338>' New_Node /tmp/lal-23.0.0/ada/ast.py:5338
--# expr-start 10905 '<FieldAccess for base_type_param at ast.py:5340>' Fld /tmp/lal-23.0.0/ada/ast.py:5340
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10905
--# expr-start 10906 '<FieldAccess for base_type_expr at ast.py:5342>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5342
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10906
      Cast_Result := Fld_2;
--# expr-start 10907 '<FieldAccess for base_type_param at ast.py:5341>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5341
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10907
--# expr-start 10908 '<Symbol Copy_Sign at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Copy_Sign); 
--# expr-done 10908
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10909
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10910
Let_Result := New_Node_1; 
--# end
--# expr-done 10911
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Copy_Sign := True;
      Self.Lf_Stg_Copy_Sign := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Copy_Sign;
--# end
--# property-start TypeAttributesRepository.remainder /tmp/lal-23.0.0/ada/ast.py:5346
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Remainder
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Remainder then
         Property_Result := Self.Lf_Stg_Remainder;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10918 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10917 '<New SyntheticSubpDecl at ast.py:5347>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5347
--# expr-start 10916 '<New SyntheticBinarySpec at ast.py:5347>' New_Node /tmp/lal-23.0.0/ada/ast.py:5347
--# expr-start 10912 '<FieldAccess for base_type_param at ast.py:5349>' Fld /tmp/lal-23.0.0/ada/ast.py:5349
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10912
--# expr-start 10913 '<FieldAccess for base_type_expr at ast.py:5351>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5351
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10913
      Cast_Result := Fld_2;
--# expr-start 10914 '<FieldAccess for base_type_param at ast.py:5350>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5350
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10914
--# expr-start 10915 '<Symbol Remainder at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Remainder); 
--# expr-done 10915
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10916
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10917
Let_Result := New_Node_1; 
--# end
--# expr-done 10918
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Remainder := True;
      Self.Lf_Stg_Remainder := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Remainder;
--# end
--# property-start TypeAttributesRepository.adjacent /tmp/lal-23.0.0/ada/ast.py:5355
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Adjacent
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Adjacent then
         Property_Result := Self.Lf_Stg_Adjacent;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10925 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10924 '<New SyntheticSubpDecl at ast.py:5356>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5356
--# expr-start 10923 '<New SyntheticBinarySpec at ast.py:5356>' New_Node /tmp/lal-23.0.0/ada/ast.py:5356
--# expr-start 10919 '<FieldAccess for base_type_param at ast.py:5358>' Fld /tmp/lal-23.0.0/ada/ast.py:5358
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10919
--# expr-start 10920 '<FieldAccess for base_type_expr at ast.py:5360>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5360
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10920
      Cast_Result := Fld_2;
--# expr-start 10921 '<FieldAccess for base_type_param at ast.py:5359>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5359
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10921
--# expr-start 10922 '<Symbol Adjacent at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Adjacent); 
--# expr-done 10922
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10923
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10924
Let_Result := New_Node_1; 
--# end
--# expr-done 10925
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Adjacent := True;
      Self.Lf_Stg_Adjacent := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Adjacent;
--# end
--# property-start TypeAttributesRepository.scaling /tmp/lal-23.0.0/ada/ast.py:5364
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Scaling
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Scaling then
         Property_Result := Self.Lf_Stg_Scaling;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10932 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10931 '<New SyntheticSubpDecl at ast.py:5365>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5365
--# expr-start 10930 '<New SyntheticBinarySpec at ast.py:5365>' New_Node /tmp/lal-23.0.0/ada/ast.py:5365
--# expr-start 10926 '<FieldAccess for base_type_param at ast.py:5367>' Fld /tmp/lal-23.0.0/ada/ast.py:5367
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10926
--# expr-start 10927 '<FieldAccess for base_type_expr at ast.py:5369>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5369
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10927
      Cast_Result := Fld_2;
--# expr-start 10928 '<FieldAccess for universal_int_param at ast.py:5368>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5368
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Param (Node => Self);
--# end
--# expr-done 10928
--# expr-start 10929 '<Symbol Scaling at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Scaling); 
--# expr-done 10929
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10930
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10931
Let_Result := New_Node_1; 
--# end
--# expr-done 10932
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Scaling := True;
      Self.Lf_Stg_Scaling := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Scaling;
--# end
--# property-start TypeAttributesRepository.compose /tmp/lal-23.0.0/ada/ast.py:5373
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Compose
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
Cast_Result : Bare_Type_Expr;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Compose then
         Property_Result := Self.Lf_Stg_Compose;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10939 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10938 '<New SyntheticSubpDecl at ast.py:5374>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5374
--# expr-start 10937 '<New SyntheticBinarySpec at ast.py:5374>' New_Node /tmp/lal-23.0.0/ada/ast.py:5374
--# expr-start 10933 '<FieldAccess for base_type_param at ast.py:5376>' Fld /tmp/lal-23.0.0/ada/ast.py:5376
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10933
--# expr-start 10934 '<FieldAccess for base_type_expr at ast.py:5378>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5378
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10934
      Cast_Result := Fld_2;
--# expr-start 10935 '<FieldAccess for universal_int_param at ast.py:5377>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5377
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Param (Node => Self);
--# end
--# expr-done 10935
--# expr-start 10936 '<Symbol Compose at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Compose); 
--# expr-done 10936
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10937
      Cast_Result_1 := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 10938
Let_Result := New_Node_1; 
--# end
--# expr-done 10939
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Compose := True;
      Self.Lf_Stg_Compose := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Compose;
--# end
--# property-start TypeAttributesRepository.mod /tmp/lal-23.0.0/ada/ast.py:5382
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Mod
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Mod then
         Property_Result := Self.Lf_Stg_Mod;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10945 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10944 '<New SyntheticSubpDecl at ast.py:5383>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5383
--# expr-start 10943 '<New SyntheticUnarySpec at ast.py:5383>' New_Node /tmp/lal-23.0.0/ada/ast.py:5383
--# expr-start 10940 '<FieldAccess for base_type_expr at ast.py:5386>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5386
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10940
--# expr-start 10941 '<FieldAccess for universal_int_param at ast.py:5385>' Fld /tmp/lal-23.0.0/ada/ast.py:5385
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Param (Node => Self);
--# end
--# expr-done 10941
--# expr-start 10942 '<Symbol Mod at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod_142); 
--# expr-done 10942
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10943
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10944
Let_Result := New_Node_1; 
--# end
--# expr-done 10945
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Mod := True;
      Self.Lf_Stg_Mod := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Mod;
--# end
--# property-start TypeAttributesRepository.value /tmp/lal-23.0.0/ada/ast.py:5390
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Value
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Sym_2 : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
New_Node_2 : Bare_Synthetic_Unary_Spec;
Cast_Result_2 : Bare_Base_Subp_Spec;
New_Node_3 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_3 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Value then
         Property_Result := Self.Lf_Stg_Value;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10957 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10956 '<New SyntheticSubpDecl at ast.py:5391>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:5391
--# expr-start 10955 '<New SyntheticUnarySpec at ast.py:5391>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5391
--# expr-start 10946 '<FieldAccess for base_type_expr at ast.py:5400>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5400
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10946
--# expr-start 10953 '<New SyntheticFormalParamDecl at ast.py:5393>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5393
--# expr-start 10951 '<New SyntheticTypeExpr at ast.py:5395>' New_Node /tmp/lal-23.0.0/ada/ast.py:5395
--# expr-start 10950 '<FieldAccess for node at ast.py:5397>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5397
--# expr-start 10949 '<Cast to BaseTypeDecl at ast.py:5397>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5397
--# expr-start 10948 '<FieldAccess for std_entity at ast.py:5396>' Fld /tmp/lal-23.0.0/ada/ast.py:5396
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10947 '<Symbol String at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 10947
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_2);
--# end
--# expr-done 10948
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 10949
Fld_1 := Cast_Result.Node;
--# expr-done 10950
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_1);
--# expr-done 10951
      Cast_Result_1 := New_Node;
--# expr-start 10952 '<Symbol Val at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val); 
--# expr-done 10952
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_1);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_1;
--# expr-done 10953
--# expr-start 10954 '<Symbol Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Value); 
--# expr-done 10954
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_2,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_2, Synthetic_Unary_Spec_F_Right_Param => New_Node_1);
      New_Node_2.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10955
      Cast_Result_2 := New_Node_2;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_3,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_2);
--# expr-done 10956
Let_Result := New_Node_3; 
--# end
--# expr-done 10957
      Cast_Result_3 := Let_Result;
      Property_Result := Cast_Result_3;
   --# end
      Self.Lf_Present_Value := True;
      Self.Lf_Stg_Value := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Value;
--# end
--# property-start TypeAttributesRepository.wide_value /tmp/lal-23.0.0/ada/ast.py:5404
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Wide_Value
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Sym_2 : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
New_Node_2 : Bare_Synthetic_Unary_Spec;
Cast_Result_2 : Bare_Base_Subp_Spec;
New_Node_3 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_3 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Wide_Value then
         Property_Result := Self.Lf_Stg_Wide_Value;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10969 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10968 '<New SyntheticSubpDecl at ast.py:5405>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:5405
--# expr-start 10967 '<New SyntheticUnarySpec at ast.py:5405>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5405
--# expr-start 10958 '<FieldAccess for base_type_expr at ast.py:5414>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5414
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10958
--# expr-start 10965 '<New SyntheticFormalParamDecl at ast.py:5407>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5407
--# expr-start 10963 '<New SyntheticTypeExpr at ast.py:5409>' New_Node /tmp/lal-23.0.0/ada/ast.py:5409
--# expr-start 10962 '<FieldAccess for node at ast.py:5411>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5411
--# expr-start 10961 '<Cast to BaseTypeDecl at ast.py:5411>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5411
--# expr-start 10960 '<FieldAccess for std_entity at ast.py:5410>' Fld /tmp/lal-23.0.0/ada/ast.py:5410
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10959 '<Symbol Wide_String at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_String); 
--# expr-done 10959
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_2);
--# end
--# expr-done 10960
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 10961
Fld_1 := Cast_Result.Node;
--# expr-done 10962
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_1);
--# expr-done 10963
      Cast_Result_1 := New_Node;
--# expr-start 10964 '<Symbol Val at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val); 
--# expr-done 10964
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_1);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_1;
--# expr-done 10965
--# expr-start 10966 '<Symbol Wide_Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Value); 
--# expr-done 10966
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_2,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_2, Synthetic_Unary_Spec_F_Right_Param => New_Node_1);
      New_Node_2.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10967
      Cast_Result_2 := New_Node_2;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_3,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_2);
--# expr-done 10968
Let_Result := New_Node_3; 
--# end
--# expr-done 10969
      Cast_Result_3 := Let_Result;
      Property_Result := Cast_Result_3;
   --# end
      Self.Lf_Present_Wide_Value := True;
      Self.Lf_Stg_Wide_Value := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Wide_Value;
--# end
--# property-start TypeAttributesRepository.wide_wide_value /tmp/lal-23.0.0/ada/ast.py:5418
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Wide_Wide_Value
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Sym_2 : Symbol_Type;
Fld : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_1 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_2 : Bare_Synthetic_Type_Expr;
New_Node_2 : Bare_Synthetic_Unary_Spec;
Cast_Result_2 : Bare_Base_Subp_Spec;
New_Node_3 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_3 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Wide_Wide_Value then
         Property_Result := Self.Lf_Stg_Wide_Wide_Value;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10981 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10980 '<New SyntheticSubpDecl at ast.py:5419>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:5419
--# expr-start 10979 '<New SyntheticUnarySpec at ast.py:5419>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5419
--# expr-start 10970 '<FieldAccess for base_type_expr at ast.py:5428>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5428
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_2 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10970
--# expr-start 10977 '<New SyntheticFormalParamDecl at ast.py:5421>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5421
--# expr-start 10975 '<New SyntheticTypeExpr at ast.py:5423>' New_Node /tmp/lal-23.0.0/ada/ast.py:5423
--# expr-start 10974 '<FieldAccess for node at ast.py:5425>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5425
--# expr-start 10973 '<Cast to BaseTypeDecl at ast.py:5425>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5425
--# expr-start 10972 '<FieldAccess for std_entity at ast.py:5424>' Fld /tmp/lal-23.0.0/ada/ast.py:5424
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 10971 '<Symbol Wide_Wide_String at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_String); 
--# expr-done 10971
--# property-call-start AdaNode.std_entity
Fld := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_2);
--# end
--# expr-done 10972
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 10973
Fld_1 := Cast_Result.Node;
--# expr-done 10974
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_1);
--# expr-done 10975
      Cast_Result_1 := New_Node;
--# expr-start 10976 '<Symbol Val at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val); 
--# expr-done 10976
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_1);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_1;
--# expr-done 10977
--# expr-start 10978 '<Symbol Wide_Wide_Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Value); 
--# expr-done 10978
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_2,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_2, Synthetic_Unary_Spec_F_Right_Param => New_Node_1);
      New_Node_2.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10979
      Cast_Result_2 := New_Node_2;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_3,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_2);
--# expr-done 10980
Let_Result := New_Node_3; 
--# end
--# expr-done 10981
      Cast_Result_3 := Let_Result;
      Property_Result := Cast_Result_3;
   --# end
      Self.Lf_Present_Wide_Wide_Value := True;
      Self.Lf_Stg_Wide_Wide_Value := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Wide_Wide_Value;
--# end
--# property-start TypeAttributesRepository.fixed_value /tmp/lal-23.0.0/ada/ast.py:5432
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Fixed_Value
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Fixed_Value then
         Property_Result := Self.Lf_Stg_Fixed_Value;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10987 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10986 '<New SyntheticSubpDecl at ast.py:5433>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5433
--# expr-start 10985 '<New SyntheticUnarySpec at ast.py:5433>' New_Node /tmp/lal-23.0.0/ada/ast.py:5433
--# expr-start 10982 '<FieldAccess for base_type_expr at ast.py:5436>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5436
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10982
--# expr-start 10983 '<FieldAccess for universal_int_param at ast.py:5435>' Fld /tmp/lal-23.0.0/ada/ast.py:5435
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Param (Node => Self);
--# end
--# expr-done 10983
--# expr-start 10984 '<Symbol Fixed_Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Fixed_Value); 
--# expr-done 10984
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10985
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10986
Let_Result := New_Node_1; 
--# end
--# expr-done 10987
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Fixed_Value := True;
      Self.Lf_Stg_Fixed_Value := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Fixed_Value;
--# end
--# property-start TypeAttributesRepository.integer_value /tmp/lal-23.0.0/ada/ast.py:5440
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Integer_Value
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Integer_Value then
         Property_Result := Self.Lf_Stg_Integer_Value;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10993 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10992 '<New SyntheticSubpDecl at ast.py:5441>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5441
--# expr-start 10991 '<New SyntheticUnarySpec at ast.py:5441>' New_Node /tmp/lal-23.0.0/ada/ast.py:5441
--# expr-start 10988 '<FieldAccess for base_type_expr at ast.py:5444>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5444
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 10988
--# expr-start 10989 '<FieldAccess for universal_real_param at ast.py:5443>' Fld /tmp/lal-23.0.0/ada/ast.py:5443
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_real_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Real_Param (Node => Self);
--# end
--# expr-done 10989
--# expr-start 10990 '<Symbol Integer_Value at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Integer_Value); 
--# expr-done 10990
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10991
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10992
Let_Result := New_Node_1; 
--# end
--# expr-done 10993
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Integer_Value := True;
      Self.Lf_Stg_Integer_Value := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Integer_Value;
--# end
--# property-start TypeAttributesRepository.pos /tmp/lal-23.0.0/ada/ast.py:5448
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Pos
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Pos then
         Property_Result := Self.Lf_Stg_Pos;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 10999 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 10998 '<New SyntheticSubpDecl at ast.py:5449>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5449
--# expr-start 10997 '<New SyntheticUnarySpec at ast.py:5449>' New_Node /tmp/lal-23.0.0/ada/ast.py:5449
--# expr-start 10994 '<FieldAccess for universal_int_type_expr at ast.py:5452>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5452
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Type_Expr (Node => Self);
--# end
--# expr-done 10994
--# expr-start 10995 '<FieldAccess for base_type_param at ast.py:5451>' Fld /tmp/lal-23.0.0/ada/ast.py:5451
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 10995
--# expr-start 10996 '<Symbol Pos at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Pos); 
--# expr-done 10996
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 10997
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 10998
Let_Result := New_Node_1; 
--# end
--# expr-done 10999
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Pos := True;
      Self.Lf_Stg_Pos := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Pos;
--# end
--# property-start TypeAttributesRepository.val_attr /tmp/lal-23.0.0/ada/ast.py:5457
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Val_Attr
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Val_Attr then
         Property_Result := Self.Lf_Stg_Val_Attr;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11005 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11004 '<New SyntheticSubpDecl at ast.py:5458>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5458
--# expr-start 11003 '<New SyntheticUnarySpec at ast.py:5458>' New_Node /tmp/lal-23.0.0/ada/ast.py:5458
--# expr-start 11000 '<FieldAccess for base_type_expr at ast.py:5461>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5461
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 11000
--# expr-start 11001 '<FieldAccess for universal_int_param at ast.py:5460>' Fld /tmp/lal-23.0.0/ada/ast.py:5460
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Param (Node => Self);
--# end
--# expr-done 11001
--# expr-start 11002 '<Symbol Val at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Val); 
--# expr-done 11002
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11003
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11004
Let_Result := New_Node_1; 
--# end
--# expr-done 11005
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Val_Attr := True;
      Self.Lf_Stg_Val_Attr := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Val_Attr;
--# end
--# property-start TypeAttributesRepository.enum_rep /tmp/lal-23.0.0/ada/ast.py:5465
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Enum_Rep
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Enum_Rep then
         Property_Result := Self.Lf_Stg_Enum_Rep;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11011 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11010 '<New SyntheticSubpDecl at ast.py:5466>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5466
--# expr-start 11009 '<New SyntheticUnarySpec at ast.py:5466>' New_Node /tmp/lal-23.0.0/ada/ast.py:5466
--# expr-start 11006 '<FieldAccess for universal_int_type_expr at ast.py:5469>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5469
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Type_Expr (Node => Self);
--# end
--# expr-done 11006
--# expr-start 11007 '<FieldAccess for base_type_param at ast.py:5468>' Fld /tmp/lal-23.0.0/ada/ast.py:5468
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11007
--# expr-start 11008 '<Symbol Enum_Rep at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Enum_Rep); 
--# expr-done 11008
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11009
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11010
Let_Result := New_Node_1; 
--# end
--# expr-done 11011
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Enum_Rep := True;
      Self.Lf_Stg_Enum_Rep := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Enum_Rep;
--# end
--# property-start TypeAttributesRepository.enum_val /tmp/lal-23.0.0/ada/ast.py:5473
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Enum_Val
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Enum_Val then
         Property_Result := Self.Lf_Stg_Enum_Val;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11017 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11016 '<New SyntheticSubpDecl at ast.py:5474>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5474
--# expr-start 11015 '<New SyntheticUnarySpec at ast.py:5474>' New_Node /tmp/lal-23.0.0/ada/ast.py:5474
--# expr-start 11012 '<FieldAccess for base_type_expr at ast.py:5477>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5477
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 11012
--# expr-start 11013 '<FieldAccess for universal_int_param at ast.py:5476>' Fld /tmp/lal-23.0.0/ada/ast.py:5476
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.universal_int_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Universal_Int_Param (Node => Self);
--# end
--# expr-done 11013
--# expr-start 11014 '<Symbol Enum_Val at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Enum_Val); 
--# expr-done 11014
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11015
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11016
Let_Result := New_Node_1; 
--# end
--# expr-done 11017
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Enum_Val := True;
      Self.Lf_Stg_Enum_Val := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Enum_Val;
--# end
--# property-start TypeAttributesRepository.read /tmp/lal-23.0.0/ada/ast.py:5481
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Read
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Read then
         Property_Result := Self.Lf_Stg_Read;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11023 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11022 '<New SyntheticSubpDecl at ast.py:5482>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5482
--# expr-start 11021 '<New SyntheticBinarySpec at ast.py:5482>' New_Node /tmp/lal-23.0.0/ada/ast.py:5482
--# expr-start 11018 '<FieldAccess for root_stream_param at ast.py:5484>' Fld /tmp/lal-23.0.0/ada/ast.py:5484
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.root_stream_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Root_Stream_Param (Node => Self);
--# end
--# expr-done 11018
--# expr-start 11019 '<FieldAccess for base_type_param at ast.py:5485>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5485
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11019
--# expr-start 11020 '<Symbol Read at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Read); 
--# expr-done 11020
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => No_Bare_Ada_Node, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11021
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11022
Let_Result := New_Node_1; 
--# end
--# expr-done 11023
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Read := True;
      Self.Lf_Stg_Read := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Read;
--# end
--# property-start TypeAttributesRepository.write /tmp/lal-23.0.0/ada/ast.py:5490
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Write
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Write then
         Property_Result := Self.Lf_Stg_Write;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11029 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11028 '<New SyntheticSubpDecl at ast.py:5491>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5491
--# expr-start 11027 '<New SyntheticBinarySpec at ast.py:5491>' New_Node /tmp/lal-23.0.0/ada/ast.py:5491
--# expr-start 11024 '<FieldAccess for root_stream_param at ast.py:5493>' Fld /tmp/lal-23.0.0/ada/ast.py:5493
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.root_stream_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Root_Stream_Param (Node => Self);
--# end
--# expr-done 11024
--# expr-start 11025 '<FieldAccess for base_type_param at ast.py:5494>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5494
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11025
--# expr-start 11026 '<Symbol Write at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Write); 
--# expr-done 11026
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => No_Bare_Ada_Node, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11027
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11028
Let_Result := New_Node_1; 
--# end
--# expr-done 11029
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Write := True;
      Self.Lf_Stg_Write := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Write;
--# end
--# property-start TypeAttributesRepository.input /tmp/lal-23.0.0/ada/ast.py:5499
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Input
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Type_Expr;
New_Node : Bare_Synthetic_Unary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Input then
         Property_Result := Self.Lf_Stg_Input;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11035 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11034 '<New SyntheticSubpDecl at ast.py:5500>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5500
--# expr-start 11033 '<New SyntheticUnarySpec at ast.py:5500>' New_Node /tmp/lal-23.0.0/ada/ast.py:5500
--# expr-start 11030 '<FieldAccess for base_type_expr at ast.py:5503>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5503
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_expr
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Expr (Node => Self);
--# end
--# expr-done 11030
--# expr-start 11031 '<FieldAccess for root_stream_param at ast.py:5502>' Fld /tmp/lal-23.0.0/ada/ast.py:5502
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.root_stream_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Root_Stream_Param (Node => Self);
--# end
--# expr-done 11031
--# expr-start 11032 '<Symbol Input at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Input); 
--# expr-done 11032
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node,
      Synthetic_Unary_Spec_F_Return_Type_Expr => Fld_1, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11033
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11034
Let_Result := New_Node_1; 
--# end
--# expr-done 11035
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Input := True;
      Self.Lf_Stg_Input := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Input;
--# end
--# property-start TypeAttributesRepository.output /tmp/lal-23.0.0/ada/ast.py:5507
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Output
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Fld_1 : Bare_Synthetic_Formal_Param_Decl;
New_Node : Bare_Synthetic_Binary_Spec;
Cast_Result : Bare_Base_Subp_Spec;
New_Node_1 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_1 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Output then
         Property_Result := Self.Lf_Stg_Output;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11041 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11040 '<New SyntheticSubpDecl at ast.py:5508>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5508
--# expr-start 11039 '<New SyntheticBinarySpec at ast.py:5508>' New_Node /tmp/lal-23.0.0/ada/ast.py:5508
--# expr-start 11036 '<FieldAccess for root_stream_param at ast.py:5510>' Fld /tmp/lal-23.0.0/ada/ast.py:5510
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.root_stream_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Root_Stream_Param (Node => Self);
--# end
--# expr-done 11036
--# expr-start 11037 '<FieldAccess for base_type_param at ast.py:5511>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5511
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_1 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11037
--# expr-start 11038 '<Symbol Output at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Output); 
--# expr-done 11038
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node,
      Synthetic_Binary_Spec_F_Left_Param => Fld, Synthetic_Binary_Spec_F_Return_Type_Expr => No_Bare_Ada_Node, Synthetic_Binary_Spec_F_Right_Param => Fld_1);
      New_Node.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11039
      Cast_Result := New_Node;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_1,
      Synthetic_Subp_Decl_F_Spec => Cast_Result);
--# expr-done 11040
Let_Result := New_Node_1; 
--# end
--# expr-done 11041
      Cast_Result_1 := Let_Result;
      Property_Result := Cast_Result_1;
   --# end
      Self.Lf_Present_Output := True;
      Self.Lf_Stg_Output := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Output;
--# end
--# property-start TypeAttributesRepository.image /tmp/lal-23.0.0/ada/ast.py:5516
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Image
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Sym_1 : Symbol_Type;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
New_Node_1 : Bare_Synthetic_Unary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_2 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Image then
         Property_Result := Self.Lf_Stg_Image;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11051 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11050 '<New SyntheticSubpDecl at ast.py:5517>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5517
--# expr-start 11049 '<New SyntheticUnarySpec at ast.py:5517>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5517
--# expr-start 11046 '<New SyntheticTypeExpr at ast.py:5520>' New_Node /tmp/lal-23.0.0/ada/ast.py:5520
--# expr-start 11045 '<FieldAccess for node at ast.py:5521>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5521
--# expr-start 11044 '<Cast to BaseTypeDecl at ast.py:5521>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5521
--# expr-start 11043 '<FieldAccess for std_entity at ast.py:5521>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5521
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11042 '<Symbol String at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 11042
--# property-call-start AdaNode.std_entity
Fld_1 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_1);
--# end
--# expr-done 11043
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 11044
Fld_2 := Cast_Result.Node;
--# expr-done 11045
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_2);
--# expr-done 11046
--# expr-start 11047 '<FieldAccess for base_type_param at ast.py:5519>' Fld /tmp/lal-23.0.0/ada/ast.py:5519
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11047
--# expr-start 11048 '<Symbol Image at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Image); 
--# expr-done 11048
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_1,
      Synthetic_Unary_Spec_F_Return_Type_Expr => New_Node, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node_1.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11049
      Cast_Result_1 := New_Node_1;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_2,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 11050
Let_Result := New_Node_2; 
--# end
--# expr-done 11051
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Image := True;
      Self.Lf_Stg_Image := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Image;
--# end
--# property-start TypeAttributesRepository.wide_image /tmp/lal-23.0.0/ada/ast.py:5526
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Wide_Image
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Sym_1 : Symbol_Type;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
New_Node_1 : Bare_Synthetic_Unary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_2 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Wide_Image then
         Property_Result := Self.Lf_Stg_Wide_Image;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11061 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11060 '<New SyntheticSubpDecl at ast.py:5527>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5527
--# expr-start 11059 '<New SyntheticUnarySpec at ast.py:5527>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5527
--# expr-start 11056 '<New SyntheticTypeExpr at ast.py:5530>' New_Node /tmp/lal-23.0.0/ada/ast.py:5530
--# expr-start 11055 '<FieldAccess for node at ast.py:5532>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5532
--# expr-start 11054 '<Cast to BaseTypeDecl at ast.py:5532>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5532
--# expr-start 11053 '<FieldAccess for std_entity at ast.py:5531>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5531
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11052 '<Symbol Wide_String at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_String); 
--# expr-done 11052
--# property-call-start AdaNode.std_entity
Fld_1 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_1);
--# end
--# expr-done 11053
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 11054
Fld_2 := Cast_Result.Node;
--# expr-done 11055
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_2);
--# expr-done 11056
--# expr-start 11057 '<FieldAccess for base_type_param at ast.py:5529>' Fld /tmp/lal-23.0.0/ada/ast.py:5529
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11057
--# expr-start 11058 '<Symbol Wide_Image at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Image); 
--# expr-done 11058
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_1,
      Synthetic_Unary_Spec_F_Return_Type_Expr => New_Node, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node_1.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11059
      Cast_Result_1 := New_Node_1;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_2,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 11060
Let_Result := New_Node_2; 
--# end
--# expr-done 11061
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Wide_Image := True;
      Self.Lf_Stg_Wide_Image := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Wide_Image;
--# end
--# property-start TypeAttributesRepository.wide_wide_image /tmp/lal-23.0.0/ada/ast.py:5537
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Wide_Wide_Image
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Fld : Bare_Synthetic_Formal_Param_Decl;
Sym_1 : Symbol_Type;
Fld_1 : Internal_Entity;
Cast_Result : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
New_Node_1 : Bare_Synthetic_Unary_Spec;
Cast_Result_1 : Bare_Base_Subp_Spec;
New_Node_2 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_2 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Wide_Wide_Image then
         Property_Result := Self.Lf_Stg_Wide_Wide_Image;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11071 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11070 '<New SyntheticSubpDecl at ast.py:5538>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5538
--# expr-start 11069 '<New SyntheticUnarySpec at ast.py:5538>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5538
--# expr-start 11066 '<New SyntheticTypeExpr at ast.py:5541>' New_Node /tmp/lal-23.0.0/ada/ast.py:5541
--# expr-start 11065 '<FieldAccess for node at ast.py:5543>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5543
--# expr-start 11064 '<Cast to BaseTypeDecl at ast.py:5543>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5543
--# expr-start 11063 '<FieldAccess for std_entity at ast.py:5542>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5542
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11062 '<Symbol Wide_Wide_String at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_String); 
--# expr-done 11062
--# property-call-start AdaNode.std_entity
Fld_1 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_1);
--# end
--# expr-done 11063
   if Fld_1.Node = null
      or else Fld_1.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
   else
         Cast_Result := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 11064
Fld_2 := Cast_Result.Node;
--# expr-done 11065
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_2);
--# expr-done 11066
--# expr-start 11067 '<FieldAccess for base_type_param at ast.py:5540>' Fld /tmp/lal-23.0.0/ada/ast.py:5540
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11067
--# expr-start 11068 '<Symbol Wide_Wide_Image at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Wide_Wide_Image); 
--# expr-done 11068
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Unary_Spec);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Unary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Unary_Spec
     (Self => New_Node_1,
      Synthetic_Unary_Spec_F_Return_Type_Expr => New_Node, Synthetic_Unary_Spec_F_Right_Param => Fld);
      New_Node_1.Synthetic_Unary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11069
      Cast_Result_1 := New_Node_1;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_2,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_1);
--# expr-done 11070
Let_Result := New_Node_2; 
--# end
--# expr-done 11071
      Cast_Result_2 := Let_Result;
      Property_Result := Cast_Result_2;
   --# end
      Self.Lf_Present_Wide_Wide_Image := True;
      Self.Lf_Stg_Wide_Wide_Image := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Wide_Wide_Image;
--# end
--# property-start TypeAttributesRepository.put_image /tmp/lal-23.0.0/ada/ast.py:5548
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Put_Image
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
      Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Classwide_Type_Decl;
Fld_2 : Bare_Classwide_Type_Decl;
Cast_Result : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_1 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_3 : Bare_Synthetic_Formal_Param_Decl;
New_Node_2 : Bare_Synthetic_Binary_Spec;
Cast_Result_2 : Bare_Base_Subp_Spec;
New_Node_3 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_3 : Bare_Basic_Subp_Decl;
begin
   --# property-body-start
      if Self.Lf_Present_Put_Image then
         Property_Result := Self.Lf_Stg_Put_Image;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11082 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11081 '<New SyntheticSubpDecl at ast.py:5549>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:5549
--# expr-start 11080 '<New SyntheticBinarySpec at ast.py:5549>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5549
--# expr-start 11077 '<New SyntheticFormalParamDecl at ast.py:5551>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5551
--# expr-start 11075 '<New SyntheticTypeExpr at ast.py:5553>' New_Node /tmp/lal-23.0.0/ada/ast.py:5553
--# expr-start 11074 '<FieldAccess for node at ast.py:5554>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5554
--# expr-start 11073 '<FieldAccess for classwide_type at ast.py:5554>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5554
--# expr-start 11072 '<FieldAccess for root_buffer_type at ast.py:5554>' Fld /tmp/lal-23.0.0/ada/ast.py:5554
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_buffer_type
Fld := Libadalang.Implementation.Ada_Node_P_Root_Buffer_Type (Node => Self);
--# end
--# expr-done 11072
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.classwide_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Classwide_Type (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 11073
Fld_2 := Fld_1.Node;
--# expr-done 11074
      Cast_Result := Fld_2;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Cast_Result);
--# expr-done 11075
      Cast_Result_1 := New_Node;
--# expr-start 11076 '<Symbol Buffer at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Buffer); 
--# expr-done 11076
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_1);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_1;
--# expr-done 11077
--# expr-start 11078 '<FieldAccess for base_type_param at ast.py:5557>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5557
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_3 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11078
--# expr-start 11079 '<Symbol Put_Image at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Put_Image); 
--# expr-done 11079
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node_2,
      Synthetic_Binary_Spec_F_Left_Param => New_Node_1, Synthetic_Binary_Spec_F_Return_Type_Expr => No_Bare_Ada_Node, Synthetic_Binary_Spec_F_Right_Param => Fld_3);
      New_Node_2.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym;
--# expr-done 11080
      Cast_Result_2 := New_Node_2;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_3,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_2);
--# expr-done 11081
Let_Result := New_Node_3; 
--# end
--# expr-done 11082
      Cast_Result_3 := Let_Result;
      Property_Result := Cast_Result_3;
   --# end
      Self.Lf_Present_Put_Image := True;
      Self.Lf_Stg_Put_Image := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Put_Image;
--# end
--# property-start TypeAttributesRepository.asm_input /tmp/lal-23.0.0/ada/ast.py:5562
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Asm_Input
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
            procedure Finalizer_Scope_409 with Inline_Always;
            procedure Finalizer_Scope_3164 with Inline_Always;
      Block_Var : Bare_Base_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Fld_2 : Bare_Ada_Node;
Cast_Result : Bare_Base_Type_Decl;
Sym_3 : Symbol_Type;
Sym_4 : Symbol_Type;
Sym_5 : Symbol_Type;
Fld_3 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_2 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_5 : Bare_Synthetic_Formal_Param_Decl;
New_Node_2 : Bare_Synthetic_Type_Expr;
Cast_Result_3 : Bare_Type_Expr;
New_Node_3 : Bare_Synthetic_Binary_Spec;
Cast_Result_4 : Bare_Base_Subp_Spec;
New_Node_4 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_5 : Bare_Basic_Subp_Decl;
            procedure Finalizer_Scope_409 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_409;
            procedure Finalizer_Scope_3164 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_3164;
begin
   --# property-body-start
      if Self.Lf_Present_Asm_Input then
         Property_Result := Self.Lf_Stg_Asm_Input;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11104 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11091 '<Cast to BaseTypeDecl at ast.py:5567>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5567
--# expr-start 11090 '<FieldAccess for node at ast.py:5567>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5567
--# expr-start 11089 '<EnvGet at ast.py:5564>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:5564
--# expr-start 11086 '<FieldAccess for get_unit_root_decl at ast.py:5564>' Fld /tmp/lal-23.0.0/ada/ast.py:5564
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11085 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11083 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 11083
--# expr-start 11084 '<Symbol Machine_Code at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Code); 
--# expr-done 11084
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 11085
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 11086
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 11087 '<FieldAccess for children_env at ast.py:5566>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5566
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 11087
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3164;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 11088 '<Symbol Asm_Input_Operand at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Input_Operand); 
--# expr-done 11088
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 11089
Fld_2 := Env_Get_Result.Node;
--# expr-done 11090
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Fld_2;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11091
Block_Var := Cast_Result; 
--# bind input_type Block_Var
--# expr-start 11103 '<New SyntheticSubpDecl at ast.py:5569>' New_Node_4 /tmp/lal-23.0.0/ada/ast.py:5569
--# expr-start 11102 '<New SyntheticBinarySpec at ast.py:5569>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:5569
--# expr-start 11098 '<New SyntheticFormalParamDecl at ast.py:5571>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5571
--# expr-start 11096 '<New SyntheticTypeExpr at ast.py:5573>' New_Node /tmp/lal-23.0.0/ada/ast.py:5573
--# expr-start 11095 '<FieldAccess for node at ast.py:5575>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5575
--# expr-start 11094 '<Cast to BaseTypeDecl at ast.py:5575>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:5575
--# expr-start 11093 '<FieldAccess for std_entity at ast.py:5574>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5574
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11092 '<Symbol String at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 11092
--# property-call-start AdaNode.std_entity
Fld_3 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_5);
--# end
--# expr-done 11093
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result_1 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 11094
Fld_4 := Cast_Result_1.Node;
--# expr-done 11095
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_4);
--# expr-done 11096
      Cast_Result_2 := New_Node;
--# expr-start 11097 '<Symbol S at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_S); 
--# expr-done 11097
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_2);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_4;
--# expr-done 11098
--# expr-start 11099 '<New SyntheticTypeExpr at ast.py:5579>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5579
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_2,
      Synthetic_Type_Expr_F_Target_Type => Block_Var);
--# expr-done 11099
      Cast_Result_3 := New_Node_2;
--# expr-start 11100 '<FieldAccess for base_type_param at ast.py:5578>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5578
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_5 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11100
--# expr-start 11101 '<Symbol Asm_Input at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Input); 
--# expr-done 11101
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node_3,
      Synthetic_Binary_Spec_F_Left_Param => New_Node_1, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result_3, Synthetic_Binary_Spec_F_Right_Param => Fld_5);
      New_Node_3.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym_3;
--# expr-done 11102
      Cast_Result_4 := New_Node_3;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_4 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_4,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_4);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_4,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_4);
--# expr-done 11103
Let_Result := New_Node_4; 
--# end
--# expr-done 11104
      Cast_Result_5 := Let_Result;
      Property_Result := Cast_Result_5;
   --# end
      Finalizer_Scope_409;
      Self.Lf_Present_Asm_Input := True;
      Self.Lf_Stg_Asm_Input := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_409;
               Finalizer_Scope_3164;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Asm_Input;
--# end
--# property-start TypeAttributesRepository.asm_output /tmp/lal-23.0.0/ada/ast.py:5583
pragma Warnings (Off, "is not referenced");
 function Type_Attributes_Repository_F_Asm_Output
  (Node : Bare_Type_Attributes_Repository
  )
   return Bare_Basic_Subp_Decl
is
   Self : Bare_Type_Attributes_Repository := Bare_Type_Attributes_Repository (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Basic_Subp_Decl;
            procedure Finalizer_Scope_410 with Inline_Always;
            procedure Finalizer_Scope_3165 with Inline_Always;
      Block_Var : Bare_Base_Type_Decl;
Var_Expr : Bare_Basic_Decl;
Sym : Symbol_Type;
Sym_1 : Symbol_Type;
Array_Lit : Symbol_Type_Array_Access;
Fld : Bare_Basic_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
Sym_2 : Symbol_Type;
Env_Get_Result : Internal_Entity;
Fld_2 : Bare_Ada_Node;
Cast_Result : Bare_Base_Type_Decl;
Sym_3 : Symbol_Type;
Sym_4 : Symbol_Type;
Sym_5 : Symbol_Type;
Fld_3 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
New_Node : Bare_Synthetic_Type_Expr;
Cast_Result_2 : Bare_Type_Expr;
New_Node_1 : Bare_Synthetic_Formal_Param_Decl;
Fld_5 : Bare_Synthetic_Formal_Param_Decl;
New_Node_2 : Bare_Synthetic_Type_Expr;
Cast_Result_3 : Bare_Type_Expr;
New_Node_3 : Bare_Synthetic_Binary_Spec;
Cast_Result_4 : Bare_Base_Subp_Spec;
New_Node_4 : Bare_Synthetic_Subp_Decl;
Let_Result : Bare_Synthetic_Subp_Decl;
Cast_Result_5 : Bare_Basic_Subp_Decl;
            procedure Finalizer_Scope_410 is
            begin
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_410;
            procedure Finalizer_Scope_3165 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_3165;
begin
   --# property-body-start
      if Self.Lf_Present_Asm_Output then
         Property_Result := Self.Lf_Stg_Asm_Output;
         return Property_Result;
      end if;
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11126 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11113 '<Cast to BaseTypeDecl at ast.py:5588>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5588
--# expr-start 11112 '<FieldAccess for node at ast.py:5588>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5588
--# expr-start 11111 '<EnvGet at ast.py:5585>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:5585
--# expr-start 11108 '<FieldAccess for get_unit_root_decl at ast.py:5585>' Fld /tmp/lal-23.0.0/ada/ast.py:5585
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11107 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11105 '<Symbol System at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_System); 
--# expr-done 11105
--# expr-start 11106 '<Symbol Machine_Code at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Machine_Code); 
--# expr-done 11106
Array_Lit := Create_Symbol_Type_Array (Internal_Symbol_Type_Array'(1 => Sym, 2 => Sym_1)); 
--# expr-done 11107
--# property-call-start AdaNode.get_unit_root_decl
Fld := Libadalang.Implementation.Ada_Node_P_Get_Unit_Root_Decl (Node => Self, Name => Array_Lit, Kind => Unit_Specification);
--# end
--# expr-done 11108
Var_Expr := Fld;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 11109 '<FieldAccess for children_env at ast.py:5587>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5587
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Children_Env (Node => Var_Expr);
--# expr-done 11109
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3165;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
--# expr-start 11110 '<Symbol Asm_Output_Operand at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Output_Operand); 
--# expr-done 11110
Env_Get_Result := AST_Envs.Get_First (Self => Result_Var, Key => Sym_2, Lookup_Kind => To_Lookup_Kind_Type (Flat), Categories => (Inherited_Primitives => True, Nocat => True)); 
--# expr-done 11111
Fld_2 := Env_Get_Result.Node;
--# expr-done 11112
   if Fld_2 = null
      or else Fld_2.Kind in Ada_Base_Type_Decl
   then
      Cast_Result := Fld_2;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11113
Block_Var := Cast_Result; 
--# bind output_type Block_Var
--# expr-start 11125 '<New SyntheticSubpDecl at ast.py:5590>' New_Node_4 /tmp/lal-23.0.0/ada/ast.py:5590
--# expr-start 11124 '<New SyntheticBinarySpec at ast.py:5590>' New_Node_3 /tmp/lal-23.0.0/ada/ast.py:5590
--# expr-start 11120 '<New SyntheticFormalParamDecl at ast.py:5592>' New_Node_1 /tmp/lal-23.0.0/ada/ast.py:5592
--# expr-start 11118 '<New SyntheticTypeExpr at ast.py:5594>' New_Node /tmp/lal-23.0.0/ada/ast.py:5594
--# expr-start 11117 '<FieldAccess for node at ast.py:5596>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5596
--# expr-start 11116 '<Cast to BaseTypeDecl at ast.py:5596>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:5596
--# expr-start 11115 '<FieldAccess for std_entity at ast.py:5595>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5595
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11114 '<Symbol String at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_String); 
--# expr-done 11114
--# property-call-start AdaNode.std_entity
Fld_3 := Libadalang.Implementation.Ada_Node_P_Std_Entity (Node => Self, Sym => Sym_5);
--# end
--# expr-done 11115
   if Fld_3.Node = null
      or else Fld_3.Node.Kind in Ada_Base_Type_Decl
   then
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_3.Node,
         Info => Fld_3.Info);
   else
         Cast_Result_1 := No_Entity_Base_Type_Decl;
   end if;
--# expr-done 11116
Fld_4 := Cast_Result_1.Node;
--# expr-done 11117
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node,
      Synthetic_Type_Expr_F_Target_Type => Fld_4);
--# expr-done 11118
      Cast_Result_2 := New_Node;
--# expr-start 11119 '<Symbol S at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_S); 
--# expr-done 11119
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_1 := new Root_Node_Record
  (Ada_Synthetic_Formal_Param_Decl);
Initialize
  (Self => New_Node_1,
   Kind => Ada_Synthetic_Formal_Param_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_1);
   Initialize_Fields_For_Synthetic_Formal_Param_Decl
     (Self => New_Node_1,
      Synthetic_Formal_Param_Decl_F_Param_Type => Cast_Result_2);
      New_Node_1.Synthetic_Formal_Param_Decl_Param_Name :=
         Sym_4;
--# expr-done 11120
--# expr-start 11121 '<New SyntheticTypeExpr at ast.py:5600>' New_Node_2 /tmp/lal-23.0.0/ada/ast.py:5600
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_2 := new Root_Node_Record
  (Ada_Synthetic_Type_Expr);
Initialize
  (Self => New_Node_2,
   Kind => Ada_Synthetic_Type_Expr,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_2);
   Initialize_Fields_For_Synthetic_Type_Expr
     (Self => New_Node_2,
      Synthetic_Type_Expr_F_Target_Type => Block_Var);
--# expr-done 11121
      Cast_Result_3 := New_Node_2;
--# expr-start 11122 '<FieldAccess for base_type_param at ast.py:5599>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5599
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeAttributesRepository.base_type_param
Fld_5 := Libadalang.Implementation.Type_Attributes_Repository_F_Base_Type_Param (Node => Self);
--# end
--# expr-done 11122
--# expr-start 11123 '<Symbol Asm_Output at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Asm_Output); 
--# expr-done 11123
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_3 := new Root_Node_Record
  (Ada_Synthetic_Binary_Spec);
Initialize
  (Self => New_Node_3,
   Kind => Ada_Synthetic_Binary_Spec,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_3);
   Initialize_Fields_For_Synthetic_Binary_Spec
     (Self => New_Node_3,
      Synthetic_Binary_Spec_F_Left_Param => New_Node_1, Synthetic_Binary_Spec_F_Return_Type_Expr => Cast_Result_3, Synthetic_Binary_Spec_F_Right_Param => Fld_5);
      New_Node_3.Synthetic_Binary_Spec_Subp_Symbol :=
         Sym_3;
--# expr-done 11124
      Cast_Result_4 := New_Node_3;
if Is_Foreign_Strict (Self.Self_Env, Self) then
   Raise_Property_Exception
     (Self,
      Property_Error'Identity,
      "synthetic nodes cannot have foreign lexical envs");
end if;
New_Node_4 := new Root_Node_Record
  (Ada_Synthetic_Subp_Decl);
Initialize
  (Self => New_Node_4,
   Kind => Ada_Synthetic_Subp_Decl,
   Unit => Self.Unit,
   Token_Start_Index => No_Token_Index,
   Token_End_Index   => No_Token_Index,
   Parent => Self,
   Self_Env => Self.Self_Env);
Register_Destroyable (Self.Unit, New_Node_4);
   Initialize_Fields_For_Synthetic_Subp_Decl
     (Self => New_Node_4,
      Synthetic_Subp_Decl_F_Spec => Cast_Result_4);
--# expr-done 11125
Let_Result := New_Node_4; 
--# end
--# expr-done 11126
      Cast_Result_5 := Let_Result;
      Property_Result := Cast_Result_5;
   --# end
      Finalizer_Scope_410;
      Self.Lf_Present_Asm_Output := True;
      Self.Lf_Stg_Asm_Output := Property_Result;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_410;
               Finalizer_Scope_3165;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Attributes_Repository_F_Asm_Output;
--# end
   --
   --  Primitives for Bare_Type_Def
   --
--# property-start '[dispatcher]TypeDef.discrete_range' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Discrete_Range
  (Node : Bare_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Interface_Type_Def | Ada_Private_Type_Def .. Ada_Record_Type_Def =>
                  --# property-call-start TypeDef.discrete_range
                  Property_Result := Type_Def_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.discrete_range
                  Property_Result := Derived_Type_Def_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Mod_Int_Type_Def =>
                  --# property-call-start ModIntTypeDef.discrete_range
                  Property_Result := Mod_Int_Type_Def_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Signed_Int_Type_Def =>
                  --# property-call-start SignedIntTypeDef.discrete_range
                  Property_Result := Signed_Int_Type_Def_P_Discrete_Range
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Discrete_Range;
--# end
--# property-start '[dispatcher]TypeDef.array_ndims' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Array_Ndims
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.array_ndims
                  Property_Result := Type_Def_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Array_Type_Def =>
                  --# property-call-start ArrayTypeDef.array_ndims
                  Property_Result := Array_Type_Def_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.array_ndims
                  Property_Result := Derived_Type_Def_P_Array_Ndims
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Array_Ndims;
--# end
--# property-start TypeDef.is_real_type /tmp/lal-23.0.0/ada/ast.py:4460
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Real_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Boolean;
Fld_1 : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11127 '<FieldAccess for is_float_type at ast.py:4461>' Fld /tmp/lal-23.0.0/ada/ast.py:4461
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_float_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Float_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11127
if Fld then
   If_Result := True;
else
   --# expr-start 11128 '<FieldAccess for is_fixed_point at ast.py:4461>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4461
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_fixed_point'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Fixed_Point (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11128
   If_Result := Fld_1;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Real_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_float_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Float_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Decimal_Fixed_Point_Def | Ada_Ordinary_Fixed_Point_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_float_type
                  Property_Result := Type_Def_P_Is_Float_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_float_type
                  Property_Result := Derived_Type_Def_P_Is_Float_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Floating_Point_Def =>
                  --# property-call-start FloatingPointDef.is_float_type
                  Property_Result := Floating_Point_Def_P_Is_Float_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Float_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_fixed_point' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Fixed_Point
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Private_Type_Def | Ada_Floating_Point_Def | Ada_Record_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_fixed_point
                  Property_Result := Type_Def_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_fixed_point
                  Property_Result := Derived_Type_Def_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Decimal_Fixed_Point_Def =>
                  --# property-call-start DecimalFixedPointDef.is_fixed_point
                  Property_Result := Decimal_Fixed_Point_Def_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Ordinary_Fixed_Point_Def =>
                  --# property-call-start OrdinaryFixedPointDef.is_fixed_point
                  Property_Result := Ordinary_Fixed_Point_Def_P_Is_Fixed_Point
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Fixed_Point;
--# end
--# property-start '[dispatcher]TypeDef.predefined_operators' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Predefined_Operators
  (Node : Bare_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Derived_Type_Def | Ada_Interface_Type_Def =>
                  --# property-call-start TypeDef.predefined_operators
                  Property_Result := Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def =>
                  --# property-call-start AccessDef.predefined_operators
                  Property_Result := Access_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Array_Type_Def =>
                  --# property-call-start ArrayTypeDef.predefined_operators
                  Property_Result := Array_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Enum_Type_Def =>
                  --# property-call-start EnumTypeDef.predefined_operators
                  Property_Result := Enum_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Formal_Discrete_Type_Def =>
                  --# property-call-start FormalDiscreteTypeDef.predefined_operators
                  Property_Result := Formal_Discrete_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Mod_Int_Type_Def =>
                  --# property-call-start ModIntTypeDef.predefined_operators
                  Property_Result := Mod_Int_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Private_Type_Def =>
                  --# property-call-start PrivateTypeDef.predefined_operators
                  Property_Result := Private_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Floating_Point_Def =>
                  --# property-call-start RealTypeDef.predefined_operators
                  Property_Result := Real_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Decimal_Fixed_Point_Def =>
                  --# property-call-start DecimalFixedPointDef.predefined_operators
                  Property_Result := Decimal_Fixed_Point_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Ordinary_Fixed_Point_Def =>
                  --# property-call-start OrdinaryFixedPointDef.predefined_operators
                  Property_Result := Ordinary_Fixed_Point_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Record_Type_Def =>
                  --# property-call-start RecordTypeDef.predefined_operators
                  Property_Result := Record_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
               when Ada_Signed_Int_Type_Def =>
                  --# property-call-start SignedIntTypeDef.predefined_operators
                  Property_Result := Signed_Int_Type_Def_P_Predefined_Operators
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Predefined_Operators;
--# end
--# property-start TypeDef.predefined_equality_operators /tmp/lal-23.0.0/ada/ast.py:4487
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Predefined_Equality_Operators
  (Node : Bare_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_281 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Fld_4 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_281 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_281;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11138 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11130 '<Cast to TypeDecl at ast.py:4488>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4488
--# expr-start 11129 '<parent at ast.py:4488>' Fld /tmp/lal-23.0.0/ada/ast.py:4488
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11129
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11130
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11132 '<FieldAccess for node at ast.py:4489>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4489
--# expr-start 11131 '<FieldAccess for bool_type at ast.py:4489>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4489
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11131
Fld_2 := Fld_1.Node;
--# expr-done 11132
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11137 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11134 '<FieldAccess for create_binop_assoc at ast.py:4491>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4491
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11133 '<Symbol "=" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11133
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
--# property-call-start AdaNode.create_binop_assoc
Fld_3 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Block_Var_1);
--# end
--# expr-done 11134
--# expr-start 11136 '<FieldAccess for create_binop_assoc at ast.py:4492>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4492
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11135 '<Symbol "/=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11135
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
--# property-call-start AdaNode.create_binop_assoc
Fld_4 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_3, Rhs => Cast_Result_4, Ret => Block_Var_1);
--# end
--# expr-done 11136
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_3, 2 => Fld_4)); 
--# expr-done 11137
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 11138
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_281;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_281;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Predefined_Equality_Operators;
--# end
--# property-start '[dispatcher]TypeDef.is_discrete_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Discrete_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Enum_Type_Def | Ada_Interface_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_discrete_type
                  Property_Result := Type_Def_P_Is_Discrete_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Formal_Discrete_Type_Def =>
                  --# property-call-start FormalDiscreteTypeDef.is_discrete_type
                  Property_Result := Formal_Discrete_Type_Def_P_Is_Discrete_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Discrete_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_int_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Int_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Interface_Type_Def | Ada_Private_Type_Def .. Ada_Record_Type_Def =>
                  --# property-call-start TypeDef.is_int_type
                  Property_Result := Type_Def_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_int_type
                  Property_Result := Derived_Type_Def_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Mod_Int_Type_Def =>
                  --# property-call-start ModIntTypeDef.is_int_type
                  Property_Result := Mod_Int_Type_Def_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Signed_Int_Type_Def =>
                  --# property-call-start SignedIntTypeDef.is_int_type
                  Property_Result := Signed_Int_Type_Def_P_Is_Int_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Int_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_access_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Access_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_access_type
                  Property_Result := Type_Def_P_Is_Access_Type
                    (Self
                        , Origin
                    );
                  --# end
               when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def =>
                  --# property-call-start AccessDef.is_access_type
                  Property_Result := Access_Def_P_Is_Access_Type
                    (Self
                        , Origin
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_access_type
                  Property_Result := Derived_Type_Def_P_Is_Access_Type
                    (Self
                        , Origin
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Access_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_char_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Char_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Formal_Discrete_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_char_type
                  Property_Result := Type_Def_P_Is_Char_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_char_type
                  Property_Result := Derived_Type_Def_P_Is_Char_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Type_Def =>
                  --# property-call-start EnumTypeDef.is_char_type
                  Property_Result := Enum_Type_Def_P_Is_Char_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Char_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_enum_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Enum_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Formal_Discrete_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_enum_type
                  Property_Result := Type_Def_P_Is_Enum_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_enum_type
                  Property_Result := Derived_Type_Def_P_Is_Enum_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Type_Def =>
                  --# property-call-start EnumTypeDef.is_enum_type
                  Property_Result := Enum_Type_Def_P_Is_Enum_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Enum_Type;
--# end
--# property-start '[dispatcher]TypeDef.accessed_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Accessed_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.accessed_type
                  Property_Result := Type_Def_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Access_To_Subp_Def =>
                  --# property-call-start AccessToSubpDef.accessed_type
                  Property_Result := Access_To_Subp_Def_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Anonymous_Type_Access_Def =>
                  --# property-call-start AnonymousTypeAccessDef.accessed_type
                  Property_Result := Anonymous_Type_Access_Def_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Type_Access_Def =>
                  --# property-call-start TypeAccessDef.accessed_type
                  Property_Result := Type_Access_Def_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.accessed_type
                  Property_Result := Derived_Type_Def_P_Accessed_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Accessed_Type;
--# end
--# property-start '[dispatcher]TypeDef.is_tagged_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Tagged_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Formal_Discrete_Type_Def | Ada_Mod_Int_Type_Def | Ada_Decimal_Fixed_Point_Def .. Ada_Ordinary_Fixed_Point_Def | Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.is_tagged_type
                  Property_Result := Type_Def_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_tagged_type
                  Property_Result := Derived_Type_Def_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Interface_Type_Def =>
                  --# property-call-start InterfaceTypeDef.is_tagged_type
                  Property_Result := Interface_Type_Def_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Private_Type_Def =>
                  --# property-call-start PrivateTypeDef.is_tagged_type
                  Property_Result := Private_Type_Def_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Record_Type_Def =>
                  --# property-call-start RecordTypeDef.is_tagged_type
                  Property_Result := Record_Type_Def_P_Is_Tagged_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Tagged_Type;
--# end
--# property-start '[dispatcher]TypeDef.base_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Base_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.base_type
                  Property_Result := Type_Def_P_Base_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.base_type
                  Property_Result := Derived_Type_Def_P_Base_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Base_Type;
--# end
--# property-start TypeDef.base_types /tmp/lal-23.0.0/ada/ast.py:4536
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Base_Types
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_290 with Inline_Always;
            procedure Finalizer_Scope_2359 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Singleton : Internal_Entity_Base_Type_Decl_Array_Access;
Scope_Result : Internal_Entity_Base_Type_Decl_Array_Access;
Result_Var : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_1 : Internal_Entity_Base_Type_Decl_Array_Access;
Concat_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_290 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Concat_Result);
            end Finalizer_Scope_290;
            procedure Finalizer_Scope_2359 is
            begin
                     Dec_Ref (Singleton);
            end Finalizer_Scope_2359;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11141 '<Concat at ast.py:4538>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:4538
--# expr-start 11139 '<FieldAccess for base_type at ast.py:4537>' Fld /tmp/lal-23.0.0/ada/ast.py:4537
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11139
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
                Singleton := Create_Internal_Entity_Base_Type_Decl_Array (Items_Count => 1);
                Singleton.Items (1) := Var_Expr;
Scope_Result := Singleton;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2359;
   Result_Var := Scope_Result;
else
   Result_Var := No_Internal_Entity_Base_Type_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var);
--# expr-start 11140 '<FieldAccess for base_interfaces at ast.py:4538>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4538
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_interfaces'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Interfaces (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 11140
Concat_Result := Concat (Result_Var, Fld_1); 
--# expr-done 11141
      Property_Result := Concat_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_290;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_290;
               Finalizer_Scope_2359;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Base_Types;
--# end
--# property-start '[dispatcher]TypeDef.base_interfaces' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Base_Interfaces
  (Node : Bare_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Array_Type_Def | Ada_Enum_Type_Def .. Ada_Formal_Discrete_Type_Def | Ada_Mod_Int_Type_Def .. Ada_Signed_Int_Type_Def =>
                  --# property-call-start TypeDef.base_interfaces
                  Property_Result := Type_Def_P_Base_Interfaces
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.base_interfaces
                  Property_Result := Derived_Type_Def_P_Base_Interfaces
                    (Self
                        , E_Info
                    );
                  --# end
               when Ada_Interface_Type_Def =>
                  --# property-call-start InterfaceTypeDef.base_interfaces
                  Property_Result := Interface_Type_Def_P_Base_Interfaces
                    (Self
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Base_Interfaces;
--# end
--# property-start TypeDef.defining_env /tmp/lal-23.0.0/ada/ast.py:4553
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Defining_Env
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_292 with Inline_Always;
            procedure Finalizer_Scope_2360 with Inline_Always;
            procedure Finalizer_Scope_2361 with Inline_Always;
            procedure Finalizer_Scope_2362 with Inline_Always;
            procedure Finalizer_Scope_2363 with Inline_Always;
            procedure Finalizer_Scope_2364 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Match_0 : Internal_Entity_Array_Type_Def;
Match_1 : Internal_Entity_Access_Def;
Match_2 : Internal_Entity_Type_Def;
Var_Expr_2 : Internal_Entity_Base_Type_Decl;
Is_A : Boolean;
Fld : Lexical_Env := Empty_Env;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Lexical_Env := Empty_Env;
Array_Lit : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Is_A_1 : Boolean;
Fld_3 : Lexical_Env := Empty_Env;
Fld_4 : Lexical_Env := Empty_Env;
Array_Lit_1 : Lexical_Env_Array_Access;
Scope_Result : Bare_Ada_Node;
Fld_5 : Bare_Ada_Node;
Result_Var : Bare_Ada_Node;
Bound_Dottable_Type : Bare_Ada_Node;
Fld_6 : Internal_Entity_Base_Type_Decl_Array_Access;
Fld_7 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Result_Var_1 : Lexical_Env := Empty_Env;
Map_Result : Lexical_Env_Array_Access;
Dyn_Var_Bind_Result : Lexical_Env_Array_Access;
Concat_Result : Lexical_Env_Array_Access;
Fld_8 : Lexical_Env := Empty_Env;
Singleton : Lexical_Env_Array_Access;
Concat_Result_1 : Lexical_Env_Array_Access;
Group_Env_1 : Lexical_Env := Empty_Env;
Fld_9 : Internal_Entity_Base_Type_Decl;
Fld_10 : Lexical_Env := Empty_Env;
Fld_11 : Internal_Entity_Base_Type_Decl;
Fld_12 : Lexical_Env := Empty_Env;
Scope_Result_2 : Lexical_Env := Empty_Env;
Result_Var_2 : Lexical_Env := Empty_Env;
Match_Prefix : Internal_Entity_Type_Def;
Cast_Result : Internal_Entity_Array_Type_Def;
Let_Result : Lexical_Env := Empty_Env;
Scope_Result_3 : Lexical_Env := Empty_Env;
Cast_Result_1 : Internal_Entity_Access_Def;
Let_Result_1 : Lexical_Env := Empty_Env;
Scope_Result_4 : Lexical_Env := Empty_Env;
Cast_Result_2 : Internal_Entity_Type_Def;
Let_Result_2 : Lexical_Env := Empty_Env;
Scope_Result_5 : Lexical_Env := Empty_Env;
Match_Result : Lexical_Env := Empty_Env;
If_Result : Lexical_Env := Empty_Env;
If_Result_1 : Lexical_Env := Empty_Env;
Let_Result_3 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_292 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Group_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Singleton);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Group_Env_1);
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_5);
                     Dec_Ref (Match_Result);
                     Dec_Ref (If_Result);
                     Dec_Ref (If_Result_1);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_292;
            procedure Finalizer_Scope_2360 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
            end Finalizer_Scope_2360;
            procedure Finalizer_Scope_2361 is
            begin
                     Dec_Ref (Fld_7);
            end Finalizer_Scope_2361;
            procedure Finalizer_Scope_2362 is
            begin
                     Dec_Ref (Fld_10);
            end Finalizer_Scope_2362;
            procedure Finalizer_Scope_2363 is
            begin
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
            end Finalizer_Scope_2363;
            procedure Finalizer_Scope_2364 is
            begin
                     Dec_Ref (Fld_12);
            end Finalizer_Scope_2364;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11167 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 11166 '<Cond at ast.py:4556>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:4556
--# expr-start 11142 '<IsA RecordTypeDef, PrivateTypeDef at ast.py:4560>' Is_A /tmp/lal-23.0.0/ada/ast.py:4560
Is_A := Self /= null 
and then Self.Kind in Ada_Record_Type_Def_Range | Ada_Private_Type_Def_Range; 
--# expr-done 11142
if Is_A then
   --# expr-start 11147 '<env_group at ast.py:4565>' Group_Env /tmp/lal-23.0.0/ada/ast.py:4565
--# expr-start 11146 '<ArrayLiteral at ast.py:4561>' Array_Lit /tmp/lal-23.0.0/ada/ast.py:4561
--# expr-start 11143 '<FieldAccess for children_env at ast.py:4562>' Fld /tmp/lal-23.0.0/ada/ast.py:4562
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11143
--# expr-start 11144 '<FieldAccess for dottable_subps_env at ast.py:4563>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4563
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.dottable_subps_env
Fld_1 := Libadalang.Implementation.Type_Def_P_Dottable_Subps_Env (Node => Ent.Node, Origin => Origin, Dottable_Type => Dottable_Type, E_Info => Ent.Info);
--# end
--# expr-done 11144
--# expr-start 11145 '<FieldAccess for previous_part_env at ast.py:4564>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4564
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.previous_part_env
Fld_2 := Libadalang.Implementation.Type_Def_P_Previous_Part_Env (Node => Ent.Node, Origin => Origin, Dottable_Type => Dottable_Type, E_Info => Ent.Info);
--# end
--# expr-done 11145
Array_Lit := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld, 2 => Fld_1, 3 => Fld_2)); 
--# expr-done 11146
Group_Env := Group (Array_Lit, No_Metadata); 
--# expr-done 11147
   If_Result_1 := Group_Env;
else
--# expr-start 11148 '<IsA DerivedTypeDef, InterfaceTypeDef at ast.py:4569>' Is_A_1 /tmp/lal-23.0.0/ada/ast.py:4569
Is_A_1 := Self /= null 
and then Self.Kind in Ada_Derived_Type_Def_Range | Ada_Interface_Type_Def_Range; 
--# expr-done 11148
if Is_A_1 then
   --# expr-start 11160 '<env_group at ast.py:4581>' Group_Env_1 /tmp/lal-23.0.0/ada/ast.py:4581
--# expr-start 11159 '<Concat at ast.py:4581>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:4581
--# expr-start 11157 '<Concat at ast.py:4576>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:4576
--# expr-start 11151 '<ArrayLiteral at ast.py:4573>' Array_Lit_1 /tmp/lal-23.0.0/ada/ast.py:4573
--# expr-start 11149 '<FieldAccess for children_env at ast.py:4574>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4574
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11149
--# expr-start 11150 '<FieldAccess for dottable_subps_env at ast.py:4575>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4575
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.dottable_subps_env
Fld_4 := Libadalang.Implementation.Type_Def_P_Dottable_Subps_Env (Node => Ent.Node, Origin => Origin, Dottable_Type => Dottable_Type, E_Info => Ent.Info);
--# end
--# expr-done 11150
Array_Lit_1 := Create_Lexical_Env_Array (Internal_Lexical_Env_Array'(1 => Fld_3, 2 => Fld_4)); 
--# expr-done 11151
--# expr-start 11156 '<bind at ast.py:4576>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:4576
Var_Expr := Dottable_Type;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind e Var_Expr
Scope_Result := Var_Expr;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 11152 '<parent at ast.py:4579>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4579
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Self.Parent; 
--# expr-done 11152
   Result_Var := Fld_5;
end if;
Bound_Dottable_Type := Result_Var; 
--# expr-start 11155 '<Map at ast.py:4580>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4580
   --# expr-start 11153 '<FieldAccess for base_types at ast.py:4580>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:4580
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.base_types
Fld_6 := Libadalang.Implementation.Type_Def_P_Base_Types (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11153
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Type_Decl_Array_Access := Fld_6;
      begin
         for Item_333 of
               Collection.Items
         loop
   --# scope-start
               --# bind bt Item_333
Var_Expr_1 := Item_333;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 11154 '<FieldAccess for defining_env at ast.py:4580>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4580
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_7 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Var_Expr_1.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Bound_Dottable_Type, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 11154
Scope_Result_1 := Fld_7;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_2361;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := Empty_Env;
end if;
      Inc_Ref (Result_Var_1);
         declare
            Item_To_Append : constant Lexical_Env := Result_Var_1;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_2360;
         end loop;
      end;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11155
Dyn_Var_Bind_Result := Map_Result; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 11156
Concat_Result := Concat (Array_Lit_1, Dyn_Var_Bind_Result); 
--# expr-done 11157
--# expr-start 11158 '<FieldAccess for previous_part_env at ast.py:4581>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4581
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.previous_part_env
Fld_8 := Libadalang.Implementation.Type_Def_P_Previous_Part_Env (Node => Ent.Node, Origin => Origin, Dottable_Type => Dottable_Type, E_Info => Ent.Info);
--# end
--# expr-done 11158
                Singleton := Create_Lexical_Env_Array (Items_Count => 1);
                Singleton.Items (1) := Fld_8;
                Inc_Ref (Singleton.Items (1));
Concat_Result_1 := Concat (Concat_Result, Singleton); 
--# expr-done 11159
Group_Env_1 := Group (Concat_Result_1, No_Metadata); 
--# expr-done 11160
   If_Result := Group_Env_1;
else
   --# expr-start 11165 '<Match at ast.py:4583>' Match_Result /tmp/lal-23.0.0/ada/ast.py:4583
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Type_Def (Match_Prefix.Node.Kind) is
         when Ada_Array_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Array_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind ar Match_0
--# expr-start 11162 '<FieldAccess for defining_env at ast.py:4584>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4584
--# expr-start 11161 '<FieldAccess for comp_type at ast.py:4584>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4584
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ArrayTypeDef.comp_type
Fld_9 := Libadalang.Implementation.Array_Type_Def_P_Comp_Type (Node => Match_0.Node, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 11161
      if Fld_9.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_10 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld_9.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld_9.Info);
--# end
--# expr-done 11162
Let_Result := Fld_10; Inc_Ref (Let_Result);
--# end
Scope_Result_3 := Let_Result;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_2362;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Access_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind ac Match_1
--# expr-start 11163 '<FieldAccess for accessed_type at ast.py:4588>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4588
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.accessed_type'
Fld_11 := Libadalang.Implementation.Dispatcher_Type_Def_P_Accessed_Type (Node => Match_1.Node, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 11163
Var_Expr_2 := Fld_11;
if Var_Expr_2 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 11164 '<FieldAccess for defining_env at ast.py:4588>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4588
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_12 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Var_Expr_2.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 11164
Scope_Result_2 := Fld_12;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_2364;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Empty_Env;
end if;
      Inc_Ref (Result_Var_2);
Let_Result_1 := Result_Var_2; Inc_Ref (Let_Result_1);
--# end
Scope_Result_4 := Let_Result_1;
   Inc_Ref (Scope_Result_4);
   --# end
      Finalizer_Scope_2363;
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
         when Ada_Derived_Type_Def .. Ada_Signed_Int_Type_Def =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Type_Def
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_2; 
--# bind _ Match_2
Let_Result_2 := Empty_Env; Inc_Ref (Let_Result_2);
--# end
Scope_Result_5 := Let_Result_2;
   Inc_Ref (Scope_Result_5);
   --# end
            Match_Result := Scope_Result_5; Inc_Ref (Match_Result);
end case;
--# expr-done 11165
   If_Result := Match_Result;
end if;
      Inc_Ref (If_Result);
   If_Result_1 := If_Result;
end if;
      Inc_Ref (If_Result_1);
--# expr-done 11166
Let_Result_3 := If_Result_1; Inc_Ref (Let_Result_3);
--# end
--# expr-done 11167
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_292;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_292;
               Finalizer_Scope_2360;
               Finalizer_Scope_2361;
               Finalizer_Scope_2362;
               Finalizer_Scope_2363;
               Finalizer_Scope_2364;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Defining_Env;
--# end
--# property-start TypeDef.containing_type /tmp/lal-23.0.0/ada/ast.py:4594
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Containing_Type
  (Node : Bare_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Type_Decl
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Type_Decl;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11169 '<Cast to TypeDecl at ast.py:4595>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4595
--# expr-start 11168 '<parent at ast.py:4595>' Fld /tmp/lal-23.0.0/ada/ast.py:4595
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11168
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Type_Decl
   then
      Cast_Result := Create_Internal_Entity_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 11169
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Containing_Type;
--# end
--# property-start TypeDef.previous_part /tmp/lal-23.0.0/ada/ast.py:4600
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Previous_Part
  (Node : Bare_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11171 '<FieldAccess for previous_part at ast.py:4600>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4600
--# expr-start 11170 '<FieldAccess for containing_type at ast.py:4600>' Fld /tmp/lal-23.0.0/ada/ast.py:4600
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.containing_type
Fld := Libadalang.Implementation.Type_Def_P_Containing_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 11170
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.previous_part'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Previous_Part (Node => Fld.Node, Go_To_Incomplete => True, E_Info => Fld.Info);
--# end
--# expr-done 11171
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Previous_Part;
--# end
--# property-start TypeDef.previous_part_env /tmp/lal-23.0.0/ada/ast.py:4602
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Previous_Part_Env
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
      ; Dottable_Type : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_295 with Inline_Always;
            procedure Finalizer_Scope_2357 with Inline_Always;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Result_Var : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_295 is
            begin
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Result_Var);
            end Finalizer_Scope_295;
            procedure Finalizer_Scope_2357 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_2357;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
--# expr-start 11172 '<FieldAccess for previous_part at ast.py:4603>' Fld /tmp/lal-23.0.0/ada/ast.py:4603
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.previous_part
Fld := Libadalang.Implementation.Type_Def_P_Previous_Part (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 11172
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 11173 '<FieldAccess for defining_env at ast.py:4603>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4603
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Var_Expr.Node, Origin => Origin, Include_Ud_Indexing => False, Dottable_Type => Dottable_Type, E_Info => Var_Expr.Info);
--# end
--# expr-done 11173
Scope_Result := Fld_1;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_2357;
   Result_Var := Scope_Result;
else
   Result_Var := Empty_Env;
end if;
      Inc_Ref (Result_Var);
      Property_Result := Result_Var;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_295;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_295;
               Finalizer_Scope_2357;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Previous_Part_Env;
--# end
--# property-start TypeDef.dottable_subps_env /tmp/lal-23.0.0/ada/ast.py:4607
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Dottable_Subps_Env
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
      ; Dottable_Type : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_296 with Inline_Always;
      Var_Expr : Bare_Ada_Node;
Fld : Internal_Entity_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Fld_2 : Internal_Entity_Info;
Fld_3 : Env_Rebindings;
Rebound_Env : Lexical_Env := Empty_Env;
Singleton : Lexical_Env_Array_Access;
Fld_4 : Bare_Ada_Node;
New_Struct : Internal_Metadata;
Scope_Result : Internal_Metadata;
Result_Var : Internal_Metadata;
Group_Env : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_296 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Rebound_Env);
                     Dec_Ref (Singleton);
                     Dec_Ref (Group_Env);
            end Finalizer_Scope_296;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11181 '<env_group at ast.py:4618>' Group_Env /tmp/lal-23.0.0/ada/ast.py:4618
--# expr-start 11178 '<rebind_env at ast.py:4618>' Rebound_Env /tmp/lal-23.0.0/ada/ast.py:4618
--# expr-start 11175 '<FieldAccess for dottable_subps_env at ast.py:4618>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4618
--# expr-start 11174 '<FieldAccess for containing_type at ast.py:4618>' Fld /tmp/lal-23.0.0/ada/ast.py:4618
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.containing_type
Fld := Libadalang.Implementation.Type_Def_P_Containing_Type (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 11174
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseTypeDecl.dottable_subps_env
Fld_1 := Libadalang.Implementation.Base_Type_Decl_F_Dottable_Subps_Env (Node => Fld.Node);
--# end
--# expr-done 11175
--# expr-start 11177 '<FieldAccess for rebindings at ast.py:4619>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4619
--# expr-start 11176 '<FieldAccess for info at ast.py:4619>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4619
Fld_2 := Ent.Info;
--# expr-done 11176
Fld_3 := Fld_2.Rebindings;
--# expr-done 11177
Rebound_Env := Rebind_Env (Fld_1, Fld_3); 
--# expr-done 11178
                Singleton := Create_Lexical_Env_Array (Items_Count => 1);
                Singleton.Items (1) := Rebound_Env;
                Inc_Ref (Singleton.Items (1));
Var_Expr := Dottable_Type;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
   --# bind t Var_Expr
--# expr-start 11180 '<New Metadata at ast.py:4621>' New_Struct /tmp/lal-23.0.0/ada/ast.py:4621
--# expr-start 11179 '<parent at ast.py:4622>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4622
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Self.Parent; 
--# expr-done 11179
New_Struct := (Dottable_Subp => False, Primitive => Fld_4, Primitive_Real_Type => Var_Expr); 
--# expr-done 11180
Scope_Result := New_Struct;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Metadata;
end if;
Group_Env := Group (Singleton, Result_Var); 
--# expr-done 11181
      Property_Result := Group_Env;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_296;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_296;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Dottable_Subps_Env;
--# end
--# property-start '[dispatcher]TypeDef.is_static' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Def_P_Is_Static
  (Node : Bare_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Def (Self.Kind) is
               when Ada_Access_To_Subp_Def .. Ada_Type_Access_Def | Ada_Formal_Discrete_Type_Def .. Ada_Interface_Type_Def | Ada_Private_Type_Def | Ada_Record_Type_Def =>
                  --# property-call-start TypeDef.is_static
                  Property_Result := Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Array_Type_Def =>
                  --# property-call-start ArrayTypeDef.is_static
                  Property_Result := Array_Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Derived_Type_Def =>
                  --# property-call-start DerivedTypeDef.is_static
                  Property_Result := Derived_Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Type_Def =>
                  --# property-call-start EnumTypeDef.is_static
                  Property_Result := Enum_Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Mod_Int_Type_Def =>
                  --# property-call-start ModIntTypeDef.is_static
                  Property_Result := Mod_Int_Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Decimal_Fixed_Point_Def .. Ada_Ordinary_Fixed_Point_Def =>
                  --# property-call-start RealTypeDef.is_static
                  Property_Result := Real_Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
               when Ada_Signed_Int_Type_Def =>
                  --# property-call-start SignedIntTypeDef.is_static
                  Property_Result := Signed_Int_Type_Def_P_Is_Static
                    (Self
                        , Imprecise_Fallback
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Def_P_Is_Static;
--# end
--# property-start TypeDef.discrete_range /tmp/lal-23.0.0/ada/ast.py:4445
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Discrete_Range
  (Node : Bare_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Discrete_Range;
      Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11182 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Discrete_Range; 
--# end
--# expr-done 11182
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Discrete_Range;
--# end
--# property-start TypeDef.array_ndims /tmp/lal-23.0.0/ada/ast.py:4451
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Array_Ndims
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := 0;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Array_Ndims;
--# end
--# property-start TypeDef.is_float_type /tmp/lal-23.0.0/ada/ast.py:4466
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Float_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Float_Type;
--# end
--# property-start TypeDef.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:4470
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Fixed_Point
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Fixed_Point;
--# end
--# property-start TypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:4476
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Predefined_Operators
  (Node : Bare_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_280 with Inline_Always;
      Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_280 is
            begin
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_280;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11183 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Internal_Env_Assoc_Array_Type; Inc_Ref (Let_Result);
--# end
--# expr-done 11183
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_280;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_280;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Predefined_Operators;
--# end
--# property-start TypeDef.is_discrete_type /tmp/lal-23.0.0/ada/ast.py:4496
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Discrete_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Def :=
     Internal_Entity_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
Scope_Result : Boolean;
Fld_2 : Boolean;
Fld_3 : Boolean;
If_Result : Boolean;
Fld_4 : Boolean;
If_Result_1 : Boolean;
Result_Var : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11189 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11184 '<FieldAccess for base_type at ast.py:4497>' Fld /tmp/lal-23.0.0/ada/ast.py:4497
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11184
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
   --# bind bt Var_Expr
--# expr-start 11185 '<FieldAccess for is_discrete_type at ast.py:4498>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4498
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_discrete_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Discrete_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 11185
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
--# expr-start 11186 '<FieldAccess for is_int_type at ast.py:4500>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4500
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_int_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Int_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11186
if Fld_2 then
   If_Result := True;
else
   --# expr-start 11187 '<FieldAccess for is_enum_type at ast.py:4500>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4500
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_enum_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Enum_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11187
   If_Result := Fld_3;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 11188 '<FieldAccess for is_char_type at ast.py:4500>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4500
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.is_char_type'
Fld_4 := Libadalang.Implementation.Dispatcher_Type_Def_P_Is_Char_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11188
   If_Result_1 := Fld_4;
end if;
   Result_Var := If_Result_1;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 11189
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Discrete_Type;
--# end
--# property-start TypeDef.is_int_type /tmp/lal-23.0.0/ada/ast.py:4505
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Int_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11190 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 11190
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Int_Type;
--# end
--# property-start TypeDef.is_access_type /tmp/lal-23.0.0/ada/ast.py:4509
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Access_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Access_Type;
--# end
--# property-start TypeDef.is_char_type /tmp/lal-23.0.0/ada/ast.py:4515
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Char_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Char_Type;
--# end
--# property-start TypeDef.is_enum_type /tmp/lal-23.0.0/ada/ast.py:4516
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Enum_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Enum_Type;
--# end
--# property-start TypeDef.accessed_type /tmp/lal-23.0.0/ada/ast.py:4519
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Accessed_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11191 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := No_Entity_Base_Type_Decl; 
--# end
--# expr-done 11191
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Accessed_Type;
--# end
--# property-start TypeDef.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:4523
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Tagged_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11192 '<Block at ???>' Let_Result None
--# scope-start
Let_Result := False; 
--# end
--# expr-done 11192
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Tagged_Type;
--# end
--# property-start TypeDef.base_type /tmp/lal-23.0.0/ada/ast.py:4529
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Base_Type
  (Node : Bare_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Entity_Base_Type_Decl;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Base_Type;
--# end
--# property-start TypeDef.base_interfaces /tmp/lal-23.0.0/ada/ast.py:4545
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Base_Interfaces
  (Node : Bare_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := No_Internal_Entity_Base_Type_Decl_Array_Type;
         Inc_Ref (Property_Result);
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Base_Interfaces;
--# end
--# property-start TypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:4629
pragma Warnings (Off, "is not referenced");
 function Type_Def_P_Is_Static
  (Node : Bare_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Type_Def := Bare_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Def_P_Is_Static;
--# end
   --
   --  Primitives for Bare_Access_Def
   --
      procedure Initialize_Fields_For_Access_Def
        (Self : Bare_Access_Def
         ; Access_Def_F_Has_Not_Null : Bare_Not_Null
        ) is
      begin
            Self.Access_Def_F_Has_Not_Null := Access_Def_F_Has_Not_Null;
      end Initialize_Fields_For_Access_Def;
   function Access_Def_F_Has_Not_Null
     (Node : Bare_Access_Def) return Bare_Not_Null
   is
   begin
         return Node.Access_Def_F_Has_Not_Null;
   end;
--# property-start AccessDef.is_access_type /tmp/lal-23.0.0/ada/ast.py:8727
pragma Warnings (Off, "is not referenced");
 function Access_Def_P_Is_Access_Type
  (Node : Bare_Access_Def
      ; Origin : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Access_Def := Bare_Access_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Access_Def_P_Is_Access_Type;
--# end
--# property-start AccessDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:8730
pragma Warnings (Off, "is not referenced");
 function Access_Def_P_Predefined_Operators
  (Node : Bare_Access_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Access_Def := Bare_Access_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_716 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_716 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_716;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Access_Def_Access_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Access_Def,
                                As_Bare_Access_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11194 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11193 '<FieldAccess for predefined_equality_operators at ast.py:8731>' Fld /tmp/lal-23.0.0/ada/ast.py:8731
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.predefined_equality_operators
Fld := Libadalang.Implementation.Type_Def_P_Predefined_Equality_Operators (Node => Self);
--# end
--# expr-done 11193
Let_Result := Fld; Inc_Ref (Let_Result);
--# end
--# expr-done 11194
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_716;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_716;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Access_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Access_To_Subp_Def
   --
      procedure Access_To_Subp_Def_Pre_Env_Actions
        (Self            : Bare_Access_To_Subp_Def;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      if Add_To_Env_Only then
         return;
      end if;
      declare
         No_Parent         : constant Boolean :=
            False;
         Transitive_Parent : constant Boolean :=
            Libadalang.Implementation.Env_Trans_Parent_16 (Node => 
Self);
         Names             : Symbol_Type_Array_Access :=
            null;
      begin
         Add_Env (Self, State, No_Parent, Transitive_Parent, Names);
      end;
      end;
      procedure Initialize_Fields_For_Access_To_Subp_Def
        (Self : Bare_Access_To_Subp_Def
         ; Access_Def_F_Has_Not_Null : Bare_Not_Null
         ; Access_To_Subp_Def_F_Has_Protected : Bare_Protected_Node
         ; Access_To_Subp_Def_F_Subp_Spec : Bare_Subp_Spec
        ) is
      begin
            Initialize_Fields_For_Access_Def
              (Self, Access_Def_F_Has_Not_Null);
            Self.Access_To_Subp_Def_F_Has_Protected := Access_To_Subp_Def_F_Has_Protected;
            Self.Access_To_Subp_Def_F_Subp_Spec := Access_To_Subp_Def_F_Subp_Spec;
      end Initialize_Fields_For_Access_To_Subp_Def;
   function Access_To_Subp_Def_F_Has_Protected
     (Node : Bare_Access_To_Subp_Def) return Bare_Protected_Node
   is
   begin
         return Node.Access_To_Subp_Def_F_Has_Protected;
   end;
   function Access_To_Subp_Def_F_Subp_Spec
     (Node : Bare_Access_To_Subp_Def) return Bare_Subp_Spec
   is
   begin
         return Node.Access_To_Subp_Def_F_Subp_Spec;
   end;
--# property-start AccessToSubpDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8741
pragma Warnings (Off, "is not referenced");
 function Access_To_Subp_Def_P_Xref_Equation
  (Node : Bare_Access_To_Subp_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Access_To_Subp_Def := Bare_Access_To_Subp_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_717 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_717 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_717;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8741") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_717;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_717;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Access_To_Subp_Def_P_Xref_Equation;
--# end
--# property-start AccessToSubpDef.accessed_type /tmp/lal-23.0.0/ada/ast.py:8743
pragma Warnings (Off, "is not referenced");
 function Access_To_Subp_Def_P_Accessed_Type
  (Node : Bare_Access_To_Subp_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Access_To_Subp_Def := Bare_Access_To_Subp_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Access_To_Subp_Def :=
     Internal_Entity_Access_To_Subp_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Subp_Spec;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11196 '<FieldAccess for return_type at ast.py:8743>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8743
--# expr-start 11195 '<FieldAccess for subp_spec at ast.py:8743>' Fld /tmp/lal-23.0.0/ada/ast.py:8743
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subp_Spec (Node => Ent.Node.Access_To_Subp_Def_F_Subp_Spec, Info => Ent.Info);
--# expr-done 11195
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BaseSubpSpec.return_type
Fld_1 := Libadalang.Implementation.Base_Subp_Spec_P_Return_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11196
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Access_To_Subp_Def_P_Accessed_Type;
--# end
--# property-start AccessToSubpDef._env_trans_parent_16 /tmp/lal-23.0.0/ada/ast.py:8747
pragma Warnings (Off, "is not referenced");
 function Env_Trans_Parent_16
  (Node : Bare_Access_To_Subp_Def
  )
   return Boolean
is
   Self : Bare_Access_To_Subp_Def := Bare_Access_To_Subp_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Env_Trans_Parent_16;
--# end
   --
   --  Primitives for Bare_Base_Type_Access_Def
   --
      procedure Initialize_Fields_For_Base_Type_Access_Def
        (Self : Bare_Base_Type_Access_Def
         ; Access_Def_F_Has_Not_Null : Bare_Not_Null
        ) is
      begin
            Initialize_Fields_For_Access_Def
              (Self, Access_Def_F_Has_Not_Null);
      end Initialize_Fields_For_Base_Type_Access_Def;
   --
   --  Primitives for Bare_Anonymous_Type_Access_Def
   --
      procedure Initialize_Fields_For_Anonymous_Type_Access_Def
        (Self : Bare_Anonymous_Type_Access_Def
         ; Access_Def_F_Has_Not_Null : Bare_Not_Null
         ; Anonymous_Type_Access_Def_F_Type_Decl : Bare_Base_Type_Decl
        ) is
      begin
            Initialize_Fields_For_Base_Type_Access_Def
              (Self, Access_Def_F_Has_Not_Null);
            Self.Anonymous_Type_Access_Def_F_Type_Decl := Anonymous_Type_Access_Def_F_Type_Decl;
      end Initialize_Fields_For_Anonymous_Type_Access_Def;
   function Anonymous_Type_Access_Def_F_Type_Decl
     (Node : Bare_Anonymous_Type_Access_Def) return Bare_Base_Type_Decl
   is
   begin
         return Node.Anonymous_Type_Access_Def_F_Type_Decl;
   end;
--# property-start AnonymousTypeAccessDef.accessed_type /tmp/lal-23.0.0/ada/ast.py:8778
pragma Warnings (Off, "is not referenced");
 function Anonymous_Type_Access_Def_P_Accessed_Type
  (Node : Bare_Anonymous_Type_Access_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Anonymous_Type_Access_Def := Bare_Anonymous_Type_Access_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Type_Access_Def :=
     Internal_Entity_Anonymous_Type_Access_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11197 '<FieldAccess for type_decl at ast.py:8778>' Fld /tmp/lal-23.0.0/ada/ast.py:8778
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Base_Type_Decl (Node => Ent.Node.Anonymous_Type_Access_Def_F_Type_Decl, Info => Ent.Info);
--# expr-done 11197
      Property_Result := Fld;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Type_Access_Def_P_Accessed_Type;
--# end
   --
   --  Primitives for Bare_Type_Access_Def
   --
      procedure Initialize_Fields_For_Type_Access_Def
        (Self : Bare_Type_Access_Def
         ; Access_Def_F_Has_Not_Null : Bare_Not_Null
         ; Type_Access_Def_F_Has_All : Bare_All_Node
         ; Type_Access_Def_F_Has_Constant : Bare_Constant_Node
         ; Type_Access_Def_F_Subtype_Indication : Bare_Subtype_Indication
        ) is
      begin
            Initialize_Fields_For_Base_Type_Access_Def
              (Self, Access_Def_F_Has_Not_Null);
            Self.Type_Access_Def_F_Has_All := Type_Access_Def_F_Has_All;
            Self.Type_Access_Def_F_Has_Constant := Type_Access_Def_F_Has_Constant;
            Self.Type_Access_Def_F_Subtype_Indication := Type_Access_Def_F_Subtype_Indication;
      end Initialize_Fields_For_Type_Access_Def;
   function Type_Access_Def_F_Has_All
     (Node : Bare_Type_Access_Def) return Bare_All_Node
   is
   begin
         return Node.Type_Access_Def_F_Has_All;
   end;
   function Type_Access_Def_F_Has_Constant
     (Node : Bare_Type_Access_Def) return Bare_Constant_Node
   is
   begin
         return Node.Type_Access_Def_F_Has_Constant;
   end;
   function Type_Access_Def_F_Subtype_Indication
     (Node : Bare_Type_Access_Def) return Bare_Subtype_Indication
   is
   begin
         return Node.Type_Access_Def_F_Subtype_Indication;
   end;
--# property-start TypeAccessDef.accessed_type /tmp/lal-23.0.0/ada/ast.py:8766
pragma Warnings (Off, "is not referenced");
 function Type_Access_Def_P_Accessed_Type
  (Node : Bare_Type_Access_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Access_Def := Bare_Type_Access_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Access_Def :=
     Internal_Entity_Type_Access_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11199 '<FieldAccess for designated_type at ast.py:8766>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8766
--# expr-start 11198 '<FieldAccess for subtype_indication at ast.py:8766>' Fld /tmp/lal-23.0.0/ada/ast.py:8766
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Type_Access_Def_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11198
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11199
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Access_Def_P_Accessed_Type;
--# end
--# property-start TypeAccessDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8767
pragma Warnings (Off, "is not referenced");
 function Type_Access_Def_P_Xref_Equation
  (Node : Bare_Type_Access_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Type_Access_Def := Bare_Type_Access_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Access_Def :=
     Internal_Entity_Type_Access_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_720 with Inline_Always;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Logic_Equation;
            procedure Finalizer_Scope_720 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_720;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11201 '<FieldAccess for xref_equation at ast.py:8767>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8767
--# expr-start 11200 '<FieldAccess for subtype_indication at ast.py:8767>' Fld /tmp/lal-23.0.0/ada/ast.py:8767
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Type_Access_Def_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11200
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11201
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_720;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_720;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Access_Def_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Array_Type_Def
   --
      procedure Initialize_Fields_For_Array_Type_Def
        (Self : Bare_Array_Type_Def
         ; Array_Type_Def_F_Indices : Bare_Array_Indices
         ; Array_Type_Def_F_Component_Type : Bare_Component_Def
        ) is
      begin
            Self.Array_Type_Def_F_Indices := Array_Type_Def_F_Indices;
            Self.Array_Type_Def_F_Component_Type := Array_Type_Def_F_Component_Type;
      end Initialize_Fields_For_Array_Type_Def;
   function Array_Type_Def_F_Indices
     (Node : Bare_Array_Type_Def) return Bare_Array_Indices
   is
   begin
         return Node.Array_Type_Def_F_Indices;
   end;
   function Array_Type_Def_F_Component_Type
     (Node : Bare_Array_Type_Def) return Bare_Component_Def
   is
   begin
         return Node.Array_Type_Def_F_Component_Type;
   end;
--# property-start ArrayTypeDef.comp_type /tmp/lal-23.0.0/ada/ast.py:8394
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Comp_Type
  (Node : Bare_Array_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Array_Type_Def :=
     Internal_Entity_Array_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Component_Def;
Fld_1 : Internal_Entity_Type_Expr;
Fld_2 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11205 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11204 '<FieldAccess for designated_type at ast.py:8396>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8396
--# expr-start 11203 '<FieldAccess for type_expr at ast.py:8396>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8396
--# expr-start 11202 '<FieldAccess for component_type at ast.py:8396>' Fld /tmp/lal-23.0.0/ada/ast.py:8396
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Component_Def (Node => Ent.Node.Array_Type_Def_F_Component_Type, Info => Ent.Info);
--# expr-done 11202
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Type_Expr (Node => Fld.Node.Component_Def_F_Type_Expr, Info => Fld.Info);
--# expr-done 11203
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_1.Node, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 11204
Let_Result := Fld_2; 
--# end
--# expr-done 11205
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Comp_Type;
--# end
--# property-start ArrayTypeDef.index_type /tmp/lal-23.0.0/ada/ast.py:8399
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Index_Type
  (Node : Bare_Array_Type_Def
      ; Dim : Integer
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Array_Type_Def :=
     Internal_Entity_Array_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind dim Dim
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Array_Indices;
Fld_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11208 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11207 '<FieldAccess for index_type at ast.py:8400>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8400
--# expr-start 11206 '<FieldAccess for indices at ast.py:8400>' Fld /tmp/lal-23.0.0/ada/ast.py:8400
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Array_Indices (Node => Ent.Node.Array_Type_Def_F_Indices, Info => Ent.Info);
--# expr-done 11206
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]ArrayIndices.index_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Index_Type (Node => Fld.Node, Dim => Dim, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11207
Let_Result := Fld_1; 
--# end
--# expr-done 11208
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Index_Type;
--# end
--# property-start ArrayTypeDef.array_ndims /tmp/lal-23.0.0/ada/ast.py:8402
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Array_Ndims
  (Node : Bare_Array_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Integer;
      Fld : Bare_Array_Indices;
Fld_1 : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11210 '<FieldAccess for ndims at ast.py:8402>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8402
--# expr-start 11209 '<FieldAccess for indices at ast.py:8402>' Fld /tmp/lal-23.0.0/ada/ast.py:8402
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Array_Type_Def_F_Indices;
--# expr-done 11209
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]ArrayIndices.ndims'
Fld_1 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Ndims (Node => Fld);
--# end
--# expr-done 11210
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Array_Ndims;
--# end
--# property-start ArrayTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8405
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Xref_Equation
  (Node : Bare_Array_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Array_Type_Def :=
     Internal_Entity_Array_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_652 with Inline_Always;
      Fld : Internal_Entity_Array_Indices;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Component_Def;
Fld_3 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_652 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Fld_3);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_652;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11216 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11215 '<And at ast.py:8406>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8406
--# expr-start 11212 '<FieldAccess for sub_equation at ast.py:8407>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8407
--# expr-start 11211 '<FieldAccess for indices at ast.py:8407>' Fld /tmp/lal-23.0.0/ada/ast.py:8407
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Array_Indices (Node => Ent.Node.Array_Type_Def_F_Indices, Info => Ent.Info);
--# expr-done 11211
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11212
--# expr-start 11214 '<FieldAccess for sub_equation at ast.py:8408>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8408
--# expr-start 11213 '<FieldAccess for component_type at ast.py:8408>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8408
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Component_Def (Node => Ent.Node.Array_Type_Def_F_Component_Type, Info => Ent.Info);
--# expr-done 11213
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_2.Node, Env => Env, Origin => Origin, E_Info => Fld_2.Info);
--# end
--# expr-done 11214
And_Pred := Create_And (Fld_1, Fld_3, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8406") else null)); 
--# expr-done 11215
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 11216
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_652;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_652;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Xref_Equation;
--# end
--# property-start ArrayTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:8412
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Predefined_Operators
  (Node : Bare_Array_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_653 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Bare_Type_Expr;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Bare_Component_Def;
Fld_4 : Bare_Type_Expr;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_6 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Fld_13 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Fld_14 : Internal_Env_Assoc := No_Env_Assoc;
Sym_10 : Symbol_Type;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Fld_15 : Internal_Env_Assoc := No_Env_Assoc;
Sym_11 : Symbol_Type;
Cast_Expr_24 : Bare_Type_Decl;
Cast_Result_25 : Bare_Base_Type_Decl;
Cast_Expr_25 : Bare_Type_Decl;
Cast_Result_26 : Bare_Base_Type_Decl;
Fld_16 : Internal_Env_Assoc := No_Env_Assoc;
Sym_12 : Symbol_Type;
Cast_Expr_26 : Bare_Type_Decl;
Cast_Result_27 : Bare_Base_Type_Decl;
Cast_Expr_27 : Bare_Type_Decl;
Cast_Result_28 : Bare_Base_Type_Decl;
Fld_17 : Internal_Env_Assoc := No_Env_Assoc;
Sym_13 : Symbol_Type;
Cast_Expr_28 : Bare_Type_Decl;
Cast_Result_29 : Bare_Base_Type_Decl;
Cast_Expr_29 : Bare_Type_Decl;
Cast_Result_30 : Bare_Base_Type_Decl;
Cast_Expr_30 : Bare_Type_Decl;
Cast_Result_31 : Bare_Base_Type_Decl;
Fld_18 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_653 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_653;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Array_Type_Def_Array_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Array_Type_Def,
                                As_Bare_Array_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11252 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11218 '<Cast to TypeDecl at ast.py:8413>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8413
--# expr-start 11217 '<parent at ast.py:8413>' Fld /tmp/lal-23.0.0/ada/ast.py:8413
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11217
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11218
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11220 '<FieldAccess for node at ast.py:8414>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8414
--# expr-start 11219 '<FieldAccess for bool_type at ast.py:8414>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8414
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11219
Fld_2 := Fld_1.Node;
--# expr-done 11220
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11222 '<FieldAccess for type_expr at ast.py:8415>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8415
--# expr-start 11221 '<FieldAccess for component_type at ast.py:8415>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8415
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Self.Array_Type_Def_F_Component_Type;
--# expr-done 11221
      if Fld_3 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Fld_3.Component_Def_F_Type_Expr;
--# expr-done 11222
Block_Var_2 := Fld_4; 
--# bind comp_type_expr Block_Var_2
--# expr-start 11251 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11224 '<FieldAccess for create_binop_assoc at ast.py:8426>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8426
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11223 '<Symbol "<" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11223
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Block_Var_1);
--# end
--# expr-done 11224
--# expr-start 11226 '<FieldAccess for create_binop_assoc at ast.py:8427>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8427
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11225 '<Symbol "<=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11225
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_3, Rhs => Cast_Result_4, Ret => Block_Var_1);
--# end
--# expr-done 11226
--# expr-start 11228 '<FieldAccess for create_binop_assoc at ast.py:8428>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:8428
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11227 '<Symbol "=" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11227
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_5, Rhs => Cast_Result_6, Ret => Block_Var_1);
--# end
--# expr-done 11228
--# expr-start 11230 '<FieldAccess for create_binop_assoc at ast.py:8429>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:8429
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11229 '<Symbol "/=" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11229
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Block_Var_1);
--# end
--# expr-done 11230
--# expr-start 11232 '<FieldAccess for create_binop_assoc at ast.py:8430>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:8430
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11231 '<Symbol ">" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11231
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Cast_Result_9, Rhs => Cast_Result_10, Ret => Block_Var_1);
--# end
--# expr-done 11232
--# expr-start 11234 '<FieldAccess for create_binop_assoc at ast.py:8431>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:8431
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11233 '<Symbol ">=" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11233
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_11, Rhs => Cast_Result_12, Ret => Block_Var_1);
--# end
--# expr-done 11234
--# expr-start 11236 '<FieldAccess for create_binop_assoc at ast.py:8432>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:8432
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11235 '<Symbol "and" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_And); 
--# expr-done 11235
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_13, Rhs => Cast_Result_14, Ret => Cast_Result_15);
--# end
--# expr-done 11236
--# expr-start 11238 '<FieldAccess for create_binop_assoc at ast.py:8433>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:8433
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11237 '<Symbol "or" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Or); 
--# expr-done 11237
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_16, Rhs => Cast_Result_17, Ret => Cast_Result_18);
--# end
--# expr-done 11238
--# expr-start 11240 '<FieldAccess for create_binop_assoc at ast.py:8434>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:8434
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11239 '<Symbol "xor" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Xor); 
--# expr-done 11239
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
--# property-call-start AdaNode.create_binop_assoc
Fld_13 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_19, Rhs => Cast_Result_20, Ret => Cast_Result_21);
--# end
--# expr-done 11240
--# expr-start 11242 '<FieldAccess for create_unop_assoc at ast.py:8435>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:8435
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11241 '<Symbol "not" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Not); 
--# expr-done 11241
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
--# property-call-start AdaNode.create_unop_assoc
Fld_14 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_9, Rhs => Cast_Result_22, Ret => Cast_Result_23);
--# end
--# expr-done 11242
--# expr-start 11244 '<FieldAccess for create_binop_assoc_l_r_expr at ast.py:8438>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:8438
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11243 '<Symbol "&" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym); 
--# expr-done 11243
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
--# property-call-start AdaNode.create_binop_assoc_l_r_expr
Fld_15 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_L_R_Expr (Node => Self, Op => Sym_10, Lhs => Block_Var_2, Rhs => Block_Var_2, Ret => Cast_Result_24);
--# end
--# expr-done 11244
--# expr-start 11246 '<FieldAccess for create_binop_assoc_l_expr at ast.py:8441>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:8441
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11245 '<Symbol "&" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym); 
--# expr-done 11245
Cast_Expr_24 := Block_Var; 
      Cast_Result_25 := Cast_Expr_24;
Cast_Expr_25 := Block_Var; 
      Cast_Result_26 := Cast_Expr_25;
--# property-call-start AdaNode.create_binop_assoc_l_expr
Fld_16 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_L_Expr (Node => Self, Op => Sym_11, Lhs => Block_Var_2, Rhs => Cast_Result_25, Ret => Cast_Result_26);
--# end
--# expr-done 11246
--# expr-start 11248 '<FieldAccess for create_binop_assoc_r_expr at ast.py:8444>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:8444
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11247 '<Symbol "&" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym); 
--# expr-done 11247
Cast_Expr_26 := Block_Var; 
      Cast_Result_27 := Cast_Expr_26;
Cast_Expr_27 := Block_Var; 
      Cast_Result_28 := Cast_Expr_27;
--# property-call-start AdaNode.create_binop_assoc_r_expr
Fld_17 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc_R_Expr (Node => Self, Op => Sym_12, Lhs => Cast_Result_27, Rhs => Block_Var_2, Ret => Cast_Result_28);
--# end
--# expr-done 11248
--# expr-start 11250 '<FieldAccess for create_binop_assoc at ast.py:8447>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:8447
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11249 '<Symbol "&" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym); 
--# expr-done 11249
Cast_Expr_28 := Block_Var; 
      Cast_Result_29 := Cast_Expr_28;
Cast_Expr_29 := Block_Var; 
      Cast_Result_30 := Cast_Expr_29;
Cast_Expr_30 := Block_Var; 
      Cast_Result_31 := Cast_Expr_30;
--# property-call-start AdaNode.create_binop_assoc
Fld_18 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_13, Lhs => Cast_Result_29, Rhs => Cast_Result_30, Ret => Cast_Result_31);
--# end
--# expr-done 11250
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_5, 2 => Fld_6, 3 => Fld_7, 4 => Fld_8, 5 => Fld_9, 6 => Fld_10, 7 => Fld_11, 8 => Fld_12, 9 => Fld_13, 10 => Fld_14, 11 => Fld_15, 12 => Fld_16, 13 => Fld_17, 14 => Fld_18)); 
--# expr-done 11251
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 11252
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_653;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_653;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Predefined_Operators;
--# end
--# property-start ArrayTypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:8452
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Is_Static
  (Node : Bare_Array_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Array_Type_Def :=
     Internal_Entity_Array_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Array_Indices;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11254 '<FieldAccess for is_static at ast.py:8452>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8452
--# expr-start 11253 '<FieldAccess for indices at ast.py:8452>' Fld /tmp/lal-23.0.0/ada/ast.py:8452
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Array_Indices (Node => Ent.Node.Array_Type_Def_F_Indices, Info => Ent.Info);
--# expr-done 11253
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]ArrayIndices.is_static'
Fld_1 := Libadalang.Implementation.Dispatcher_Array_Indices_P_Is_Static (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 11254
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Is_Static;
--# end
--# property-start ArrayTypeDef.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:8454
pragma Warnings (Off, "is not referenced");
 function Array_Type_Def_P_Xref_Entry_Point
  (Node : Bare_Array_Type_Def
  )
   return Boolean
is
   Self : Bare_Array_Type_Def := Bare_Array_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Array_Type_Def_P_Xref_Entry_Point;
--# end
   --
   --  Primitives for Bare_Derived_Type_Def
   --
      procedure Initialize_Fields_For_Derived_Type_Def
        (Self : Bare_Derived_Type_Def
         ; Derived_Type_Def_F_Has_Abstract : Bare_Abstract_Node
         ; Derived_Type_Def_F_Has_Limited : Bare_Limited_Node
         ; Derived_Type_Def_F_Has_Synchronized : Bare_Synchronized_Node
         ; Derived_Type_Def_F_Subtype_Indication : Bare_Subtype_Indication
         ; Derived_Type_Def_F_Interfaces : Bare_Parent_List
         ; Derived_Type_Def_F_Record_Extension : Bare_Base_Record_Def
         ; Derived_Type_Def_F_Has_With_Private : Bare_With_Private
        ) is
      begin
            Self.Derived_Type_Def_F_Has_Abstract := Derived_Type_Def_F_Has_Abstract;
            Self.Derived_Type_Def_F_Has_Limited := Derived_Type_Def_F_Has_Limited;
            Self.Derived_Type_Def_F_Has_Synchronized := Derived_Type_Def_F_Has_Synchronized;
            Self.Derived_Type_Def_F_Subtype_Indication := Derived_Type_Def_F_Subtype_Indication;
            Self.Derived_Type_Def_F_Interfaces := Derived_Type_Def_F_Interfaces;
            Self.Derived_Type_Def_F_Record_Extension := Derived_Type_Def_F_Record_Extension;
            Self.Derived_Type_Def_F_Has_With_Private := Derived_Type_Def_F_Has_With_Private;
      end Initialize_Fields_For_Derived_Type_Def;
   function Derived_Type_Def_F_Has_Abstract
     (Node : Bare_Derived_Type_Def) return Bare_Abstract_Node
   is
   begin
         return Node.Derived_Type_Def_F_Has_Abstract;
   end;
   function Derived_Type_Def_F_Has_Limited
     (Node : Bare_Derived_Type_Def) return Bare_Limited_Node
   is
   begin
         return Node.Derived_Type_Def_F_Has_Limited;
   end;
   function Derived_Type_Def_F_Has_Synchronized
     (Node : Bare_Derived_Type_Def) return Bare_Synchronized_Node
   is
   begin
         return Node.Derived_Type_Def_F_Has_Synchronized;
   end;
   function Derived_Type_Def_F_Subtype_Indication
     (Node : Bare_Derived_Type_Def) return Bare_Subtype_Indication
   is
   begin
         return Node.Derived_Type_Def_F_Subtype_Indication;
   end;
   function Derived_Type_Def_F_Interfaces
     (Node : Bare_Derived_Type_Def) return Bare_Parent_List
   is
   begin
         return Node.Derived_Type_Def_F_Interfaces;
   end;
   function Derived_Type_Def_F_Record_Extension
     (Node : Bare_Derived_Type_Def) return Bare_Base_Record_Def
   is
   begin
         return Node.Derived_Type_Def_F_Record_Extension;
   end;
   function Derived_Type_Def_F_Has_With_Private
     (Node : Bare_Derived_Type_Def) return Bare_With_Private
   is
   begin
         return Node.Derived_Type_Def_F_Has_With_Private;
   end;
--# property-start DerivedTypeDef.array_ndims /tmp/lal-23.0.0/ada/ast.py:8095
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Array_Ndims
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Integer;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11256 '<FieldAccess for array_ndims at ast.py:8095>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8095
--# expr-start 11255 '<FieldAccess for base_type at ast.py:8095>' Fld /tmp/lal-23.0.0/ada/ast.py:8095
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11255
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11256
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Array_Ndims;
--# end
--# property-start DerivedTypeDef.base_type /tmp/lal-23.0.0/ada/ast.py:8098
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Base_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Subtype_Indication;
Fld_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11260 '<bind at ast.py:8099>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:8099
--# expr-start 11257 '<FieldAccess for origin_node at ast.py:8099>' Fld /tmp/lal-23.0.0/ada/ast.py:8099
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 11257
Bound_Origin := Fld; 
--# expr-start 11259 '<FieldAccess for designated_type at ast.py:8100>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8100
--# expr-start 11258 '<FieldAccess for subtype_indication at ast.py:8100>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8100
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Derived_Type_Def_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11258
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld_1.Node, Origin => Bound_Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 11259
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 11260
      Property_Result := Dyn_Var_Bind_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Base_Type;
--# end
--# property-start DerivedTypeDef.base_interfaces /tmp/lal-23.0.0/ada/ast.py:8103
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Base_Interfaces
  (Node : Bare_Derived_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_609 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Item_334 : Internal_Entity_Name;
Bare_Item_334 : Bare_Name;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_609 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_609;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11263 '<Map at ast.py:8104>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8104
   --# expr-start 11261 '<FieldAccess for interfaces at ast.py:8104>' Fld /tmp/lal-23.0.0/ada/ast.py:8104
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Derived_Type_Def_F_Interfaces, Info => Ent.Info);
--# expr-done 11261
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Type_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_334 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_334 := Untyped_Item_334; 
Is_Null := Bare_Item_334 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_334); 
   If_Result := As_Entity;
end if;
                  Item_334 := If_Result; 
   --# scope-start
               --# bind i Item_334
      --# expr-start 11262 '<FieldAccess for name_designated_type at ast.py:8104>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8104
      if Item_334.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Item_334.Node, E_Info => Item_334.Info);
--# end
--# expr-done 11262
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Fld_3;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11263
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_609;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_609;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Base_Interfaces;
--# end
--# property-start DerivedTypeDef.is_int_type /tmp/lal-23.0.0/ada/ast.py:8107
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Int_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11265 '<FieldAccess for is_int_type at ast.py:8107>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8107
--# expr-start 11264 '<FieldAccess for base_type at ast.py:8107>' Fld /tmp/lal-23.0.0/ada/ast.py:8107
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11264
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_int_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Int_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11265
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Int_Type;
--# end
--# property-start DerivedTypeDef.is_access_type /tmp/lal-23.0.0/ada/ast.py:8108
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Access_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      As_Entity : Internal_Entity_Derived_Type_Def;
Is_Null : Boolean;
If_Result : Internal_Entity_Derived_Type_Def;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11268 '<FieldAccess for is_access_type at ast.py:8108>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8108
--# expr-start 11267 '<FieldAccess for base_type at ast.py:8108>' Fld /tmp/lal-23.0.0/ada/ast.py:8108
--# expr-start 11266 '<as_bare_entity at ast.py:8108>' If_Result /tmp/lal-23.0.0/ada/ast.py:8108
Is_Null := Self = null; 
if Is_Null then
   If_Result := No_Entity_Derived_Type_Def;
else
As_Entity := (Info => No_Entity_Info, Node => Self); 
   If_Result := As_Entity;
end if;
--# expr-done 11266
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => If_Result.Node, Origin => Origin, E_Info => If_Result.Info);
--# end
--# expr-done 11267
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_access_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Access_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11268
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Access_Type;
--# end
--# property-start DerivedTypeDef.is_char_type /tmp/lal-23.0.0/ada/ast.py:8109
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Char_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11270 '<FieldAccess for is_char_type at ast.py:8109>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8109
--# expr-start 11269 '<FieldAccess for base_type at ast.py:8109>' Fld /tmp/lal-23.0.0/ada/ast.py:8109
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11269
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_char_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Char_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11270
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Char_Type;
--# end
--# property-start DerivedTypeDef.is_float_type /tmp/lal-23.0.0/ada/ast.py:8110
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Float_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11272 '<FieldAccess for is_float_type at ast.py:8110>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8110
--# expr-start 11271 '<FieldAccess for base_type at ast.py:8110>' Fld /tmp/lal-23.0.0/ada/ast.py:8110
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11271
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_float_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Float_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11272
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Float_Type;
--# end
--# property-start DerivedTypeDef.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:8111
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Fixed_Point
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11274 '<FieldAccess for is_fixed_point at ast.py:8111>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8111
--# expr-start 11273 '<FieldAccess for base_type at ast.py:8111>' Fld /tmp/lal-23.0.0/ada/ast.py:8111
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11273
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_fixed_point'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Fixed_Point (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11274
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Fixed_Point;
--# end
--# property-start DerivedTypeDef.accessed_type /tmp/lal-23.0.0/ada/ast.py:8112
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Accessed_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11276 '<FieldAccess for accessed_type at ast.py:8112>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8112
--# expr-start 11275 '<FieldAccess for base_type at ast.py:8112>' Fld /tmp/lal-23.0.0/ada/ast.py:8112
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11275
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11276
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Accessed_Type;
--# end
--# property-start DerivedTypeDef.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:8113
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Tagged_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Record_Def;
Is_Null : Boolean;
Not_Val : Boolean;
Fld_1 : Internal_Entity_With_Private;
Fld_2 : Boolean;
If_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 11279 '<Not at ast.py:8114>' Not_Val /tmp/lal-23.0.0/ada/ast.py:8114
--# expr-start 11278 '<IsNull at ast.py:8114>' Is_Null /tmp/lal-23.0.0/ada/ast.py:8114
--# expr-start 11277 '<FieldAccess for record_extension at ast.py:8114>' Fld /tmp/lal-23.0.0/ada/ast.py:8114
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Base_Record_Def (Node => Ent.Node.Derived_Type_Def_F_Record_Extension, Info => Ent.Info);
--# expr-done 11277
Is_Null := Fld.Node = null; 
--# expr-done 11278
Not_Val := not (Is_Null); 
--# expr-done 11279
if Not_Val then
   If_Result := True;
else
   --# expr-start 11281 '<FieldAccess for as_bool at ast.py:8114>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8114
--# expr-start 11280 '<FieldAccess for has_with_private at ast.py:8114>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8114
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_With_Private (Node => Ent.Node.Derived_Type_Def_F_Has_With_Private, Info => Ent.Info);
--# expr-done 11280
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]WithPrivate.as_bool'
Fld_2 := Libadalang.Implementation.Dispatcher_With_Private_P_As_Bool (Node => Fld_1.Node);
--# end
--# expr-done 11281
   If_Result := Fld_2;
end if;
      Property_Result := If_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Tagged_Type;
--# end
--# property-start DerivedTypeDef.is_enum_type /tmp/lal-23.0.0/ada/ast.py:8117
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Enum_Type
  (Node : Bare_Derived_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11283 '<FieldAccess for is_enum_type at ast.py:8117>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8117
--# expr-start 11282 '<FieldAccess for base_type at ast.py:8117>' Fld /tmp/lal-23.0.0/ada/ast.py:8117
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeDef.base_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Def_P_Base_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11282
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.is_enum_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Is_Enum_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11283
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Enum_Type;
--# end
--# property-start DerivedTypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:8118
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Is_Static
  (Node : Bare_Derived_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11285 '<FieldAccess for is_static_subtype at ast.py:8118>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8118
--# expr-start 11284 '<FieldAccess for subtype_indication at ast.py:8118>' Fld /tmp/lal-23.0.0/ada/ast.py:8118
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Derived_Type_Def_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11284
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.is_static_subtype
Fld_1 := Libadalang.Implementation.Subtype_Indication_P_Is_Static_Subtype (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 11285
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Is_Static;
--# end
--# property-start DerivedTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8121
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Xref_Equation
  (Node : Bare_Derived_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_619 with Inline_Always;
            procedure Finalizer_Scope_3167 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Subtype_Indication;
Fld_2 : Logic_Equation;
Fld_3 : Internal_Entity_Parent_List;
Fld_4 : Bare_Parent_List;
Fld_5 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_6 : Logic_Equation;
Item_335 : Internal_Entity_Name;
Bare_Item_335 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
And_Pred : Logic_Equation;
Dyn_Var_Bind_Result : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_619 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_2);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_619;
            procedure Finalizer_Scope_3167 is
            begin
                     Dec_Ref (Fld_6);
            end Finalizer_Scope_3167;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11295 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11294 '<bind at ast.py:8124>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:8124
--# expr-start 11286 '<FieldAccess for children_env at ast.py:8124>' Fld /tmp/lal-23.0.0/ada/ast.py:8124
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11286
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 11293 '<And at ast.py:8125>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8125
--# expr-start 11288 '<FieldAccess for xref_equation at ast.py:8125>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8125
--# expr-start 11287 '<FieldAccess for subtype_indication at ast.py:8125>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8125
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Derived_Type_Def_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11287
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_2 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld_1.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 11288
--# expr-start 11292 '<LogicAll at ast.py:8126>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8126
--# expr-start 11291 '<Map at ast.py:8126>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8126
   --# expr-start 11289 '<FieldAccess for interfaces at ast.py:8126>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8126
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Parent_List (Node => Ent.Node.Derived_Type_Def_F_Interfaces, Info => Ent.Info);
--# expr-done 11289
Fld_4 := Fld_3.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_4 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_4;
      begin
         for Untyped_Item_335 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_335 := Untyped_Item_335; 
Is_Null := Bare_Item_335 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_5 := Fld_3.Info;
As_Entity := (Info => Fld_5, Node => Bare_Item_335); 
   If_Result := As_Entity;
end if;
                  Item_335 := If_Result; 
   --# scope-start
               --# bind ifc Item_335
      --# expr-start 11290 '<FieldAccess for xref_equation at ast.py:8126>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8126
      if Item_335.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_6 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Item_335.Node, Env => Bound_Env, Origin => Origin, E_Info => Item_335.Info);
--# end
--# expr-done 11290
         declare
            Item_To_Append : constant Logic_Equation := Fld_6;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3167;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11291
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8126") else null)); 
--# expr-done 11292
And_Pred := Create_And (Fld_2, Logic_Boolean_Op, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8125") else null)); 
--# expr-done 11293
Dyn_Var_Bind_Result := And_Pred; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 11294
Let_Result := Dyn_Var_Bind_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11295
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_619;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_619;
               Finalizer_Scope_3167;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Xref_Equation;
--# end
--# property-start DerivedTypeDef.discrete_range /tmp/lal-23.0.0/ada/ast.py:8130
pragma Warnings (Off, "is not referenced");
 function Derived_Type_Def_P_Discrete_Range
  (Node : Bare_Derived_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Derived_Type_Def := Bare_Derived_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Derived_Type_Def :=
     Internal_Entity_Derived_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Internal_Discrete_Range;
Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11298 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11297 '<FieldAccess for discrete_range at ast.py:8131>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8131
--# expr-start 11296 '<FieldAccess for subtype_indication at ast.py:8131>' Fld /tmp/lal-23.0.0/ada/ast.py:8131
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Derived_Type_Def_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11296
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start SubtypeIndication.discrete_range
Fld_1 := Libadalang.Implementation.Subtype_Indication_P_Discrete_Range (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 11297
Let_Result := Fld_1; 
--# end
--# expr-done 11298
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Derived_Type_Def_P_Discrete_Range;
--# end
   --
   --  Primitives for Bare_Enum_Type_Def
   --
      procedure Initialize_Fields_For_Enum_Type_Def
        (Self : Bare_Enum_Type_Def
         ; Enum_Type_Def_F_Enum_Literals : Bare_Enum_Literal_Decl_List
        ) is
      begin
            Self.Enum_Type_Def_F_Enum_Literals := Enum_Type_Def_F_Enum_Literals;
      end Initialize_Fields_For_Enum_Type_Def;
   function Enum_Type_Def_F_Enum_Literals
     (Node : Bare_Enum_Type_Def) return Bare_Enum_Literal_Decl_List
   is
   begin
         return Node.Enum_Type_Def_F_Enum_Literals;
   end;
--# property-start EnumTypeDef.is_char_type /tmp/lal-23.0.0/ada/ast.py:7664
pragma Warnings (Off, "is not referenced");
 function Enum_Type_Def_P_Is_Char_Type
  (Node : Bare_Enum_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Enum_Type_Def := Bare_Enum_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Bare_Enum_Literal_Decl_List;
Fld_1 : Bare_Defining_Name;
Fld_2 : Bare_Name;
Is_A : Boolean;
Item_336 : Bare_Enum_Literal_Decl;
Quantifier_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11303 '<AnyQuantifier at ast.py:7664>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:7664
   --# expr-start 11299 '<FieldAccess for enum_literals at ast.py:7664>' Fld /tmp/lal-23.0.0/ada/ast.py:7664
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Enum_Type_Def_F_Enum_Literals;
--# expr-done 11299
      Quantifier_Result := False;
      if Fld = null then
      null;
      else
      declare
         Collection : constant Bare_Enum_Literal_Decl_List := Fld;
      begin
         for Untyped_Item_336 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_336 := Untyped_Item_336; 
   --# scope-start
               --# bind lit Item_336
      --# expr-start 11302 '<IsA CharLiteral at ast.py:7665>' Is_A /tmp/lal-23.0.0/ada/ast.py:7665
--# expr-start 11301 '<FieldAccess for name at ast.py:7665>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7665
--# expr-start 11300 '<FieldAccess for name at ast.py:7665>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7665
      if Item_336 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Item_336.Enum_Literal_Decl_F_Name;
--# expr-done 11300
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Fld_1.Defining_Name_F_Name;
--# expr-done 11301
Is_A := Fld_2 /= null 
and then Fld_2.Kind in Ada_Char_Literal_Range; 
--# expr-done 11302
      Quantifier_Result := Is_A;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 11303
      Property_Result := Quantifier_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Type_Def_P_Is_Char_Type;
--# end
--# property-start EnumTypeDef.is_enum_type /tmp/lal-23.0.0/ada/ast.py:7668
pragma Warnings (Off, "is not referenced");
 function Enum_Type_Def_P_Is_Enum_Type
  (Node : Bare_Enum_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Enum_Type_Def := Bare_Enum_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Type_Def_P_Is_Enum_Type;
--# end
--# property-start EnumTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:7670
pragma Warnings (Off, "is not referenced");
 function Enum_Type_Def_P_Xref_Equation
  (Node : Bare_Enum_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Enum_Type_Def := Bare_Enum_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_581 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_581 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_581;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7670") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_581;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_581;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Type_Def_P_Xref_Equation;
--# end
--# property-start EnumTypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:7672
pragma Warnings (Off, "is not referenced");
 function Enum_Type_Def_P_Is_Static
  (Node : Bare_Enum_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Enum_Type_Def := Bare_Enum_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Type_Def_P_Is_Static;
--# end
--# property-start EnumTypeDef.is_std_char_type /tmp/lal-23.0.0/ada/ast.py:7675
pragma Warnings (Off, "is not referenced");
 function Enum_Type_Def_P_Is_Std_Char_Type
  (Node : Bare_Enum_Type_Def
  )
   return Boolean
is
   Self : Bare_Enum_Type_Def := Bare_Enum_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Block_Var : Bare_Type_Decl;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Is_Equal : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Is_Equal_1 : Boolean;
If_Result : Boolean;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Bare_Base_Type_Decl;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Is_Equal_2 : Boolean;
If_Result_1 : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11315 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11305 '<Cast to TypeDecl at ast.py:7676>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7676
--# expr-start 11304 '<parent at ast.py:7676>' Fld /tmp/lal-23.0.0/ada/ast.py:7676
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11304
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11305
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11308 '<Eq at ast.py:7677>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:7677
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
--# expr-start 11307 '<FieldAccess for node at ast.py:7678>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7678
--# expr-start 11306 '<FieldAccess for std_char_type at ast.py:7678>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7678
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_char_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Std_Char_Type (Node => Self);
--# end
--# expr-done 11306
Fld_2 := Fld_1.Node;
--# expr-done 11307
Is_Equal := Cast_Result_1 = Fld_2; 
--# expr-done 11308
if Is_Equal then
   If_Result := True;
else
   --# expr-start 11311 '<Eq at ast.py:7677>' Is_Equal_1 /tmp/lal-23.0.0/ada/ast.py:7677
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
--# expr-start 11310 '<FieldAccess for node at ast.py:7679>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7679
--# expr-start 11309 '<FieldAccess for std_wide_char_type at ast.py:7679>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7679
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_wide_char_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Std_Wide_Char_Type (Node => Self);
--# end
--# expr-done 11309
Fld_4 := Fld_3.Node;
--# expr-done 11310
Is_Equal_1 := Cast_Result_2 = Fld_4; 
--# expr-done 11311
   If_Result := Is_Equal_1;
end if;
if If_Result then
   If_Result_1 := True;
else
   --# expr-start 11314 '<Eq at ast.py:7677>' Is_Equal_2 /tmp/lal-23.0.0/ada/ast.py:7677
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
--# expr-start 11313 '<FieldAccess for node at ast.py:7680>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7680
--# expr-start 11312 '<FieldAccess for std_wide_wide_char_type at ast.py:7680>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7680
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.std_wide_wide_char_type
Fld_5 := Libadalang.Implementation.Ada_Node_P_Std_Wide_Wide_Char_Type (Node => Self);
--# end
--# expr-done 11312
Fld_6 := Fld_5.Node;
--# expr-done 11313
Is_Equal_2 := Cast_Result_3 = Fld_6; 
--# expr-done 11314
   If_Result_1 := Is_Equal_2;
end if;
Let_Result := If_Result_1; 
--# end
--# expr-done 11315
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Type_Def_P_Is_Std_Char_Type;
--# end
--# property-start EnumTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:7684
pragma Warnings (Off, "is not referenced");
 function Enum_Type_Def_P_Predefined_Operators
  (Node : Bare_Enum_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Enum_Type_Def := Bare_Enum_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_584 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Internal_Env_Assoc_Array_Access;
Block_Var_3 : Internal_Env_Assoc_Array_Access;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Fld_4 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Sym_6 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit_1 : Internal_Env_Assoc_Array_Access;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Is_Equal : Boolean;
If_Result : Internal_Env_Assoc_Array_Access;
Concat_Result : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_584 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Block_Var_2);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_584;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Enum_Type_Def_Enum_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Enum_Type_Def,
                                As_Bare_Enum_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11345 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11317 '<Cast to TypeDecl at ast.py:7685>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7685
--# expr-start 11316 '<parent at ast.py:7685>' Fld /tmp/lal-23.0.0/ada/ast.py:7685
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11316
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11317
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11319 '<FieldAccess for node at ast.py:7686>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7686
--# expr-start 11318 '<FieldAccess for bool_type at ast.py:7686>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7686
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11318
Fld_2 := Fld_1.Node;
--# expr-done 11319
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11332 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11321 '<FieldAccess for create_binop_assoc at ast.py:7689>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7689
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11320 '<Symbol "<" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11320
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
--# property-call-start AdaNode.create_binop_assoc
Fld_3 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Block_Var_1);
--# end
--# expr-done 11321
--# expr-start 11323 '<FieldAccess for create_binop_assoc at ast.py:7690>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7690
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11322 '<Symbol "<=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11322
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
--# property-call-start AdaNode.create_binop_assoc
Fld_4 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_3, Rhs => Cast_Result_4, Ret => Block_Var_1);
--# end
--# expr-done 11323
--# expr-start 11325 '<FieldAccess for create_binop_assoc at ast.py:7691>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7691
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11324 '<Symbol "=" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11324
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_5, Rhs => Cast_Result_6, Ret => Block_Var_1);
--# end
--# expr-done 11325
--# expr-start 11327 '<FieldAccess for create_binop_assoc at ast.py:7692>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7692
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11326 '<Symbol "/=" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11326
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Block_Var_1);
--# end
--# expr-done 11327
--# expr-start 11329 '<FieldAccess for create_binop_assoc at ast.py:7693>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7693
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11328 '<Symbol ">" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11328
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Cast_Result_9, Rhs => Cast_Result_10, Ret => Block_Var_1);
--# end
--# expr-done 11329
--# expr-start 11331 '<FieldAccess for create_binop_assoc at ast.py:7694>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7694
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11330 '<Symbol ">=" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11330
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_11, Rhs => Cast_Result_12, Ret => Block_Var_1);
--# end
--# expr-done 11331
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_3, 2 => Fld_4, 3 => Fld_5, 4 => Fld_6, 5 => Fld_7, 6 => Fld_8)); 
--# expr-done 11332
Block_Var_2 := Array_Lit; Inc_Ref (Block_Var_2);
--# bind defaults Block_Var_2
--# expr-start 11343 '<If at ast.py:7698>' If_Result /tmp/lal-23.0.0/ada/ast.py:7698
--# expr-start 11333 '<Eq at ast.py:7699>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:7699
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
Is_Equal := Cast_Result_24 = Block_Var_1; 
--# expr-done 11333
if Is_Equal then
   --# expr-start 11342 '<ArrayLiteral at ???>' Array_Lit_1 None
--# expr-start 11335 '<FieldAccess for create_binop_assoc at ast.py:7700>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7700
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11334 '<Symbol "and" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_And); 
--# expr-done 11334
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_13, Rhs => Cast_Result_14, Ret => Cast_Result_15);
--# end
--# expr-done 11335
--# expr-start 11337 '<FieldAccess for create_binop_assoc at ast.py:7701>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7701
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11336 '<Symbol "or" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Or); 
--# expr-done 11336
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_16, Rhs => Cast_Result_17, Ret => Cast_Result_18);
--# end
--# expr-done 11337
--# expr-start 11339 '<FieldAccess for create_binop_assoc at ast.py:7702>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7702
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11338 '<Symbol "xor" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Xor); 
--# expr-done 11338
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_19, Rhs => Cast_Result_20, Ret => Cast_Result_21);
--# end
--# expr-done 11339
--# expr-start 11341 '<FieldAccess for create_unop_assoc at ast.py:7703>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7703
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11340 '<Symbol "not" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Not); 
--# expr-done 11340
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
--# property-call-start AdaNode.create_unop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_9, Rhs => Cast_Result_22, Ret => Cast_Result_23);
--# end
--# expr-done 11341
Array_Lit_1 := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_9, 2 => Fld_10, 3 => Fld_11, 4 => Fld_12)); 
--# expr-done 11342
   If_Result := Array_Lit_1;
else
   If_Result := No_Internal_Env_Assoc_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 11343
Block_Var_3 := If_Result; Inc_Ref (Block_Var_3);
--# bind specials Block_Var_3
--# expr-start 11344 '<Concat at ast.py:7707>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:7707
Concat_Result := Concat (Block_Var_2, Block_Var_3); 
--# expr-done 11344
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11345
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_584;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_584;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Type_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Formal_Discrete_Type_Def
   --
--# property-start FormalDiscreteTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8786
pragma Warnings (Off, "is not referenced");
 function Formal_Discrete_Type_Def_P_Xref_Equation
  (Node : Bare_Formal_Discrete_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Formal_Discrete_Type_Def := Bare_Formal_Discrete_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_722 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_722 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_722;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8786") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_722;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_722;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Discrete_Type_Def_P_Xref_Equation;
--# end
--# property-start FormalDiscreteTypeDef.is_discrete_type /tmp/lal-23.0.0/ada/ast.py:8788
pragma Warnings (Off, "is not referenced");
 function Formal_Discrete_Type_Def_P_Is_Discrete_Type
  (Node : Bare_Formal_Discrete_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Formal_Discrete_Type_Def := Bare_Formal_Discrete_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Discrete_Type_Def_P_Is_Discrete_Type;
--# end
--# property-start FormalDiscreteTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:8791
pragma Warnings (Off, "is not referenced");
 function Formal_Discrete_Type_Def_P_Predefined_Operators
  (Node : Bare_Formal_Discrete_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Formal_Discrete_Type_Def := Bare_Formal_Discrete_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_724 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Fld_4 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_724 is
            begin
                     Dec_Ref (Fld_3);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_724;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Formal_Discrete_Type_Def_Formal_Discrete_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Formal_Discrete_Type_Def,
                                As_Bare_Formal_Discrete_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11363 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11347 '<Cast to TypeDecl at ast.py:8792>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8792
--# expr-start 11346 '<parent at ast.py:8792>' Fld /tmp/lal-23.0.0/ada/ast.py:8792
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11346
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11347
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11349 '<FieldAccess for node at ast.py:8793>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8793
--# expr-start 11348 '<FieldAccess for bool_type at ast.py:8793>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8793
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11348
Fld_2 := Fld_1.Node;
--# expr-done 11349
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11362 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11351 '<FieldAccess for create_binop_assoc at ast.py:8795>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8795
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11350 '<Symbol "<" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11350
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
--# property-call-start AdaNode.create_binop_assoc
Fld_3 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Block_Var_1);
--# end
--# expr-done 11351
--# expr-start 11353 '<FieldAccess for create_binop_assoc at ast.py:8796>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8796
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11352 '<Symbol "<=" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11352
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
--# property-call-start AdaNode.create_binop_assoc
Fld_4 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_3, Rhs => Cast_Result_4, Ret => Block_Var_1);
--# end
--# expr-done 11353
--# expr-start 11355 '<FieldAccess for create_binop_assoc at ast.py:8797>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8797
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11354 '<Symbol "=" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11354
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_5, Rhs => Cast_Result_6, Ret => Block_Var_1);
--# end
--# expr-done 11355
--# expr-start 11357 '<FieldAccess for create_binop_assoc at ast.py:8798>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8798
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11356 '<Symbol "/=" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11356
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Block_Var_1);
--# end
--# expr-done 11357
--# expr-start 11359 '<FieldAccess for create_binop_assoc at ast.py:8799>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:8799
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11358 '<Symbol ">" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11358
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Cast_Result_9, Rhs => Cast_Result_10, Ret => Block_Var_1);
--# end
--# expr-done 11359
--# expr-start 11361 '<FieldAccess for create_binop_assoc at ast.py:8800>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:8800
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11360 '<Symbol ">=" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11360
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_11, Rhs => Cast_Result_12, Ret => Block_Var_1);
--# end
--# expr-done 11361
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_3, 2 => Fld_4, 3 => Fld_5, 4 => Fld_6, 5 => Fld_7, 6 => Fld_8)); 
--# expr-done 11362
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 11363
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_724;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_724;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Formal_Discrete_Type_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Interface_Type_Def
   --
      procedure Initialize_Fields_For_Interface_Type_Def
        (Self : Bare_Interface_Type_Def
         ; Interface_Type_Def_F_Interface_Kind : Bare_Interface_Kind
         ; Interface_Type_Def_F_Interfaces : Bare_Parent_List
        ) is
      begin
            Self.Interface_Type_Def_F_Interface_Kind := Interface_Type_Def_F_Interface_Kind;
            Self.Interface_Type_Def_F_Interfaces := Interface_Type_Def_F_Interfaces;
      end Initialize_Fields_For_Interface_Type_Def;
   function Interface_Type_Def_F_Interface_Kind
     (Node : Bare_Interface_Type_Def) return Bare_Interface_Kind
   is
   begin
         return Node.Interface_Type_Def_F_Interface_Kind;
   end;
   function Interface_Type_Def_F_Interfaces
     (Node : Bare_Interface_Type_Def) return Bare_Parent_List
   is
   begin
         return Node.Interface_Type_Def_F_Interfaces;
   end;
--# property-start InterfaceTypeDef.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:8472
pragma Warnings (Off, "is not referenced");
 function Interface_Type_Def_P_Is_Tagged_Type
  (Node : Bare_Interface_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Interface_Type_Def := Bare_Interface_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Interface_Type_Def_P_Is_Tagged_Type;
--# end
--# property-start InterfaceTypeDef.base_interfaces /tmp/lal-23.0.0/ada/ast.py:8474
pragma Warnings (Off, "is not referenced");
 function Interface_Type_Def_P_Base_Interfaces
  (Node : Bare_Interface_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl_Array_Access
is
   Self : Bare_Interface_Type_Def := Bare_Interface_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Interface_Type_Def :=
     Internal_Entity_Interface_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_657 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Internal_Entity_Base_Type_Decl;
Item_337 : Internal_Entity_Name;
Bare_Item_337 : Bare_Name;
Map_Result : Internal_Entity_Base_Type_Decl_Array_Access;
            procedure Finalizer_Scope_657 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_657;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11366 '<Map at ast.py:8475>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8475
   --# expr-start 11364 '<FieldAccess for interfaces at ast.py:8475>' Fld /tmp/lal-23.0.0/ada/ast.py:8475
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Interface_Type_Def_F_Interfaces, Info => Ent.Info);
--# expr-done 11364
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Internal_Entity_Base_Type_Decl_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Internal_Entity_Base_Type_Decl_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_337 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_337 := Untyped_Item_337; 
Is_Null := Bare_Item_337 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_337); 
   If_Result := As_Entity;
end if;
                  Item_337 := If_Result; 
   --# scope-start
               --# bind i Item_337
      --# expr-start 11365 '<FieldAccess for name_designated_type at ast.py:8475>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8475
      if Item_337.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_3 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Item_337.Node, E_Info => Item_337.Info);
--# end
--# expr-done 11365
         declare
            Item_To_Append : constant Internal_Entity_Base_Type_Decl := Fld_3;
         begin
            Internal_Entity_Base_Type_Decl_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Entity_Base_Type_Decl_Array
           (Items_Count => Natural (Internal_Entity_Base_Type_Decl_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Entity_Base_Type_Decl_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Entity_Base_Type_Decl_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Entity_Base_Type_Decl_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11366
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_657;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_657;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Interface_Type_Def_P_Base_Interfaces;
--# end
--# property-start InterfaceTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8479
pragma Warnings (Off, "is not referenced");
 function Interface_Type_Def_P_Xref_Equation
  (Node : Bare_Interface_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Interface_Type_Def := Bare_Interface_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Interface_Type_Def :=
     Internal_Entity_Interface_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_658 with Inline_Always;
            procedure Finalizer_Scope_3170 with Inline_Always;
      Fld : Internal_Entity_Parent_List;
Fld_1 : Bare_Parent_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Item_338 : Internal_Entity_Name;
Bare_Item_338 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_658 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_658;
            procedure Finalizer_Scope_3170 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3170;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11371 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11370 '<LogicAll at ast.py:8480>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8480
--# expr-start 11369 '<Map at ast.py:8480>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8480
   --# expr-start 11367 '<FieldAccess for interfaces at ast.py:8480>' Fld /tmp/lal-23.0.0/ada/ast.py:8480
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Parent_List (Node => Ent.Node.Interface_Type_Def_F_Interfaces, Info => Ent.Info);
--# expr-done 11367
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Parent_List := Fld_1;
      begin
         for Untyped_Item_338 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_338 := Untyped_Item_338; 
Is_Null := Bare_Item_338 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_338); 
   If_Result := As_Entity;
end if;
                  Item_338 := If_Result; 
   --# scope-start
               --# bind ifc Item_338
      --# expr-start 11368 '<FieldAccess for xref_equation at ast.py:8480>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8480
      if Item_338.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_3 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Item_338.Node, Env => Env, Origin => Origin, E_Info => Item_338.Info);
--# end
--# expr-done 11368
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3170;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11369
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8480") else null)); 
--# expr-done 11370
Let_Result := Logic_Boolean_Op; Inc_Ref (Let_Result);
--# end
--# expr-done 11371
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_658;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_658;
               Finalizer_Scope_3170;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Interface_Type_Def_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Mod_Int_Type_Def
   --
      procedure Initialize_Fields_For_Mod_Int_Type_Def
        (Self : Bare_Mod_Int_Type_Def
         ; Mod_Int_Type_Def_F_Expr : Bare_Expr
        ) is
      begin
            Self.Mod_Int_Type_Def_F_Expr := Mod_Int_Type_Def_F_Expr;
      end Initialize_Fields_For_Mod_Int_Type_Def;
   function Mod_Int_Type_Def_F_Expr
     (Node : Bare_Mod_Int_Type_Def) return Bare_Expr
   is
   begin
         return Node.Mod_Int_Type_Def_F_Expr;
   end;
--# property-start ModIntTypeDef.is_int_type /tmp/lal-23.0.0/ada/ast.py:8210
pragma Warnings (Off, "is not referenced");
 function Mod_Int_Type_Def_P_Is_Int_Type
  (Node : Bare_Mod_Int_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Mod_Int_Type_Def := Bare_Mod_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Mod_Int_Type_Def_P_Is_Int_Type;
--# end
--# property-start ModIntTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8212
pragma Warnings (Off, "is not referenced");
 function Mod_Int_Type_Def_P_Xref_Equation
  (Node : Bare_Mod_Int_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Mod_Int_Type_Def := Bare_Mod_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Mod_Int_Type_Def :=
     Internal_Entity_Mod_Int_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_630 with Inline_Always;
      Fld : Internal_Entity_Expr;
Fld_1 : Logic_Equation;
            procedure Finalizer_Scope_630 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_630;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11373 '<FieldAccess for sub_equation at ast.py:8212>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8212
--# expr-start 11372 '<FieldAccess for expr at ast.py:8212>' Fld /tmp/lal-23.0.0/ada/ast.py:8212
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Mod_Int_Type_Def_F_Expr, Info => Ent.Info);
--# expr-done 11372
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11373
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_630;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_630;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Mod_Int_Type_Def_P_Xref_Equation;
--# end
--# property-start ModIntTypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:8214
pragma Warnings (Off, "is not referenced");
 function Mod_Int_Type_Def_P_Is_Static
  (Node : Bare_Mod_Int_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Mod_Int_Type_Def := Bare_Mod_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Mod_Int_Type_Def :=
     Internal_Entity_Mod_Int_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Expr;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11375 '<FieldAccess for is_static_expr at ast.py:8214>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8214
--# expr-start 11374 '<FieldAccess for expr at ast.py:8214>' Fld /tmp/lal-23.0.0/ada/ast.py:8214
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Mod_Int_Type_Def_F_Expr, Info => Ent.Info);
--# expr-done 11374
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_1 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld.Info);
--# end
--# expr-done 11375
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Mod_Int_Type_Def_P_Is_Static;
--# end
--# property-start ModIntTypeDef.discrete_range /tmp/lal-23.0.0/ada/ast.py:8217
pragma Warnings (Off, "is not referenced");
 function Mod_Int_Type_Def_P_Discrete_Range
  (Node : Bare_Mod_Int_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Mod_Int_Type_Def := Bare_Mod_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Mod_Int_Type_Def :=
     Internal_Entity_Mod_Int_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Fld : Internal_Entity_Expr;
New_Struct : Internal_Discrete_Range;
Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11378 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11377 '<New DiscreteRange at ast.py:8218>' New_Struct /tmp/lal-23.0.0/ada/ast.py:8218
--# expr-start 11376 '<FieldAccess for expr at ast.py:8219>' Fld /tmp/lal-23.0.0/ada/ast.py:8219
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Mod_Int_Type_Def_F_Expr, Info => Ent.Info);
--# expr-done 11376
New_Struct := (High_Bound => Fld, Low_Bound => No_Entity_Expr); 
--# expr-done 11377
Let_Result := New_Struct; 
--# end
--# expr-done 11378
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Mod_Int_Type_Def_P_Discrete_Range;
--# end
--# property-start ModIntTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:8222
pragma Warnings (Off, "is not referenced");
 function Mod_Int_Type_Def_P_Predefined_Operators
  (Node : Bare_Mod_Int_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Mod_Int_Type_Def := Bare_Mod_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_633 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Bare_Base_Type_Decl;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_6 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_24 : Bare_Type_Decl;
Cast_Result_25 : Bare_Base_Type_Decl;
Cast_Expr_25 : Bare_Type_Decl;
Cast_Result_26 : Bare_Base_Type_Decl;
Fld_13 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_26 : Bare_Type_Decl;
Cast_Result_27 : Bare_Base_Type_Decl;
Cast_Expr_27 : Bare_Type_Decl;
Cast_Result_28 : Bare_Base_Type_Decl;
Fld_14 : Internal_Env_Assoc := No_Env_Assoc;
Sym_10 : Symbol_Type;
Cast_Expr_28 : Bare_Type_Decl;
Cast_Result_29 : Bare_Base_Type_Decl;
Cast_Expr_29 : Bare_Type_Decl;
Cast_Result_30 : Bare_Base_Type_Decl;
Fld_15 : Internal_Env_Assoc := No_Env_Assoc;
Sym_11 : Symbol_Type;
Cast_Expr_30 : Bare_Type_Decl;
Cast_Result_31 : Bare_Base_Type_Decl;
Cast_Expr_31 : Bare_Type_Decl;
Cast_Result_32 : Bare_Base_Type_Decl;
Fld_16 : Internal_Env_Assoc := No_Env_Assoc;
Sym_12 : Symbol_Type;
Cast_Expr_32 : Bare_Type_Decl;
Cast_Result_33 : Bare_Base_Type_Decl;
Cast_Expr_33 : Bare_Type_Decl;
Cast_Result_34 : Bare_Base_Type_Decl;
Fld_17 : Internal_Env_Assoc := No_Env_Assoc;
Sym_13 : Symbol_Type;
Cast_Expr_34 : Bare_Type_Decl;
Cast_Result_35 : Bare_Base_Type_Decl;
Cast_Expr_35 : Bare_Type_Decl;
Cast_Result_36 : Bare_Base_Type_Decl;
Fld_18 : Internal_Env_Assoc := No_Env_Assoc;
Sym_14 : Symbol_Type;
Cast_Expr_36 : Bare_Type_Decl;
Cast_Result_37 : Bare_Base_Type_Decl;
Cast_Expr_37 : Bare_Type_Decl;
Cast_Result_38 : Bare_Base_Type_Decl;
Fld_19 : Internal_Env_Assoc := No_Env_Assoc;
Sym_15 : Symbol_Type;
Cast_Expr_38 : Bare_Type_Decl;
Cast_Result_39 : Bare_Base_Type_Decl;
Cast_Expr_39 : Bare_Type_Decl;
Cast_Result_40 : Bare_Base_Type_Decl;
Fld_20 : Internal_Env_Assoc := No_Env_Assoc;
Sym_16 : Symbol_Type;
Cast_Expr_40 : Bare_Type_Decl;
Cast_Result_41 : Bare_Base_Type_Decl;
Cast_Expr_41 : Bare_Type_Decl;
Cast_Result_42 : Bare_Base_Type_Decl;
Fld_21 : Internal_Env_Assoc := No_Env_Assoc;
Sym_17 : Symbol_Type;
Cast_Expr_42 : Bare_Type_Decl;
Cast_Result_43 : Bare_Base_Type_Decl;
Cast_Expr_43 : Bare_Type_Decl;
Cast_Result_44 : Bare_Base_Type_Decl;
Fld_22 : Internal_Env_Assoc := No_Env_Assoc;
Sym_18 : Symbol_Type;
Cast_Expr_44 : Bare_Type_Decl;
Cast_Result_45 : Bare_Base_Type_Decl;
Cast_Expr_45 : Bare_Type_Decl;
Cast_Result_46 : Bare_Base_Type_Decl;
Fld_23 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_633 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Fld_22);
                     Dec_Ref (Fld_23);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_633;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Mod_Int_Type_Def_Mod_Int_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Mod_Int_Type_Def,
                                As_Bare_Mod_Int_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11424 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11380 '<Cast to TypeDecl at ast.py:8223>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8223
--# expr-start 11379 '<parent at ast.py:8223>' Fld /tmp/lal-23.0.0/ada/ast.py:8223
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11379
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11380
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11382 '<FieldAccess for node at ast.py:8224>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8224
--# expr-start 11381 '<FieldAccess for bool_type at ast.py:8224>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8224
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11381
Fld_2 := Fld_1.Node;
--# expr-done 11382
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11384 '<FieldAccess for node at ast.py:8225>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8225
--# expr-start 11383 '<FieldAccess for int_type at ast.py:8225>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8225
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 11383
Fld_4 := Fld_3.Node;
--# expr-done 11384
Block_Var_2 := Fld_4; 
--# bind int_type Block_Var_2
--# expr-start 11423 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11386 '<FieldAccess for create_binop_assoc at ast.py:8228>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8228
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11385 '<Symbol "+" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11385
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Cast_Result_3);
--# end
--# expr-done 11386
--# expr-start 11388 '<FieldAccess for create_binop_assoc at ast.py:8229>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8229
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11387 '<Symbol "-" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11387
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_4, Rhs => Cast_Result_5, Ret => Cast_Result_6);
--# end
--# expr-done 11388
--# expr-start 11390 '<FieldAccess for create_binop_assoc at ast.py:8230>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:8230
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11389 '<Symbol "*" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11389
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Cast_Result_9);
--# end
--# expr-done 11390
--# expr-start 11392 '<FieldAccess for create_binop_assoc at ast.py:8231>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:8231
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11391 '<Symbol "/" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11391
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_10, Rhs => Cast_Result_11, Ret => Cast_Result_12);
--# end
--# expr-done 11392
--# expr-start 11394 '<FieldAccess for create_binop_assoc at ast.py:8232>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:8232
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11393 '<Symbol "mod" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod); 
--# expr-done 11393
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Cast_Result_13, Rhs => Cast_Result_14, Ret => Cast_Result_15);
--# end
--# expr-done 11394
--# expr-start 11396 '<FieldAccess for create_binop_assoc at ast.py:8233>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:8233
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11395 '<Symbol "rem" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rem); 
--# expr-done 11395
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_16, Rhs => Cast_Result_17, Ret => Cast_Result_18);
--# end
--# expr-done 11396
--# expr-start 11398 '<FieldAccess for create_binop_assoc at ast.py:8234>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:8234
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11397 '<Symbol "and" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_And); 
--# expr-done 11397
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_19, Rhs => Cast_Result_20, Ret => Cast_Result_21);
--# end
--# expr-done 11398
--# expr-start 11400 '<FieldAccess for create_binop_assoc at ast.py:8235>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:8235
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11399 '<Symbol "or" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Or); 
--# expr-done 11399
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
--# property-call-start AdaNode.create_binop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_22, Rhs => Cast_Result_23, Ret => Cast_Result_24);
--# end
--# expr-done 11400
--# expr-start 11402 '<FieldAccess for create_binop_assoc at ast.py:8237>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:8237
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11401 '<Symbol "**" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_3); 
--# expr-done 11401
Cast_Expr_24 := Block_Var; 
      Cast_Result_25 := Cast_Expr_24;
Cast_Expr_25 := Block_Var; 
      Cast_Result_26 := Cast_Expr_25;
--# property-call-start AdaNode.create_binop_assoc
Fld_13 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_25, Rhs => Block_Var_2, Ret => Cast_Result_26);
--# end
--# expr-done 11402
--# expr-start 11404 '<FieldAccess for create_binop_assoc at ast.py:8239>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:8239
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11403 '<Symbol "<" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11403
Cast_Expr_26 := Block_Var; 
      Cast_Result_27 := Cast_Expr_26;
Cast_Expr_27 := Block_Var; 
      Cast_Result_28 := Cast_Expr_27;
--# property-call-start AdaNode.create_binop_assoc
Fld_14 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_9, Lhs => Cast_Result_27, Rhs => Cast_Result_28, Ret => Block_Var_1);
--# end
--# expr-done 11404
--# expr-start 11406 '<FieldAccess for create_binop_assoc at ast.py:8240>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:8240
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11405 '<Symbol "<=" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11405
Cast_Expr_28 := Block_Var; 
      Cast_Result_29 := Cast_Expr_28;
Cast_Expr_29 := Block_Var; 
      Cast_Result_30 := Cast_Expr_29;
--# property-call-start AdaNode.create_binop_assoc
Fld_15 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_10, Lhs => Cast_Result_29, Rhs => Cast_Result_30, Ret => Block_Var_1);
--# end
--# expr-done 11406
--# expr-start 11408 '<FieldAccess for create_binop_assoc at ast.py:8241>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:8241
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11407 '<Symbol "=" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11407
Cast_Expr_30 := Block_Var; 
      Cast_Result_31 := Cast_Expr_30;
Cast_Expr_31 := Block_Var; 
      Cast_Result_32 := Cast_Expr_31;
--# property-call-start AdaNode.create_binop_assoc
Fld_16 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_11, Lhs => Cast_Result_31, Rhs => Cast_Result_32, Ret => Block_Var_1);
--# end
--# expr-done 11408
--# expr-start 11410 '<FieldAccess for create_binop_assoc at ast.py:8242>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:8242
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11409 '<Symbol "/=" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11409
Cast_Expr_32 := Block_Var; 
      Cast_Result_33 := Cast_Expr_32;
Cast_Expr_33 := Block_Var; 
      Cast_Result_34 := Cast_Expr_33;
--# property-call-start AdaNode.create_binop_assoc
Fld_17 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_12, Lhs => Cast_Result_33, Rhs => Cast_Result_34, Ret => Block_Var_1);
--# end
--# expr-done 11410
--# expr-start 11412 '<FieldAccess for create_binop_assoc at ast.py:8243>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:8243
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11411 '<Symbol ">" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11411
Cast_Expr_34 := Block_Var; 
      Cast_Result_35 := Cast_Expr_34;
Cast_Expr_35 := Block_Var; 
      Cast_Result_36 := Cast_Expr_35;
--# property-call-start AdaNode.create_binop_assoc
Fld_18 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_13, Lhs => Cast_Result_35, Rhs => Cast_Result_36, Ret => Block_Var_1);
--# end
--# expr-done 11412
--# expr-start 11414 '<FieldAccess for create_binop_assoc at ast.py:8244>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:8244
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11413 '<Symbol ">=" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11413
Cast_Expr_36 := Block_Var; 
      Cast_Result_37 := Cast_Expr_36;
Cast_Expr_37 := Block_Var; 
      Cast_Result_38 := Cast_Expr_37;
--# property-call-start AdaNode.create_binop_assoc
Fld_19 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_14, Lhs => Cast_Result_37, Rhs => Cast_Result_38, Ret => Block_Var_1);
--# end
--# expr-done 11414
--# expr-start 11416 '<FieldAccess for create_unop_assoc at ast.py:8246>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:8246
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11415 '<Symbol "+" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11415
Cast_Expr_38 := Block_Var; 
      Cast_Result_39 := Cast_Expr_38;
Cast_Expr_39 := Block_Var; 
      Cast_Result_40 := Cast_Expr_39;
--# property-call-start AdaNode.create_unop_assoc
Fld_20 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_15, Rhs => Cast_Result_39, Ret => Cast_Result_40);
--# end
--# expr-done 11416
--# expr-start 11418 '<FieldAccess for create_unop_assoc at ast.py:8247>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:8247
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11417 '<Symbol "-" at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11417
Cast_Expr_40 := Block_Var; 
      Cast_Result_41 := Cast_Expr_40;
Cast_Expr_41 := Block_Var; 
      Cast_Result_42 := Cast_Expr_41;
--# property-call-start AdaNode.create_unop_assoc
Fld_21 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_16, Rhs => Cast_Result_41, Ret => Cast_Result_42);
--# end
--# expr-done 11418
--# expr-start 11420 '<FieldAccess for create_unop_assoc at ast.py:8248>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:8248
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11419 '<Symbol "abs" at ???>' Sym_17 None
Sym_17 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 11419
Cast_Expr_42 := Block_Var; 
      Cast_Result_43 := Cast_Expr_42;
Cast_Expr_43 := Block_Var; 
      Cast_Result_44 := Cast_Expr_43;
--# property-call-start AdaNode.create_unop_assoc
Fld_22 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_17, Rhs => Cast_Result_43, Ret => Cast_Result_44);
--# end
--# expr-done 11420
--# expr-start 11422 '<FieldAccess for create_unop_assoc at ast.py:8249>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:8249
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11421 '<Symbol "not" at ???>' Sym_18 None
Sym_18 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Not); 
--# expr-done 11421
Cast_Expr_44 := Block_Var; 
      Cast_Result_45 := Cast_Expr_44;
Cast_Expr_45 := Block_Var; 
      Cast_Result_46 := Cast_Expr_45;
--# property-call-start AdaNode.create_unop_assoc
Fld_23 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_18, Rhs => Cast_Result_45, Ret => Cast_Result_46);
--# end
--# expr-done 11422
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_5, 2 => Fld_6, 3 => Fld_7, 4 => Fld_8, 5 => Fld_9, 6 => Fld_10, 7 => Fld_11, 8 => Fld_12, 9 => Fld_13, 10 => Fld_14, 11 => Fld_15, 12 => Fld_16, 13 => Fld_17, 14 => Fld_18, 15 => Fld_19, 16 => Fld_20, 17 => Fld_21, 18 => Fld_22, 19 => Fld_23)); 
--# expr-done 11423
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 11424
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_633;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_633;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Mod_Int_Type_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Private_Type_Def
   --
      procedure Initialize_Fields_For_Private_Type_Def
        (Self : Bare_Private_Type_Def
         ; Private_Type_Def_F_Has_Abstract : Bare_Abstract_Node
         ; Private_Type_Def_F_Has_Tagged : Bare_Tagged_Node
         ; Private_Type_Def_F_Has_Limited : Bare_Limited_Node
        ) is
      begin
            Self.Private_Type_Def_F_Has_Abstract := Private_Type_Def_F_Has_Abstract;
            Self.Private_Type_Def_F_Has_Tagged := Private_Type_Def_F_Has_Tagged;
            Self.Private_Type_Def_F_Has_Limited := Private_Type_Def_F_Has_Limited;
      end Initialize_Fields_For_Private_Type_Def;
   function Private_Type_Def_F_Has_Abstract
     (Node : Bare_Private_Type_Def) return Bare_Abstract_Node
   is
   begin
         return Node.Private_Type_Def_F_Has_Abstract;
   end;
   function Private_Type_Def_F_Has_Tagged
     (Node : Bare_Private_Type_Def) return Bare_Tagged_Node
   is
   begin
         return Node.Private_Type_Def_F_Has_Tagged;
   end;
   function Private_Type_Def_F_Has_Limited
     (Node : Bare_Private_Type_Def) return Bare_Limited_Node
   is
   begin
         return Node.Private_Type_Def_F_Has_Limited;
   end;
--# property-start PrivateTypeDef.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:8146
pragma Warnings (Off, "is not referenced");
 function Private_Type_Def_P_Is_Tagged_Type
  (Node : Bare_Private_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Private_Type_Def := Bare_Private_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Bare_Tagged_Node;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11426 '<FieldAccess for as_bool at ast.py:8146>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8146
--# expr-start 11425 '<FieldAccess for has_tagged at ast.py:8146>' Fld /tmp/lal-23.0.0/ada/ast.py:8146
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Private_Type_Def_F_Has_Tagged;
--# expr-done 11425
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Tagged.as_bool'
Fld_1 := Libadalang.Implementation.Dispatcher_Tagged_Node_P_As_Bool (Node => Fld);
--# end
--# expr-done 11426
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Type_Def_P_Is_Tagged_Type;
--# end
--# property-start PrivateTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8148
pragma Warnings (Off, "is not referenced");
 function Private_Type_Def_P_Xref_Equation
  (Node : Bare_Private_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Private_Type_Def := Bare_Private_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_622 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_622 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_622;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8148") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_622;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_622;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Type_Def_P_Xref_Equation;
--# end
--# property-start PrivateTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:8151
pragma Warnings (Off, "is not referenced");
 function Private_Type_Def_P_Predefined_Operators
  (Node : Bare_Private_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Private_Type_Def := Bare_Private_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_623 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
Fld_1 : Bare_Limited_Node;
Fld_2 : Boolean;
If_Result : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_623 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_623;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Private_Type_Def_Private_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Private_Type_Def,
                                As_Bare_Private_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11431 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11430 '<If at ast.py:8152>' If_Result /tmp/lal-23.0.0/ada/ast.py:8152
--# expr-start 11428 '<FieldAccess for as_bool at ast.py:8153>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8153
--# expr-start 11427 '<FieldAccess for has_limited at ast.py:8153>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8153
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Private_Type_Def_F_Has_Limited;
--# expr-done 11427
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Limited.as_bool'
Fld_2 := Libadalang.Implementation.Dispatcher_Limited_Node_P_As_Bool (Node => Fld_1);
--# end
--# expr-done 11428
if Fld_2 then
   If_Result := No_Internal_Env_Assoc_Array_Type;
else
   --# expr-start 11429 '<FieldAccess for predefined_equality_operators at ast.py:8155>' Fld /tmp/lal-23.0.0/ada/ast.py:8155
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.predefined_equality_operators
Fld := Libadalang.Implementation.Type_Def_P_Predefined_Equality_Operators (Node => Self);
--# end
--# expr-done 11429
   If_Result := Fld;
end if;
      Inc_Ref (If_Result);
--# expr-done 11430
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11431
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_623;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_623;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Private_Type_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Real_Type_Def
   --
--# property-start RealTypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:5104
pragma Warnings (Off, "is not referenced");
 function Real_Type_Def_P_Is_Static
  (Node : Bare_Real_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Real_Type_Def := Bare_Real_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Real_Type_Def_P_Is_Static;
--# end
--# property-start RealTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:5107
pragma Warnings (Off, "is not referenced");
 function Real_Type_Def_P_Predefined_Operators
  (Node : Bare_Real_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Real_Type_Def := Bare_Real_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_367 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Bare_Base_Type_Decl;
Block_Var_3 : Bare_Base_Type_Decl;
Block_Var_4 : Internal_Env_Assoc_Array_Access;
Block_Var_5 : Internal_Env_Assoc_Array_Access;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
Fld_5 : Internal_Entity_Base_Type_Decl;
Fld_6 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Sym_6 : Symbol_Type;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_13 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Fld_14 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Fld_15 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Fld_16 : Internal_Env_Assoc := No_Env_Assoc;
Sym_10 : Symbol_Type;
Cast_Expr_24 : Bare_Type_Decl;
Cast_Result_25 : Bare_Base_Type_Decl;
Cast_Expr_25 : Bare_Type_Decl;
Cast_Result_26 : Bare_Base_Type_Decl;
Fld_17 : Internal_Env_Assoc := No_Env_Assoc;
Sym_11 : Symbol_Type;
Cast_Expr_26 : Bare_Type_Decl;
Cast_Result_27 : Bare_Base_Type_Decl;
Cast_Expr_27 : Bare_Type_Decl;
Cast_Result_28 : Bare_Base_Type_Decl;
Fld_18 : Internal_Env_Assoc := No_Env_Assoc;
Sym_12 : Symbol_Type;
Cast_Expr_28 : Bare_Type_Decl;
Cast_Result_29 : Bare_Base_Type_Decl;
Cast_Expr_29 : Bare_Type_Decl;
Cast_Result_30 : Bare_Base_Type_Decl;
Fld_19 : Internal_Env_Assoc := No_Env_Assoc;
Sym_13 : Symbol_Type;
Cast_Expr_30 : Bare_Type_Decl;
Cast_Result_31 : Bare_Base_Type_Decl;
Cast_Expr_31 : Bare_Type_Decl;
Cast_Result_32 : Bare_Base_Type_Decl;
Fld_20 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Sym_14 : Symbol_Type;
Cast_Expr_32 : Bare_Type_Decl;
Cast_Result_33 : Bare_Base_Type_Decl;
Cast_Expr_33 : Bare_Type_Decl;
Cast_Result_34 : Bare_Base_Type_Decl;
Fld_21 : Internal_Env_Assoc := No_Env_Assoc;
Sym_15 : Symbol_Type;
Cast_Expr_34 : Bare_Type_Decl;
Cast_Result_35 : Bare_Base_Type_Decl;
Cast_Expr_35 : Bare_Type_Decl;
Cast_Result_36 : Bare_Base_Type_Decl;
Fld_22 : Internal_Env_Assoc := No_Env_Assoc;
Sym_16 : Symbol_Type;
Cast_Expr_36 : Bare_Type_Decl;
Cast_Result_37 : Bare_Base_Type_Decl;
Cast_Expr_37 : Bare_Type_Decl;
Cast_Result_38 : Bare_Base_Type_Decl;
Fld_23 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit_1 : Internal_Env_Assoc_Array_Access;
Fld_24 : Internal_Entity_Base_Type_Decl;
Fld_25 : Bare_Base_Type_Decl;
Cast_Expr_38 : Bare_Type_Decl;
Cast_Result_39 : Bare_Base_Type_Decl;
Is_Equal : Boolean;
If_Result : Internal_Env_Assoc_Array_Access;
Concat_Result : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_367 is
            begin
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Block_Var_4);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Fld_22);
                     Dec_Ref (Fld_23);
                     Dec_Ref (Array_Lit_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Block_Var_5);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_367;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Real_Type_Def_Real_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Real_Type_Def,
                                As_Bare_Real_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11481 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11433 '<Cast to TypeDecl at ast.py:5108>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:5108
--# expr-start 11432 '<parent at ast.py:5108>' Fld /tmp/lal-23.0.0/ada/ast.py:5108
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11432
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11433
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11435 '<FieldAccess for node at ast.py:5109>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5109
--# expr-start 11434 '<FieldAccess for bool_type at ast.py:5109>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5109
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11434
Fld_2 := Fld_1.Node;
--# expr-done 11435
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11437 '<FieldAccess for node at ast.py:5110>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:5110
--# expr-start 11436 '<FieldAccess for int_type at ast.py:5110>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:5110
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 11436
Fld_4 := Fld_3.Node;
--# expr-done 11437
Block_Var_2 := Fld_4; 
--# bind int_type Block_Var_2
--# expr-start 11439 '<FieldAccess for node at ast.py:5111>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:5111
--# expr-start 11438 '<FieldAccess for root_int_type at ast.py:5111>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:5111
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_int_type
Fld_5 := Libadalang.Implementation.Ada_Node_P_Root_Int_Type (Node => Self);
--# end
--# expr-done 11438
Fld_6 := Fld_5.Node;
--# expr-done 11439
Block_Var_3 := Fld_6; 
--# bind root_int_type Block_Var_3
--# expr-start 11468 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11441 '<FieldAccess for create_binop_assoc at ast.py:5114>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:5114
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11440 '<Symbol "+" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11440
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Cast_Result_3);
--# end
--# expr-done 11441
--# expr-start 11443 '<FieldAccess for create_binop_assoc at ast.py:5115>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:5115
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11442 '<Symbol "-" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11442
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_4, Rhs => Cast_Result_5, Ret => Cast_Result_6);
--# end
--# expr-done 11443
--# expr-start 11445 '<FieldAccess for create_binop_assoc at ast.py:5116>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:5116
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11444 '<Symbol "*" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11444
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Cast_Result_9);
--# end
--# expr-done 11445
--# expr-start 11447 '<FieldAccess for create_binop_assoc at ast.py:5117>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:5117
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11446 '<Symbol "/" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11446
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_10, Rhs => Cast_Result_11, Ret => Cast_Result_12);
--# end
--# expr-done 11447
--# expr-start 11449 '<FieldAccess for create_binop_assoc at ast.py:5119>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:5119
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11448 '<Symbol "**" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_3); 
--# expr-done 11448
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Cast_Result_13, Rhs => Block_Var_2, Ret => Cast_Result_14);
--# end
--# expr-done 11449
--# expr-start 11451 '<FieldAccess for create_binop_assoc at ast.py:5121>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:5121
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11450 '<Symbol "<" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11450
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
--# property-call-start AdaNode.create_binop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_15, Rhs => Cast_Result_16, Ret => Block_Var_1);
--# end
--# expr-done 11451
--# expr-start 11453 '<FieldAccess for create_binop_assoc at ast.py:5122>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:5122
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11452 '<Symbol "<=" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11452
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_13 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_17, Rhs => Cast_Result_18, Ret => Block_Var_1);
--# end
--# expr-done 11453
--# expr-start 11455 '<FieldAccess for create_binop_assoc at ast.py:5123>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:5123
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11454 '<Symbol "=" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11454
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
--# property-call-start AdaNode.create_binop_assoc
Fld_14 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_19, Rhs => Cast_Result_20, Ret => Block_Var_1);
--# end
--# expr-done 11455
--# expr-start 11457 '<FieldAccess for create_binop_assoc at ast.py:5124>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:5124
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11456 '<Symbol "/=" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11456
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
--# property-call-start AdaNode.create_binop_assoc
Fld_15 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_21, Rhs => Cast_Result_22, Ret => Block_Var_1);
--# end
--# expr-done 11457
--# expr-start 11459 '<FieldAccess for create_binop_assoc at ast.py:5125>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:5125
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11458 '<Symbol ">" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11458
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
--# property-call-start AdaNode.create_binop_assoc
Fld_16 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_9, Lhs => Cast_Result_23, Rhs => Cast_Result_24, Ret => Block_Var_1);
--# end
--# expr-done 11459
--# expr-start 11461 '<FieldAccess for create_binop_assoc at ast.py:5126>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:5126
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11460 '<Symbol ">=" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11460
Cast_Expr_24 := Block_Var; 
      Cast_Result_25 := Cast_Expr_24;
Cast_Expr_25 := Block_Var; 
      Cast_Result_26 := Cast_Expr_25;
--# property-call-start AdaNode.create_binop_assoc
Fld_17 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_10, Lhs => Cast_Result_25, Rhs => Cast_Result_26, Ret => Block_Var_1);
--# end
--# expr-done 11461
--# expr-start 11463 '<FieldAccess for create_unop_assoc at ast.py:5128>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:5128
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11462 '<Symbol "+" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11462
Cast_Expr_26 := Block_Var; 
      Cast_Result_27 := Cast_Expr_26;
Cast_Expr_27 := Block_Var; 
      Cast_Result_28 := Cast_Expr_27;
--# property-call-start AdaNode.create_unop_assoc
Fld_18 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_11, Rhs => Cast_Result_27, Ret => Cast_Result_28);
--# end
--# expr-done 11463
--# expr-start 11465 '<FieldAccess for create_unop_assoc at ast.py:5129>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:5129
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11464 '<Symbol "-" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11464
Cast_Expr_28 := Block_Var; 
      Cast_Result_29 := Cast_Expr_28;
Cast_Expr_29 := Block_Var; 
      Cast_Result_30 := Cast_Expr_29;
--# property-call-start AdaNode.create_unop_assoc
Fld_19 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_12, Rhs => Cast_Result_29, Ret => Cast_Result_30);
--# end
--# expr-done 11465
--# expr-start 11467 '<FieldAccess for create_unop_assoc at ast.py:5130>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:5130
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11466 '<Symbol "abs" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 11466
Cast_Expr_30 := Block_Var; 
      Cast_Result_31 := Cast_Expr_30;
Cast_Expr_31 := Block_Var; 
      Cast_Result_32 := Cast_Expr_31;
--# property-call-start AdaNode.create_unop_assoc
Fld_20 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_13, Rhs => Cast_Result_31, Ret => Cast_Result_32);
--# end
--# expr-done 11467
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_7, 2 => Fld_8, 3 => Fld_9, 4 => Fld_10, 5 => Fld_11, 6 => Fld_12, 7 => Fld_13, 8 => Fld_14, 9 => Fld_15, 10 => Fld_16, 11 => Fld_17, 12 => Fld_18, 13 => Fld_19, 14 => Fld_20)); 
--# expr-done 11468
Block_Var_4 := Array_Lit; Inc_Ref (Block_Var_4);
--# bind defaults Block_Var_4
--# expr-start 11479 '<If at ast.py:5134>' If_Result /tmp/lal-23.0.0/ada/ast.py:5134
--# expr-start 11471 '<Eq at ast.py:5135>' Is_Equal /tmp/lal-23.0.0/ada/ast.py:5135
Cast_Expr_38 := Block_Var; 
      Cast_Result_39 := Cast_Expr_38;
--# expr-start 11470 '<FieldAccess for node at ast.py:5135>' Fld_25 /tmp/lal-23.0.0/ada/ast.py:5135
--# expr-start 11469 '<FieldAccess for root_real_type at ast.py:5135>' Fld_24 /tmp/lal-23.0.0/ada/ast.py:5135
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.root_real_type
Fld_24 := Libadalang.Implementation.Ada_Node_P_Root_Real_Type (Node => Self);
--# end
--# expr-done 11469
Fld_25 := Fld_24.Node;
--# expr-done 11470
Is_Equal := Cast_Result_39 = Fld_25; 
--# expr-done 11471
if Is_Equal then
   --# expr-start 11478 '<ArrayLiteral at ???>' Array_Lit_1 None
--# expr-start 11473 '<FieldAccess for create_binop_assoc at ast.py:5137>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:5137
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11472 '<Symbol "*" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11472
Cast_Expr_32 := Block_Var; 
      Cast_Result_33 := Cast_Expr_32;
Cast_Expr_33 := Block_Var; 
      Cast_Result_34 := Cast_Expr_33;
--# property-call-start AdaNode.create_binop_assoc
Fld_21 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_14, Lhs => Block_Var_3, Rhs => Cast_Result_33, Ret => Cast_Result_34);
--# end
--# expr-done 11473
--# expr-start 11475 '<FieldAccess for create_binop_assoc at ast.py:5140>' Fld_22 /tmp/lal-23.0.0/ada/ast.py:5140
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11474 '<Symbol "*" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11474
Cast_Expr_34 := Block_Var; 
      Cast_Result_35 := Cast_Expr_34;
Cast_Expr_35 := Block_Var; 
      Cast_Result_36 := Cast_Expr_35;
--# property-call-start AdaNode.create_binop_assoc
Fld_22 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_15, Lhs => Cast_Result_35, Rhs => Block_Var_3, Ret => Cast_Result_36);
--# end
--# expr-done 11475
--# expr-start 11477 '<FieldAccess for create_binop_assoc at ast.py:5143>' Fld_23 /tmp/lal-23.0.0/ada/ast.py:5143
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11476 '<Symbol "/" at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11476
Cast_Expr_36 := Block_Var; 
      Cast_Result_37 := Cast_Expr_36;
Cast_Expr_37 := Block_Var; 
      Cast_Result_38 := Cast_Expr_37;
--# property-call-start AdaNode.create_binop_assoc
Fld_23 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_16, Lhs => Cast_Result_37, Rhs => Block_Var_3, Ret => Cast_Result_38);
--# end
--# expr-done 11477
Array_Lit_1 := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_21, 2 => Fld_22, 3 => Fld_23)); 
--# expr-done 11478
   If_Result := Array_Lit_1;
else
   If_Result := No_Internal_Env_Assoc_Array_Type;
end if;
      Inc_Ref (If_Result);
--# expr-done 11479
Block_Var_5 := If_Result; Inc_Ref (Block_Var_5);
--# bind specials Block_Var_5
--# expr-start 11480 '<Concat at ast.py:5150>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:5150
Concat_Result := Concat (Block_Var_4, Block_Var_5); 
--# expr-done 11480
Let_Result := Concat_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11481
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_367;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_367;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Real_Type_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Decimal_Fixed_Point_Def
   --
      procedure Initialize_Fields_For_Decimal_Fixed_Point_Def
        (Self : Bare_Decimal_Fixed_Point_Def
         ; Decimal_Fixed_Point_Def_F_Delta : Bare_Expr
         ; Decimal_Fixed_Point_Def_F_Digits : Bare_Expr
         ; Decimal_Fixed_Point_Def_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Decimal_Fixed_Point_Def_F_Delta := Decimal_Fixed_Point_Def_F_Delta;
            Self.Decimal_Fixed_Point_Def_F_Digits := Decimal_Fixed_Point_Def_F_Digits;
            Self.Decimal_Fixed_Point_Def_F_Range := Decimal_Fixed_Point_Def_F_Range;
      end Initialize_Fields_For_Decimal_Fixed_Point_Def;
   function Decimal_Fixed_Point_Def_F_Delta
     (Node : Bare_Decimal_Fixed_Point_Def) return Bare_Expr
   is
   begin
         return Node.Decimal_Fixed_Point_Def_F_Delta;
   end;
   function Decimal_Fixed_Point_Def_F_Digits
     (Node : Bare_Decimal_Fixed_Point_Def) return Bare_Expr
   is
   begin
         return Node.Decimal_Fixed_Point_Def_F_Digits;
   end;
   function Decimal_Fixed_Point_Def_F_Range
     (Node : Bare_Decimal_Fixed_Point_Def) return Bare_Range_Spec
   is
   begin
         return Node.Decimal_Fixed_Point_Def_F_Range;
   end;
--# property-start DecimalFixedPointDef.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:7812
pragma Warnings (Off, "is not referenced");
 function Decimal_Fixed_Point_Def_P_Is_Fixed_Point
  (Node : Bare_Decimal_Fixed_Point_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Decimal_Fixed_Point_Def := Bare_Decimal_Fixed_Point_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Decimal_Fixed_Point_Def_P_Is_Fixed_Point;
--# end
--# property-start DecimalFixedPointDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:7815
pragma Warnings (Off, "is not referenced");
 function Decimal_Fixed_Point_Def_P_Xref_Equation
  (Node : Bare_Decimal_Fixed_Point_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Decimal_Fixed_Point_Def := Bare_Decimal_Fixed_Point_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Decimal_Fixed_Point_Def :=
     Internal_Entity_Decimal_Fixed_Point_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_591 with Inline_Always;
            procedure Finalizer_Scope_3171 with Inline_Always;
      Var_Expr : Internal_Entity_Range_Spec;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_7 : Internal_Entity_Expr;
Fld_8 : Logic_Var;
Fld_9 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_10 : Internal_Entity_Expr;
Fld_11 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Fld_12 : Internal_Entity_Expr;
Fld_13 : Logic_Equation;
And_Pred_4 : Logic_Equation;
Fld_14 : Internal_Entity_Range_Spec;
Fld_15 : Internal_Entity_Expr;
Fld_16 : Logic_Var;
Fld_17 : Logic_Equation;
Fld_18 : Internal_Entity_Expr;
Fld_19 : Logic_Equation;
And_Pred_5 : Logic_Equation;
Fld_20 : Internal_Entity_Expr;
Fld_21 : Logic_Equation;
And_Pred_6 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_7 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_591 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Fld_9);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_11);
                     Dec_Ref (And_Pred_3);
                     Dec_Ref (Fld_13);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_7);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_591;
            procedure Finalizer_Scope_3171 is
            begin
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_19);
                     Dec_Ref (And_Pred_5);
                     Dec_Ref (Fld_21);
                     Dec_Ref (And_Pred_6);
            end Finalizer_Scope_3171;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11512 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11511 '<And at ast.py:7819>' And_Pred_7 /tmp/lal-23.0.0/ada/ast.py:7819
--# expr-start 11500 '<And at ast.py:7819>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:7819
--# expr-start 11497 '<And at ast.py:7819>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:7819
--# expr-start 11494 '<And at ast.py:7819>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:7819
--# expr-start 11490 '<And at ast.py:7819>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:7819
--# expr-start 11487 '<And at ast.py:7819>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7819
--# expr-start 11484 '<FieldAccess for universal_real_bind at ast.py:7822>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7822
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11483 '<FieldAccess for expected_type_var at ast.py:7822>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7822
--# expr-start 11482 '<FieldAccess for delta at ast.py:7822>' Fld /tmp/lal-23.0.0/ada/ast.py:7822
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Delta, Info => Ent.Info);
--# expr-done 11482
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld.Node);
--# expr-done 11483
--# property-call-start AdaNode.universal_real_bind
Fld_2 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Ent.Node, Type_Var => Fld_1, Origin => Origin);
--# end
--# expr-done 11484
--# expr-start 11486 '<FieldAccess for sub_equation at ast.py:7823>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7823
--# expr-start 11485 '<FieldAccess for delta at ast.py:7823>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7823
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Delta, Info => Ent.Info);
--# expr-done 11485
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 11486
And_Pred := Create_And (Fld_2, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7819") else null)); 
--# expr-done 11487
--# expr-start 11489 '<FieldAccess for matches_expected_type at ast.py:7824>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7824
--# expr-start 11488 '<FieldAccess for delta at ast.py:7824>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7824
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Delta, Info => Ent.Info);
--# expr-done 11488
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 11489
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7819") else null)); 
--# expr-done 11490
--# expr-start 11493 '<FieldAccess for universal_int_bind at ast.py:7827>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7827
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11492 '<FieldAccess for expected_type_var at ast.py:7827>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7827
--# expr-start 11491 '<FieldAccess for digits at ast.py:7827>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7827
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Expr (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Digits, Info => Ent.Info);
--# expr-done 11491
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_7.Node);
--# expr-done 11492
--# property-call-start AdaNode.universal_int_bind
Fld_9 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Ent.Node, Type_Var => Fld_8, Origin => Origin);
--# end
--# expr-done 11493
And_Pred_2 := Create_And (And_Pred_1, Fld_9, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7819") else null)); 
--# expr-done 11494
--# expr-start 11496 '<FieldAccess for sub_equation at ast.py:7828>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7828
--# expr-start 11495 '<FieldAccess for digits at ast.py:7828>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7828
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Create_Internal_Entity_Expr (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Digits, Info => Ent.Info);
--# expr-done 11495
      if Fld_10.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_11 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_10.Node, Env => Env, Origin => Origin, E_Info => Fld_10.Info);
--# end
--# expr-done 11496
And_Pred_3 := Create_And (And_Pred_2, Fld_11, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7819") else null)); 
--# expr-done 11497
--# expr-start 11499 '<FieldAccess for matches_expected_type at ast.py:7829>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7829
--# expr-start 11498 '<FieldAccess for digits at ast.py:7829>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7829
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_12 := Create_Internal_Entity_Expr (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Digits, Info => Ent.Info);
--# expr-done 11498
      if Fld_12.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_13 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_12.Node, Origin => Origin);
--# end
--# expr-done 11499
And_Pred_4 := Create_And (And_Pred_3, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7819") else null)); 
--# expr-done 11500
--# expr-start 11501 '<FieldAccess for range at ast.py:7833>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7833
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_14 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Decimal_Fixed_Point_Def_F_Range, Info => Ent.Info);
--# expr-done 11501
Var_Expr := Fld_14;
if Var_Expr /= No_Entity_Range_Spec then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 11510 '<And at ast.py:7835>' And_Pred_6 /tmp/lal-23.0.0/ada/ast.py:7835
--# expr-start 11507 '<And at ast.py:7835>' And_Pred_5 /tmp/lal-23.0.0/ada/ast.py:7835
--# expr-start 11504 '<FieldAccess for universal_real_bind at ast.py:7835>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7835
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11503 '<FieldAccess for expected_type_var at ast.py:7835>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7835
--# expr-start 11502 '<FieldAccess for range at ast.py:7835>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:7835
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_15 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11502
      if Fld_15.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_16 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_15.Node);
--# expr-done 11503
--# property-call-start AdaNode.universal_real_bind
Fld_17 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Ent.Node, Type_Var => Fld_16, Origin => Origin);
--# end
--# expr-done 11504
--# expr-start 11506 '<FieldAccess for sub_equation at ast.py:7836>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:7836
--# expr-start 11505 '<FieldAccess for range at ast.py:7836>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7836
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_18 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11505
      if Fld_18.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_19 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_18.Node, Env => Env, Origin => Origin, E_Info => Fld_18.Info);
--# end
--# expr-done 11506
And_Pred_5 := Create_And (Fld_17, Fld_19, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7835") else null)); 
--# expr-done 11507
--# expr-start 11509 '<FieldAccess for matches_expected_type at ast.py:7837>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:7837
--# expr-start 11508 '<FieldAccess for range at ast.py:7837>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:7837
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_20 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11508
      if Fld_20.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_21 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_20.Node, Origin => Origin);
--# end
--# expr-done 11509
And_Pred_6 := Create_And (And_Pred_5, Fld_21, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7835") else null)); 
--# expr-done 11510
Scope_Result := And_Pred_6;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3171;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7838") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_7 := Create_And (And_Pred_4, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7819") else null)); 
--# expr-done 11511
Let_Result := And_Pred_7; Inc_Ref (Let_Result);
--# end
--# expr-done 11512
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_591;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_591;
               Finalizer_Scope_3171;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Decimal_Fixed_Point_Def_P_Xref_Equation;
--# end
--# property-start DecimalFixedPointDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:7843
pragma Warnings (Off, "is not referenced");
 function Decimal_Fixed_Point_Def_P_Predefined_Operators
  (Node : Bare_Decimal_Fixed_Point_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Decimal_Fixed_Point_Def := Bare_Decimal_Fixed_Point_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_592 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Bare_Base_Type_Decl;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_6 : Symbol_Type;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Fld_13 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Fld_14 : Internal_Env_Assoc := No_Env_Assoc;
Sym_10 : Symbol_Type;
Cast_Expr_24 : Bare_Type_Decl;
Cast_Result_25 : Bare_Base_Type_Decl;
Cast_Expr_25 : Bare_Type_Decl;
Cast_Result_26 : Bare_Base_Type_Decl;
Fld_15 : Internal_Env_Assoc := No_Env_Assoc;
Sym_11 : Symbol_Type;
Cast_Expr_26 : Bare_Type_Decl;
Cast_Result_27 : Bare_Base_Type_Decl;
Cast_Expr_27 : Bare_Type_Decl;
Cast_Result_28 : Bare_Base_Type_Decl;
Fld_16 : Internal_Env_Assoc := No_Env_Assoc;
Sym_12 : Symbol_Type;
Cast_Expr_28 : Bare_Type_Decl;
Cast_Result_29 : Bare_Base_Type_Decl;
Cast_Expr_29 : Bare_Type_Decl;
Cast_Result_30 : Bare_Base_Type_Decl;
Fld_17 : Internal_Env_Assoc := No_Env_Assoc;
Sym_13 : Symbol_Type;
Cast_Expr_30 : Bare_Type_Decl;
Cast_Result_31 : Bare_Base_Type_Decl;
Cast_Expr_31 : Bare_Type_Decl;
Cast_Result_32 : Bare_Base_Type_Decl;
Fld_18 : Internal_Env_Assoc := No_Env_Assoc;
Sym_14 : Symbol_Type;
Cast_Expr_32 : Bare_Type_Decl;
Cast_Result_33 : Bare_Base_Type_Decl;
Cast_Expr_33 : Bare_Type_Decl;
Cast_Result_34 : Bare_Base_Type_Decl;
Fld_19 : Internal_Env_Assoc := No_Env_Assoc;
Sym_15 : Symbol_Type;
Cast_Expr_34 : Bare_Type_Decl;
Cast_Result_35 : Bare_Base_Type_Decl;
Cast_Expr_35 : Bare_Type_Decl;
Cast_Result_36 : Bare_Base_Type_Decl;
Fld_20 : Internal_Env_Assoc := No_Env_Assoc;
Sym_16 : Symbol_Type;
Cast_Expr_36 : Bare_Type_Decl;
Cast_Result_37 : Bare_Base_Type_Decl;
Cast_Expr_37 : Bare_Type_Decl;
Cast_Result_38 : Bare_Base_Type_Decl;
Fld_21 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_592 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_592;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Decimal_Fixed_Point_Def_Decimal_Fixed_Point_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Decimal_Fixed_Point_Def,
                                As_Bare_Decimal_Fixed_Point_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11554 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11514 '<Cast to TypeDecl at ast.py:7844>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7844
--# expr-start 11513 '<parent at ast.py:7844>' Fld /tmp/lal-23.0.0/ada/ast.py:7844
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11513
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11514
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11516 '<FieldAccess for node at ast.py:7845>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7845
--# expr-start 11515 '<FieldAccess for bool_type at ast.py:7845>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7845
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11515
Fld_2 := Fld_1.Node;
--# expr-done 11516
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11518 '<FieldAccess for node at ast.py:7846>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7846
--# expr-start 11517 '<FieldAccess for int_type at ast.py:7846>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7846
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 11517
Fld_4 := Fld_3.Node;
--# expr-done 11518
Block_Var_2 := Fld_4; 
--# bind int_type Block_Var_2
--# expr-start 11553 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11520 '<FieldAccess for create_binop_assoc at ast.py:7849>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7849
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11519 '<Symbol "+" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11519
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Cast_Result_3);
--# end
--# expr-done 11520
--# expr-start 11522 '<FieldAccess for create_binop_assoc at ast.py:7850>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7850
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11521 '<Symbol "-" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11521
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_4, Rhs => Cast_Result_5, Ret => Cast_Result_6);
--# end
--# expr-done 11522
--# expr-start 11524 '<FieldAccess for create_binop_assoc at ast.py:7851>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7851
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11523 '<Symbol "*" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11523
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Cast_Result_9);
--# end
--# expr-done 11524
--# expr-start 11526 '<FieldAccess for create_binop_assoc at ast.py:7852>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7852
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11525 '<Symbol "/" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11525
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_10, Rhs => Cast_Result_11, Ret => Cast_Result_12);
--# end
--# expr-done 11526
--# expr-start 11528 '<FieldAccess for create_binop_assoc at ast.py:7854>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7854
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11527 '<Symbol "*" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11527
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Block_Var_2, Rhs => Cast_Result_13, Ret => Cast_Result_14);
--# end
--# expr-done 11528
--# expr-start 11530 '<FieldAccess for create_binop_assoc at ast.py:7855>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7855
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11529 '<Symbol "*" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11529
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_15, Rhs => Block_Var_2, Ret => Cast_Result_16);
--# end
--# expr-done 11530
--# expr-start 11532 '<FieldAccess for create_binop_assoc at ast.py:7856>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7856
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11531 '<Symbol "/" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11531
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_17, Rhs => Block_Var_2, Ret => Cast_Result_18);
--# end
--# expr-done 11532
--# expr-start 11534 '<FieldAccess for create_binop_assoc at ast.py:7857>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7857
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11533 '<Symbol "**" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_3); 
--# expr-done 11533
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
--# property-call-start AdaNode.create_binop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_19, Rhs => Block_Var_2, Ret => Cast_Result_20);
--# end
--# expr-done 11534
--# expr-start 11536 '<FieldAccess for create_binop_assoc at ast.py:7859>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7859
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11535 '<Symbol "<" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11535
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
--# property-call-start AdaNode.create_binop_assoc
Fld_13 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_21, Rhs => Cast_Result_22, Ret => Block_Var_1);
--# end
--# expr-done 11536
--# expr-start 11538 '<FieldAccess for create_binop_assoc at ast.py:7860>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7860
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11537 '<Symbol "<=" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11537
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
--# property-call-start AdaNode.create_binop_assoc
Fld_14 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_9, Lhs => Cast_Result_23, Rhs => Cast_Result_24, Ret => Block_Var_1);
--# end
--# expr-done 11538
--# expr-start 11540 '<FieldAccess for create_binop_assoc at ast.py:7861>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:7861
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11539 '<Symbol "=" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11539
Cast_Expr_24 := Block_Var; 
      Cast_Result_25 := Cast_Expr_24;
Cast_Expr_25 := Block_Var; 
      Cast_Result_26 := Cast_Expr_25;
--# property-call-start AdaNode.create_binop_assoc
Fld_15 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_10, Lhs => Cast_Result_25, Rhs => Cast_Result_26, Ret => Block_Var_1);
--# end
--# expr-done 11540
--# expr-start 11542 '<FieldAccess for create_binop_assoc at ast.py:7862>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7862
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11541 '<Symbol "/=" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11541
Cast_Expr_26 := Block_Var; 
      Cast_Result_27 := Cast_Expr_26;
Cast_Expr_27 := Block_Var; 
      Cast_Result_28 := Cast_Expr_27;
--# property-call-start AdaNode.create_binop_assoc
Fld_16 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_11, Lhs => Cast_Result_27, Rhs => Cast_Result_28, Ret => Block_Var_1);
--# end
--# expr-done 11542
--# expr-start 11544 '<FieldAccess for create_binop_assoc at ast.py:7863>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7863
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11543 '<Symbol ">" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11543
Cast_Expr_28 := Block_Var; 
      Cast_Result_29 := Cast_Expr_28;
Cast_Expr_29 := Block_Var; 
      Cast_Result_30 := Cast_Expr_29;
--# property-call-start AdaNode.create_binop_assoc
Fld_17 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_12, Lhs => Cast_Result_29, Rhs => Cast_Result_30, Ret => Block_Var_1);
--# end
--# expr-done 11544
--# expr-start 11546 '<FieldAccess for create_binop_assoc at ast.py:7864>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7864
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11545 '<Symbol ">=" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11545
Cast_Expr_30 := Block_Var; 
      Cast_Result_31 := Cast_Expr_30;
Cast_Expr_31 := Block_Var; 
      Cast_Result_32 := Cast_Expr_31;
--# property-call-start AdaNode.create_binop_assoc
Fld_18 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_13, Lhs => Cast_Result_31, Rhs => Cast_Result_32, Ret => Block_Var_1);
--# end
--# expr-done 11546
--# expr-start 11548 '<FieldAccess for create_unop_assoc at ast.py:7866>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:7866
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11547 '<Symbol "+" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11547
Cast_Expr_32 := Block_Var; 
      Cast_Result_33 := Cast_Expr_32;
Cast_Expr_33 := Block_Var; 
      Cast_Result_34 := Cast_Expr_33;
--# property-call-start AdaNode.create_unop_assoc
Fld_19 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_14, Rhs => Cast_Result_33, Ret => Cast_Result_34);
--# end
--# expr-done 11548
--# expr-start 11550 '<FieldAccess for create_unop_assoc at ast.py:7867>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:7867
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11549 '<Symbol "-" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11549
Cast_Expr_34 := Block_Var; 
      Cast_Result_35 := Cast_Expr_34;
Cast_Expr_35 := Block_Var; 
      Cast_Result_36 := Cast_Expr_35;
--# property-call-start AdaNode.create_unop_assoc
Fld_20 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_15, Rhs => Cast_Result_35, Ret => Cast_Result_36);
--# end
--# expr-done 11550
--# expr-start 11552 '<FieldAccess for create_unop_assoc at ast.py:7868>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:7868
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11551 '<Symbol "abs" at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 11551
Cast_Expr_36 := Block_Var; 
      Cast_Result_37 := Cast_Expr_36;
Cast_Expr_37 := Block_Var; 
      Cast_Result_38 := Cast_Expr_37;
--# property-call-start AdaNode.create_unop_assoc
Fld_21 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_16, Rhs => Cast_Result_37, Ret => Cast_Result_38);
--# end
--# expr-done 11552
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_5, 2 => Fld_6, 3 => Fld_7, 4 => Fld_8, 5 => Fld_9, 6 => Fld_10, 7 => Fld_11, 8 => Fld_12, 9 => Fld_13, 10 => Fld_14, 11 => Fld_15, 12 => Fld_16, 13 => Fld_17, 14 => Fld_18, 15 => Fld_19, 16 => Fld_20, 17 => Fld_21)); 
--# expr-done 11553
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 11554
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_592;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_592;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Decimal_Fixed_Point_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Floating_Point_Def
   --
      procedure Initialize_Fields_For_Floating_Point_Def
        (Self : Bare_Floating_Point_Def
         ; Floating_Point_Def_F_Num_Digits : Bare_Expr
         ; Floating_Point_Def_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Floating_Point_Def_F_Num_Digits := Floating_Point_Def_F_Num_Digits;
            Self.Floating_Point_Def_F_Range := Floating_Point_Def_F_Range;
      end Initialize_Fields_For_Floating_Point_Def;
   function Floating_Point_Def_F_Num_Digits
     (Node : Bare_Floating_Point_Def) return Bare_Expr
   is
   begin
         return Node.Floating_Point_Def_F_Num_Digits;
   end;
   function Floating_Point_Def_F_Range
     (Node : Bare_Floating_Point_Def) return Bare_Range_Spec
   is
   begin
         return Node.Floating_Point_Def_F_Range;
   end;
--# property-start FloatingPointDef.is_float_type /tmp/lal-23.0.0/ada/ast.py:7716
pragma Warnings (Off, "is not referenced");
 function Floating_Point_Def_P_Is_Float_Type
  (Node : Bare_Floating_Point_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Floating_Point_Def := Bare_Floating_Point_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Floating_Point_Def_P_Is_Float_Type;
--# end
--# property-start FloatingPointDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:7719
pragma Warnings (Off, "is not referenced");
 function Floating_Point_Def_P_Xref_Equation
  (Node : Bare_Floating_Point_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Floating_Point_Def := Bare_Floating_Point_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Floating_Point_Def :=
     Internal_Entity_Floating_Point_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_586 with Inline_Always;
            procedure Finalizer_Scope_3172 with Inline_Always;
      Var_Expr : Internal_Entity_Range_Spec;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_7 : Internal_Entity_Range_Spec;
Fld_8 : Internal_Entity_Expr;
Fld_9 : Logic_Var;
Fld_10 : Logic_Equation;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_13 : Internal_Entity_Expr;
Fld_14 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_4 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_586 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_586;
            procedure Finalizer_Scope_3172 is
            begin
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_12);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_14);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_3172;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11575 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11574 '<And at ast.py:7723>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:7723
--# expr-start 11563 '<And at ast.py:7723>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:7723
--# expr-start 11560 '<And at ast.py:7723>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7723
--# expr-start 11557 '<FieldAccess for universal_int_bind at ast.py:7726>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7726
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11556 '<FieldAccess for expected_type_var at ast.py:7726>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7726
--# expr-start 11555 '<FieldAccess for num_digits at ast.py:7726>' Fld /tmp/lal-23.0.0/ada/ast.py:7726
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Floating_Point_Def_F_Num_Digits, Info => Ent.Info);
--# expr-done 11555
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld.Node);
--# expr-done 11556
--# property-call-start AdaNode.universal_int_bind
Fld_2 := Libadalang.Implementation.Ada_Node_P_Universal_Int_Bind (Node => Ent.Node, Type_Var => Fld_1, Origin => Origin);
--# end
--# expr-done 11557
--# expr-start 11559 '<FieldAccess for sub_equation at ast.py:7727>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7727
--# expr-start 11558 '<FieldAccess for num_digits at ast.py:7727>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7727
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Floating_Point_Def_F_Num_Digits, Info => Ent.Info);
--# expr-done 11558
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 11559
And_Pred := Create_And (Fld_2, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7723") else null)); 
--# expr-done 11560
--# expr-start 11562 '<FieldAccess for matches_expected_type at ast.py:7728>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7728
--# expr-start 11561 '<FieldAccess for num_digits at ast.py:7728>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7728
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Floating_Point_Def_F_Num_Digits, Info => Ent.Info);
--# expr-done 11561
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 11562
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7723") else null)); 
--# expr-done 11563
--# expr-start 11564 '<FieldAccess for range at ast.py:7732>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7732
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Floating_Point_Def_F_Range, Info => Ent.Info);
--# expr-done 11564
Var_Expr := Fld_7;
if Var_Expr /= No_Entity_Range_Spec then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 11573 '<And at ast.py:7734>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:7734
--# expr-start 11570 '<And at ast.py:7734>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:7734
--# expr-start 11567 '<FieldAccess for universal_real_bind at ast.py:7734>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7734
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11566 '<FieldAccess for expected_type_var at ast.py:7734>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7734
--# expr-start 11565 '<FieldAccess for range at ast.py:7734>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7734
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11565
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_8.Node);
--# expr-done 11566
--# property-call-start AdaNode.universal_real_bind
Fld_10 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Ent.Node, Type_Var => Fld_9, Origin => Origin);
--# end
--# expr-done 11567
--# expr-start 11569 '<FieldAccess for sub_equation at ast.py:7735>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7735
--# expr-start 11568 '<FieldAccess for range at ast.py:7735>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7735
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11568
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_12 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_11.Node, Env => Env, Origin => Origin, E_Info => Fld_11.Info);
--# end
--# expr-done 11569
And_Pred_2 := Create_And (Fld_10, Fld_12, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7734") else null)); 
--# expr-done 11570
--# expr-start 11572 '<FieldAccess for matches_expected_type at ast.py:7736>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7736
--# expr-start 11571 '<FieldAccess for range at ast.py:7736>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7736
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11571
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_14 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_13.Node, Origin => Origin);
--# end
--# expr-done 11572
And_Pred_3 := Create_And (And_Pred_2, Fld_14, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7734") else null)); 
--# expr-done 11573
Scope_Result := And_Pred_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3172;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7737") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_4 := Create_And (And_Pred_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7723") else null)); 
--# expr-done 11574
Let_Result := And_Pred_4; Inc_Ref (Let_Result);
--# end
--# expr-done 11575
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_586;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_586;
               Finalizer_Scope_3172;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Floating_Point_Def_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Ordinary_Fixed_Point_Def
   --
      procedure Initialize_Fields_For_Ordinary_Fixed_Point_Def
        (Self : Bare_Ordinary_Fixed_Point_Def
         ; Ordinary_Fixed_Point_Def_F_Delta : Bare_Expr
         ; Ordinary_Fixed_Point_Def_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Ordinary_Fixed_Point_Def_F_Delta := Ordinary_Fixed_Point_Def_F_Delta;
            Self.Ordinary_Fixed_Point_Def_F_Range := Ordinary_Fixed_Point_Def_F_Range;
      end Initialize_Fields_For_Ordinary_Fixed_Point_Def;
   function Ordinary_Fixed_Point_Def_F_Delta
     (Node : Bare_Ordinary_Fixed_Point_Def) return Bare_Expr
   is
   begin
         return Node.Ordinary_Fixed_Point_Def_F_Delta;
   end;
   function Ordinary_Fixed_Point_Def_F_Range
     (Node : Bare_Ordinary_Fixed_Point_Def) return Bare_Range_Spec
   is
   begin
         return Node.Ordinary_Fixed_Point_Def_F_Range;
   end;
--# property-start OrdinaryFixedPointDef.is_fixed_point /tmp/lal-23.0.0/ada/ast.py:7749
pragma Warnings (Off, "is not referenced");
 function Ordinary_Fixed_Point_Def_P_Is_Fixed_Point
  (Node : Bare_Ordinary_Fixed_Point_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Ordinary_Fixed_Point_Def := Bare_Ordinary_Fixed_Point_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ordinary_Fixed_Point_Def_P_Is_Fixed_Point;
--# end
--# property-start OrdinaryFixedPointDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:7752
pragma Warnings (Off, "is not referenced");
 function Ordinary_Fixed_Point_Def_P_Xref_Equation
  (Node : Bare_Ordinary_Fixed_Point_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Ordinary_Fixed_Point_Def := Bare_Ordinary_Fixed_Point_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Ordinary_Fixed_Point_Def :=
     Internal_Entity_Ordinary_Fixed_Point_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_588 with Inline_Always;
            procedure Finalizer_Scope_3173 with Inline_Always;
      Var_Expr : Internal_Entity_Range_Spec;
Fld : Internal_Entity_Expr;
Fld_1 : Logic_Var;
Fld_2 : Logic_Equation;
Fld_3 : Internal_Entity_Expr;
Fld_4 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_5 : Internal_Entity_Expr;
Fld_6 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Fld_7 : Internal_Entity_Range_Spec;
Fld_8 : Internal_Entity_Expr;
Fld_9 : Logic_Var;
Fld_10 : Logic_Equation;
Fld_11 : Internal_Entity_Expr;
Fld_12 : Logic_Equation;
And_Pred_2 : Logic_Equation;
Fld_13 : Internal_Entity_Expr;
Fld_14 : Logic_Equation;
And_Pred_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred_4 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_588 is
            begin
                     Dec_Ref (Fld_2);
                     Dec_Ref (Fld_4);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_6);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred_4);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_588;
            procedure Finalizer_Scope_3173 is
            begin
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_12);
                     Dec_Ref (And_Pred_2);
                     Dec_Ref (Fld_14);
                     Dec_Ref (And_Pred_3);
            end Finalizer_Scope_3173;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11596 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11595 '<And at ast.py:7756>' And_Pred_4 /tmp/lal-23.0.0/ada/ast.py:7756
--# expr-start 11584 '<And at ast.py:7756>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:7756
--# expr-start 11581 '<And at ast.py:7756>' And_Pred /tmp/lal-23.0.0/ada/ast.py:7756
--# expr-start 11578 '<FieldAccess for universal_real_bind at ast.py:7759>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7759
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11577 '<FieldAccess for expected_type_var at ast.py:7759>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7759
--# expr-start 11576 '<FieldAccess for delta at ast.py:7759>' Fld /tmp/lal-23.0.0/ada/ast.py:7759
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Expr (Node => Ent.Node.Ordinary_Fixed_Point_Def_F_Delta, Info => Ent.Info);
--# expr-done 11576
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld.Node);
--# expr-done 11577
--# property-call-start AdaNode.universal_real_bind
Fld_2 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Ent.Node, Type_Var => Fld_1, Origin => Origin);
--# end
--# expr-done 11578
--# expr-start 11580 '<FieldAccess for sub_equation at ast.py:7760>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7760
--# expr-start 11579 '<FieldAccess for delta at ast.py:7760>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7760
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Create_Internal_Entity_Expr (Node => Ent.Node.Ordinary_Fixed_Point_Def_F_Delta, Info => Ent.Info);
--# expr-done 11579
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_4 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_3.Node, Env => Env, Origin => Origin, E_Info => Fld_3.Info);
--# end
--# expr-done 11580
And_Pred := Create_And (Fld_2, Fld_4, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7756") else null)); 
--# expr-done 11581
--# expr-start 11583 '<FieldAccess for matches_expected_type at ast.py:7761>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7761
--# expr-start 11582 '<FieldAccess for delta at ast.py:7761>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7761
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Expr (Node => Ent.Node.Ordinary_Fixed_Point_Def_F_Delta, Info => Ent.Info);
--# expr-done 11582
      if Fld_5.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_6 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_5.Node, Origin => Origin);
--# end
--# expr-done 11583
And_Pred_1 := Create_And (And_Pred, Fld_6, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7756") else null)); 
--# expr-done 11584
--# expr-start 11585 '<FieldAccess for range at ast.py:7765>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7765
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Ordinary_Fixed_Point_Def_F_Range, Info => Ent.Info);
--# expr-done 11585
Var_Expr := Fld_7;
if Var_Expr /= No_Entity_Range_Spec then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 11594 '<And at ast.py:7767>' And_Pred_3 /tmp/lal-23.0.0/ada/ast.py:7767
--# expr-start 11591 '<And at ast.py:7767>' And_Pred_2 /tmp/lal-23.0.0/ada/ast.py:7767
--# expr-start 11588 '<FieldAccess for universal_real_bind at ast.py:7767>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7767
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11587 '<FieldAccess for expected_type_var at ast.py:7767>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7767
--# expr-start 11586 '<FieldAccess for range at ast.py:7767>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7767
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11586
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Fld_8.Node);
--# expr-done 11587
--# property-call-start AdaNode.universal_real_bind
Fld_10 := Libadalang.Implementation.Ada_Node_P_Universal_Real_Bind (Node => Ent.Node, Type_Var => Fld_9, Origin => Origin);
--# end
--# expr-done 11588
--# expr-start 11590 '<FieldAccess for sub_equation at ast.py:7768>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7768
--# expr-start 11589 '<FieldAccess for range at ast.py:7768>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7768
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11589
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_12 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld_11.Node, Env => Env, Origin => Origin, E_Info => Fld_11.Info);
--# end
--# expr-done 11590
And_Pred_2 := Create_And (Fld_10, Fld_12, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7767") else null)); 
--# expr-done 11591
--# expr-start 11593 '<FieldAccess for matches_expected_type at ast.py:7769>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7769
--# expr-start 11592 '<FieldAccess for range at ast.py:7769>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7769
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_13 := Create_Internal_Entity_Expr (Node => Var_Expr.Node.Range_Spec_F_Range, Info => Var_Expr.Info);
--# expr-done 11592
      if Fld_13.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_14 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Fld_13.Node, Origin => Origin);
--# end
--# expr-done 11593
And_Pred_3 := Create_And (And_Pred_2, Fld_14, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7767") else null)); 
--# expr-done 11594
Scope_Result := And_Pred_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3173;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7770") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred_4 := Create_And (And_Pred_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:7756") else null)); 
--# expr-done 11595
Let_Result := And_Pred_4; Inc_Ref (Let_Result);
--# end
--# expr-done 11596
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_588;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_588;
               Finalizer_Scope_3173;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ordinary_Fixed_Point_Def_P_Xref_Equation;
--# end
--# property-start OrdinaryFixedPointDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:7775
pragma Warnings (Off, "is not referenced");
 function Ordinary_Fixed_Point_Def_P_Predefined_Operators
  (Node : Bare_Ordinary_Fixed_Point_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Ordinary_Fixed_Point_Def := Bare_Ordinary_Fixed_Point_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_589 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Bare_Base_Type_Decl;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_6 : Symbol_Type;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Fld_13 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Fld_14 : Internal_Env_Assoc := No_Env_Assoc;
Sym_10 : Symbol_Type;
Cast_Expr_24 : Bare_Type_Decl;
Cast_Result_25 : Bare_Base_Type_Decl;
Cast_Expr_25 : Bare_Type_Decl;
Cast_Result_26 : Bare_Base_Type_Decl;
Fld_15 : Internal_Env_Assoc := No_Env_Assoc;
Sym_11 : Symbol_Type;
Cast_Expr_26 : Bare_Type_Decl;
Cast_Result_27 : Bare_Base_Type_Decl;
Cast_Expr_27 : Bare_Type_Decl;
Cast_Result_28 : Bare_Base_Type_Decl;
Fld_16 : Internal_Env_Assoc := No_Env_Assoc;
Sym_12 : Symbol_Type;
Cast_Expr_28 : Bare_Type_Decl;
Cast_Result_29 : Bare_Base_Type_Decl;
Cast_Expr_29 : Bare_Type_Decl;
Cast_Result_30 : Bare_Base_Type_Decl;
Fld_17 : Internal_Env_Assoc := No_Env_Assoc;
Sym_13 : Symbol_Type;
Cast_Expr_30 : Bare_Type_Decl;
Cast_Result_31 : Bare_Base_Type_Decl;
Cast_Expr_31 : Bare_Type_Decl;
Cast_Result_32 : Bare_Base_Type_Decl;
Fld_18 : Internal_Env_Assoc := No_Env_Assoc;
Sym_14 : Symbol_Type;
Cast_Expr_32 : Bare_Type_Decl;
Cast_Result_33 : Bare_Base_Type_Decl;
Cast_Expr_33 : Bare_Type_Decl;
Cast_Result_34 : Bare_Base_Type_Decl;
Fld_19 : Internal_Env_Assoc := No_Env_Assoc;
Sym_15 : Symbol_Type;
Cast_Expr_34 : Bare_Type_Decl;
Cast_Result_35 : Bare_Base_Type_Decl;
Cast_Expr_35 : Bare_Type_Decl;
Cast_Result_36 : Bare_Base_Type_Decl;
Fld_20 : Internal_Env_Assoc := No_Env_Assoc;
Sym_16 : Symbol_Type;
Cast_Expr_36 : Bare_Type_Decl;
Cast_Result_37 : Bare_Base_Type_Decl;
Cast_Expr_37 : Bare_Type_Decl;
Cast_Result_38 : Bare_Base_Type_Decl;
Fld_21 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_589 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Fld_21);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_589;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Ordinary_Fixed_Point_Def_Ordinary_Fixed_Point_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Ordinary_Fixed_Point_Def,
                                As_Bare_Ordinary_Fixed_Point_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11638 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11598 '<Cast to TypeDecl at ast.py:7776>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:7776
--# expr-start 11597 '<parent at ast.py:7776>' Fld /tmp/lal-23.0.0/ada/ast.py:7776
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11597
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11598
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11600 '<FieldAccess for node at ast.py:7777>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:7777
--# expr-start 11599 '<FieldAccess for bool_type at ast.py:7777>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:7777
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11599
Fld_2 := Fld_1.Node;
--# expr-done 11600
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11602 '<FieldAccess for node at ast.py:7778>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:7778
--# expr-start 11601 '<FieldAccess for int_type at ast.py:7778>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:7778
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 11601
Fld_4 := Fld_3.Node;
--# expr-done 11602
Block_Var_2 := Fld_4; 
--# bind int_type Block_Var_2
--# expr-start 11637 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11604 '<FieldAccess for create_binop_assoc at ast.py:7781>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:7781
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11603 '<Symbol "+" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11603
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Cast_Result_3);
--# end
--# expr-done 11604
--# expr-start 11606 '<FieldAccess for create_binop_assoc at ast.py:7782>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:7782
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11605 '<Symbol "-" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11605
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_4, Rhs => Cast_Result_5, Ret => Cast_Result_6);
--# end
--# expr-done 11606
--# expr-start 11608 '<FieldAccess for create_binop_assoc at ast.py:7783>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:7783
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11607 '<Symbol "*" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11607
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Cast_Result_9);
--# end
--# expr-done 11608
--# expr-start 11610 '<FieldAccess for create_binop_assoc at ast.py:7784>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:7784
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11609 '<Symbol "/" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11609
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_10, Rhs => Cast_Result_11, Ret => Cast_Result_12);
--# end
--# expr-done 11610
--# expr-start 11612 '<FieldAccess for create_binop_assoc at ast.py:7786>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:7786
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11611 '<Symbol "*" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11611
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Block_Var_2, Rhs => Cast_Result_13, Ret => Cast_Result_14);
--# end
--# expr-done 11612
--# expr-start 11614 '<FieldAccess for create_binop_assoc at ast.py:7787>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:7787
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11613 '<Symbol "*" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11613
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_15, Rhs => Block_Var_2, Ret => Cast_Result_16);
--# end
--# expr-done 11614
--# expr-start 11616 '<FieldAccess for create_binop_assoc at ast.py:7788>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:7788
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11615 '<Symbol "/" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11615
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_17, Rhs => Block_Var_2, Ret => Cast_Result_18);
--# end
--# expr-done 11616
--# expr-start 11618 '<FieldAccess for create_binop_assoc at ast.py:7789>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:7789
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11617 '<Symbol "**" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_3); 
--# expr-done 11617
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
--# property-call-start AdaNode.create_binop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_19, Rhs => Block_Var_2, Ret => Cast_Result_20);
--# end
--# expr-done 11618
--# expr-start 11620 '<FieldAccess for create_binop_assoc at ast.py:7791>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:7791
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11619 '<Symbol "<" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11619
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
--# property-call-start AdaNode.create_binop_assoc
Fld_13 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_21, Rhs => Cast_Result_22, Ret => Block_Var_1);
--# end
--# expr-done 11620
--# expr-start 11622 '<FieldAccess for create_binop_assoc at ast.py:7792>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:7792
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11621 '<Symbol "<=" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11621
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
--# property-call-start AdaNode.create_binop_assoc
Fld_14 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_9, Lhs => Cast_Result_23, Rhs => Cast_Result_24, Ret => Block_Var_1);
--# end
--# expr-done 11622
--# expr-start 11624 '<FieldAccess for create_binop_assoc at ast.py:7793>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:7793
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11623 '<Symbol "=" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11623
Cast_Expr_24 := Block_Var; 
      Cast_Result_25 := Cast_Expr_24;
Cast_Expr_25 := Block_Var; 
      Cast_Result_26 := Cast_Expr_25;
--# property-call-start AdaNode.create_binop_assoc
Fld_15 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_10, Lhs => Cast_Result_25, Rhs => Cast_Result_26, Ret => Block_Var_1);
--# end
--# expr-done 11624
--# expr-start 11626 '<FieldAccess for create_binop_assoc at ast.py:7794>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:7794
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11625 '<Symbol "/=" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11625
Cast_Expr_26 := Block_Var; 
      Cast_Result_27 := Cast_Expr_26;
Cast_Expr_27 := Block_Var; 
      Cast_Result_28 := Cast_Expr_27;
--# property-call-start AdaNode.create_binop_assoc
Fld_16 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_11, Lhs => Cast_Result_27, Rhs => Cast_Result_28, Ret => Block_Var_1);
--# end
--# expr-done 11626
--# expr-start 11628 '<FieldAccess for create_binop_assoc at ast.py:7795>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:7795
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11627 '<Symbol ">" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11627
Cast_Expr_28 := Block_Var; 
      Cast_Result_29 := Cast_Expr_28;
Cast_Expr_29 := Block_Var; 
      Cast_Result_30 := Cast_Expr_29;
--# property-call-start AdaNode.create_binop_assoc
Fld_17 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_12, Lhs => Cast_Result_29, Rhs => Cast_Result_30, Ret => Block_Var_1);
--# end
--# expr-done 11628
--# expr-start 11630 '<FieldAccess for create_binop_assoc at ast.py:7796>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:7796
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11629 '<Symbol ">=" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11629
Cast_Expr_30 := Block_Var; 
      Cast_Result_31 := Cast_Expr_30;
Cast_Expr_31 := Block_Var; 
      Cast_Result_32 := Cast_Expr_31;
--# property-call-start AdaNode.create_binop_assoc
Fld_18 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_13, Lhs => Cast_Result_31, Rhs => Cast_Result_32, Ret => Block_Var_1);
--# end
--# expr-done 11630
--# expr-start 11632 '<FieldAccess for create_unop_assoc at ast.py:7798>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:7798
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11631 '<Symbol "+" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11631
Cast_Expr_32 := Block_Var; 
      Cast_Result_33 := Cast_Expr_32;
Cast_Expr_33 := Block_Var; 
      Cast_Result_34 := Cast_Expr_33;
--# property-call-start AdaNode.create_unop_assoc
Fld_19 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_14, Rhs => Cast_Result_33, Ret => Cast_Result_34);
--# end
--# expr-done 11632
--# expr-start 11634 '<FieldAccess for create_unop_assoc at ast.py:7799>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:7799
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11633 '<Symbol "-" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11633
Cast_Expr_34 := Block_Var; 
      Cast_Result_35 := Cast_Expr_34;
Cast_Expr_35 := Block_Var; 
      Cast_Result_36 := Cast_Expr_35;
--# property-call-start AdaNode.create_unop_assoc
Fld_20 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_15, Rhs => Cast_Result_35, Ret => Cast_Result_36);
--# end
--# expr-done 11634
--# expr-start 11636 '<FieldAccess for create_unop_assoc at ast.py:7800>' Fld_21 /tmp/lal-23.0.0/ada/ast.py:7800
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11635 '<Symbol "abs" at ???>' Sym_16 None
Sym_16 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 11635
Cast_Expr_36 := Block_Var; 
      Cast_Result_37 := Cast_Expr_36;
Cast_Expr_37 := Block_Var; 
      Cast_Result_38 := Cast_Expr_37;
--# property-call-start AdaNode.create_unop_assoc
Fld_21 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_16, Rhs => Cast_Result_37, Ret => Cast_Result_38);
--# end
--# expr-done 11636
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_5, 2 => Fld_6, 3 => Fld_7, 4 => Fld_8, 5 => Fld_9, 6 => Fld_10, 7 => Fld_11, 8 => Fld_12, 9 => Fld_13, 10 => Fld_14, 11 => Fld_15, 12 => Fld_16, 13 => Fld_17, 14 => Fld_18, 15 => Fld_19, 16 => Fld_20, 17 => Fld_21)); 
--# expr-done 11637
Let_Result := Array_Lit; Inc_Ref (Let_Result);
--# end
--# expr-done 11638
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_589;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_589;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ordinary_Fixed_Point_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Record_Type_Def
   --
      procedure Initialize_Fields_For_Record_Type_Def
        (Self : Bare_Record_Type_Def
         ; Record_Type_Def_F_Has_Abstract : Bare_Abstract_Node
         ; Record_Type_Def_F_Has_Tagged : Bare_Tagged_Node
         ; Record_Type_Def_F_Has_Limited : Bare_Limited_Node
         ; Record_Type_Def_F_Record_Def : Bare_Base_Record_Def
        ) is
      begin
            Self.Record_Type_Def_F_Has_Abstract := Record_Type_Def_F_Has_Abstract;
            Self.Record_Type_Def_F_Has_Tagged := Record_Type_Def_F_Has_Tagged;
            Self.Record_Type_Def_F_Has_Limited := Record_Type_Def_F_Has_Limited;
            Self.Record_Type_Def_F_Record_Def := Record_Type_Def_F_Record_Def;
      end Initialize_Fields_For_Record_Type_Def;
   function Record_Type_Def_F_Has_Abstract
     (Node : Bare_Record_Type_Def) return Bare_Abstract_Node
   is
   begin
         return Node.Record_Type_Def_F_Has_Abstract;
   end;
   function Record_Type_Def_F_Has_Tagged
     (Node : Bare_Record_Type_Def) return Bare_Tagged_Node
   is
   begin
         return Node.Record_Type_Def_F_Has_Tagged;
   end;
   function Record_Type_Def_F_Has_Limited
     (Node : Bare_Record_Type_Def) return Bare_Limited_Node
   is
   begin
         return Node.Record_Type_Def_F_Has_Limited;
   end;
   function Record_Type_Def_F_Record_Def
     (Node : Bare_Record_Type_Def) return Bare_Base_Record_Def
   is
   begin
         return Node.Record_Type_Def_F_Record_Def;
   end;
--# property-start RecordTypeDef.is_tagged_type /tmp/lal-23.0.0/ada/ast.py:5086
pragma Warnings (Off, "is not referenced");
 function Record_Type_Def_P_Is_Tagged_Type
  (Node : Bare_Record_Type_Def
      ; Origin : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Record_Type_Def := Bare_Record_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
      Fld : Bare_Tagged_Node;
Fld_1 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11640 '<FieldAccess for as_bool at ast.py:5086>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5086
--# expr-start 11639 '<FieldAccess for has_tagged at ast.py:5086>' Fld /tmp/lal-23.0.0/ada/ast.py:5086
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Record_Type_Def_F_Has_Tagged;
--# expr-done 11639
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Tagged.as_bool'
Fld_1 := Libadalang.Implementation.Dispatcher_Tagged_Node_P_As_Bool (Node => Fld);
--# end
--# expr-done 11640
      Property_Result := Fld_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Record_Type_Def_P_Is_Tagged_Type;
--# end
--# property-start RecordTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:5088
pragma Warnings (Off, "is not referenced");
 function Record_Type_Def_P_Xref_Equation
  (Node : Bare_Record_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Record_Type_Def := Bare_Record_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_364 with Inline_Always;
      True_Rel : Logic_Equation;
            procedure Finalizer_Scope_364 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_364;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:5088") else null)); 
      Property_Result := True_Rel;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_364;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_364;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Record_Type_Def_P_Xref_Equation;
--# end
--# property-start RecordTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:5091
pragma Warnings (Off, "is not referenced");
 function Record_Type_Def_P_Predefined_Operators
  (Node : Bare_Record_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Record_Type_Def := Bare_Record_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_365 with Inline_Always;
      Fld : Internal_Env_Assoc_Array_Access;
Fld_1 : Bare_Limited_Node;
Fld_2 : Boolean;
If_Result : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_365 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_365;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Record_Type_Def_Record_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Record_Type_Def,
                                As_Bare_Record_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11645 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11644 '<If at ast.py:5092>' If_Result /tmp/lal-23.0.0/ada/ast.py:5092
--# expr-start 11642 '<FieldAccess for as_bool at ast.py:5093>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:5093
--# expr-start 11641 '<FieldAccess for has_limited at ast.py:5093>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:5093
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Self.Record_Type_Def_F_Has_Limited;
--# expr-done 11641
      if Fld_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Limited.as_bool'
Fld_2 := Libadalang.Implementation.Dispatcher_Limited_Node_P_As_Bool (Node => Fld_1);
--# end
--# expr-done 11642
if Fld_2 then
   If_Result := No_Internal_Env_Assoc_Array_Type;
else
   --# expr-start 11643 '<FieldAccess for predefined_equality_operators at ast.py:5095>' Fld /tmp/lal-23.0.0/ada/ast.py:5095
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeDef.predefined_equality_operators
Fld := Libadalang.Implementation.Type_Def_P_Predefined_Equality_Operators (Node => Self);
--# end
--# expr-done 11643
   If_Result := Fld;
end if;
      Inc_Ref (If_Result);
--# expr-done 11644
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11645
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_365;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_365;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Record_Type_Def_P_Predefined_Operators;
--# end
   --
   --  Primitives for Bare_Signed_Int_Type_Def
   --
      procedure Initialize_Fields_For_Signed_Int_Type_Def
        (Self : Bare_Signed_Int_Type_Def
         ; Signed_Int_Type_Def_F_Range : Bare_Range_Spec
        ) is
      begin
            Self.Signed_Int_Type_Def_F_Range := Signed_Int_Type_Def_F_Range;
      end Initialize_Fields_For_Signed_Int_Type_Def;
   function Signed_Int_Type_Def_F_Range
     (Node : Bare_Signed_Int_Type_Def) return Bare_Range_Spec
   is
   begin
         return Node.Signed_Int_Type_Def_F_Range;
   end;
--# property-start SignedIntTypeDef.is_int_type /tmp/lal-23.0.0/ada/ast.py:8164
pragma Warnings (Off, "is not referenced");
 function Signed_Int_Type_Def_P_Is_Int_Type
  (Node : Bare_Signed_Int_Type_Def
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Signed_Int_Type_Def := Bare_Signed_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Signed_Int_Type_Def_P_Is_Int_Type;
--# end
--# property-start SignedIntTypeDef.xref_equation /tmp/lal-23.0.0/ada/ast.py:8166
pragma Warnings (Off, "is not referenced");
 function Signed_Int_Type_Def_P_Xref_Equation
  (Node : Bare_Signed_Int_Type_Def
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Signed_Int_Type_Def := Bare_Signed_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Signed_Int_Type_Def :=
     Internal_Entity_Signed_Int_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_625 with Inline_Always;
      Fld : Internal_Entity_Range_Spec;
Fld_1 : Logic_Equation;
            procedure Finalizer_Scope_625 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_625;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11647 '<FieldAccess for xref_equation at ast.py:8166>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8166
--# expr-start 11646 '<FieldAccess for range at ast.py:8166>' Fld /tmp/lal-23.0.0/ada/ast.py:8166
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Signed_Int_Type_Def_F_Range, Info => Ent.Info);
--# expr-done 11646
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_1 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11647
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_625;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_625;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Signed_Int_Type_Def_P_Xref_Equation;
--# end
--# property-start SignedIntTypeDef.discrete_range /tmp/lal-23.0.0/ada/ast.py:8169
pragma Warnings (Off, "is not referenced");
 function Signed_Int_Type_Def_P_Discrete_Range
  (Node : Bare_Signed_Int_Type_Def
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Signed_Int_Type_Def := Bare_Signed_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Signed_Int_Type_Def :=
     Internal_Entity_Signed_Int_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Fld : Internal_Entity_Range_Spec;
Fld_1 : Internal_Entity_Expr;
Fld_2 : Internal_Discrete_Range;
Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11651 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11650 '<FieldAccess for discrete_range at ast.py:8170>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8170
--# expr-start 11649 '<FieldAccess for range at ast.py:8170>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8170
--# expr-start 11648 '<FieldAccess for range at ast.py:8170>' Fld /tmp/lal-23.0.0/ada/ast.py:8170
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Signed_Int_Type_Def_F_Range, Info => Ent.Info);
--# expr-done 11648
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Expr (Node => Fld.Node.Range_Spec_F_Range, Info => Fld.Info);
--# expr-done 11649
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.discrete_range
Fld_2 := Libadalang.Implementation.Expr_P_Discrete_Range (Node => Fld_1.Node, E_Info => Fld_1.Info);
--# end
--# expr-done 11650
Let_Result := Fld_2; 
--# end
--# expr-done 11651
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Signed_Int_Type_Def_P_Discrete_Range;
--# end
--# property-start SignedIntTypeDef.predefined_operators /tmp/lal-23.0.0/ada/ast.py:8173
pragma Warnings (Off, "is not referenced");
 function Signed_Int_Type_Def_P_Predefined_Operators
  (Node : Bare_Signed_Int_Type_Def
  )
   return Internal_Env_Assoc_Array_Access
is
   Self : Bare_Signed_Int_Type_Def := Bare_Signed_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_627 with Inline_Always;
      Block_Var : Bare_Type_Decl;
Block_Var_1 : Bare_Base_Type_Decl;
Block_Var_2 : Bare_Base_Type_Decl;
Block_Var_3 : Internal_Env_Assoc_Array_Access;
Fld : Bare_Ada_Node;
Cast_Result : Bare_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Bare_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Bare_Base_Type_Decl;
Sym : Symbol_Type;
Cast_Expr : Bare_Type_Decl;
Cast_Result_1 : Bare_Base_Type_Decl;
Cast_Expr_1 : Bare_Type_Decl;
Cast_Result_2 : Bare_Base_Type_Decl;
Cast_Expr_2 : Bare_Type_Decl;
Cast_Result_3 : Bare_Base_Type_Decl;
Fld_5 : Internal_Env_Assoc := No_Env_Assoc;
Sym_1 : Symbol_Type;
Cast_Expr_3 : Bare_Type_Decl;
Cast_Result_4 : Bare_Base_Type_Decl;
Cast_Expr_4 : Bare_Type_Decl;
Cast_Result_5 : Bare_Base_Type_Decl;
Cast_Expr_5 : Bare_Type_Decl;
Cast_Result_6 : Bare_Base_Type_Decl;
Fld_6 : Internal_Env_Assoc := No_Env_Assoc;
Sym_2 : Symbol_Type;
Cast_Expr_6 : Bare_Type_Decl;
Cast_Result_7 : Bare_Base_Type_Decl;
Cast_Expr_7 : Bare_Type_Decl;
Cast_Result_8 : Bare_Base_Type_Decl;
Cast_Expr_8 : Bare_Type_Decl;
Cast_Result_9 : Bare_Base_Type_Decl;
Fld_7 : Internal_Env_Assoc := No_Env_Assoc;
Sym_3 : Symbol_Type;
Cast_Expr_9 : Bare_Type_Decl;
Cast_Result_10 : Bare_Base_Type_Decl;
Cast_Expr_10 : Bare_Type_Decl;
Cast_Result_11 : Bare_Base_Type_Decl;
Cast_Expr_11 : Bare_Type_Decl;
Cast_Result_12 : Bare_Base_Type_Decl;
Fld_8 : Internal_Env_Assoc := No_Env_Assoc;
Sym_4 : Symbol_Type;
Cast_Expr_12 : Bare_Type_Decl;
Cast_Result_13 : Bare_Base_Type_Decl;
Cast_Expr_13 : Bare_Type_Decl;
Cast_Result_14 : Bare_Base_Type_Decl;
Cast_Expr_14 : Bare_Type_Decl;
Cast_Result_15 : Bare_Base_Type_Decl;
Fld_9 : Internal_Env_Assoc := No_Env_Assoc;
Sym_5 : Symbol_Type;
Cast_Expr_15 : Bare_Type_Decl;
Cast_Result_16 : Bare_Base_Type_Decl;
Cast_Expr_16 : Bare_Type_Decl;
Cast_Result_17 : Bare_Base_Type_Decl;
Cast_Expr_17 : Bare_Type_Decl;
Cast_Result_18 : Bare_Base_Type_Decl;
Fld_10 : Internal_Env_Assoc := No_Env_Assoc;
Sym_6 : Symbol_Type;
Cast_Expr_18 : Bare_Type_Decl;
Cast_Result_19 : Bare_Base_Type_Decl;
Cast_Expr_19 : Bare_Type_Decl;
Cast_Result_20 : Bare_Base_Type_Decl;
Fld_11 : Internal_Env_Assoc := No_Env_Assoc;
Sym_7 : Symbol_Type;
Cast_Expr_20 : Bare_Type_Decl;
Cast_Result_21 : Bare_Base_Type_Decl;
Cast_Expr_21 : Bare_Type_Decl;
Cast_Result_22 : Bare_Base_Type_Decl;
Fld_12 : Internal_Env_Assoc := No_Env_Assoc;
Sym_8 : Symbol_Type;
Cast_Expr_22 : Bare_Type_Decl;
Cast_Result_23 : Bare_Base_Type_Decl;
Cast_Expr_23 : Bare_Type_Decl;
Cast_Result_24 : Bare_Base_Type_Decl;
Fld_13 : Internal_Env_Assoc := No_Env_Assoc;
Sym_9 : Symbol_Type;
Cast_Expr_24 : Bare_Type_Decl;
Cast_Result_25 : Bare_Base_Type_Decl;
Cast_Expr_25 : Bare_Type_Decl;
Cast_Result_26 : Bare_Base_Type_Decl;
Fld_14 : Internal_Env_Assoc := No_Env_Assoc;
Sym_10 : Symbol_Type;
Cast_Expr_26 : Bare_Type_Decl;
Cast_Result_27 : Bare_Base_Type_Decl;
Cast_Expr_27 : Bare_Type_Decl;
Cast_Result_28 : Bare_Base_Type_Decl;
Fld_15 : Internal_Env_Assoc := No_Env_Assoc;
Sym_11 : Symbol_Type;
Cast_Expr_28 : Bare_Type_Decl;
Cast_Result_29 : Bare_Base_Type_Decl;
Cast_Expr_29 : Bare_Type_Decl;
Cast_Result_30 : Bare_Base_Type_Decl;
Fld_16 : Internal_Env_Assoc := No_Env_Assoc;
Sym_12 : Symbol_Type;
Cast_Expr_30 : Bare_Type_Decl;
Cast_Result_31 : Bare_Base_Type_Decl;
Cast_Expr_31 : Bare_Type_Decl;
Cast_Result_32 : Bare_Base_Type_Decl;
Fld_17 : Internal_Env_Assoc := No_Env_Assoc;
Sym_13 : Symbol_Type;
Cast_Expr_32 : Bare_Type_Decl;
Cast_Result_33 : Bare_Base_Type_Decl;
Cast_Expr_33 : Bare_Type_Decl;
Cast_Result_34 : Bare_Base_Type_Decl;
Fld_18 : Internal_Env_Assoc := No_Env_Assoc;
Sym_14 : Symbol_Type;
Cast_Expr_34 : Bare_Type_Decl;
Cast_Result_35 : Bare_Base_Type_Decl;
Cast_Expr_35 : Bare_Type_Decl;
Cast_Result_36 : Bare_Base_Type_Decl;
Fld_19 : Internal_Env_Assoc := No_Env_Assoc;
Sym_15 : Symbol_Type;
Cast_Expr_36 : Bare_Type_Decl;
Cast_Result_37 : Bare_Base_Type_Decl;
Cast_Expr_37 : Bare_Type_Decl;
Cast_Result_38 : Bare_Base_Type_Decl;
Fld_20 : Internal_Env_Assoc := No_Env_Assoc;
Array_Lit : Internal_Env_Assoc_Array_Access;
Let_Result : Internal_Env_Assoc_Array_Access;
            procedure Finalizer_Scope_627 is
            begin
                     Dec_Ref (Fld_5);
                     Dec_Ref (Fld_6);
                     Dec_Ref (Fld_7);
                     Dec_Ref (Fld_8);
                     Dec_Ref (Fld_9);
                     Dec_Ref (Fld_10);
                     Dec_Ref (Fld_11);
                     Dec_Ref (Fld_12);
                     Dec_Ref (Fld_13);
                     Dec_Ref (Fld_14);
                     Dec_Ref (Fld_15);
                     Dec_Ref (Fld_16);
                     Dec_Ref (Fld_17);
                     Dec_Ref (Fld_18);
                     Dec_Ref (Fld_19);
                     Dec_Ref (Fld_20);
                     Dec_Ref (Array_Lit);
                     Dec_Ref (Block_Var_3);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_627;
      Mmz_Handle : Memoization_Handle;
      Mmz_Val    : Mmz_Value;
      Mmz_Stored : Boolean;
      --  Whether the memoization couple was actually stored. Used to determine
      --  whether to inc-ref the memoized value.
      function Create_Mmz_Key return Mmz_Key;
      --  Create a memoization key for this property call and return it
      --------------------
      -- Create_Mmz_Key --
      --------------------
      function Create_Mmz_Key return Mmz_Key is
      begin
         return Mmz_K : Mmz_Key :=
           (Property => Mmz_Bare_Signed_Int_Type_Def_Signed_Int_Type_Def_P_Predefined_Operators,
            Items    => new Mmz_Key_Array (1 ..  1))
         do
            Mmz_K.Items (1) := (Kind => Mmz_Bare_Signed_Int_Type_Def,
                                As_Bare_Signed_Int_Type_Def => Self);
         end return;
      end Create_Mmz_Key;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            if Find_Memoized_Value
              (Self.Unit, Mmz_Handle, Mmz_Val, Create_Mmz_Key'Access)
            then
               --# memoization-lookup
               if Mmz_Val.Kind = Mmz_Evaluating then
                  --# memoization-return
                  Raise_Property_Exception
                    (Self,
                     Property_Error'Identity,
                     "Infinite recursion detected");
               elsif Mmz_Val.Kind = Mmz_Error then
                  --# memoization-return
                  Ada.Exceptions.Raise_Exception
                    (Mmz_Val.Exc_Id, "Memoized error");
               else
                  Property_Result := Mmz_Val.As_Internal_Env_Assoc_Array_Access;
                     Inc_Ref (Property_Result);
                  --# memoization-return
                  Exit_Call (Self.Unit.Context, Call_Depth);
                  return Property_Result;
               end if;
               --# end
            end if;
         end if;
      end if;
   --# scope-start
      --# expr-start 11691 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11653 '<Cast to TypeDecl at ast.py:8174>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8174
--# expr-start 11652 '<parent at ast.py:8174>' Fld /tmp/lal-23.0.0/ada/ast.py:8174
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11652
   if Fld = null
      or else Fld.Kind in Ada_Type_Decl
   then
      Cast_Result := Fld;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11653
Block_Var := Cast_Result; 
--# bind self_type Block_Var
--# expr-start 11655 '<FieldAccess for node at ast.py:8175>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8175
--# expr-start 11654 '<FieldAccess for bool_type at ast.py:8175>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8175
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.bool_type
Fld_1 := Libadalang.Implementation.Ada_Node_P_Bool_Type (Node => Self);
--# end
--# expr-done 11654
Fld_2 := Fld_1.Node;
--# expr-done 11655
Block_Var_1 := Fld_2; 
--# bind bool_type Block_Var_1
--# expr-start 11657 '<FieldAccess for node at ast.py:8176>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8176
--# expr-start 11656 '<FieldAccess for int_type at ast.py:8176>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8176
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.int_type
Fld_3 := Libadalang.Implementation.Ada_Node_P_Int_Type (Node => Self);
--# end
--# expr-done 11656
Fld_4 := Fld_3.Node;
--# expr-done 11657
Block_Var_2 := Fld_4; 
--# bind int_type Block_Var_2
--# expr-start 11690 '<ArrayLiteral at ???>' Array_Lit None
--# expr-start 11659 '<FieldAccess for create_binop_assoc at ast.py:8179>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:8179
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11658 '<Symbol "+" at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11658
Cast_Expr := Block_Var; 
      Cast_Result_1 := Cast_Expr;
Cast_Expr_1 := Block_Var; 
      Cast_Result_2 := Cast_Expr_1;
Cast_Expr_2 := Block_Var; 
      Cast_Result_3 := Cast_Expr_2;
--# property-call-start AdaNode.create_binop_assoc
Fld_5 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym, Lhs => Cast_Result_1, Rhs => Cast_Result_2, Ret => Cast_Result_3);
--# end
--# expr-done 11659
--# expr-start 11661 '<FieldAccess for create_binop_assoc at ast.py:8180>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:8180
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11660 '<Symbol "-" at ???>' Sym_1 None
Sym_1 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11660
Cast_Expr_3 := Block_Var; 
      Cast_Result_4 := Cast_Expr_3;
Cast_Expr_4 := Block_Var; 
      Cast_Result_5 := Cast_Expr_4;
Cast_Expr_5 := Block_Var; 
      Cast_Result_6 := Cast_Expr_5;
--# property-call-start AdaNode.create_binop_assoc
Fld_6 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_1, Lhs => Cast_Result_4, Rhs => Cast_Result_5, Ret => Cast_Result_6);
--# end
--# expr-done 11661
--# expr-start 11663 '<FieldAccess for create_binop_assoc at ast.py:8181>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:8181
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11662 '<Symbol "*" at ???>' Sym_2 None
Sym_2 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_2); 
--# expr-done 11662
Cast_Expr_6 := Block_Var; 
      Cast_Result_7 := Cast_Expr_6;
Cast_Expr_7 := Block_Var; 
      Cast_Result_8 := Cast_Expr_7;
Cast_Expr_8 := Block_Var; 
      Cast_Result_9 := Cast_Expr_8;
--# property-call-start AdaNode.create_binop_assoc
Fld_7 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_2, Lhs => Cast_Result_7, Rhs => Cast_Result_8, Ret => Cast_Result_9);
--# end
--# expr-done 11663
--# expr-start 11665 '<FieldAccess for create_binop_assoc at ast.py:8182>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:8182
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11664 '<Symbol "/" at ???>' Sym_3 None
Sym_3 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_6); 
--# expr-done 11664
Cast_Expr_9 := Block_Var; 
      Cast_Result_10 := Cast_Expr_9;
Cast_Expr_10 := Block_Var; 
      Cast_Result_11 := Cast_Expr_10;
Cast_Expr_11 := Block_Var; 
      Cast_Result_12 := Cast_Expr_11;
--# property-call-start AdaNode.create_binop_assoc
Fld_8 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_3, Lhs => Cast_Result_10, Rhs => Cast_Result_11, Ret => Cast_Result_12);
--# end
--# expr-done 11665
--# expr-start 11667 '<FieldAccess for create_binop_assoc at ast.py:8183>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:8183
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11666 '<Symbol "mod" at ???>' Sym_4 None
Sym_4 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Mod); 
--# expr-done 11666
Cast_Expr_12 := Block_Var; 
      Cast_Result_13 := Cast_Expr_12;
Cast_Expr_13 := Block_Var; 
      Cast_Result_14 := Cast_Expr_13;
Cast_Expr_14 := Block_Var; 
      Cast_Result_15 := Cast_Expr_14;
--# property-call-start AdaNode.create_binop_assoc
Fld_9 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_4, Lhs => Cast_Result_13, Rhs => Cast_Result_14, Ret => Cast_Result_15);
--# end
--# expr-done 11667
--# expr-start 11669 '<FieldAccess for create_binop_assoc at ast.py:8184>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:8184
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11668 '<Symbol "rem" at ???>' Sym_5 None
Sym_5 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Rem); 
--# expr-done 11668
Cast_Expr_15 := Block_Var; 
      Cast_Result_16 := Cast_Expr_15;
Cast_Expr_16 := Block_Var; 
      Cast_Result_17 := Cast_Expr_16;
Cast_Expr_17 := Block_Var; 
      Cast_Result_18 := Cast_Expr_17;
--# property-call-start AdaNode.create_binop_assoc
Fld_10 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_5, Lhs => Cast_Result_16, Rhs => Cast_Result_17, Ret => Cast_Result_18);
--# end
--# expr-done 11669
--# expr-start 11671 '<FieldAccess for create_binop_assoc at ast.py:8186>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:8186
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11670 '<Symbol "**" at ???>' Sym_6 None
Sym_6 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_3); 
--# expr-done 11670
Cast_Expr_18 := Block_Var; 
      Cast_Result_19 := Cast_Expr_18;
Cast_Expr_19 := Block_Var; 
      Cast_Result_20 := Cast_Expr_19;
--# property-call-start AdaNode.create_binop_assoc
Fld_11 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_6, Lhs => Cast_Result_19, Rhs => Block_Var_2, Ret => Cast_Result_20);
--# end
--# expr-done 11671
--# expr-start 11673 '<FieldAccess for create_binop_assoc at ast.py:8188>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:8188
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11672 '<Symbol "<" at ???>' Sym_7 None
Sym_7 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_8); 
--# expr-done 11672
Cast_Expr_20 := Block_Var; 
      Cast_Result_21 := Cast_Expr_20;
Cast_Expr_21 := Block_Var; 
      Cast_Result_22 := Cast_Expr_21;
--# property-call-start AdaNode.create_binop_assoc
Fld_12 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_7, Lhs => Cast_Result_21, Rhs => Cast_Result_22, Ret => Block_Var_1);
--# end
--# expr-done 11673
--# expr-start 11675 '<FieldAccess for create_binop_assoc at ast.py:8189>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:8189
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11674 '<Symbol "<=" at ???>' Sym_8 None
Sym_8 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_9); 
--# expr-done 11674
Cast_Expr_22 := Block_Var; 
      Cast_Result_23 := Cast_Expr_22;
Cast_Expr_23 := Block_Var; 
      Cast_Result_24 := Cast_Expr_23;
--# property-call-start AdaNode.create_binop_assoc
Fld_13 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_8, Lhs => Cast_Result_23, Rhs => Cast_Result_24, Ret => Block_Var_1);
--# end
--# expr-done 11675
--# expr-start 11677 '<FieldAccess for create_binop_assoc at ast.py:8190>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:8190
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11676 '<Symbol "=" at ???>' Sym_9 None
Sym_9 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_10); 
--# expr-done 11676
Cast_Expr_24 := Block_Var; 
      Cast_Result_25 := Cast_Expr_24;
Cast_Expr_25 := Block_Var; 
      Cast_Result_26 := Cast_Expr_25;
--# property-call-start AdaNode.create_binop_assoc
Fld_14 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_9, Lhs => Cast_Result_25, Rhs => Cast_Result_26, Ret => Block_Var_1);
--# end
--# expr-done 11677
--# expr-start 11679 '<FieldAccess for create_binop_assoc at ast.py:8191>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:8191
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11678 '<Symbol "/=" at ???>' Sym_10 None
Sym_10 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_7); 
--# expr-done 11678
Cast_Expr_26 := Block_Var; 
      Cast_Result_27 := Cast_Expr_26;
Cast_Expr_27 := Block_Var; 
      Cast_Result_28 := Cast_Expr_27;
--# property-call-start AdaNode.create_binop_assoc
Fld_15 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_10, Lhs => Cast_Result_27, Rhs => Cast_Result_28, Ret => Block_Var_1);
--# end
--# expr-done 11679
--# expr-start 11681 '<FieldAccess for create_binop_assoc at ast.py:8192>' Fld_16 /tmp/lal-23.0.0/ada/ast.py:8192
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11680 '<Symbol ">" at ???>' Sym_11 None
Sym_11 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_11); 
--# expr-done 11680
Cast_Expr_28 := Block_Var; 
      Cast_Result_29 := Cast_Expr_28;
Cast_Expr_29 := Block_Var; 
      Cast_Result_30 := Cast_Expr_29;
--# property-call-start AdaNode.create_binop_assoc
Fld_16 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_11, Lhs => Cast_Result_29, Rhs => Cast_Result_30, Ret => Block_Var_1);
--# end
--# expr-done 11681
--# expr-start 11683 '<FieldAccess for create_binop_assoc at ast.py:8193>' Fld_17 /tmp/lal-23.0.0/ada/ast.py:8193
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11682 '<Symbol ">=" at ???>' Sym_12 None
Sym_12 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_12); 
--# expr-done 11682
Cast_Expr_30 := Block_Var; 
      Cast_Result_31 := Cast_Expr_30;
Cast_Expr_31 := Block_Var; 
      Cast_Result_32 := Cast_Expr_31;
--# property-call-start AdaNode.create_binop_assoc
Fld_17 := Libadalang.Implementation.Ada_Node_P_Create_Binop_Assoc (Node => Self, Op => Sym_12, Lhs => Cast_Result_31, Rhs => Cast_Result_32, Ret => Block_Var_1);
--# end
--# expr-done 11683
--# expr-start 11685 '<FieldAccess for create_unop_assoc at ast.py:8195>' Fld_18 /tmp/lal-23.0.0/ada/ast.py:8195
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11684 '<Symbol "+" at ???>' Sym_13 None
Sym_13 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_4); 
--# expr-done 11684
Cast_Expr_32 := Block_Var; 
      Cast_Result_33 := Cast_Expr_32;
Cast_Expr_33 := Block_Var; 
      Cast_Result_34 := Cast_Expr_33;
--# property-call-start AdaNode.create_unop_assoc
Fld_18 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_13, Rhs => Cast_Result_33, Ret => Cast_Result_34);
--# end
--# expr-done 11685
--# expr-start 11687 '<FieldAccess for create_unop_assoc at ast.py:8196>' Fld_19 /tmp/lal-23.0.0/ada/ast.py:8196
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11686 '<Symbol "-" at ???>' Sym_14 None
Sym_14 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_5); 
--# expr-done 11686
Cast_Expr_34 := Block_Var; 
      Cast_Result_35 := Cast_Expr_34;
Cast_Expr_35 := Block_Var; 
      Cast_Result_36 := Cast_Expr_35;
--# property-call-start AdaNode.create_unop_assoc
Fld_19 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_14, Rhs => Cast_Result_35, Ret => Cast_Result_36);
--# end
--# expr-done 11687
--# expr-start 11689 '<FieldAccess for create_unop_assoc at ast.py:8197>' Fld_20 /tmp/lal-23.0.0/ada/ast.py:8197
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11688 '<Symbol "abs" at ???>' Sym_15 None
Sym_15 := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Abs); 
--# expr-done 11688
Cast_Expr_36 := Block_Var; 
      Cast_Result_37 := Cast_Expr_36;
Cast_Expr_37 := Block_Var; 
      Cast_Result_38 := Cast_Expr_37;
--# property-call-start AdaNode.create_unop_assoc
Fld_20 := Libadalang.Implementation.Ada_Node_P_Create_Unop_Assoc (Node => Self, Op => Sym_15, Rhs => Cast_Result_37, Ret => Cast_Result_38);
--# end
--# expr-done 11689
Array_Lit := Create_Internal_Env_Assoc_Array (Internal_Internal_Env_Assoc_Array'(1 => Fld_5, 2 => Fld_6, 3 => Fld_7, 4 => Fld_8, 5 => Fld_9, 6 => Fld_10, 7 => Fld_11, 8 => Fld_12, 9 => Fld_13, 10 => Fld_14, 11 => Fld_15, 12 => Fld_16, 13 => Fld_17, 14 => Fld_18, 15 => Fld_19, 16 => Fld_20)); 
--# expr-done 11690
Block_Var_3 := Array_Lit; Inc_Ref (Block_Var_3);
--# bind defaults Block_Var_3
Let_Result := Block_Var_3; Inc_Ref (Let_Result);
--# end
--# expr-done 11691
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_627;
      if Self /= null then
         if not Self.Unit.Context.In_Populate_Lexical_Env then
            Mmz_Val := (Kind => Mmz_Internal_Env_Assoc_Array_Access,
                        As_Internal_Env_Assoc_Array_Access => Property_Result);
            Add_Memoized_Value (Self.Unit, Mmz_Handle, Mmz_Val, Mmz_Stored);
               if Mmz_Stored then
                  Inc_Ref (Property_Result);
               end if;
         end if;
      end if;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_627;
         if Self /= null then
            if not Self.Unit.Context.In_Populate_Lexical_Env then
               Add_Memoized_Value
                 (Self.Unit,
                  Mmz_Handle,
                  (Kind   => Mmz_Error,
                   Exc_Id => Ada.Exceptions.Exception_Identity (Exc)),
                  Mmz_Stored);
            end if;
         end if;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Signed_Int_Type_Def_P_Predefined_Operators;
--# end
--# property-start SignedIntTypeDef.is_static /tmp/lal-23.0.0/ada/ast.py:8202
pragma Warnings (Off, "is not referenced");
 function Signed_Int_Type_Def_P_Is_Static
  (Node : Bare_Signed_Int_Type_Def
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Signed_Int_Type_Def := Bare_Signed_Int_Type_Def (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Signed_Int_Type_Def :=
     Internal_Entity_Signed_Int_Type_Def'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Fld : Internal_Entity_Range_Spec;
Fld_1 : Internal_Entity_Expr;
Fld_2 : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11694 '<FieldAccess for is_static_expr at ast.py:8202>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8202
--# expr-start 11693 '<FieldAccess for range at ast.py:8202>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8202
--# expr-start 11692 '<FieldAccess for range at ast.py:8202>' Fld /tmp/lal-23.0.0/ada/ast.py:8202
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Range_Spec (Node => Ent.Node.Signed_Int_Type_Def_F_Range, Info => Ent.Info);
--# expr-done 11692
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Expr (Node => Fld.Node.Range_Spec_F_Range, Info => Fld.Info);
--# expr-done 11693
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.is_static_expr
Fld_2 := Libadalang.Implementation.Expr_P_Is_Static_Expr (Node => Fld_1.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_1.Info);
--# end
--# expr-done 11694
      Property_Result := Fld_2;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Signed_Int_Type_Def_P_Is_Static;
--# end
   --
   --  Primitives for Bare_Type_Expr
   --
--# property-start TypeExpr.array_ndims /tmp/lal-23.0.0/ada/ast.py:8964
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Array_Ndims
  (Node : Bare_Type_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Integer
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Integer;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Base_Type_Decl;
Fld_2 : Integer;
Dyn_Var_Bind_Result : Integer;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11698 '<bind at ast.py:8965>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:8965
--# expr-start 11695 '<FieldAccess for origin_node at ast.py:8965>' Fld /tmp/lal-23.0.0/ada/ast.py:8965
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 11695
Bound_Origin := Fld; 
--# expr-start 11697 '<FieldAccess for array_ndims at ast.py:8965>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8965
--# expr-start 11696 '<FieldAccess for designated_type at ast.py:8965>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8965
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 11696
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.array_ndims'
Fld_2 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Array_Ndims (Node => Fld_1.Node, Origin => Bound_Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 11697
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 11698
      Property_Result := Dyn_Var_Bind_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Array_Ndims;
--# end
--# property-start TypeExpr.type_name /tmp/lal-23.0.0/ada/ast.py:8968
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Type_Name
  (Node : Bare_Type_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Name
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Name;
      Var_Expr : Internal_Entity_Subtype_Indication;
Cast_Expr : Internal_Entity_Type_Expr;
Cast_Result : Internal_Entity_Subtype_Indication;
Fld : Internal_Entity_Name;
Scope_Result : Internal_Entity_Name;
Result_Var : Internal_Entity_Name;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 11699 '<Cast to SubtypeIndication at ast.py:8969>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8969
Cast_Expr := Ent; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Subtype_Indication_Range
   then
      Cast_Result := Create_Internal_Entity_Subtype_Indication
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Subtype_Indication;
   end if;
--# expr-done 11699
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Subtype_Indication then
   --# scope-start
   --# bind sti Var_Expr
--# expr-start 11700 '<FieldAccess for name at ast.py:8969>' Fld /tmp/lal-23.0.0/ada/ast.py:8969
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Var_Expr.Node.Subtype_Indication_F_Name, Info => Var_Expr.Info);
--# expr-done 11700
Scope_Result := Fld;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Name;
end if;
      Property_Result := Result_Var;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Type_Name;
--# end
--# property-start TypeExpr.defining_env /tmp/lal-23.0.0/ada/ast.py:8977
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Defining_Env
  (Node : Bare_Type_Expr
      ; Origin : Bare_Ada_Node
      ; Include_Ud_Indexing : Boolean
      ; Dottable_Type : Bare_Ada_Node
         := No_Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   --# bind include_ud_indexing Include_Ud_Indexing
   --# bind dottable_type Dottable_Type
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_737 with Inline_Always;
      Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_737 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_737;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11703 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11702 '<FieldAccess for defining_env at ast.py:8978>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8978
--# expr-start 11701 '<FieldAccess for designated_type at ast.py:8978>' Fld /tmp/lal-23.0.0/ada/ast.py:8978
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11701
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.defining_env'
Fld_1 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Defining_Env (Node => Fld.Node, Origin => Origin, Include_Ud_Indexing => Include_Ud_Indexing, Dottable_Type => Dottable_Type, E_Info => Fld.Info);
--# end
--# expr-done 11702
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 11703
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_737;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_737;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Defining_Env;
--# end
--# property-start '[dispatcher]TypeExpr.designated_type' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Type_Expr_P_Designated_Type
  (Node : Bare_Type_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Type_Expr (Self.Kind) is
               when Ada_Anonymous_Type =>
                  --# property-call-start AnonymousType.designated_type
                  Property_Result := Anonymous_Type_P_Designated_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Enum_Lit_Synth_Type_Expr =>
                  --# property-call-start EnumLitSynthTypeExpr.designated_type
                  Property_Result := Enum_Lit_Synth_Type_Expr_P_Designated_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
                  --# property-call-start SubtypeIndication.designated_type
                  Property_Result := Subtype_Indication_P_Designated_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
               when Ada_Synthetic_Type_Expr =>
                  --# property-call-start SyntheticTypeExpr.designated_type
                  Property_Result := Synthetic_Type_Expr_P_Designated_Type
                    (Self
                        , Origin
                        , E_Info
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Type_Expr_P_Designated_Type;
--# end
--# property-start TypeExpr.designated_type_decl /tmp/lal-23.0.0/ada/ast.py:8988
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Designated_Type_Decl
  (Node : Bare_Type_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11706 '<bind at ast.py:8989>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:8989
--# expr-start 11704 '<FieldAccess for origin_node at ast.py:8989>' Fld /tmp/lal-23.0.0/ada/ast.py:8989
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 11704
Bound_Origin := Fld; 
--# expr-start 11705 '<FieldAccess for designated_type at ast.py:8989>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8989
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 11705
Dyn_Var_Bind_Result := Fld_1; 
--# expr-done 11706
      Property_Result := Dyn_Var_Bind_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Designated_Type_Decl;
--# end
--# property-start TypeExpr.designated_type_decl_from /tmp/lal-23.0.0/ada/ast.py:8997
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Designated_Type_Decl_From
  (Node : Bare_Type_Expr
      ; Origin_Node : Internal_Entity
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin_node Origin_Node
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11711 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11710 '<bind at ast.py:9002>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:9002
--# expr-start 11708 '<FieldAccess for origin_node at ast.py:9002>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9002
--# expr-start 11707 '<FieldAccess for node at ast.py:9002>' Fld /tmp/lal-23.0.0/ada/ast.py:9002
Fld := Origin_Node.Node;
--# expr-done 11707
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_1 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Fld);
--# end
--# expr-done 11708
Bound_Origin := Fld_1; 
--# expr-start 11709 '<FieldAccess for designated_type at ast.py:9003>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9003
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_2 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 11709
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 11710
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 11711
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Designated_Type_Decl_From;
--# end
--# property-start TypeExpr.element_type /tmp/lal-23.0.0/ada/ast.py:9006
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Element_Type
  (Node : Bare_Type_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Block_Var : Internal_Entity_Base_Type_Decl;
Var_Expr : Internal_Entity_Anonymous_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Cast_Expr : Internal_Entity_Base_Type_Decl;
Cast_Result : Internal_Entity_Anonymous_Type_Decl;
Fld_2 : Internal_Entity_Type_Def;
Scope_Result : Internal_Entity_Type_Def;
Result_Var : Internal_Entity_Type_Def;
Cast_Result_1 : Internal_Entity_Access_Def;
Is_Null : Boolean;
If_Result : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11719 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11712 '<FieldAccess for designated_type at ast.py:9011>' Fld /tmp/lal-23.0.0/ada/ast.py:9011
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11712
Block_Var := Fld; 
--# bind d Block_Var
--# expr-start 11718 '<If at ast.py:9012>' If_Result /tmp/lal-23.0.0/ada/ast.py:9012
--# expr-start 11716 '<IsNull at ast.py:9013>' Is_Null /tmp/lal-23.0.0/ada/ast.py:9013
--# expr-start 11715 '<Cast to AccessDef at ast.py:9013>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9013
--# expr-start 11713 '<Cast to AnonymousTypeDecl at ast.py:9013>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9013
Cast_Expr := Block_Var; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Anonymous_Type_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Anonymous_Type_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Anonymous_Type_Decl;
   end if;
--# expr-done 11713
Var_Expr := Cast_Result;
if Var_Expr /= No_Entity_Anonymous_Type_Decl then
   --# scope-start
--# expr-start 11714 '<FieldAccess for type_def at ast.py:9013>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9013
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Type_Def (Node => Var_Expr.Node.Type_Decl_F_Type_Def, Info => Var_Expr.Info);
--# expr-done 11714
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Type_Def;
end if;
   if Result_Var.Node = null
      or else Result_Var.Node.Kind in Ada_Access_Def
   then
      Cast_Result_1 := Create_Internal_Entity_Access_Def
        (Node => Result_Var.Node,
         Info => Result_Var.Info);
   else
         Cast_Result_1 := No_Entity_Access_Def;
   end if;
--# expr-done 11715
Is_Null := Cast_Result_1.Node = null; 
--# expr-done 11716
if Is_Null then
   If_Result := Block_Var;
else
   --# expr-start 11717 '<FieldAccess for accessed_type at ast.py:9015>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9015
      if Block_Var.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.accessed_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Accessed_Type (Node => Block_Var.Node, Origin => Origin, E_Info => Block_Var.Info);
--# end
--# expr-done 11717
   If_Result := Fld_1;
end if;
--# expr-done 11718
Let_Result := If_Result; 
--# end
--# expr-done 11719
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Element_Type;
--# end
--# property-start TypeExpr.canonical_type /tmp/lal-23.0.0/ada/ast.py:9020
pragma Warnings (Off, "is not referenced");
 function Type_Expr_P_Canonical_Type
  (Node : Bare_Type_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Type_Expr := Bare_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Type_Expr :=
     Internal_Entity_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Var_Expr : Internal_Entity_Base_Type_Decl;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11722 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11720 '<FieldAccess for designated_type at ast.py:9021>' Fld /tmp/lal-23.0.0/ada/ast.py:9021
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Origin, E_Info => Ent.Info);
--# end
--# expr-done 11720
Var_Expr := Fld;
if Var_Expr /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 11721 '<FieldAccess for canonical_type at ast.py:9021>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9021
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.canonical_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Canonical_Type (Node => Var_Expr.Node, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 11721
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 11722
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Type_Expr_P_Canonical_Type;
--# end
   --
   --  Primitives for Bare_Anonymous_Type
   --
      procedure Initialize_Fields_For_Anonymous_Type
        (Self : Bare_Anonymous_Type
         ; Anonymous_Type_F_Type_Decl : Bare_Anonymous_Type_Decl
        ) is
      begin
            Self.Anonymous_Type_F_Type_Decl := Anonymous_Type_F_Type_Decl;
      end Initialize_Fields_For_Anonymous_Type;
   function Anonymous_Type_F_Type_Decl
     (Node : Bare_Anonymous_Type) return Bare_Anonymous_Type_Decl
   is
   begin
         return Node.Anonymous_Type_F_Type_Decl;
   end;
--# property-start AnonymousType.designated_type /tmp/lal-23.0.0/ada/ast.py:9057
pragma Warnings (Off, "is not referenced");
 function Anonymous_Type_P_Designated_Type
  (Node : Bare_Anonymous_Type
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Anonymous_Type := Bare_Anonymous_Type (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Type :=
     Internal_Entity_Anonymous_Type'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Anonymous_Type_Decl;
Cast_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 11723 '<FieldAccess for type_decl at ast.py:9057>' Fld /tmp/lal-23.0.0/ada/ast.py:9057
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Anonymous_Type_Decl (Node => Ent.Node.Anonymous_Type_F_Type_Decl, Info => Ent.Info);
--# expr-done 11723
      Cast_Result := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
      Property_Result := Cast_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Type_P_Designated_Type;
--# end
--# property-start AnonymousType.xref_equation /tmp/lal-23.0.0/ada/ast.py:9058
pragma Warnings (Off, "is not referenced");
 function Anonymous_Type_P_Xref_Equation
  (Node : Bare_Anonymous_Type
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Anonymous_Type := Bare_Anonymous_Type (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Type :=
     Internal_Entity_Anonymous_Type'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_746 with Inline_Always;
      Fld : Internal_Entity_Anonymous_Type_Decl;
Fld_1 : Logic_Equation;
            procedure Finalizer_Scope_746 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_746;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11725 '<FieldAccess for sub_equation at ast.py:9058>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9058
--# expr-start 11724 '<FieldAccess for type_decl at ast.py:9058>' Fld /tmp/lal-23.0.0/ada/ast.py:9058
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Anonymous_Type_Decl (Node => Ent.Node.Anonymous_Type_F_Type_Decl, Info => Ent.Info);
--# expr-done 11724
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_1 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11725
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_746;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_746;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Type_P_Xref_Equation;
--# end
--# property-start AnonymousType.custom_id_text /tmp/lal-23.0.0/ada/ast.py:9065
pragma Warnings (Off, "is not referenced");
 function Anonymous_Type_P_Custom_Id_Text
  (Node : Bare_Anonymous_Type
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Anonymous_Type := Bare_Anonymous_Type (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Anonymous_Type :=
     Internal_Entity_Anonymous_Type'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_747 with Inline_Always;
      Fld : Internal_Entity_Anonymous_Type_Decl;
Fld_1 : String_Type;
            procedure Finalizer_Scope_747 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_747;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11727 '<FieldAccess for text at ast.py:9065>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9065
--# expr-start 11726 '<FieldAccess for type_decl at ast.py:9065>' Fld /tmp/lal-23.0.0/ada/ast.py:9065
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Anonymous_Type_Decl (Node => Ent.Node.Anonymous_Type_F_Type_Decl, Info => Ent.Info);
--# expr-done 11726
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Text (Node => Fld.Node);
--# expr-done 11727
      Property_Result := Fld_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_747;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_747;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Anonymous_Type_P_Custom_Id_Text;
--# end
   --
   --  Primitives for Bare_Enum_Lit_Synth_Type_Expr
   --
--# property-start EnumLitSynthTypeExpr.designated_type /tmp/lal-23.0.0/ada/ast.py:9029
pragma Warnings (Off, "is not referenced");
 function Enum_Lit_Synth_Type_Expr_P_Designated_Type
  (Node : Bare_Enum_Lit_Synth_Type_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Enum_Lit_Synth_Type_Expr := Bare_Enum_Lit_Synth_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Lit_Synth_Type_Expr :=
     Internal_Entity_Enum_Lit_Synth_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity;
Cast_Result : Internal_Entity_Enum_Literal_Decl;
Fld_1 : Internal_Entity_Type_Decl;
Cast_Result_1 : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
--# expr-start 11730 '<FieldAccess for enum_type at ast.py:9030>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9030
--# expr-start 11729 '<Cast to EnumLiteralDecl at ast.py:9030>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9030
--# expr-start 11728 '<parent at ast.py:9030>' Fld /tmp/lal-23.0.0/ada/ast.py:9030
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11728
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Enum_Literal_Decl_Range
   then
      Cast_Result := Create_Internal_Entity_Enum_Literal_Decl
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Cast_Result := No_Entity_Enum_Literal_Decl;
   end if;
--# expr-done 11729
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]EnumLiteralDecl.enum_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Enum_Literal_Decl_P_Enum_Type (Node => Cast_Result.Node, E_Info => Cast_Result.Info);
--# end
--# expr-done 11730
      Cast_Result_1 := Create_Internal_Entity_Base_Type_Decl
        (Node => Fld_1.Node,
         Info => Fld_1.Info);
      Property_Result := Cast_Result_1;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Lit_Synth_Type_Expr_P_Designated_Type;
--# end
--# property-start EnumLitSynthTypeExpr.custom_id_text /tmp/lal-23.0.0/ada/ast.py:9033
pragma Warnings (Off, "is not referenced");
 function Enum_Lit_Synth_Type_Expr_P_Custom_Id_Text
  (Node : Bare_Enum_Lit_Synth_Type_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Enum_Lit_Synth_Type_Expr := Bare_Enum_Lit_Synth_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Enum_Lit_Synth_Type_Expr :=
     Internal_Entity_Enum_Lit_Synth_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_744 with Inline_Always;
      Cast_Expr : Bare_Enum_Lit_Synth_Type_Expr;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : String_Type;
Str : String_Type;
Concat_Result : String_Type;
Fld_2 : Internal_Entity;
Cast_Result_1 : Internal_Entity_Enum_Literal_Decl;
Fld_3 : Internal_Entity_Defining_Name;
Fld_4 : Symbol_Type_Array_Access;
Str_1 : String_Type;
Fld_5 : String_Type;
Concat_Result_1 : String_Type;
Dyn_Var_Bind_Result : String_Type;
            procedure Finalizer_Scope_744 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Str);
                     Dec_Ref (Concat_Result);
                     Dec_Ref (Fld_4);
                     Dec_Ref (Str_1);
                     Dec_Ref (Fld_5);
                     Dec_Ref (Concat_Result_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
            end Finalizer_Scope_744;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11742 '<bind at ast.py:9036>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:9036
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 11741 '<Concat at ast.py:9040>' Concat_Result_1 /tmp/lal-23.0.0/ada/ast.py:9040
--# expr-start 11734 '<Concat at ast.py:9039>' Concat_Result /tmp/lal-23.0.0/ada/ast.py:9039
--# expr-start 11732 '<FieldAccess for canonical_fully_qualified_name at ast.py:9038>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9038
--# expr-start 11731 '<FieldAccess for designated_type at ast.py:9038>' Fld /tmp/lal-23.0.0/ada/ast.py:9038
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 11731
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_fully_qualified_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Fully_Qualified_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 11732
--# expr-start 11733 '<String at ast.py:9039>' Str /tmp/lal-23.0.0/ada/ast.py:9039
Str := Create_String ("."); 
--# expr-done 11733
Concat_Result := Concat_String (Fld_1, Str); 
--# expr-done 11734
--# expr-start 11740 '<FieldAccess for sym_join at ast.py:9041>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9041
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11738 '<FieldAccess for as_symbol_array at ast.py:9043>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9043
--# expr-start 11737 '<FieldAccess for defining_name at ast.py:9043>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9043
--# expr-start 11736 '<Cast to EnumLiteralDecl at ast.py:9042>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9042
--# expr-start 11735 '<parent at ast.py:9042>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9042
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11735
   if Fld_2.Node = null
      or else Fld_2.Node.Kind in Ada_Enum_Literal_Decl_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Enum_Literal_Decl
        (Node => Fld_2.Node,
         Info => Fld_2.Info);
   else
         Cast_Result_1 := No_Entity_Enum_Literal_Decl;
   end if;
--# expr-done 11736
      if Cast_Result_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.defining_name
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Defining_Name (Node => Cast_Result_1.Node, E_Info => Cast_Result_1.Info);
--# end
--# expr-done 11737
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.as_symbol_array'
Fld_4 := Libadalang.Implementation.Dispatcher_Name_P_As_Symbol_Array (Node => Fld_3.Node);
--# end
--# expr-done 11738
--# expr-start 11739 '<String at ast.py:9044>' Str_1 /tmp/lal-23.0.0/ada/ast.py:9044
Str_1 := Create_String (""); 
--# expr-done 11739
--# property-call-start AdaNode.sym_join
Fld_5 := Libadalang.Implementation.Ada_Node_P_Sym_Join (Node => Ent.Node, Syms => Fld_4, Sep => Str_1);
--# end
--# expr-done 11740
Concat_Result_1 := Concat_String (Concat_Result, Fld_5); 
--# expr-done 11741
Dyn_Var_Bind_Result := Concat_Result_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 11742
      Property_Result := Dyn_Var_Bind_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_744;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_744;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Enum_Lit_Synth_Type_Expr_P_Custom_Id_Text;
--# end
   --
   --  Primitives for Bare_Subtype_Indication
   --
      procedure Initialize_Fields_For_Subtype_Indication
        (Self : Bare_Subtype_Indication
         ; Subtype_Indication_F_Has_Not_Null : Bare_Not_Null
         ; Subtype_Indication_F_Name : Bare_Name
         ; Subtype_Indication_F_Constraint : Bare_Constraint
        ) is
      begin
            Self.Subtype_Indication_F_Has_Not_Null := Subtype_Indication_F_Has_Not_Null;
            Self.Subtype_Indication_F_Name := Subtype_Indication_F_Name;
            Self.Subtype_Indication_F_Constraint := Subtype_Indication_F_Constraint;
      end Initialize_Fields_For_Subtype_Indication;
   function Subtype_Indication_F_Has_Not_Null
     (Node : Bare_Subtype_Indication) return Bare_Not_Null
   is
   begin
         return Node.Subtype_Indication_F_Has_Not_Null;
   end;
   function Subtype_Indication_F_Name
     (Node : Bare_Subtype_Indication) return Bare_Name
   is
   begin
         return Node.Subtype_Indication_F_Name;
   end;
   function Subtype_Indication_F_Constraint
     (Node : Bare_Subtype_Indication) return Bare_Constraint
   is
   begin
         return Node.Subtype_Indication_F_Constraint;
   end;
--# property-start SubtypeIndication.designated_type /tmp/lal-23.0.0/ada/ast.py:9092
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Designated_Type
  (Node : Bare_Subtype_Indication
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_748 with Inline_Always;
      Fld : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Name;
Fld_2 : Internal_Entity_Base_Type_Decl;
Dyn_Var_Bind_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_748 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Bound_Env);
            end Finalizer_Scope_748;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11746 '<bind at ast.py:9093>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:9093
--# expr-start 11743 '<FieldAccess for node_env at ast.py:9093>' Fld /tmp/lal-23.0.0/ada/ast.py:9093
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11743
Bound_Env := Fld; Inc_Ref (Bound_Env);
--# expr-start 11745 '<FieldAccess for designated_type_impl at ast.py:9093>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9093
--# expr-start 11744 '<FieldAccess for name at ast.py:9093>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9093
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Ent.Node.Subtype_Indication_F_Name, Info => Ent.Info);
--# expr-done 11744
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.designated_type_impl'
Fld_2 := Libadalang.Implementation.Dispatcher_Name_P_Designated_Type_Impl (Node => Fld_1.Node, Env => Bound_Env, Origin => Origin, E_Info => Fld_1.Info);
--# end
--# expr-done 11745
Dyn_Var_Bind_Result := Fld_2; 
--# expr-done 11746
      Property_Result := Dyn_Var_Bind_Result;
   --# end
      Finalizer_Scope_748;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_748;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Designated_Type;
--# end
--# property-start SubtypeIndication.complete_items /tmp/lal-23.0.0/ada/ast.py:9097
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Complete_Items
  (Node : Bare_Subtype_Indication
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Completion_Item_Array_Access
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_749 with Inline_Always;
      Match_0 : Internal_Entity_Base_Type_Decl;
Match_1 : Internal_Entity_Package_Decl;
Match_2 : Internal_Entity;
Fld : Lexical_Env := Empty_Env;
Env_Get_Result : Internal_Entity_Array_Access;
Cast_Expr : Internal_Entity;
Cast_Result : Internal_Entity_Basic_Decl;
Fld_1 : Internal_Entity_Info;
Fld_2 : Internal_Metadata;
Fld_3 : Boolean;
Fld_4 : Internal_Unit;
Fld_5 : Boolean;
Fld_6 : Internal_Entity;
Is_A : Boolean;
Fld_7 : Internal_Entity;
Fld_8 : Internal_Entity;
Cast_Expr_1 : Internal_Entity_Base_Type_Decl;
Cast_Result_1 : Internal_Entity;
Is_Equiv : Boolean;
If_Result : Boolean;
If_Result_1 : Integer;
Match_Prefix : Internal_Entity;
Cast_Result_2 : Internal_Entity_Base_Type_Decl;
Let_Result : Integer;
Scope_Result : Integer;
Cast_Result_3 : Internal_Entity_Package_Decl;
Let_Result_1 : Integer;
Scope_Result_1 : Integer;
Cast_Result_4 : Internal_Entity;
Let_Result_2 : Integer;
Scope_Result_2 : Integer;
Match_Result : Integer;
New_Struct : Internal_Completion_Item;
Map_Result : Internal_Completion_Item_Array_Access;
Let_Result_3 : Internal_Completion_Item_Array_Access;
            procedure Finalizer_Scope_749 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Env_Get_Result);
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result_3);
            end Finalizer_Scope_749;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11764 '<Block at ???>' Let_Result_3 None
--# scope-start
--# expr-start 11763 '<Map at ast.py:9104>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9104
   --# expr-start 11748 '<EnvGet at ast.py:9104>' Env_Get_Result /tmp/lal-23.0.0/ada/ast.py:9104
--# expr-start 11747 '<FieldAccess for children_env at ast.py:9104>' Fld /tmp/lal-23.0.0/ada/ast.py:9104
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Libadalang.Implementation.Children_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11747
Env_Get_Result := Construct_Entity_Array (AST_Envs.Get (Self => Fld, Key => null, Lookup_Kind => To_Lookup_Kind_Type (Recursive), Categories => (Inherited_Primitives => True, Nocat => True))); 
--# expr-done 11748
      declare
         Map_Result_Vec : Internal_Completion_Item_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Array_Access := Env_Get_Result;
      begin
         for Item_339 of
               Collection.Items
         loop
   --# scope-start
               --# bind n Item_339
      --# expr-start 11762 '<New CompletionItem at ast.py:9105>' New_Struct /tmp/lal-23.0.0/ada/ast.py:9105
--# expr-start 11749 '<Cast to BasicDecl at ast.py:9106>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9106
Cast_Expr := Item_339; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Basic_Decl
   then
      Cast_Result := Create_Internal_Entity_Basic_Decl
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Basic_Decl;
   end if;
--# expr-done 11749
--# expr-start 11752 '<FieldAccess for dottable_subp at ast.py:9107>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9107
--# expr-start 11751 '<FieldAccess for md at ast.py:9107>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9107
--# expr-start 11750 '<FieldAccess for info at ast.py:9107>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9107
Fld_1 := Item_339.Info;
--# expr-done 11750
Fld_2 := Fld_1.Md;
--# expr-done 11751
Fld_3 := Fld_2.Dottable_Subp;
--# expr-done 11752
--# expr-start 11754 '<FieldAccess for has_with_visibility at ast.py:9108>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9108
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11753 '<FieldAccess for unit at ast.py:9108>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9108
      if Item_339.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Libadalang.Implementation.Unit (Node => Item_339.Node);
--# expr-done 11753
--# property-call-start AdaNode.has_with_visibility
Fld_5 := Libadalang.Implementation.Ada_Node_P_Has_With_Visibility (Node => Self, Refd_Unit => Fld_4);
--# end
--# expr-done 11754
--# expr-start 11761 '<Match at ast.py:9109>' Match_Result /tmp/lal-23.0.0/ada/ast.py:9109
      if Item_339.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_339; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Discrete_Base_Subtype_Decl .. Ada_Formal_Type_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Base_Type_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind btd Match_0
--# expr-start 11760 '<If at ast.py:9110>' If_Result_1 /tmp/lal-23.0.0/ada/ast.py:9110
--# expr-start 11756 '<IsA DerivedTypeDef at ast.py:9117>' Is_A /tmp/lal-23.0.0/ada/ast.py:9117
--# expr-start 11755 '<parent at ast.py:9117>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:9117
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11755
Is_A := Fld_6.Node /= null 
and then Fld_6.Node.Kind in Ada_Derived_Type_Def_Range; 
--# expr-done 11756
if Is_A then
   --# expr-start 11759 '<Eq at ast.py:9118>' Is_Equiv /tmp/lal-23.0.0/ada/ast.py:9118
--# expr-start 11758 '<parent at ast.py:9118>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9118
--# expr-start 11757 '<parent at ast.py:9118>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9118
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Libadalang.Implementation.Parent (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11757
      if Fld_7.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_8 := Libadalang.Implementation.Parent (Node => Fld_7.Node, E_Info => Fld_7.Info);
--# expr-done 11758
Cast_Expr_1 := Match_0; 
      Cast_Result_1 := Create_Internal_Entity
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
Is_Equiv := Equivalent (Fld_8, Cast_Result_1); 
--# expr-done 11759
   If_Result := Is_Equiv;
else
   If_Result := False;
end if;
if If_Result then
   If_Result_1 := 0;
else
   If_Result_1 := 100;
end if;
--# expr-done 11760
Let_Result := If_Result_1; 
--# end
Scope_Result := Let_Result;
   --# end
            Match_Result := Scope_Result; 
         when Ada_Package_Decl =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Package_Decl
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind _ Match_1
Let_Result_1 := 50; 
--# end
Scope_Result_1 := Let_Result_1;
   --# end
            Match_Result := Scope_Result_1; 
         when Ada_Abort_Absent .. Ada_Generic_Package_Internal | Ada_Abstract_Subp_Decl .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
Let_Result_2 := 0; 
--# end
Scope_Result_2 := Let_Result_2;
   --# end
            Match_Result := Scope_Result_2; 
end case;
--# expr-done 11761
New_Struct := (Decl => Cast_Result, Is_Dot_Call => Fld_3, Is_Visible => Fld_5, Weight => Match_Result); 
--# expr-done 11762
         declare
            Item_To_Append : constant Internal_Completion_Item := New_Struct;
         begin
            Internal_Completion_Item_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
         Map_Result := Create_Internal_Completion_Item_Array
           (Items_Count => Natural (Internal_Completion_Item_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Completion_Item_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Completion_Item_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Completion_Item_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11763
Let_Result_3 := Map_Result; Inc_Ref (Let_Result_3);
--# end
--# expr-done 11764
      Property_Result := Let_Result_3;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_749;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_749;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Complete_Items;
--# end
--# property-start SubtypeIndication.subtype_constraints /tmp/lal-23.0.0/ada/ast.py:9130
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Subtype_Constraints
  (Node : Bare_Subtype_Indication
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Param_Actual_Array_Access
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_750 with Inline_Always;
            procedure Finalizer_Scope_3182 with Inline_Always;
            procedure Finalizer_Scope_3183 with Inline_Always;
            procedure Finalizer_Scope_3185 with Inline_Always;
      Block_Var : Internal_Entity_Assoc_List;
Block_Var_1 : Internal_Param_Actual_Array_Access;
Var_Expr : Internal_Entity_Constraint;
Var_Expr_1 : Internal_Entity_Base_Type_Decl;
Ds : Internal_Entity_Discriminant_Spec;
Var_Expr_2 : Internal_Entity_Assoc_List;
Fld : Internal_Entity_Constraint;
Cast_Expr : Internal_Entity_Constraint;
Cast_Result : Internal_Entity_Composite_Constraint;
Fld_1 : Internal_Entity_Assoc_List;
Scope_Result : Internal_Entity_Assoc_List;
Result_Var : Internal_Entity_Assoc_List;
Fld_2 : Internal_Entity_Base_Type_Decl;
Fld_3 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Scope_Result_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Result_Var_1 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Cast_Expr_1 : Internal_Entity_Base_Formal_Param_Decl;
Cast_Result_1 : Internal_Entity_Discriminant_Spec;
Fld_4 : Internal_Entity_Defining_Name_List;
Fld_5 : Bare_Defining_Name_List;
Fld_6 : Internal_Entity_Info;
As_Entity : Internal_Entity_Defining_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Defining_Name;
Fld_7 : Internal_Entity_Expr;
New_Struct : Internal_Param_Actual;
Item_341 : Internal_Entity_Defining_Name;
Bare_Item_341 : Bare_Defining_Name;
Map_Result : Internal_Param_Actual_Array_Access;
Let_Result : Internal_Param_Actual_Array_Access;
Map_Result_1 : Internal_Param_Actual_Array_Access;
Fld_8 : Internal_Entity_Defining_Name;
Fld_9 : Internal_Entity_Defining_Name;
Fld_10 : Internal_Entity_Expr;
Fld_11 : Internal_Entity_Expr;
New_Struct_1 : Internal_Param_Actual;
Index_343 : Integer;
Map_Result_2 : Internal_Param_Actual_Array_Access;
Scope_Result_2 : Internal_Param_Actual_Array_Access;
Result_Var_2 : Internal_Param_Actual_Array_Access;
Let_Result_1 : Internal_Param_Actual_Array_Access;
            procedure Finalizer_Scope_750 is
            begin
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Block_Var_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Result_Var_2);
                     Dec_Ref (Let_Result_1);
            end Finalizer_Scope_750;
            procedure Finalizer_Scope_3182 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3182;
            procedure Finalizer_Scope_3183 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_3183;
            procedure Finalizer_Scope_3185 is
            begin
                     Dec_Ref (Map_Result_2);
            end Finalizer_Scope_3185;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11783 '<Block at ???>' Let_Result_1 None
--# scope-start
--# expr-start 11765 '<FieldAccess for constraint at ast.py:9136>' Fld /tmp/lal-23.0.0/ada/ast.py:9136
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Constraint (Node => Ent.Node.Subtype_Indication_F_Constraint, Info => Ent.Info);
--# expr-done 11765
Var_Expr := Fld;
if Var_Expr /= No_Entity_Constraint then
   --# scope-start
--# expr-start 11767 '<FieldAccess for constraints at ast.py:9136>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9136
--# expr-start 11766 '<Cast to CompositeConstraint at ast.py:9136>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9136
Cast_Expr := Var_Expr; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Composite_Constraint_Range
   then
      Cast_Result := Create_Internal_Entity_Composite_Constraint
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Composite_Constraint;
   end if;
--# expr-done 11766
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Assoc_List (Node => Cast_Result.Node.Composite_Constraint_F_Constraints, Info => Cast_Result.Info);
--# expr-done 11767
Scope_Result := Fld_1;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Assoc_List;
end if;
Block_Var := Result_Var; 
--# bind constraints Block_Var
--# expr-start 11776 '<Mapcat at ast.py:9140>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:9140
--# expr-start 11768 '<FieldAccess for designated_type_decl at ast.py:9140>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9140
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.designated_type_decl
Fld_2 := Libadalang.Implementation.Type_Expr_P_Designated_Type_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 11768
Var_Expr_1 := Fld_2;
if Var_Expr_1 /= No_Entity_Base_Type_Decl then
   --# scope-start
--# expr-start 11769 '<FieldAccess for discriminants_list at ast.py:9140>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9140
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discriminants_list'
Fld_3 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discriminants_List (Node => Var_Expr_1.Node, Origin => No_Bare_Ada_Node, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 11769
Scope_Result_1 := Fld_3;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3182;
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := No_Internal_Entity_Base_Formal_Param_Decl_Array_Type;
end if;
      Inc_Ref (Result_Var_1);
      declare
         Map_Result_1_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      declare
         Collection : constant Internal_Entity_Base_Formal_Param_Decl_Array_Access := Result_Var_1;
      begin
         for Item_340 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_340
      --# expr-start 11775 '<Let at ast.py:9141>' Let_Result /tmp/lal-23.0.0/ada/ast.py:9141
--# scope-start
--# expr-start 11770 '<Cast to DiscriminantSpec at ast.py:9142>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:9142
Cast_Expr_1 := Item_340; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Discriminant_Spec_Range
   then
      Cast_Result_1 := Create_Internal_Entity_Discriminant_Spec
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Discriminant_Spec;
   end if;
--# expr-done 11770
Ds := Cast_Result_1; 
--# bind ds Ds
--# expr-start 11774 '<Map at ast.py:9143>' Map_Result /tmp/lal-23.0.0/ada/ast.py:9143
   --# expr-start 11771 '<FieldAccess for ids at ast.py:9143>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9143
      if Ds.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Defining_Name_List (Node => Ds.Node.Discriminant_Spec_F_Ids, Info => Ds.Info);
--# expr-done 11771
Fld_5 := Fld_4.Node;
      declare
         Map_Result_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
      if Fld_5 = null then
      Map_Result := Create_Internal_Param_Actual_Array (0);
      else
      declare
         Collection : constant Bare_Defining_Name_List := Fld_5;
      begin
         for Untyped_Item_341 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_341 := Untyped_Item_341; 
Is_Null := Bare_Item_341 = null; 
if Is_Null then
   If_Result := No_Entity_Defining_Name;
else
Fld_6 := Fld_4.Info;
As_Entity := (Info => Fld_6, Node => Bare_Item_341); 
   If_Result := As_Entity;
end if;
                  Item_341 := If_Result; 
   --# scope-start
               --# bind i Item_341
      --# expr-start 11773 '<New ParamActual at ast.py:9144>' New_Struct /tmp/lal-23.0.0/ada/ast.py:9144
--# expr-start 11772 '<FieldAccess for default_expr at ast.py:9146>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:9146
      if Ds.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_7 := Create_Internal_Entity_Expr (Node => Ds.Node.Discriminant_Spec_F_Default_Expr, Info => Ds.Info);
--# expr-done 11772
New_Struct := (Actual => Fld_7, Param => Item_341); 
--# expr-done 11773
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11774
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11775
         for Item_To_Append of
               Let_Result.Items
         loop
            Internal_Param_Actual_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end loop;
   --# end
      Finalizer_Scope_3183;
         end loop;
      end;
         Map_Result_1 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_1_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 11776
Block_Var_1 := Map_Result_1; Inc_Ref (Block_Var_1);
--# bind discrs Block_Var_1
Var_Expr_2 := Block_Var;
if Var_Expr_2 /= No_Entity_Assoc_List then
   --# scope-start
   --# bind c Var_Expr_2
--# expr-start 11782 '<Map at ast.py:9155>' Map_Result_2 /tmp/lal-23.0.0/ada/ast.py:9155
      declare
         Map_Result_2_Vec : Internal_Param_Actual_Vectors.Vector;
      begin
         Index_343 := 0;
      declare
         Collection : constant Internal_Param_Actual_Array_Access := Block_Var_1;
      begin
         for Item_342 of
               Collection.Items
         loop
   --# scope-start
               --# bind dp Item_342
               --# bind i Index_343
      --# expr-start 11781 '<New ParamActual at ast.py:9156>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:9156
--# expr-start 11779 '<FieldAccess for actual_for_param_at at ast.py:9158>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:9158
      if Var_Expr_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11777 '<FieldAccess for param at ast.py:9158>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:9158
Fld_9 := Item_342.Param;
--# expr-done 11777
--# expr-start 11778 '<FieldAccess for actual at ast.py:9158>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:9158
Fld_10 := Item_342.Actual;
--# expr-done 11778
--# property-call-start AssocList.actual_for_param_at
Fld_11 := Libadalang.Implementation.Assoc_List_P_Actual_For_Param_At (Node => Var_Expr_2.Node, Param => Fld_9, Pos => Index_343, Default_Expr => Fld_10, E_Info => Var_Expr_2.Info);
--# end
--# expr-done 11779
--# expr-start 11780 '<FieldAccess for param at ast.py:9157>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:9157
Fld_8 := Item_342.Param;
--# expr-done 11780
New_Struct_1 := (Actual => Fld_11, Param => Fld_8); 
--# expr-done 11781
         declare
            Item_To_Append : constant Internal_Param_Actual := New_Struct_1;
         begin
            Internal_Param_Actual_Vectors.Append (Map_Result_2_Vec, Item_To_Append);
         end;
   --# end
               Index_343 := Index_343 + 1;
         end loop;
      end;
         Map_Result_2 := Create_Internal_Param_Actual_Array
           (Items_Count => Natural (Internal_Param_Actual_Vectors.Length (Map_Result_2_Vec)));
         for I in Map_Result_2.Items'Range loop
            Map_Result_2.Items (I) := Internal_Param_Actual_Vectors.Get
              (Map_Result_2_Vec,
               I + Internal_Param_Actual_Vectors.Index_Type'First - Map_Result_2.Items'First);
         end loop;
         Internal_Param_Actual_Vectors.Destroy (Map_Result_2_Vec);
      end;
--# expr-done 11782
Scope_Result_2 := Map_Result_2;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_3185;
   Result_Var_2 := Scope_Result_2;
else
   Result_Var_2 := Block_Var_1;
end if;
      Inc_Ref (Result_Var_2);
Let_Result_1 := Result_Var_2; Inc_Ref (Let_Result_1);
--# end
--# expr-done 11783
      Property_Result := Let_Result_1;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_750;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_750;
               Finalizer_Scope_3182;
               Finalizer_Scope_3183;
               Finalizer_Scope_3185;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Subtype_Constraints;
--# end
--# property-start SubtypeIndication.xref_equation /tmp/lal-23.0.0/ada/ast.py:9165
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Xref_Equation
  (Node : Bare_Subtype_Indication
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_751 with Inline_Always;
            procedure Finalizer_Scope_3187 with Inline_Always;
      Var_Expr : Internal_Entity_Constraint;
Fld : Internal_Entity_Name;
Fld_1 : Logic_Equation;
Fld_2 : Internal_Entity_Constraint;
Fld_3 : Logic_Equation;
Scope_Result : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_751 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_751;
            procedure Finalizer_Scope_3187 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3187;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11789 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11788 '<And at ast.py:9168>' And_Pred /tmp/lal-23.0.0/ada/ast.py:9168
--# expr-start 11785 '<FieldAccess for subtype_indication_equation at ast.py:9169>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9169
--# expr-start 11784 '<FieldAccess for name at ast.py:9169>' Fld /tmp/lal-23.0.0/ada/ast.py:9169
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name (Node => Ent.Node.Subtype_Indication_F_Name, Info => Ent.Info);
--# expr-done 11784
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.subtype_indication_equation
Fld_1 := Libadalang.Implementation.Name_P_Subtype_Indication_Equation (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11785
--# expr-start 11786 '<FieldAccess for constraint at ast.py:9170>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9170
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Constraint (Node => Ent.Node.Subtype_Indication_F_Constraint, Info => Ent.Info);
--# expr-done 11786
Var_Expr := Fld_2;
if Var_Expr /= No_Entity_Constraint then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 11787 '<FieldAccess for sub_equation at ast.py:9171>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9171
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_3 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Var_Expr.Node, Env => Env, Origin => Origin, E_Info => Var_Expr.Info);
--# end
--# expr-done 11787
Scope_Result := Fld_3;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3187;
   Result_Var := Scope_Result;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9171") else null)); 
   Result_Var := True_Rel;
end if;
      Inc_Ref (Result_Var);
And_Pred := Create_And (Fld_1, Result_Var, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:9168") else null)); 
--# expr-done 11788
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 11789
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_751;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_751;
               Finalizer_Scope_3187;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Xref_Equation;
--# end
--# property-start SubtypeIndication.discrete_range /tmp/lal-23.0.0/ada/ast.py:9176
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Discrete_Range
  (Node : Bare_Subtype_Indication
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Discrete_Range
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Internal_Discrete_Range;
      Block_Var : Internal_Entity_Range_Constraint;
Var_Expr : Internal_Entity_Range_Constraint;
Fld : Internal_Entity_Constraint;
Cast_Result : Internal_Entity_Range_Constraint;
Fld_1 : Internal_Entity_Range_Spec;
Fld_2 : Internal_Entity_Expr;
Fld_3 : Internal_Discrete_Range;
Scope_Result : Internal_Discrete_Range;
Fld_4 : Internal_Entity_Base_Type_Decl;
Fld_5 : Internal_Discrete_Range;
Result_Var : Internal_Discrete_Range;
Let_Result : Internal_Discrete_Range;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11797 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11791 '<Cast to RangeConstraint at ast.py:9177>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:9177
--# expr-start 11790 '<FieldAccess for constraint at ast.py:9177>' Fld /tmp/lal-23.0.0/ada/ast.py:9177
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Constraint (Node => Ent.Node.Subtype_Indication_F_Constraint, Info => Ent.Info);
--# expr-done 11790
   if Fld.Node = null
      or else Fld.Node.Kind in Ada_Range_Constraint_Range
   then
      Cast_Result := Create_Internal_Entity_Range_Constraint
        (Node => Fld.Node,
         Info => Fld.Info);
   else
         Raise_Property_Exception
           (Self, Property_Error'Identity, "invalid object cast");
   end if;
--# expr-done 11791
Block_Var := Cast_Result; 
--# bind rc Block_Var
Var_Expr := Block_Var;
if Var_Expr /= No_Entity_Range_Constraint then
   --# scope-start
   --# bind r Var_Expr
--# expr-start 11794 '<FieldAccess for discrete_range at ast.py:9179>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9179
--# expr-start 11793 '<FieldAccess for range at ast.py:9179>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9179
--# expr-start 11792 '<FieldAccess for range at ast.py:9179>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9179
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Range_Spec (Node => Var_Expr.Node.Range_Constraint_F_Range, Info => Var_Expr.Info);
--# expr-done 11792
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Expr (Node => Fld_1.Node.Range_Spec_F_Range, Info => Fld_1.Info);
--# expr-done 11793
      if Fld_2.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.discrete_range
Fld_3 := Libadalang.Implementation.Expr_P_Discrete_Range (Node => Fld_2.Node, E_Info => Fld_2.Info);
--# end
--# expr-done 11794
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 11796 '<FieldAccess for discrete_range at ast.py:9182>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:9182
--# expr-start 11795 '<FieldAccess for designated_type_decl at ast.py:9182>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9182
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start TypeExpr.designated_type_decl
Fld_4 := Libadalang.Implementation.Type_Expr_P_Designated_Type_Decl (Node => Ent.Node, E_Info => Ent.Info);
--# end
--# expr-done 11795
      if Fld_4.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BaseTypeDecl.discrete_range'
Fld_5 := Libadalang.Implementation.Dispatcher_Base_Type_Decl_P_Discrete_Range (Node => Fld_4.Node, E_Info => Fld_4.Info);
--# end
--# expr-done 11796
   Result_Var := Fld_5;
end if;
Let_Result := Result_Var; 
--# end
--# expr-done 11797
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Discrete_Range;
--# end
--# property-start SubtypeIndication.is_static_subtype /tmp/lal-23.0.0/ada/ast.py:9188
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Is_Static_Subtype
  (Node : Bare_Subtype_Indication
      ; Imprecise_Fallback : Boolean
         := False
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind imprecise_fallback Imprecise_Fallback
   Property_Result : Boolean;
      Var_Expr : Internal_Entity_Constraint;
Fld : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld_1 : Internal_Entity_Constraint;
Fld_2 : Boolean;
Scope_Result : Boolean;
Fld_3 : Internal_Entity_Base_Type_Decl;
Fld_4 : Boolean;
Result_Var : Boolean;
Dyn_Var_Bind_Result : Boolean;
Let_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
            Populate_Lexical_Env (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11804 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11803 '<bind at ast.py:9192>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:9192
--# expr-start 11798 '<FieldAccess for origin_node at ast.py:9192>' Fld /tmp/lal-23.0.0/ada/ast.py:9192
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Self);
--# end
--# expr-done 11798
Bound_Origin := Fld; 
--# expr-start 11799 '<FieldAccess for constraint at ast.py:9192>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9192
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Constraint (Node => Ent.Node.Subtype_Indication_F_Constraint, Info => Ent.Info);
--# expr-done 11799
Var_Expr := Fld_1;
if Var_Expr /= No_Entity_Constraint then
   --# scope-start
   --# bind c Var_Expr
--# expr-start 11800 '<FieldAccess for is_static at ast.py:9193>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:9193
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Constraint.is_static
Fld_2 := Libadalang.Implementation.Constraint_P_Is_Static (Node => Var_Expr.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Var_Expr.Info);
--# end
--# expr-done 11800
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   --# expr-start 11802 '<FieldAccess for is_static_decl at ast.py:9194>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:9194
--# expr-start 11801 '<FieldAccess for designated_type at ast.py:9194>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:9194
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_3 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 11801
      if Fld_3.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicDecl.is_static_decl'
Fld_4 := Libadalang.Implementation.Dispatcher_Basic_Decl_P_Is_Static_Decl (Node => Fld_3.Node, Imprecise_Fallback => Imprecise_Fallback, E_Info => Fld_3.Info);
--# end
--# expr-done 11802
   Result_Var := Fld_4;
end if;
Dyn_Var_Bind_Result := Result_Var; 
--# expr-done 11803
Let_Result := Dyn_Var_Bind_Result; 
--# end
--# expr-done 11804
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Is_Static_Subtype;
--# end
--# property-start SubtypeIndication.custom_id_text /tmp/lal-23.0.0/ada/ast.py:9197
pragma Warnings (Off, "is not referenced");
 function Subtype_Indication_P_Custom_Id_Text
  (Node : Bare_Subtype_Indication
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return String_Type
is
   Self : Bare_Subtype_Indication := Bare_Subtype_Indication (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Subtype_Indication :=
     Internal_Entity_Subtype_Indication'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : String_Type;
            procedure Finalizer_Scope_754 with Inline_Always;
      Cast_Expr : Bare_Subtype_Indication;
Cast_Result : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
Fld : Internal_Entity_Base_Type_Decl;
Fld_1 : String_Type;
Dyn_Var_Bind_Result : String_Type;
            procedure Finalizer_Scope_754 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Dyn_Var_Bind_Result);
            end Finalizer_Scope_754;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11807 '<bind at ast.py:9197>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:9197
Cast_Expr := Self; 
      Cast_Result := Cast_Expr;
Bound_Origin := Cast_Result; 
--# expr-start 11806 '<FieldAccess for canonical_fully_qualified_name at ast.py:9199>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:9199
--# expr-start 11805 '<FieldAccess for designated_type at ast.py:9199>' Fld /tmp/lal-23.0.0/ada/ast.py:9199
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Ent.Node, Origin => Bound_Origin, E_Info => Ent.Info);
--# end
--# expr-done 11805
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start BasicDecl.canonical_fully_qualified_name
Fld_1 := Libadalang.Implementation.Basic_Decl_P_Canonical_Fully_Qualified_Name (Node => Fld.Node, E_Info => Fld.Info);
--# end
--# expr-done 11806
Dyn_Var_Bind_Result := Fld_1; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 11807
      Property_Result := Dyn_Var_Bind_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_754;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_754;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Subtype_Indication_P_Custom_Id_Text;
--# end
   --
   --  Primitives for Bare_Constrained_Subtype_Indication
   --
      procedure Initialize_Fields_For_Constrained_Subtype_Indication
        (Self : Bare_Constrained_Subtype_Indication
         ; Subtype_Indication_F_Has_Not_Null : Bare_Not_Null
         ; Subtype_Indication_F_Name : Bare_Name
         ; Subtype_Indication_F_Constraint : Bare_Constraint
        ) is
      begin
            Initialize_Fields_For_Subtype_Indication
              (Self, Subtype_Indication_F_Has_Not_Null, Subtype_Indication_F_Name, Subtype_Indication_F_Constraint);
      end Initialize_Fields_For_Constrained_Subtype_Indication;
   --
   --  Primitives for Bare_Discrete_Subtype_Indication
   --
      procedure Initialize_Fields_For_Discrete_Subtype_Indication
        (Self : Bare_Discrete_Subtype_Indication
         ; Subtype_Indication_F_Has_Not_Null : Bare_Not_Null
         ; Subtype_Indication_F_Name : Bare_Name
         ; Subtype_Indication_F_Constraint : Bare_Constraint
        ) is
      begin
            Initialize_Fields_For_Subtype_Indication
              (Self, Subtype_Indication_F_Has_Not_Null, Subtype_Indication_F_Name, Subtype_Indication_F_Constraint);
      end Initialize_Fields_For_Discrete_Subtype_Indication;
   --
   --  Primitives for Bare_Synthetic_Type_Expr
   --
      procedure Initialize_Fields_For_Synthetic_Type_Expr
        (Self : Bare_Synthetic_Type_Expr
         ; Synthetic_Type_Expr_F_Target_Type : Bare_Base_Type_Decl
        ) is
      begin
            Self.Synthetic_Type_Expr_F_Target_Type := Synthetic_Type_Expr_F_Target_Type;
      end Initialize_Fields_For_Synthetic_Type_Expr;
   function Synthetic_Type_Expr_F_Target_Type
     (Node : Bare_Synthetic_Type_Expr) return Bare_Base_Type_Decl
   is
   begin
         return Node.Synthetic_Type_Expr_F_Target_Type;
   end;
--# property-start SyntheticTypeExpr.designated_type /tmp/lal-23.0.0/ada/ast.py:17476
pragma Warnings (Off, "is not referenced");
 function Synthetic_Type_Expr_P_Designated_Type
  (Node : Bare_Synthetic_Type_Expr
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Synthetic_Type_Expr := Bare_Synthetic_Type_Expr (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Synthetic_Type_Expr :=
     Internal_Entity_Synthetic_Type_Expr'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1249 with Inline_Always;
      Block_Var : Internal_Entity_Generic_Decl;
Block_Var_1 : Env_Rebindings;
Var_Expr : Internal_Entity_Basic_Decl;
Var_Expr_1 : Internal_Entity_Generic_Decl;
Fld : Bare_Base_Type_Decl;
Node_Parents : Bare_Ada_Node_Array_Access;
Is_A : Boolean;
Find_Result : Bare_Ada_Node;
Cast_Result : Bare_Generic_Decl;
As_Entity : Internal_Entity_Generic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Generic_Decl;
Fld_1 : Internal_Entity_Info;
Fld_2 : Env_Rebindings;
Fld_3 : Internal_Entity_Basic_Decl;
Scope_Result : Internal_Entity_Basic_Decl;
Result_Var : Internal_Entity_Basic_Decl;
Fld_4 : Internal_Entity_Info;
Fld_5 : Env_Rebindings;
Scope_Result_1 : Env_Rebindings;
Result_Var_1 : Env_Rebindings;
Fld_6 : Bare_Base_Type_Decl;
Fld_7 : Internal_Entity_Info;
Fld_8 : Boolean;
New_Struct : Internal_Entity_Info;
New_Struct_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
            procedure Finalizer_Scope_1249 is
            begin
                     Dec_Ref (Node_Parents);
            end Finalizer_Scope_1249;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11824 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11813 '<as_bare_entity at ast.py:17492>' If_Result /tmp/lal-23.0.0/ada/ast.py:17492
--# expr-start 11812 '<Cast to GenericDecl at ast.py:17492>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:17492
--# expr-start 11811 '<Find at ast.py:17490>' Find_Result /tmp/lal-23.0.0/ada/ast.py:17490
   --# expr-start 11809 '<FieldAccess for parents at ast.py:17490>' Node_Parents /tmp/lal-23.0.0/ada/ast.py:17490
--# expr-start 11808 '<FieldAccess for target_type at ast.py:17490>' Fld /tmp/lal-23.0.0/ada/ast.py:17490
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Synthetic_Type_Expr_F_Target_Type;
--# expr-done 11808
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Node_Parents := Parents (Fld, True); 
--# expr-done 11809
      Find_Result := No_Bare_Ada_Node;
      declare
         Collection : constant Bare_Ada_Node_Array_Access := Node_Parents;
      begin
         for Item_344 of
               Collection.Items
         loop
   --# scope-start
               --# bind p Item_344
      --# expr-start 11810 '<IsA GenericDecl at ast.py:17491>' Is_A /tmp/lal-23.0.0/ada/ast.py:17491
Is_A := Item_344 /= null 
and then Item_344.Kind in Ada_Generic_Decl; 
--# expr-done 11810
      if Is_A then
         Find_Result := Item_344;
      end if;
   --# end
               exit when Is_A;
         end loop;
      end;
--# expr-done 11811
   if Find_Result = null
      or else Find_Result.Kind in Ada_Generic_Decl
   then
      Cast_Result := Find_Result;
   else
         Cast_Result := No_Bare_Ada_Node;
   end if;
--# expr-done 11812
Is_Null := Cast_Result = null; 
if Is_Null then
   If_Result := No_Entity_Generic_Decl;
else
As_Entity := (Info => No_Entity_Info, Node => Cast_Result); 
   If_Result := As_Entity;
end if;
--# expr-done 11813
Block_Var := If_Result; 
--# bind gd Block_Var
Var_Expr_1 := Block_Var;
if Var_Expr_1 /= No_Entity_Generic_Decl then
   --# scope-start
--# expr-start 11816 '<FieldAccess for unshed_rebindings at ast.py:17495>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:17495
      if Var_Expr_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11815 '<FieldAccess for rebindings at ast.py:17496>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:17496
--# expr-start 11814 '<FieldAccess for info at ast.py:17496>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:17496
Fld_1 := Ent.Info;
--# expr-done 11814
Fld_2 := Fld_1.Rebindings;
--# expr-done 11815
--# property-call-start BasicDecl.unshed_rebindings
Fld_3 := Libadalang.Implementation.Basic_Decl_P_Unshed_Rebindings (Node => Var_Expr_1.Node, Rebindings => Fld_2, E_Info => Var_Expr_1.Info);
--# end
--# expr-done 11816
Scope_Result := Fld_3;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Basic_Decl;
end if;
Var_Expr := Result_Var;
if Var_Expr /= No_Entity_Basic_Decl then
   --# scope-start
   --# bind fixed Var_Expr
--# expr-start 11818 '<FieldAccess for rebindings at ast.py:17498>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:17498
--# expr-start 11817 '<FieldAccess for info at ast.py:17498>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:17498
Fld_4 := Var_Expr.Info;
--# expr-done 11817
Fld_5 := Fld_4.Rebindings;
--# expr-done 11818
Scope_Result_1 := Fld_5;
   --# end
   Result_Var_1 := Scope_Result_1;
else
   Result_Var_1 := null;
end if;
Block_Var_1 := Result_Var_1; 
--# bind relevant_rebindings Block_Var_1
--# expr-start 11823 '<New BaseTypeDecl.entity at ???>' New_Struct_1 None
--# expr-start 11821 '<New EntityInfo at ast.py:17505>' New_Struct /tmp/lal-23.0.0/ada/ast.py:17505
--# expr-start 11820 '<FieldAccess for from_rebound at ast.py:17508>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:17508
--# expr-start 11819 '<FieldAccess for info at ast.py:17508>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:17508
Fld_7 := Ent.Info;
--# expr-done 11819
Fld_8 := Fld_7.From_Rebound;
--# expr-done 11820
New_Struct := (From_Rebound => Fld_8, Md => No_Metadata, Rebindings => Block_Var_1); 
--# expr-done 11821
--# expr-start 11822 '<FieldAccess for target_type at ast.py:17504>' Fld_6 /tmp/lal-23.0.0/ada/ast.py:17504
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_6 := Self.Synthetic_Type_Expr_F_Target_Type;
--# expr-done 11822
New_Struct_1 := (Info => New_Struct, Node => Fld_6); 
--# expr-done 11823
Let_Result := New_Struct_1; 
--# end
--# expr-done 11824
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_1249;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1249;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Synthetic_Type_Expr_P_Designated_Type;
--# end
   --
   --  Primitives for Bare_Unconstrained_Array_Index
   --
      procedure Initialize_Fields_For_Unconstrained_Array_Index
        (Self : Bare_Unconstrained_Array_Index
         ; Unconstrained_Array_Index_F_Subtype_Indication : Bare_Subtype_Indication
        ) is
      begin
            Self.Unconstrained_Array_Index_F_Subtype_Indication := Unconstrained_Array_Index_F_Subtype_Indication;
      end Initialize_Fields_For_Unconstrained_Array_Index;
   function Unconstrained_Array_Index_F_Subtype_Indication
     (Node : Bare_Unconstrained_Array_Index) return Bare_Subtype_Indication
   is
   begin
         return Node.Unconstrained_Array_Index_F_Subtype_Indication;
   end;
--# property-start UnconstrainedArrayIndex.designated_type /tmp/lal-23.0.0/ada/ast.py:20882
pragma Warnings (Off, "is not referenced");
 function Unconstrained_Array_Index_P_Designated_Type
  (Node : Bare_Unconstrained_Array_Index
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Type_Decl
is
   Self : Bare_Unconstrained_Array_Index := Bare_Unconstrained_Array_Index (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Unconstrained_Array_Index :=
     Internal_Entity_Unconstrained_Array_Index'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind origin Origin
   Property_Result : Internal_Entity_Base_Type_Decl;
      Fld : Internal_Entity_Subtype_Indication;
Fld_1 : Internal_Entity_Base_Type_Decl;
Let_Result : Internal_Entity_Base_Type_Decl;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11827 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11826 '<FieldAccess for designated_type at ast.py:20883>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:20883
--# expr-start 11825 '<FieldAccess for subtype_indication at ast.py:20883>' Fld /tmp/lal-23.0.0/ada/ast.py:20883
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Subtype_Indication (Node => Ent.Node.Unconstrained_Array_Index_F_Subtype_Indication, Info => Ent.Info);
--# expr-done 11825
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]TypeExpr.designated_type'
Fld_1 := Libadalang.Implementation.Dispatcher_Type_Expr_P_Designated_Type (Node => Fld.Node, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11826
Let_Result := Fld_1; 
--# end
--# expr-done 11827
      Property_Result := Let_Result;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Unconstrained_Array_Index_P_Designated_Type;
--# end
   --
   --  Primitives for Bare_Until_Node
   --
--# property-start '[dispatcher]Until.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_Until_Node_P_As_Bool
  (Node : Bare_Until_Node
  )
   return Boolean
is
   Self : Bare_Until_Node := Bare_Until_Node (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_Until_Node (Self.Kind) is
               when Ada_Until_Absent =>
                  --# property-call-start Until.Absent.as_bool
                  Property_Result := Until_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_Until_Present =>
                  --# property-call-start Until.Present.as_bool
                  Property_Result := Until_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_Until_Node_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Until_Absent
   --
--# property-start Until.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5053
pragma Warnings (Off, "is not referenced");
 function Until_Absent_P_As_Bool
  (Node : Bare_Until_Absent
  )
   return Boolean
is
   Self : Bare_Until_Absent := Bare_Until_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Until_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Until_Present
   --
--# property-start Until.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5053
pragma Warnings (Off, "is not referenced");
 function Until_Present_P_As_Bool
  (Node : Bare_Until_Present
  )
   return Boolean
is
   Self : Bare_Until_Present := Bare_Until_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Until_Present_P_As_Bool;
--# end
   --
   --  Primitives for Bare_Use_Clause
   --
--# property-start UseClause.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:8849
pragma Warnings (Off, "is not referenced");
 function Use_Clause_P_Xref_Entry_Point
  (Node : Bare_Use_Clause
  )
   return Boolean
is
   Self : Bare_Use_Clause := Bare_Use_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Clause_P_Xref_Entry_Point;
--# end
--# property-start UseClause.used_envs /tmp/lal-23.0.0/ada/ast.py:8852
pragma Warnings (Off, "is not referenced");
 function Use_Clause_P_Used_Envs
  (Node : Bare_Use_Clause
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Use_Clause := Bare_Use_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Use_Clause :=
     Internal_Entity_Use_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_729 with Inline_Always;
            procedure Finalizer_Scope_3192 with Inline_Always;
            procedure Finalizer_Scope_3193 with Inline_Always;
            procedure Finalizer_Scope_3194 with Inline_Always;
      Match_0 : Internal_Entity_Use_Package_Clause;
Match_1 : Internal_Entity_Use_Type_Clause;
Fld : Lexical_Env_Array_Access;
Group_Env : Lexical_Env := Empty_Env;
Fld_1 : Internal_Entity_Name_List;
Fld_2 : Bare_Name_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_4 : Lexical_Env := Empty_Env;
Item_345 : Internal_Entity_Name;
Bare_Item_345 : Bare_Name;
Map_Result : Lexical_Env_Array_Access;
Group_Env_1 : Lexical_Env := Empty_Env;
Match_Prefix : Internal_Entity_Use_Clause;
Cast_Result : Internal_Entity_Use_Package_Clause;
Let_Result : Lexical_Env := Empty_Env;
Scope_Result : Lexical_Env := Empty_Env;
Cast_Result_1 : Internal_Entity_Use_Type_Clause;
Let_Result_1 : Lexical_Env := Empty_Env;
Scope_Result_1 : Lexical_Env := Empty_Env;
Match_Result : Lexical_Env := Empty_Env;
Let_Result_2 : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_729 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Match_Result);
                     Dec_Ref (Let_Result_2);
            end Finalizer_Scope_729;
            procedure Finalizer_Scope_3192 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Group_Env);
            end Finalizer_Scope_3192;
            procedure Finalizer_Scope_3193 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Group_Env_1);
            end Finalizer_Scope_3193;
            procedure Finalizer_Scope_3194 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_3194;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11835 '<Block at ???>' Let_Result_2 None
--# scope-start
--# expr-start 11834 '<Match at ast.py:8857>' Match_Result /tmp/lal-23.0.0/ada/ast.py:8857
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Ent; 
case Ada_Use_Clause (Match_Prefix.Node.Kind) is
         when Ada_Use_Package_Clause =>
   --# scope-start
--# scope-start
      Cast_Result := Create_Internal_Entity_Use_Package_Clause
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result; 
--# bind upc Match_0
--# expr-start 11829 '<env_group at ast.py:8858>' Group_Env /tmp/lal-23.0.0/ada/ast.py:8858
--# expr-start 11828 '<FieldAccess for designated_envs at ast.py:8858>' Fld /tmp/lal-23.0.0/ada/ast.py:8858
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UsePackageClause.designated_envs
Fld := Libadalang.Implementation.Use_Package_Clause_P_Designated_Envs (Node => Match_0.Node, E_Info => Match_0.Info);
--# end
--# expr-done 11828
Group_Env := Group (Fld, No_Metadata); 
--# expr-done 11829
Let_Result := Group_Env; Inc_Ref (Let_Result);
--# end
Scope_Result := Let_Result;
   Inc_Ref (Scope_Result);
   --# end
      Finalizer_Scope_3192;
            Match_Result := Scope_Result; Inc_Ref (Match_Result);
         when Ada_Use_Type_Clause =>
   --# scope-start
--# scope-start
      Cast_Result_1 := Create_Internal_Entity_Use_Type_Clause
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_1; 
--# bind utc Match_1
--# expr-start 11833 '<env_group at ast.py:8860>' Group_Env_1 /tmp/lal-23.0.0/ada/ast.py:8860
--# expr-start 11832 '<Map at ast.py:8860>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8860
   --# expr-start 11830 '<FieldAccess for types at ast.py:8860>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8860
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name_List (Node => Match_1.Node.Use_Type_Clause_F_Types, Info => Match_1.Info);
--# expr-done 11830
Fld_2 := Fld_1.Node;
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      if Fld_2 = null then
      Map_Result := Create_Lexical_Env_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld_2;
      begin
         for Untyped_Item_345 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_345 := Untyped_Item_345; 
Is_Null := Bare_Item_345 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_345); 
   If_Result := As_Entity;
end if;
                  Item_345 := If_Result; 
   --# scope-start
               --# bind n Item_345
      --# expr-start 11831 '<FieldAccess for name_designated_type_env at ast.py:8860>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8860
      if Item_345.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type_env
Fld_4 := Libadalang.Implementation.Name_P_Name_Designated_Type_Env (Node => Item_345.Node, E_Info => Item_345.Info);
--# end
--# expr-done 11831
         declare
            Item_To_Append : constant Lexical_Env := Fld_4;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3194;
         end loop;
      end;
      end if;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11832
Group_Env_1 := Group (Map_Result, No_Metadata); 
--# expr-done 11833
Let_Result_1 := Group_Env_1; Inc_Ref (Let_Result_1);
--# end
Scope_Result_1 := Let_Result_1;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3193;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
end case;
--# expr-done 11834
Let_Result_2 := Match_Result; Inc_Ref (Let_Result_2);
--# end
--# expr-done 11835
      Property_Result := Let_Result_2;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_729;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_729;
               Finalizer_Scope_3192;
               Finalizer_Scope_3193;
               Finalizer_Scope_3194;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Clause_P_Used_Envs;
--# end
--# property-start UseClause.initial_env /tmp/lal-23.0.0/ada/ast.py:8864
pragma Warnings (Off, "is not referenced");
 function Use_Clause_P_Initial_Env
  (Node : Bare_Use_Clause
  )
   return Internal_Designated_Env
is
   Self : Bare_Use_Clause := Bare_Use_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_730 with Inline_Always;
      Sym : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
New_Struct_1 : Internal_Designated_Env := No_Designated_Env;
Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
If_Result : Internal_Designated_Env := No_Designated_Env;
Let_Result : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_730 is
            begin
                     Dec_Ref (New_Struct);
                     Dec_Ref (New_Struct_1);
                     Dec_Ref (If_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_730;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11843 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11842 '<If at ast.py:8869>' If_Result /tmp/lal-23.0.0/ada/ast.py:8869
--# expr-start 11838 '<IsA CompilationUnit at ast.py:8870>' Is_A /tmp/lal-23.0.0/ada/ast.py:8870
--# expr-start 11837 '<parent at ast.py:8870>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8870
--# expr-start 11836 '<parent at ast.py:8870>' Fld /tmp/lal-23.0.0/ada/ast.py:8870
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11836
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 11837
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 11838
if Is_A then
   --# expr-start 11840 '<New DesignatedEnv at ast.py:8871>' New_Struct /tmp/lal-23.0.0/ada/ast.py:8871
--# expr-start 11839 '<Symbol Standard at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Standard); 
--# expr-done 11839
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Sym, Kind => Named_Env); 
--# expr-done 11840
   If_Result := New_Struct;
else
   --# expr-start 11841 '<New DesignatedEnv at ast.py:8872>' New_Struct_1 /tmp/lal-23.0.0/ada/ast.py:8872
Inc_Ref (Empty_Env);
New_Struct_1 := (Direct_Env => Empty_Env, Env_Name => null, Kind => Current_Env); 
--# expr-done 11841
   If_Result := New_Struct_1;
end if;
      Inc_Ref (If_Result);
--# expr-done 11842
Let_Result := If_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11843
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_730;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_730;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Clause_P_Initial_Env;
--# end
   --
   --  Primitives for Bare_Use_Package_Clause
   --
      procedure Use_Package_Clause_Pre_Env_Actions
        (Self            : Bare_Use_Package_Clause;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_18 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:8883");
      end;
      end;
      procedure Use_Package_Clause_Post_Env_Actions
        (Self : Bare_Use_Package_Clause; State : in out PLE_Node_State) is
      begin
      if Libadalang.Implementation.Ref_Cond_20 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_19 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Use_Package_Name_Designated_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Use_Package_Clause
        (Self : Bare_Use_Package_Clause
         ; Use_Package_Clause_F_Packages : Bare_Name_List
        ) is
      begin
            Self.Use_Package_Clause_F_Packages := Use_Package_Clause_F_Packages;
      end Initialize_Fields_For_Use_Package_Clause;
   function Use_Package_Clause_F_Packages
     (Node : Bare_Use_Package_Clause) return Bare_Name_List
   is
   begin
         return Node.Use_Package_Clause_F_Packages;
   end;
--# property-start UsePackageClause.designated_env /tmp/lal-23.0.0/ada/ast.py:8896
pragma Warnings (Off, "is not referenced");
 function Use_Package_Clause_P_Designated_Env
  (Node : Bare_Use_Package_Clause
      ; Index : Integer
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env
is
   Self : Bare_Use_Package_Clause := Bare_Use_Package_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Use_Package_Clause :=
     Internal_Entity_Use_Package_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind index Index
   Property_Result : Lexical_Env;
            procedure Finalizer_Scope_731 with Inline_Always;
      Block_Var : Bare_Name;
Fld : Bare_Name_List;
Get_Result : Bare_Name;
Fld_1 : Lexical_Env := Empty_Env;
Bound_Env : Lexical_Env := Empty_Env;
Fld_2 : Bare_Ada_Node;
Bound_Origin : Bare_Ada_Node;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result : Lexical_Env := Empty_Env;
Dyn_Var_Bind_Result_1 : Lexical_Env := Empty_Env;
Let_Result : Lexical_Env := Empty_Env;
            procedure Finalizer_Scope_731 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Bound_Env);
                     Dec_Ref (Fld_3);
                     Dec_Ref (Dyn_Var_Bind_Result);
                     Dec_Ref (Dyn_Var_Bind_Result_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_731;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11852 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11845 '<at at ast.py:8901>' Get_Result /tmp/lal-23.0.0/ada/ast.py:8901
--# expr-start 11844 '<FieldAccess for packages at ast.py:8901>' Fld /tmp/lal-23.0.0/ada/ast.py:8901
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Use_Package_Clause_F_Packages;
--# expr-done 11844
Get_Result := Get (Self, Fld, Index, True); 
--# expr-done 11845
Block_Var := Get_Result; 
--# bind pkg Block_Var
--# expr-start 11851 '<bind at ast.py:8902>' Dyn_Var_Bind_Result_1 /tmp/lal-23.0.0/ada/ast.py:8902
--# expr-start 11846 '<FieldAccess for node_env at ast.py:8903>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8903
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Libadalang.Implementation.Node_Env (Node => Ent.Node, E_Info => Ent.Info);
--# expr-done 11846
Bound_Env := Fld_1; Inc_Ref (Bound_Env);
--# expr-start 11850 '<bind at ast.py:8904>' Dyn_Var_Bind_Result /tmp/lal-23.0.0/ada/ast.py:8904
--# expr-start 11847 '<FieldAccess for origin_node at ast.py:8905>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8905
      if Block_Var = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.origin_node
Fld_2 := Libadalang.Implementation.Ada_Node_P_Origin_Node (Node => Block_Var);
--# end
--# expr-done 11847
Bound_Origin := Fld_2; 
--# expr-start 11849 '<FieldAccess for designated_env at ast.py:8906>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8906
--# expr-start 11848 '<as_bare_entity at ast.py:8906>' If_Result /tmp/lal-23.0.0/ada/ast.py:8906
Is_Null := Block_Var = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
As_Entity := (Info => No_Entity_Info, Node => Block_Var); 
   If_Result := As_Entity;
end if;
--# expr-done 11848
      if If_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Expr.designated_env'
Fld_3 := Libadalang.Implementation.Dispatcher_Expr_P_Designated_Env (Node => If_Result.Node, Env => Bound_Env, Origin => Bound_Origin, No_Visibility => False, E_Info => If_Result.Info);
--# end
--# expr-done 11849
Dyn_Var_Bind_Result := Fld_3; Inc_Ref (Dyn_Var_Bind_Result);
--# expr-done 11850
Dyn_Var_Bind_Result_1 := Dyn_Var_Bind_Result; Inc_Ref (Dyn_Var_Bind_Result_1);
--# expr-done 11851
Let_Result := Dyn_Var_Bind_Result_1; Inc_Ref (Let_Result);
--# end
--# expr-done 11852
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_731;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_731;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Package_Clause_P_Designated_Env;
--# end
--# property-start UsePackageClause.designated_envs /tmp/lal-23.0.0/ada/ast.py:8911
pragma Warnings (Off, "is not referenced");
 function Use_Package_Clause_P_Designated_Envs
  (Node : Bare_Use_Package_Clause
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Lexical_Env_Array_Access
is
   Self : Bare_Use_Package_Clause := Bare_Use_Package_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Use_Package_Clause :=
     Internal_Entity_Use_Package_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   Property_Result : Lexical_Env_Array_Access;
            procedure Finalizer_Scope_732 with Inline_Always;
            procedure Finalizer_Scope_3195 with Inline_Always;
      Fld : Bare_Name_List;
Fld_1 : Lexical_Env := Empty_Env;
Item_346 : Bare_Name;
Index_347 : Integer;
Map_Result : Lexical_Env_Array_Access;
Let_Result : Lexical_Env_Array_Access;
            procedure Finalizer_Scope_732 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_732;
            procedure Finalizer_Scope_3195 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_3195;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11856 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11855 '<Map at ast.py:8918>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8918
   --# expr-start 11853 '<FieldAccess for packages at ast.py:8918>' Fld /tmp/lal-23.0.0/ada/ast.py:8918
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Use_Package_Clause_F_Packages;
--# expr-done 11853
      declare
         Map_Result_Vec : Lexical_Env_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Lexical_Env_Array (0);
      else
         Index_347 := 0;
      declare
         Collection : constant Bare_Name_List := Fld;
      begin
         for Untyped_Item_346 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_346 := Untyped_Item_346; 
   --# scope-start
               --# bind _ Item_346
               --# bind i Index_347
      --# expr-start 11854 '<FieldAccess for designated_env at ast.py:8919>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8919
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UsePackageClause.designated_env
Fld_1 := Libadalang.Implementation.Use_Package_Clause_P_Designated_Env (Node => Ent.Node, Index => Index_347, E_Info => Ent.Info);
--# end
--# expr-done 11854
         declare
            Item_To_Append : constant Lexical_Env := Fld_1;
         begin
               Inc_Ref (Item_To_Append);
            Lexical_Env_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3195;
               Index_347 := Index_347 + 1;
         end loop;
      end;
      end if;
         Map_Result := Create_Lexical_Env_Array
           (Items_Count => Natural (Lexical_Env_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Lexical_Env_Vectors.Get
              (Map_Result_Vec,
               I + Lexical_Env_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Lexical_Env_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11855
Let_Result := Map_Result; Inc_Ref (Let_Result);
--# end
--# expr-done 11856
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_732;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_732;
               Finalizer_Scope_3195;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Package_Clause_P_Designated_Envs;
--# end
--# property-start UsePackageClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:8922
pragma Warnings (Off, "is not referenced");
 function Use_Package_Clause_P_Xref_Equation
  (Node : Bare_Use_Package_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Use_Package_Clause := Bare_Use_Package_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Use_Package_Clause :=
     Internal_Entity_Use_Package_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_733 with Inline_Always;
            procedure Finalizer_Scope_3196 with Inline_Always;
      Fld : Internal_Entity_Name_List;
Fld_1 : Bare_Name_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Item_348 : Internal_Entity_Name;
Bare_Item_348 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
            procedure Finalizer_Scope_733 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_733;
            procedure Finalizer_Scope_3196 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3196;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11860 '<LogicAll at ast.py:8923>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8923
--# expr-start 11859 '<Map at ast.py:8923>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8923
   --# expr-start 11857 '<FieldAccess for packages at ast.py:8923>' Fld /tmp/lal-23.0.0/ada/ast.py:8923
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name_List (Node => Ent.Node.Use_Package_Clause_F_Packages, Info => Ent.Info);
--# expr-done 11857
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld_1;
      begin
         for Untyped_Item_348 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_348 := Untyped_Item_348; 
Is_Null := Bare_Item_348 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_348); 
   If_Result := As_Entity;
end if;
                  Item_348 := If_Result; 
   --# scope-start
               --# bind p Item_348
      --# expr-start 11858 '<FieldAccess for xref_no_overloading at ast.py:8923>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8923
      if Item_348.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_3 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Item_348.Node, Env => Env, Origin => Origin, E_Info => Item_348.Info);
--# end
--# expr-done 11858
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3196;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11859
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8923") else null)); 
--# expr-done 11860
      Property_Result := Logic_Boolean_Op;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_733;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_733;
               Finalizer_Scope_3196;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Package_Clause_P_Xref_Equation;
--# end
--# property-start UsePackageClause._initial_env_18 /tmp/lal-23.0.0/ada/ast.py:8883
pragma Warnings (Off, "is not referenced");
 function Initial_Env_18
  (Node : Bare_Use_Package_Clause
  )
   return Internal_Designated_Env
is
   Self : Bare_Use_Package_Clause := Bare_Use_Package_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1487 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1487 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1487;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11861 '<FieldAccess for initial_env at ast.py:8883>' Fld /tmp/lal-23.0.0/ada/ast.py:8883
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UseClause.initial_env
Fld := Libadalang.Implementation.Use_Clause_P_Initial_Env (Node => Self);
--# end
--# expr-done 11861
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1487;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1487;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_18;
--# end
--# property-start UsePackageClause._ref_env_nodes_19 /tmp/lal-23.0.0/ada/ast.py:8889
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_19
  (Node : Bare_Use_Package_Clause
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Use_Package_Clause := Bare_Use_Package_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1488 with Inline_Always;
      Fld : Bare_Name_List;
Cast_Expr : Bare_Name;
Cast_Result : Bare_Ada_Node;
Item_349 : Bare_Name;
Map_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1488 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1488;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11864 '<Map at ast.py:8889>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8889
   --# expr-start 11862 '<FieldAccess for packages at ast.py:8889>' Fld /tmp/lal-23.0.0/ada/ast.py:8889
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Use_Package_Clause_F_Packages;
--# expr-done 11862
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld;
      begin
         for Untyped_Item_349 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_349 := Untyped_Item_349; 
   --# scope-start
               --# bind n Item_349
      --# expr-start 11863 '<Cast to AdaNode at ast.py:8889>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8889
Cast_Expr := Item_349; 
      Cast_Result := Cast_Expr;
--# expr-done 11863
         declare
            Item_To_Append : constant Bare_Ada_Node := Cast_Result;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11864
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1488;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1488;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_19;
--# end
--# property-start UsePackageClause._ref_cond_20 /tmp/lal-23.0.0/ada/ast.py:8891
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_20
  (Node : Bare_Use_Package_Clause
  )
   return Boolean
is
   Self : Bare_Use_Package_Clause := Bare_Use_Package_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11868 '<Not at ast.py:8891>' Not_Val /tmp/lal-23.0.0/ada/ast.py:8891
--# expr-start 11867 '<IsA CompilationUnit at ast.py:8891>' Is_A /tmp/lal-23.0.0/ada/ast.py:8891
--# expr-start 11866 '<parent at ast.py:8891>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8891
--# expr-start 11865 '<parent at ast.py:8891>' Fld /tmp/lal-23.0.0/ada/ast.py:8891
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11865
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 11866
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 11867
Not_Val := not (Is_A); 
--# expr-done 11868
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_20;
--# end
   --
   --  Primitives for Bare_Use_Type_Clause
   --
      procedure Use_Type_Clause_Pre_Env_Actions
        (Self            : Bare_Use_Type_Clause;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_21 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:8935");
      end;
      end;
      procedure Use_Type_Clause_Post_Env_Actions
        (Self : Bare_Use_Type_Clause; State : in out PLE_Node_State) is
      begin
      if Libadalang.Implementation.Ref_Cond_23 (Node => 
Self) then
         declare
            Ref_Env_Nodes : Bare_Ada_Node_Array_Access :=
               Libadalang.Implementation.Ref_Env_Nodes_22 (Node => 
Self);
            Env : Lexical_Env :=
              Self.Self_Env;
         begin
            Ref_Env
              (Self,
               Env,
               Ref_Env_Nodes,
               Name_P_Name_Designated_Type_Env'Access,
               Normal,
               All_Cats,
               False);
            Dec_Ref (Ref_Env_Nodes);
         end;
      end if;
      end;
      procedure Initialize_Fields_For_Use_Type_Clause
        (Self : Bare_Use_Type_Clause
         ; Use_Type_Clause_F_Has_All : Bare_All_Node
         ; Use_Type_Clause_F_Types : Bare_Name_List
        ) is
      begin
            Self.Use_Type_Clause_F_Has_All := Use_Type_Clause_F_Has_All;
            Self.Use_Type_Clause_F_Types := Use_Type_Clause_F_Types;
      end Initialize_Fields_For_Use_Type_Clause;
   function Use_Type_Clause_F_Has_All
     (Node : Bare_Use_Type_Clause) return Bare_All_Node
   is
   begin
         return Node.Use_Type_Clause_F_Has_All;
   end;
   function Use_Type_Clause_F_Types
     (Node : Bare_Use_Type_Clause) return Bare_Name_List
   is
   begin
         return Node.Use_Type_Clause_F_Types;
   end;
--# property-start UseTypeClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:8947
pragma Warnings (Off, "is not referenced");
 function Use_Type_Clause_P_Xref_Equation
  (Node : Bare_Use_Type_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Use_Type_Clause := Bare_Use_Type_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Use_Type_Clause :=
     Internal_Entity_Use_Type_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_734 with Inline_Always;
            procedure Finalizer_Scope_3198 with Inline_Always;
      Fld : Internal_Entity_Name_List;
Fld_1 : Bare_Name_List;
Fld_2 : Internal_Entity_Info;
As_Entity : Internal_Entity_Name;
Is_Null : Boolean;
If_Result : Internal_Entity_Name;
Fld_3 : Logic_Equation;
Item_350 : Internal_Entity_Name;
Bare_Item_350 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
            procedure Finalizer_Scope_734 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_734;
            procedure Finalizer_Scope_3198 is
            begin
                     Dec_Ref (Fld_3);
            end Finalizer_Scope_3198;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11872 '<LogicAll at ast.py:8948>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8948
--# expr-start 11871 '<Map at ast.py:8948>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8948
   --# expr-start 11869 '<FieldAccess for types at ast.py:8948>' Fld /tmp/lal-23.0.0/ada/ast.py:8948
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Name_List (Node => Ent.Node.Use_Type_Clause_F_Types, Info => Ent.Info);
--# expr-done 11869
Fld_1 := Fld.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_1 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld_1;
      begin
         for Untyped_Item_350 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_350 := Untyped_Item_350; 
Is_Null := Bare_Item_350 = null; 
if Is_Null then
   If_Result := No_Entity_Name;
else
Fld_2 := Fld.Info;
As_Entity := (Info => Fld_2, Node => Bare_Item_350); 
   If_Result := As_Entity;
end if;
                  Item_350 := If_Result; 
   --# scope-start
               --# bind p Item_350
      --# expr-start 11870 '<FieldAccess for xref_no_overloading at ast.py:8948>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8948
      if Item_350.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_3 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Item_350.Node, Env => Env, Origin => Origin, E_Info => Item_350.Info);
--# end
--# expr-done 11870
         declare
            Item_To_Append : constant Logic_Equation := Fld_3;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3198;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11871
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8948") else null)); 
--# expr-done 11872
      Property_Result := Logic_Boolean_Op;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_734;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_734;
               Finalizer_Scope_3198;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Use_Type_Clause_P_Xref_Equation;
--# end
--# property-start UseTypeClause._initial_env_21 /tmp/lal-23.0.0/ada/ast.py:8935
pragma Warnings (Off, "is not referenced");
 function Initial_Env_21
  (Node : Bare_Use_Type_Clause
  )
   return Internal_Designated_Env
is
   Self : Bare_Use_Type_Clause := Bare_Use_Type_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1490 with Inline_Always;
      Fld : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1490 is
            begin
                     Dec_Ref (Fld);
            end Finalizer_Scope_1490;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11873 '<FieldAccess for initial_env at ast.py:8935>' Fld /tmp/lal-23.0.0/ada/ast.py:8935
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start UseClause.initial_env
Fld := Libadalang.Implementation.Use_Clause_P_Initial_Env (Node => Self);
--# end
--# expr-done 11873
      Property_Result := Fld;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1490;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1490;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_21;
--# end
--# property-start UseTypeClause._ref_env_nodes_22 /tmp/lal-23.0.0/ada/ast.py:8941
pragma Warnings (Off, "is not referenced");
 function Ref_Env_Nodes_22
  (Node : Bare_Use_Type_Clause
  )
   return Bare_Ada_Node_Array_Access
is
   Self : Bare_Use_Type_Clause := Bare_Use_Type_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1491 with Inline_Always;
      Fld : Bare_Name_List;
Cast_Expr : Bare_Name;
Cast_Result : Bare_Ada_Node;
Item_351 : Bare_Name;
Map_Result : Bare_Ada_Node_Array_Access;
            procedure Finalizer_Scope_1491 is
            begin
                     Dec_Ref (Map_Result);
            end Finalizer_Scope_1491;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11876 '<Map at ast.py:8941>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8941
   --# expr-start 11874 '<FieldAccess for types at ast.py:8941>' Fld /tmp/lal-23.0.0/ada/ast.py:8941
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Use_Type_Clause_F_Types;
--# expr-done 11874
      declare
         Map_Result_Vec : Bare_Ada_Node_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Bare_Ada_Node_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld;
      begin
         for Untyped_Item_351 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_351 := Untyped_Item_351; 
   --# scope-start
               --# bind n Item_351
      --# expr-start 11875 '<Cast to AdaNode at ast.py:8941>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:8941
Cast_Expr := Item_351; 
      Cast_Result := Cast_Expr;
--# expr-done 11875
         declare
            Item_To_Append : constant Bare_Ada_Node := Cast_Result;
         begin
            Bare_Ada_Node_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
         end loop;
      end;
      end if;
         Map_Result := Create_Bare_Ada_Node_Array
           (Items_Count => Natural (Bare_Ada_Node_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Bare_Ada_Node_Vectors.Get
              (Map_Result_Vec,
               I + Bare_Ada_Node_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Bare_Ada_Node_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11876
      Property_Result := Map_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1491;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1491;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Env_Nodes_22;
--# end
--# property-start UseTypeClause._ref_cond_23 /tmp/lal-23.0.0/ada/ast.py:8943
pragma Warnings (Off, "is not referenced");
 function Ref_Cond_23
  (Node : Bare_Use_Type_Clause
  )
   return Boolean
is
   Self : Bare_Use_Type_Clause := Bare_Use_Type_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
      Fld : Bare_Ada_Node;
Fld_1 : Bare_Ada_Node;
Is_A : Boolean;
Not_Val : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11880 '<Not at ast.py:8943>' Not_Val /tmp/lal-23.0.0/ada/ast.py:8943
--# expr-start 11879 '<IsA CompilationUnit at ast.py:8943>' Is_A /tmp/lal-23.0.0/ada/ast.py:8943
--# expr-start 11878 '<parent at ast.py:8943>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8943
--# expr-start 11877 '<parent at ast.py:8943>' Fld /tmp/lal-23.0.0/ada/ast.py:8943
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.Parent; 
--# expr-done 11877
      if Fld = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Fld.Parent; 
--# expr-done 11878
Is_A := Fld_1 /= null 
and then Fld_1.Kind in Ada_Compilation_Unit_Range; 
--# expr-done 11879
Not_Val := not (Is_A); 
--# expr-done 11880
      Property_Result := Not_Val;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Ref_Cond_23;
--# end
   --
   --  Primitives for Bare_Value_Sequence
   --
      procedure Initialize_Fields_For_Value_Sequence
        (Self : Bare_Value_Sequence
         ; Value_Sequence_F_Iter_Assoc : Bare_Iterated_Assoc
        ) is
      begin
            Self.Value_Sequence_F_Iter_Assoc := Value_Sequence_F_Iter_Assoc;
      end Initialize_Fields_For_Value_Sequence;
   function Value_Sequence_F_Iter_Assoc
     (Node : Bare_Value_Sequence) return Bare_Iterated_Assoc
   is
   begin
         return Node.Value_Sequence_F_Iter_Assoc;
   end;
--# property-start ValueSequence.xref_equation /tmp/lal-23.0.0/ada/ast.py:18676
pragma Warnings (Off, "is not referenced");
 function Value_Sequence_P_Xref_Equation
  (Node : Bare_Value_Sequence
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Value_Sequence := Bare_Value_Sequence (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Value_Sequence :=
     Internal_Entity_Value_Sequence'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_1329 with Inline_Always;
      Fld : Internal_Entity_Iterated_Assoc;
Fld_1 : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_1329 is
            begin
                     Dec_Ref (Fld_1);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_1329;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11883 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11882 '<FieldAccess for xref_equation_for_reduce at ast.py:18680>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:18680
--# expr-start 11881 '<FieldAccess for iter_assoc at ast.py:18680>' Fld /tmp/lal-23.0.0/ada/ast.py:18680
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Iterated_Assoc (Node => Ent.Node.Value_Sequence_F_Iter_Assoc, Info => Ent.Info);
--# expr-done 11881
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start IteratedAssoc.xref_equation_for_reduce
Fld_1 := Libadalang.Implementation.Iterated_Assoc_P_Xref_Equation_For_Reduce (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11882
Let_Result := Fld_1; Inc_Ref (Let_Result);
--# end
--# expr-done 11883
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1329;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1329;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Value_Sequence_P_Xref_Equation;
--# end
   --
   --  Primitives for Bare_Variant
   --
      procedure Initialize_Fields_For_Variant
        (Self : Bare_Variant
         ; Variant_F_Choices : Bare_Alternatives_List
         ; Variant_F_Components : Bare_Component_List
        ) is
      begin
            Self.Variant_F_Choices := Variant_F_Choices;
            Self.Variant_F_Components := Variant_F_Components;
      end Initialize_Fields_For_Variant;
   function Variant_F_Choices
     (Node : Bare_Variant) return Bare_Alternatives_List
   is
   begin
         return Node.Variant_F_Choices;
   end;
   function Variant_F_Components
     (Node : Bare_Variant) return Bare_Component_List
   is
   begin
         return Node.Variant_F_Components;
   end;
--# property-start Variant.matches /tmp/lal-23.0.0/ada/ast.py:4642
pragma Warnings (Off, "is not referenced");
 function Variant_P_Matches
  (Node : Bare_Variant
      ; Expr : Internal_Entity_Expr
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Boolean
is
   Self : Bare_Variant := Bare_Variant (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Variant :=
     Internal_Entity_Variant'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind expr Expr
   Property_Result : Boolean;
            procedure Finalizer_Scope_298 with Inline_Always;
      Block_Var : Big_Integer_Type;
Fld : Big_Integer_Type;
Fld_1 : Internal_Entity_Alternatives_List;
Fld_2 : Bare_Alternatives_List;
Fld_3 : Internal_Entity_Info;
As_Entity : Internal_Entity;
Is_Null : Boolean;
If_Result : Internal_Entity;
Fld_4 : Boolean;
Item_352 : Internal_Entity;
Bare_Item_352 : Bare_Ada_Node;
Quantifier_Result : Boolean;
Let_Result : Boolean;
            procedure Finalizer_Scope_298 is
            begin
                     Dec_Ref (Fld);
                     Dec_Ref (Block_Var);
            end Finalizer_Scope_298;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11888 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11884 '<FieldAccess for eval_as_int at ast.py:4647>' Fld /tmp/lal-23.0.0/ada/ast.py:4647
      if Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.eval_as_int
Fld := Libadalang.Implementation.Expr_P_Eval_As_Int (Node => Expr.Node, E_Info => Expr.Info);
--# end
--# expr-done 11884
Block_Var := Fld; Inc_Ref (Block_Var);
--# bind expr_val Block_Var
--# expr-start 11887 '<AnyQuantifier at ast.py:4649>' Quantifier_Result /tmp/lal-23.0.0/ada/ast.py:4649
   --# expr-start 11885 '<FieldAccess for choices at ast.py:4649>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4649
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Alternatives_List (Node => Ent.Node.Variant_F_Choices, Info => Ent.Info);
--# expr-done 11885
Fld_2 := Fld_1.Node;
      Quantifier_Result := False;
      if Fld_2 = null then
      null;
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_2;
      begin
         for Untyped_Item_352 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_352 := Untyped_Item_352; 
Is_Null := Bare_Item_352 = null; 
if Is_Null then
   If_Result := No_Entity;
else
Fld_3 := Fld_1.Info;
As_Entity := (Info => Fld_3, Node => Bare_Item_352); 
   If_Result := As_Entity;
end if;
                  Item_352 := If_Result; 
   --# scope-start
               --# bind c Item_352
      --# expr-start 11886 '<FieldAccess for choice_match at ast.py:4650>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4650
      if Item_352.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.choice_match
Fld_4 := Libadalang.Implementation.Ada_Node_P_Choice_Match (Node => Item_352.Node, Value => Block_Var, E_Info => Item_352.Info);
--# end
--# expr-done 11886
      Quantifier_Result := Fld_4;
   --# end
               exit when Quantifier_Result;
         end loop;
      end;
      end if;
--# expr-done 11887
Let_Result := Quantifier_Result; 
--# end
--# expr-done 11888
      Property_Result := Let_Result;
   --# end
      Finalizer_Scope_298;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_298;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Variant_P_Matches;
--# end
   --
   --  Primitives for Bare_Variant_Part
   --
      procedure Initialize_Fields_For_Variant_Part
        (Self : Bare_Variant_Part
         ; Variant_Part_F_Discr_Name : Bare_Identifier
         ; Variant_Part_F_Variant : Bare_Variant_List
        ) is
      begin
            Self.Variant_Part_F_Discr_Name := Variant_Part_F_Discr_Name;
            Self.Variant_Part_F_Variant := Variant_Part_F_Variant;
      end Initialize_Fields_For_Variant_Part;
   function Variant_Part_F_Discr_Name
     (Node : Bare_Variant_Part) return Bare_Identifier
   is
   begin
         return Node.Variant_Part_F_Discr_Name;
   end;
   function Variant_Part_F_Variant
     (Node : Bare_Variant_Part) return Bare_Variant_List
   is
   begin
         return Node.Variant_Part_F_Variant;
   end;
--# property-start VariantPart.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:4664
pragma Warnings (Off, "is not referenced");
 function Variant_Part_P_Xref_Entry_Point
  (Node : Bare_Variant_Part
  )
   return Boolean
is
   Self : Bare_Variant_Part := Bare_Variant_Part (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Variant_Part_P_Xref_Entry_Point;
--# end
--# property-start VariantPart.xref_equation /tmp/lal-23.0.0/ada/ast.py:4667
pragma Warnings (Off, "is not referenced");
 function Variant_Part_P_Xref_Equation
  (Node : Bare_Variant_Part
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_Variant_Part := Bare_Variant_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Variant_Part :=
     Internal_Entity_Variant_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_300 with Inline_Always;
            procedure Finalizer_Scope_3201 with Inline_Always;
            procedure Finalizer_Scope_3202 with Inline_Always;
            procedure Finalizer_Scope_3203 with Inline_Always;
            procedure Finalizer_Scope_3205 with Inline_Always;
            procedure Finalizer_Scope_3206 with Inline_Always;
      Block_Var : Boolean;
Match_0 : Internal_Entity_Expr;
Match_1 : Internal_Entity_Subtype_Indication;
Match_2 : Internal_Entity_Others_Designator;
Match_3 : Internal_Entity;
Var_Expr : Internal_Entity_Name;
Fld : Internal_Entity_Identifier;
Fld_1 : Boolean;
Fld_2 : Internal_Entity_Variant_List;
Fld_3 : Bare_Variant_List;
Fld_4 : Internal_Entity_Info;
As_Entity : Internal_Entity_Variant;
Is_Null : Boolean;
If_Result : Internal_Entity_Variant;
Fld_5 : Internal_Entity_Alternatives_List;
Fld_6 : Bare_Alternatives_List;
Fld_7 : Internal_Entity_Info;
As_Entity_1 : Internal_Entity;
Is_Null_1 : Boolean;
If_Result_1 : Internal_Entity;
Cast_Expr : Internal_Entity_Expr;
Cast_Result : Internal_Entity_Name;
Fld_8 : Logic_Equation;
Fld_9 : Logic_Var;
Fld_10 : Bare_Identifier;
Fld_11 : Internal_Entity;
Bind_Result : Logic_Equation;
Fld_12 : Logic_Equation;
And_Pred : Logic_Equation;
Fld_13 : Logic_Equation;
And_Pred_1 : Logic_Equation;
Cast_Expr_1 : Internal_Entity_Expr;
Cast_Result_1 : Internal_Entity_Name;
Fld_14 : Internal_Entity_Base_Type_Decl;
Scope_Result : Internal_Entity_Base_Type_Decl;
Result_Var : Internal_Entity_Base_Type_Decl;
Is_Null_2 : Boolean;
Not_Val : Boolean;
If_Result_2 : Logic_Equation;
Fld_15 : Logic_Equation;
True_Rel : Logic_Equation;
Match_Prefix : Internal_Entity;
Cast_Result_2 : Internal_Entity_Expr;
Let_Result : Logic_Equation;
Scope_Result_1 : Logic_Equation;
Cast_Result_3 : Internal_Entity_Subtype_Indication;
Let_Result_1 : Logic_Equation;
Scope_Result_2 : Logic_Equation;
Cast_Result_4 : Internal_Entity_Others_Designator;
Let_Result_2 : Logic_Equation;
Scope_Result_3 : Logic_Equation;
Cast_Result_5 : Internal_Entity;
Let_Result_3 : Logic_Equation;
Scope_Result_4 : Logic_Equation;
Match_Result : Logic_Equation;
Item_354 : Internal_Entity;
Bare_Item_354 : Bare_Ada_Node;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
Item_353 : Internal_Entity_Variant;
Bare_Item_353 : Bare_Variant;
Map_Result_1 : Logic_Equation_Array_Access;
Logic_Boolean_Op_1 : Logic_Equation;
Let_Result_4 : Logic_Equation;
            procedure Finalizer_Scope_300 is
            begin
                     Dec_Ref (Map_Result_1);
                     Dec_Ref (Logic_Boolean_Op_1);
                     Dec_Ref (Let_Result_4);
            end Finalizer_Scope_300;
            procedure Finalizer_Scope_3201 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_3201;
            procedure Finalizer_Scope_3202 is
            begin
                     Dec_Ref (Let_Result);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (Let_Result_1);
                     Dec_Ref (Scope_Result_2);
                     Dec_Ref (Let_Result_2);
                     Dec_Ref (Scope_Result_3);
                     Dec_Ref (Let_Result_3);
                     Dec_Ref (Scope_Result_4);
                     Dec_Ref (Match_Result);
            end Finalizer_Scope_3202;
            procedure Finalizer_Scope_3203 is
            begin
                     Dec_Ref (Fld_8);
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Fld_12);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Fld_13);
                     Dec_Ref (And_Pred_1);
                     Dec_Ref (If_Result_2);
            end Finalizer_Scope_3203;
            procedure Finalizer_Scope_3205 is
            begin
                     Dec_Ref (Fld_15);
            end Finalizer_Scope_3205;
            procedure Finalizer_Scope_3206 is
            begin
                     Dec_Ref (True_Rel);
            end Finalizer_Scope_3206;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11914 '<Block at ???>' Let_Result_4 None
--# scope-start
--# expr-start 11890 '<FieldAccess for resolve_names_internal at ast.py:4668>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4668
--# expr-start 11889 '<FieldAccess for discr_name at ast.py:4668>' Fld /tmp/lal-23.0.0/ada/ast.py:4668
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Create_Internal_Entity_Identifier (Node => Ent.Node.Variant_Part_F_Discr_Name, Info => Ent.Info);
--# expr-done 11889
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.resolve_names_internal
Fld_1 := Libadalang.Implementation.Ada_Node_P_Resolve_Names_Internal (Node => Fld.Node, Env => Env, Origin => Origin, E_Info => Fld.Info);
--# end
--# expr-done 11890
Block_Var := Fld_1; 
--# expr-start 11913 '<LogicAll at ast.py:4670>' Logic_Boolean_Op_1 /tmp/lal-23.0.0/ada/ast.py:4670
--# expr-start 11912 '<Map at ast.py:4670>' Map_Result_1 /tmp/lal-23.0.0/ada/ast.py:4670
   --# expr-start 11891 '<FieldAccess for variant at ast.py:4670>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4670
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Create_Internal_Entity_Variant_List (Node => Ent.Node.Variant_Part_F_Variant, Info => Ent.Info);
--# expr-done 11891
Fld_3 := Fld_2.Node;
      declare
         Map_Result_1_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_3 = null then
      Map_Result_1 := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Variant_List := Fld_3;
      begin
         for Untyped_Item_353 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_353 := Untyped_Item_353; 
Is_Null := Bare_Item_353 = null; 
if Is_Null then
   If_Result := No_Entity_Variant;
else
Fld_4 := Fld_2.Info;
As_Entity := (Info => Fld_4, Node => Bare_Item_353); 
   If_Result := As_Entity;
end if;
                  Item_353 := If_Result; 
   --# scope-start
               --# bind var Item_353
      --# expr-start 11911 '<LogicAll at ast.py:4671>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:4671
--# expr-start 11910 '<Map at ast.py:4671>' Map_Result /tmp/lal-23.0.0/ada/ast.py:4671
   --# expr-start 11892 '<FieldAccess for choices at ast.py:4671>' Fld_5 /tmp/lal-23.0.0/ada/ast.py:4671
      if Item_353.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_5 := Create_Internal_Entity_Alternatives_List (Node => Item_353.Node.Variant_F_Choices, Info => Item_353.Info);
--# expr-done 11892
Fld_6 := Fld_5.Node;
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld_6 = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Alternatives_List := Fld_6;
      begin
         for Untyped_Item_354 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_354 := Untyped_Item_354; 
Is_Null_1 := Bare_Item_354 = null; 
if Is_Null_1 then
   If_Result_1 := No_Entity;
else
Fld_7 := Fld_5.Info;
As_Entity_1 := (Info => Fld_7, Node => Bare_Item_354); 
   If_Result_1 := As_Entity_1;
end if;
                  Item_354 := If_Result_1; 
   --# scope-start
               --# bind c Item_354
      --# expr-start 11909 '<Match at ast.py:4671>' Match_Result /tmp/lal-23.0.0/ada/ast.py:4671
      if Item_354.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Match_Prefix := Item_354; 
case Ada_Ada_Node (Match_Prefix.Node.Kind) is
         when Ada_Abstract_State_Decl_Expr .. Ada_Un_Op =>
   --# scope-start
--# scope-start
      Cast_Result_2 := Create_Internal_Entity_Expr
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_0 := Cast_Result_2; 
--# bind e Match_0
--# expr-start 11907 '<If at ast.py:4673>' If_Result_2 /tmp/lal-23.0.0/ada/ast.py:4673
--# expr-start 11896 '<Not at ast.py:4674>' Not_Val /tmp/lal-23.0.0/ada/ast.py:4674
--# expr-start 11895 '<IsNull at ast.py:4674>' Is_Null_2 /tmp/lal-23.0.0/ada/ast.py:4674
--# expr-start 11893 '<Cast to Name at ast.py:4674>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:4674
Cast_Expr_1 := Match_0; 
   if Cast_Expr_1.Node = null
      or else Cast_Expr_1.Node.Kind in Ada_Name
   then
      Cast_Result_1 := Create_Internal_Entity_Name
        (Node => Cast_Expr_1.Node,
         Info => Cast_Expr_1.Info);
   else
         Cast_Result_1 := No_Entity_Name;
   end if;
--# expr-done 11893
Var_Expr := Cast_Result_1;
if Var_Expr /= No_Entity_Name then
   --# scope-start
--# expr-start 11894 '<FieldAccess for name_designated_type at ast.py:4674>' Fld_14 /tmp/lal-23.0.0/ada/ast.py:4674
      if Var_Expr.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.name_designated_type
Fld_14 := Libadalang.Implementation.Name_P_Name_Designated_Type (Node => Var_Expr.Node, E_Info => Var_Expr.Info);
--# end
--# expr-done 11894
Scope_Result := Fld_14;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Entity_Base_Type_Decl;
end if;
Is_Null_2 := Result_Var.Node = null; 
--# expr-done 11895
Not_Val := not (Is_Null_2); 
--# expr-done 11896
if Not_Val then
   --# expr-start 11898 '<FieldAccess for xref_no_overloading at ast.py:4676>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4676
--# expr-start 11897 '<Cast to Name at ast.py:4676>' Cast_Result /tmp/lal-23.0.0/ada/ast.py:4676
Cast_Expr := Match_0; 
   if Cast_Expr.Node = null
      or else Cast_Expr.Node.Kind in Ada_Name
   then
      Cast_Result := Create_Internal_Entity_Name
        (Node => Cast_Expr.Node,
         Info => Cast_Expr.Info);
   else
         Cast_Result := No_Entity_Name;
   end if;
--# expr-done 11897
      if Cast_Result.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Name.xref_no_overloading
Fld_8 := Libadalang.Implementation.Name_P_Xref_No_Overloading (Node => Cast_Result.Node, Env => Env, Origin => Origin, E_Info => Cast_Result.Info);
--# end
--# expr-done 11898
   If_Result_2 := Fld_8;
else
   --# expr-start 11906 '<And at ast.py:4678>' And_Pred_1 /tmp/lal-23.0.0/ada/ast.py:4678
--# expr-start 11904 '<And at ast.py:4678>' And_Pred /tmp/lal-23.0.0/ada/ast.py:4678
--# expr-start 11902 '<Bind at ast.py:4678>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:4678
--# expr-start 11899 '<FieldAccess for expected_type_var at ast.py:4678>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4678
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_9 := Libadalang.Implementation.Extensions.Expr_P_Expected_Type_Var (Node => Match_0.Node);
--# expr-done 11899
Fld_9.Value := No_Entity;
Entity_Vars.Reset (Fld_9);
--# expr-start 11901 '<FieldAccess for type_val at ast.py:4678>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4678
--# expr-start 11900 '<FieldAccess for discr_name at ast.py:4678>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4678
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_10 := Self.Variant_Part_F_Discr_Name;
--# expr-done 11900
      if Fld_10 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.type_val
Fld_11 := Libadalang.Implementation.Expr_P_Type_Val (Node => Fld_10);
--# end
--# expr-done 11901
Bind_Result := Solver.Create_Assign (Fld_9, Fld_11, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4678") else null)); 
--# expr-done 11902
--# expr-start 11903 '<FieldAccess for sub_equation at ast.py:4679>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4679
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.sub_equation
Fld_12 := Libadalang.Implementation.Ada_Node_P_Sub_Equation (Node => Match_0.Node, Env => Env, Origin => Origin, E_Info => Match_0.Info);
--# end
--# expr-done 11903
And_Pred := Create_And (Bind_Result, Fld_12, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4678") else null)); 
--# expr-done 11904
--# expr-start 11905 '<FieldAccess for matches_expected_type at ast.py:4680>' Fld_13 /tmp/lal-23.0.0/ada/ast.py:4680
      if Match_0.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start Expr.matches_expected_type
Fld_13 := Libadalang.Implementation.Expr_P_Matches_Expected_Type (Node => Match_0.Node, Origin => Origin);
--# end
--# expr-done 11905
And_Pred_1 := Create_And (And_Pred, Fld_13, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4678") else null)); 
--# expr-done 11906
   If_Result_2 := And_Pred_1;
end if;
      Inc_Ref (If_Result_2);
--# expr-done 11907
Let_Result := If_Result_2; Inc_Ref (Let_Result);
--# end
Scope_Result_1 := Let_Result;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3203;
            Match_Result := Scope_Result_1; Inc_Ref (Match_Result);
         when Ada_Subtype_Indication .. Ada_Discrete_Subtype_Indication =>
   --# scope-start
--# scope-start
      Cast_Result_3 := Create_Internal_Entity_Subtype_Indication
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_1 := Cast_Result_3; 
--# bind t Match_1
--# expr-start 11908 '<FieldAccess for xref_equation at ast.py:4685>' Fld_15 /tmp/lal-23.0.0/ada/ast.py:4685
      if Match_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]AdaNode.xref_equation'
Fld_15 := Libadalang.Implementation.Dispatcher_Ada_Node_P_Xref_Equation (Node => Match_1.Node, Env => Env, Origin => Origin, E_Info => Match_1.Info);
--# end
--# expr-done 11908
Let_Result_1 := Fld_15; Inc_Ref (Let_Result_1);
--# end
Scope_Result_2 := Let_Result_1;
   Inc_Ref (Scope_Result_2);
   --# end
      Finalizer_Scope_3205;
            Match_Result := Scope_Result_2; Inc_Ref (Match_Result);
         when Ada_Others_Designator =>
   --# scope-start
--# scope-start
      Cast_Result_4 := Create_Internal_Entity_Others_Designator
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_2 := Cast_Result_4; 
--# bind _ Match_2
True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4687") else null)); 
Let_Result_2 := True_Rel; Inc_Ref (Let_Result_2);
--# end
Scope_Result_3 := Let_Result_2;
   Inc_Ref (Scope_Result_3);
   --# end
      Finalizer_Scope_3206;
            Match_Result := Scope_Result_3; Inc_Ref (Match_Result);
         when Ada_Abort_Absent .. Ada_Elsif_Stmt_Part | Ada_Handled_Stmts .. Ada_Null_Component_Decl | Ada_Overriding_Not_Overriding .. Ada_Enum_Lit_Synth_Type_Expr | Ada_Synthetic_Type_Expr .. Ada_With_Private_Present =>
   --# scope-start
--# scope-start
      Cast_Result_5 := Create_Internal_Entity
        (Node => Match_Prefix.Node,
         Info => Match_Prefix.Info);
Match_3 := Cast_Result_5; 
--# bind _ Match_3
Let_Result_3 := raise Property_Error with "Should not happen"; Inc_Ref (Let_Result_3);
--# end
Scope_Result_4 := Let_Result_3;
   Inc_Ref (Scope_Result_4);
   --# end
            Match_Result := Scope_Result_4; Inc_Ref (Match_Result);
end case;
--# expr-done 11909
         declare
            Item_To_Append : constant Logic_Equation := Match_Result;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3202;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11910
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4671") else null)); 
--# expr-done 11911
         declare
            Item_To_Append : constant Logic_Equation := Logic_Boolean_Op;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_1_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3201;
         end loop;
      end;
      end if;
         Map_Result_1 := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_1_Vec)));
         for I in Map_Result_1.Items'Range loop
            Map_Result_1.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_1_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result_1.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_1_Vec);
      end;
--# expr-done 11912
Logic_Boolean_Op_1 := Solver.Create_All (Relation_Array (Map_Result_1.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:4670") else null)); 
--# expr-done 11913
Let_Result_4 := Logic_Boolean_Op_1; Inc_Ref (Let_Result_4);
--# end
--# expr-done 11914
      Property_Result := Let_Result_4;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_300;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_300;
               Finalizer_Scope_3201;
               Finalizer_Scope_3202;
               Finalizer_Scope_3203;
               Finalizer_Scope_3205;
               Finalizer_Scope_3206;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Variant_Part_P_Xref_Equation;
--# end
--# property-start VariantPart.get_components /tmp/lal-23.0.0/ada/ast.py:4694
pragma Warnings (Off, "is not referenced");
 function Variant_Part_P_Get_Components
  (Node : Bare_Variant_Part
      ; Discriminants : Internal_Param_Match_Array_Access
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Internal_Entity_Base_Formal_Param_Decl_Array_Access
is
   Self : Bare_Variant_Part := Bare_Variant_Part (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_Variant_Part :=
     Internal_Entity_Variant_Part'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind discriminants Discriminants
   Property_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_301 with Inline_Always;
      Block_Var : Internal_Param_Match;
Block_Var_1 : Internal_Entity_Variant;
Fld : Internal_Entity_Defining_Name;
Fld_1 : Internal_Entity_Name;
Fld_2 : Bare_Identifier;
Sym : Symbol_Type;
Fld_3 : Boolean;
Find_Result : Internal_Param_Match;
Fld_4 : Internal_Entity_Variant_List;
Fld_5 : Bare_Variant_List;
Fld_6 : Internal_Entity_Info;
As_Entity : Internal_Entity_Variant;
Is_Null : Boolean;
If_Result : Internal_Entity_Variant;
Fld_7 : Internal_Single_Actual;
Fld_8 : Internal_Entity_Basic_Assoc;
Fld_9 : Internal_Entity_Expr;
Fld_10 : Boolean;
Item_356 : Internal_Entity_Variant;
Bare_Item_356 : Bare_Variant;
Find_Result_1 : Internal_Entity_Variant;
Fld_11 : Internal_Entity_Component_List;
Fld_12 : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
Let_Result : Internal_Entity_Base_Formal_Param_Decl_Array_Access;
            procedure Finalizer_Scope_301 is
            begin
                     Dec_Ref (Fld_12);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_301;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11929 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11920 '<Find at ast.py:4700>' Find_Result /tmp/lal-23.0.0/ada/ast.py:4700
      Find_Result := No_Param_Match;
      declare
         Collection : constant Internal_Param_Match_Array_Access := Discriminants;
      begin
         for Item_355 of
               Collection.Items
         loop
   --# scope-start
               --# bind d Item_355
      --# expr-start 11919 '<FieldAccess for name_is at ast.py:4701>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:4701
--# expr-start 11916 '<FieldAccess for name at ast.py:4701>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:4701
--# expr-start 11915 '<FieldAccess for formal at ast.py:4701>' Fld /tmp/lal-23.0.0/ada/ast.py:4701
Fld := Item_355.Formal;
--# expr-done 11915
      if Fld.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_1 := Create_Internal_Entity_Name (Node => Fld.Node.Defining_Name_F_Name, Info => Fld.Info);
--# expr-done 11916
      if Fld_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11918 '<GetSymbol at ast.py:4701>' Sym /tmp/lal-23.0.0/ada/ast.py:4701
--# expr-start 11917 '<FieldAccess for discr_name at ast.py:4701>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:4701
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_2 := Self.Variant_Part_F_Discr_Name;
--# expr-done 11917
Sym := Get_Symbol (Fld_2); 
--# expr-done 11918
--# property-call-start Name.name_is
Fld_3 := Libadalang.Implementation.Name_P_Name_Is (Node => Fld_1.Node, Sym => Sym);
--# end
--# expr-done 11919
      if Fld_3 then
         Find_Result := Item_355;
      end if;
   --# end
               exit when Fld_3;
         end loop;
      end;
--# expr-done 11920
Block_Var := Find_Result; 
--# bind discr Block_Var
--# expr-start 11926 '<Find at ast.py:4706>' Find_Result_1 /tmp/lal-23.0.0/ada/ast.py:4706
   --# expr-start 11921 '<FieldAccess for variant at ast.py:4706>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:4706
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_4 := Create_Internal_Entity_Variant_List (Node => Ent.Node.Variant_Part_F_Variant, Info => Ent.Info);
--# expr-done 11921
Fld_5 := Fld_4.Node;
      Find_Result_1 := No_Entity_Variant;
      if Fld_5 = null then
      Find_Result_1 := No_Entity_Variant;
      else
      declare
         Collection : constant Bare_Variant_List := Fld_5;
      begin
         for Untyped_Item_356 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Bare_Item_356 := Untyped_Item_356; 
Is_Null := Bare_Item_356 = null; 
if Is_Null then
   If_Result := No_Entity_Variant;
else
Fld_6 := Fld_4.Info;
As_Entity := (Info => Fld_6, Node => Bare_Item_356); 
   If_Result := As_Entity;
end if;
                  Item_356 := If_Result; 
   --# scope-start
               --# bind v Item_356
      --# expr-start 11925 '<FieldAccess for matches at ast.py:4707>' Fld_10 /tmp/lal-23.0.0/ada/ast.py:4707
      if Item_356.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11924 '<FieldAccess for expr at ast.py:4707>' Fld_9 /tmp/lal-23.0.0/ada/ast.py:4707
--# expr-start 11923 '<FieldAccess for assoc at ast.py:4707>' Fld_8 /tmp/lal-23.0.0/ada/ast.py:4707
--# expr-start 11922 '<FieldAccess for actual at ast.py:4707>' Fld_7 /tmp/lal-23.0.0/ada/ast.py:4707
Fld_7 := Block_Var.Actual;
--# expr-done 11922
Fld_8 := Fld_7.Assoc;
--# expr-done 11923
      if Fld_8.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]BasicAssoc.expr'
Fld_9 := Libadalang.Implementation.Dispatcher_Basic_Assoc_P_Expr (Node => Fld_8.Node, E_Info => Fld_8.Info);
--# end
--# expr-done 11924
--# property-call-start Variant.matches
Fld_10 := Libadalang.Implementation.Variant_P_Matches (Node => Item_356.Node, Expr => Fld_9, E_Info => Item_356.Info);
--# end
--# expr-done 11925
      if Fld_10 then
         Find_Result_1 := Item_356;
      end if;
   --# end
               exit when Fld_10;
         end loop;
      end;
      end if;
--# expr-done 11926
Block_Var_1 := Find_Result_1; 
--# bind variant Block_Var_1
--# expr-start 11928 '<FieldAccess for abstract_formal_params_impl at ast.py:4713>' Fld_12 /tmp/lal-23.0.0/ada/ast.py:4713
--# expr-start 11927 '<FieldAccess for components at ast.py:4713>' Fld_11 /tmp/lal-23.0.0/ada/ast.py:4713
      if Block_Var_1.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_11 := Create_Internal_Entity_Component_List (Node => Block_Var_1.Node.Variant_F_Components, Info => Block_Var_1.Info);
--# expr-done 11927
      if Fld_11.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start ComponentList.abstract_formal_params_impl
Fld_12 := Libadalang.Implementation.Component_List_P_Abstract_Formal_Params_Impl (Node => Fld_11.Node, Discriminants => Discriminants, Include_Discriminants => False, Recurse => False, E_Info => Fld_11.Info);
--# end
--# expr-done 11928
Let_Result := Fld_12; Inc_Ref (Let_Result);
--# end
--# expr-done 11929
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_301;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_301;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Variant_Part_P_Get_Components;
--# end
   --
   --  Primitives for Bare_With_Clause
   --
      procedure With_Clause_Pre_Env_Actions
        (Self            : Bare_With_Clause;
         State           : in out PLE_Node_State;
         Add_To_Env_Only : Boolean := False) is
      begin
      declare
         Env : constant Internal_Designated_Env :=
           Libadalang.Implementation.Initial_Env_17 (Node => 
Self);
      begin
         Set_Initial_Env
           (Self,
            State,
            Env,
            DSL_Location => "ast.py:8840");
      end;
      end;
      procedure Initialize_Fields_For_With_Clause
        (Self : Bare_With_Clause
         ; With_Clause_F_Has_Limited : Bare_Limited_Node
         ; With_Clause_F_Has_Private : Bare_Private_Node
         ; With_Clause_F_Packages : Bare_Name_List
        ) is
      begin
            Self.With_Clause_F_Has_Limited := With_Clause_F_Has_Limited;
            Self.With_Clause_F_Has_Private := With_Clause_F_Has_Private;
            Self.With_Clause_F_Packages := With_Clause_F_Packages;
      end Initialize_Fields_For_With_Clause;
   function With_Clause_F_Has_Limited
     (Node : Bare_With_Clause) return Bare_Limited_Node
   is
   begin
         return Node.With_Clause_F_Has_Limited;
   end;
   function With_Clause_F_Has_Private
     (Node : Bare_With_Clause) return Bare_Private_Node
   is
   begin
         return Node.With_Clause_F_Has_Private;
   end;
   function With_Clause_F_Packages
     (Node : Bare_With_Clause) return Bare_Name_List
   is
   begin
         return Node.With_Clause_F_Packages;
   end;
--# property-start WithClause.child_unit_xref_equation /tmp/lal-23.0.0/ada/ast.py:8820
pragma Warnings (Off, "is not referenced");
 function With_Clause_P_Child_Unit_Xref_Equation
  (Node : Bare_With_Clause
      ; Name : Bare_Name
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_With_Clause := Bare_With_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_With_Clause :=
     Internal_Entity_With_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind name Name
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_725 with Inline_Always;
            procedure Finalizer_Scope_3211 with Inline_Always;
      Block_Var : Logic_Equation;
Var_Expr : Bare_Compilation_Unit;
Var_Expr_1 : Bare_Dotted_Name;
Fld : Logic_Var;
Fld_1 : Bare_Compilation_Unit;
Fld_2 : Bare_Basic_Decl;
Scope_Result : Bare_Basic_Decl;
Result_Var : Bare_Basic_Decl;
As_Entity : Internal_Entity_Basic_Decl;
Is_Null : Boolean;
If_Result : Internal_Entity_Basic_Decl;
Cast_Result : Internal_Entity;
Bind_Result : Logic_Equation;
Cast_Expr : Bare_Name;
Cast_Result_1 : Bare_Dotted_Name;
Fld_3 : Bare_Name;
Fld_4 : Logic_Equation;
Scope_Result_1 : Logic_Equation;
True_Rel : Logic_Equation;
Result_Var_1 : Logic_Equation;
And_Pred : Logic_Equation;
Let_Result : Logic_Equation;
            procedure Finalizer_Scope_725 is
            begin
                     Dec_Ref (Bind_Result);
                     Dec_Ref (Block_Var);
                     Dec_Ref (Scope_Result_1);
                     Dec_Ref (True_Rel);
                     Dec_Ref (Result_Var_1);
                     Dec_Ref (And_Pred);
                     Dec_Ref (Let_Result);
            end Finalizer_Scope_725;
            procedure Finalizer_Scope_3211 is
            begin
                     Dec_Ref (Fld_4);
            end Finalizer_Scope_3211;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11938 '<Block at ???>' Let_Result None
--# scope-start
--# expr-start 11933 '<Bind at ast.py:8826>' Bind_Result /tmp/lal-23.0.0/ada/ast.py:8826
--# expr-start 11930 '<FieldAccess for ref_var at ast.py:8826>' Fld /tmp/lal-23.0.0/ada/ast.py:8826
      if Name = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start '[dispatcher]Name.ref_var'
Fld := Libadalang.Implementation.Dispatcher_Name_P_Ref_Var (Node => Name);
--# end
--# expr-done 11930
Fld.Value := No_Entity;
Entity_Vars.Reset (Fld);
--# expr-start 11931 '<FieldAccess for withed_unit_helper at ast.py:8826>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8826
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start AdaNode.withed_unit_helper
Fld_1 := Libadalang.Implementation.Ada_Node_P_Withed_Unit_Helper (Node => Self, Unit_Name => Name);
--# end
--# expr-done 11931
Var_Expr := Fld_1;
if Var_Expr /= No_Bare_Ada_Node then
   --# scope-start
--# expr-start 11932 '<FieldAccess for decl at ast.py:8826>' Fld_2 /tmp/lal-23.0.0/ada/ast.py:8826
      if Var_Expr = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start CompilationUnit.decl
Fld_2 := Libadalang.Implementation.Compilation_Unit_P_Decl (Node => Var_Expr);
--# end
--# expr-done 11932
Scope_Result := Fld_2;
   --# end
   Result_Var := Scope_Result;
else
   Result_Var := No_Bare_Ada_Node;
end if;
Is_Null := Result_Var = null; 
if Is_Null then
   If_Result := No_Entity_Basic_Decl;
else
As_Entity := (Info => E_Info, Node => Result_Var); 
   If_Result := As_Entity;
end if;
      Cast_Result := Create_Internal_Entity
        (Node => If_Result.Node,
         Info => If_Result.Info);
Bind_Result := Solver.Create_Assign (Fld, Cast_Result, Solver_Ifc.No_Converter, Debug_String => (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8826") else null)); 
--# expr-done 11933
Block_Var := Bind_Result; Inc_Ref (Block_Var);
--# bind self_eq Block_Var
--# expr-start 11937 '<And at ast.py:8827>' And_Pred /tmp/lal-23.0.0/ada/ast.py:8827
--# expr-start 11934 '<Cast to DottedName at ast.py:8827>' Cast_Result_1 /tmp/lal-23.0.0/ada/ast.py:8827
Cast_Expr := Name; 
   if Cast_Expr = null
      or else Cast_Expr.Kind in Ada_Dotted_Name_Range
   then
      Cast_Result_1 := Cast_Expr;
   else
         Cast_Result_1 := No_Bare_Ada_Node;
   end if;
--# expr-done 11934
Var_Expr_1 := Cast_Result_1;
if Var_Expr_1 /= No_Bare_Ada_Node then
   --# scope-start
   --# bind dn Var_Expr_1
--# expr-start 11936 '<FieldAccess for child_unit_xref_equation at ast.py:8828>' Fld_4 /tmp/lal-23.0.0/ada/ast.py:8828
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# expr-start 11935 '<FieldAccess for prefix at ast.py:8828>' Fld_3 /tmp/lal-23.0.0/ada/ast.py:8828
      if Var_Expr_1 = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld_3 := Var_Expr_1.Dotted_Name_F_Prefix;
--# expr-done 11935
--# property-call-start WithClause.child_unit_xref_equation
Fld_4 := Libadalang.Implementation.With_Clause_P_Child_Unit_Xref_Equation (Node => Ent.Node, Name => Fld_3, E_Info => Ent.Info);
--# end
--# expr-done 11936
Scope_Result_1 := Fld_4;
   Inc_Ref (Scope_Result_1);
   --# end
      Finalizer_Scope_3211;
   Result_Var_1 := Scope_Result_1;
else
   True_Rel := Solver.Create_True ((if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8829") else null)); 
   Result_Var_1 := True_Rel;
end if;
      Inc_Ref (Result_Var_1);
And_Pred := Create_And (Block_Var, Result_Var_1, (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8827") else null)); 
--# expr-done 11937
Let_Result := And_Pred; Inc_Ref (Let_Result);
--# end
--# expr-done 11938
      Property_Result := Let_Result;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_725;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_725;
               Finalizer_Scope_3211;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end With_Clause_P_Child_Unit_Xref_Equation;
--# end
--# property-start WithClause.xref_entry_point /tmp/lal-23.0.0/ada/ast.py:8832
pragma Warnings (Off, "is not referenced");
 function With_Clause_P_Xref_Entry_Point
  (Node : Bare_With_Clause
  )
   return Boolean
is
   Self : Bare_With_Clause := Bare_With_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end With_Clause_P_Xref_Entry_Point;
--# end
--# property-start WithClause.xref_equation /tmp/lal-23.0.0/ada/ast.py:8833
pragma Warnings (Off, "is not referenced");
 function With_Clause_P_Xref_Equation
  (Node : Bare_With_Clause
      ; Env : Lexical_Env
      ; Origin : Bare_Ada_Node
   ; E_Info : Internal_Entity_Info :=
      No_Entity_Info
  )
   return Logic_Equation
is
   Self : Bare_With_Clause := Bare_With_Clause (Node);
   Call_Depth : aliased Natural;
   Ent : Internal_Entity_With_Clause :=
     Internal_Entity_With_Clause'(Node => Self, Info => E_Info);
   --# bind entity Ent
   --# bind env Env
   --# bind origin Origin
   Property_Result : Logic_Equation;
            procedure Finalizer_Scope_727 with Inline_Always;
            procedure Finalizer_Scope_3212 with Inline_Always;
      Fld : Bare_Name_List;
Fld_1 : Logic_Equation;
Item_357 : Bare_Name;
Map_Result : Logic_Equation_Array_Access;
Logic_Boolean_Op : Logic_Equation;
            procedure Finalizer_Scope_727 is
            begin
                     Dec_Ref (Map_Result);
                     Dec_Ref (Logic_Boolean_Op);
            end Finalizer_Scope_727;
            procedure Finalizer_Scope_3212 is
            begin
                     Dec_Ref (Fld_1);
            end Finalizer_Scope_3212;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self /= null then
         Reset_Caches (Self.Unit);
      end if;
   --# scope-start
      --# expr-start 11942 '<LogicAll at ast.py:8834>' Logic_Boolean_Op /tmp/lal-23.0.0/ada/ast.py:8834
--# expr-start 11941 '<Map at ast.py:8834>' Map_Result /tmp/lal-23.0.0/ada/ast.py:8834
   --# expr-start 11939 '<FieldAccess for packages at ast.py:8834>' Fld /tmp/lal-23.0.0/ada/ast.py:8834
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
Fld := Self.With_Clause_F_Packages;
--# expr-done 11939
      declare
         Map_Result_Vec : Logic_Equation_Vectors.Vector;
      begin
      if Fld = null then
      Map_Result := Create_Logic_Equation_Array (0);
      else
      declare
         Collection : constant Bare_Name_List := Fld;
      begin
         for Untyped_Item_357 of
               Collection.Nodes (1 .. Children_Count (Collection))
         loop
                  Item_357 := Untyped_Item_357; 
   --# scope-start
               --# bind p Item_357
      --# expr-start 11940 '<FieldAccess for child_unit_xref_equation at ast.py:8835>' Fld_1 /tmp/lal-23.0.0/ada/ast.py:8835
      if Ent.Node = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dereferencing a null access");
      end if;
--# property-call-start WithClause.child_unit_xref_equation
Fld_1 := Libadalang.Implementation.With_Clause_P_Child_Unit_Xref_Equation (Node => Ent.Node, Name => Item_357, E_Info => Ent.Info);
--# end
--# expr-done 11940
         declare
            Item_To_Append : constant Logic_Equation := Fld_1;
         begin
               Inc_Ref (Item_To_Append);
            Logic_Equation_Vectors.Append (Map_Result_Vec, Item_To_Append);
         end;
   --# end
      Finalizer_Scope_3212;
         end loop;
      end;
      end if;
         Map_Result := Create_Logic_Equation_Array
           (Items_Count => Natural (Logic_Equation_Vectors.Length (Map_Result_Vec)));
         for I in Map_Result.Items'Range loop
            Map_Result.Items (I) := Logic_Equation_Vectors.Get
              (Map_Result_Vec,
               I + Logic_Equation_Vectors.Index_Type'First - Map_Result.Items'First);
         end loop;
         Logic_Equation_Vectors.Destroy (Map_Result_Vec);
      end;
--# expr-done 11941
Logic_Boolean_Op := Solver.Create_All (Relation_Array (Map_Result.Items), (if Langkit_Support.Adalog.Debug.Debug then New_Unit_String (Node.Unit, "ast.py:8834") else null)); 
--# expr-done 11942
      Property_Result := Logic_Boolean_Op;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_727;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_727;
               Finalizer_Scope_3212;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end With_Clause_P_Xref_Equation;
--# end
--# property-start WithClause._initial_env_17 /tmp/lal-23.0.0/ada/ast.py:8840
pragma Warnings (Off, "is not referenced");
 function Initial_Env_17
  (Node : Bare_With_Clause
  )
   return Internal_Designated_Env
is
   Self : Bare_With_Clause := Bare_With_Clause (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Internal_Designated_Env;
            procedure Finalizer_Scope_1486 with Inline_Always;
      Sym : Symbol_Type;
New_Struct : Internal_Designated_Env := No_Designated_Env;
            procedure Finalizer_Scope_1486 is
            begin
                     Dec_Ref (New_Struct);
            end Finalizer_Scope_1486;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      --# expr-start 11944 '<New DesignatedEnv at ast.py:8840>' New_Struct /tmp/lal-23.0.0/ada/ast.py:8840
--# expr-start 11943 '<Symbol Standard at ???>' Sym None
Sym := Precomputed_Symbol (Precomputed_Symbol_Table (Self.Unit.Context.Symbols), Precomputed_Sym_Standard); 
--# expr-done 11943
Inc_Ref (Empty_Env);
New_Struct := (Direct_Env => Empty_Env, Env_Name => Sym, Kind => Named_Env); 
--# expr-done 11944
      Property_Result := New_Struct;
         Inc_Ref (Property_Result);
   --# end
      Finalizer_Scope_1486;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when Exc : Precondition_Failure | Property_Error =>
               Finalizer_Scope_1486;
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Initial_Env_17;
--# end
   --
   --  Primitives for Bare_With_Private
   --
--# property-start '[dispatcher]WithPrivate.as_bool' dispatcher
pragma Warnings (Off, "is not referenced");
 function Dispatcher_With_Private_P_As_Bool
  (Node : Bare_With_Private
  )
   return Boolean
is
   Self : Bare_With_Private := Bare_With_Private (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
      if Self = null then
         Raise_Property_Exception
           (Self, Property_Error'Identity, "dispatching on null node");
      end if;
      case Ada_With_Private (Self.Kind) is
               when Ada_With_Private_Absent =>
                  --# property-call-start WithPrivate.Absent.as_bool
                  Property_Result := With_Private_Absent_P_As_Bool
                    (Self
                    );
                  --# end
               when Ada_With_Private_Present =>
                  --# property-call-start WithPrivate.Present.as_bool
                  Property_Result := With_Private_Present_P_As_Bool
                    (Self
                    );
                  --# end
      end case;
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end Dispatcher_With_Private_P_As_Bool;
--# end
   --
   --  Primitives for Bare_With_Private_Absent
   --
--# property-start WithPrivate.Absent.as_bool /tmp/lal-23.0.0/ada/ast.py:5045
pragma Warnings (Off, "is not referenced");
 function With_Private_Absent_P_As_Bool
  (Node : Bare_With_Private_Absent
  )
   return Boolean
is
   Self : Bare_With_Private_Absent := Bare_With_Private_Absent (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := False;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end With_Private_Absent_P_As_Bool;
--# end
   --
   --  Primitives for Bare_With_Private_Present
   --
--# property-start WithPrivate.Present.as_bool /tmp/lal-23.0.0/ada/ast.py:5045
pragma Warnings (Off, "is not referenced");
 function With_Private_Present_P_As_Bool
  (Node : Bare_With_Private_Present
  )
   return Boolean
is
   Self : Bare_With_Private_Present := Bare_With_Private_Present (Node);
   Call_Depth : aliased Natural;
   --# bind self Self
   Property_Result : Boolean;
begin
   --# property-body-start
   if Self /= null then
      Enter_Call (Self.Unit.Context, Call_Depth'Access);
   end if;
   --# scope-start
      Property_Result := True;
   --# end
   if Self /= null then
      Exit_Call (Self.Unit.Context, Call_Depth);
   end if;
   return Property_Result;
exception
   when others =>
      if Self /= null then
         Exit_Call (Self.Unit.Context, Call_Depth);
      end if;
      raise;
end With_Private_Present_P_As_Bool;
--# end
   ----------------------------
   -- Destroy_Synthetic_Node --
   ----------------------------
   procedure Destroy_Synthetic_Node (Node : in out Bare_Ada_Node) is
      procedure Free is new Ada.Unchecked_Deallocation
        (Root_Node_Record, Bare_Ada_Node);
   begin
      --  Don't call Node.Destroy, as Node's children may be gone already: they
      --  have their own destructor and there is no specified order for the
      --  call of these destructors.
      Free_User_Fields (Node);
      Free (Node);
   end Destroy_Synthetic_Node;
   -----------
   -- Image --
   -----------
   function Image (Value : Boolean) return String
   is (if Value then "True" else "False");
      -----------------
      -- Trace_Image --
      -----------------
      function Trace_Image
        (Node       : Bare_Ada_Node;
         Decoration : Boolean := True) return String is
      begin
         if Node = null then
            return "None";
         else
            declare
               Result : constant String :=
                 (Kind_Name (Node) & " "
                  & Basename (Node.Unit) & ":"
                  & Image (Sloc_Range (Node)));
            begin
               return (if Decoration then "<" & Result & ">" else Result);
            end;
         end if;
      end Trace_Image;
   Kind_Names : array (Ada_Node_Kind_Type) of Unbounded_String :=
     (Ada_Abort_Absent => To_Unbounded_String ("AbortAbsent"), 
Ada_Abort_Present => To_Unbounded_String ("AbortPresent"), 
Ada_Abstract_Absent => To_Unbounded_String ("AbstractAbsent"), 
Ada_Abstract_Present => To_Unbounded_String ("AbstractPresent"), 
Ada_Ada_Node_List => To_Unbounded_String ("AdaNodeList"), 
Ada_Abstract_State_Decl_List => To_Unbounded_String ("AbstractStateDeclList"), 
Ada_Alternatives_List => To_Unbounded_String ("AlternativesList"), 
Ada_Constraint_List => To_Unbounded_String ("ConstraintList"), 
Ada_Decl_List => To_Unbounded_String ("DeclList"), 
Ada_Stmt_List => To_Unbounded_String ("StmtList"), 
Ada_Aspect_Assoc_List => To_Unbounded_String ("AspectAssocList"), 
Ada_Base_Assoc_List => To_Unbounded_String ("BaseAssocList"), 
Ada_Assoc_List => To_Unbounded_String ("AssocList"), 
Ada_Basic_Decl_List => To_Unbounded_String ("BasicDeclList"), 
Ada_Case_Expr_Alternative_List => To_Unbounded_String ("CaseExprAlternativeList"), 
Ada_Case_Stmt_Alternative_List => To_Unbounded_String ("CaseStmtAlternativeList"), 
Ada_Compilation_Unit_List => To_Unbounded_String ("CompilationUnitList"), 
Ada_Concat_Operand_List => To_Unbounded_String ("ConcatOperandList"), 
Ada_Contract_Case_Assoc_List => To_Unbounded_String ("ContractCaseAssocList"), 
Ada_Defining_Name_List => To_Unbounded_String ("DefiningNameList"), 
Ada_Discriminant_Spec_List => To_Unbounded_String ("DiscriminantSpecList"), 
Ada_Elsif_Expr_Part_List => To_Unbounded_String ("ElsifExprPartList"), 
Ada_Elsif_Stmt_Part_List => To_Unbounded_String ("ElsifStmtPartList"), 
Ada_Enum_Literal_Decl_List => To_Unbounded_String ("EnumLiteralDeclList"), 
Ada_Expr_Alternatives_List => To_Unbounded_String ("ExprAlternativesList"), 
Ada_Discriminant_Choice_List => To_Unbounded_String ("DiscriminantChoiceList"), 
Ada_Name_List => To_Unbounded_String ("NameList"), 
Ada_Parent_List => To_Unbounded_String ("ParentList"), 
Ada_Param_Spec_List => To_Unbounded_String ("ParamSpecList"), 
Ada_Pragma_Node_List => To_Unbounded_String ("PragmaNodeList"), 
Ada_Select_When_Part_List => To_Unbounded_String ("SelectWhenPartList"), 
Ada_Unconstrained_Array_Index_List => To_Unbounded_String ("UnconstrainedArrayIndexList"), 
Ada_Variant_List => To_Unbounded_String ("VariantList"), 
Ada_Aliased_Absent => To_Unbounded_String ("AliasedAbsent"), 
Ada_Aliased_Present => To_Unbounded_String ("AliasedPresent"), 
Ada_All_Absent => To_Unbounded_String ("AllAbsent"), 
Ada_All_Present => To_Unbounded_String ("AllPresent"), 
Ada_Constrained_Array_Indices => To_Unbounded_String ("ConstrainedArrayIndices"), 
Ada_Unconstrained_Array_Indices => To_Unbounded_String ("UnconstrainedArrayIndices"), 
Ada_Aspect_Assoc => To_Unbounded_String ("AspectAssoc"), 
Ada_At_Clause => To_Unbounded_String ("AtClause"), 
Ada_Attribute_Def_Clause => To_Unbounded_String ("AttributeDefClause"), 
Ada_Enum_Rep_Clause => To_Unbounded_String ("EnumRepClause"), 
Ada_Record_Rep_Clause => To_Unbounded_String ("RecordRepClause"), 
Ada_Aspect_Spec => To_Unbounded_String ("AspectSpec"), 
Ada_Contract_Case_Assoc => To_Unbounded_String ("ContractCaseAssoc"), 
Ada_Pragma_Argument_Assoc => To_Unbounded_String ("PragmaArgumentAssoc"), 
Ada_Entry_Spec => To_Unbounded_String ("EntrySpec"), 
Ada_Enum_Subp_Spec => To_Unbounded_String ("EnumSubpSpec"), 
Ada_Subp_Spec => To_Unbounded_String ("SubpSpec"), 
Ada_Synthetic_Binary_Spec => To_Unbounded_String ("SyntheticBinarySpec"), 
Ada_Synthetic_Unary_Spec => To_Unbounded_String ("SyntheticUnarySpec"), 
Ada_Component_List => To_Unbounded_String ("ComponentList"), 
Ada_Known_Discriminant_Part => To_Unbounded_String ("KnownDiscriminantPart"), 
Ada_Unknown_Discriminant_Part => To_Unbounded_String ("UnknownDiscriminantPart"), 
Ada_Entry_Completion_Formal_Params => To_Unbounded_String ("EntryCompletionFormalParams"), 
Ada_Generic_Formal_Part => To_Unbounded_String ("GenericFormalPart"), 
Ada_Null_Record_Def => To_Unbounded_String ("NullRecordDef"), 
Ada_Record_Def => To_Unbounded_String ("RecordDef"), 
Ada_Aggregate_Assoc => To_Unbounded_String ("AggregateAssoc"), 
Ada_Multi_Dim_Array_Assoc => To_Unbounded_String ("MultiDimArrayAssoc"), 
Ada_Composite_Constraint_Assoc => To_Unbounded_String ("CompositeConstraintAssoc"), 
Ada_Iterated_Assoc => To_Unbounded_String ("IteratedAssoc"), 
Ada_Param_Assoc => To_Unbounded_String ("ParamAssoc"), 
Ada_Abstract_State_Decl => To_Unbounded_String ("AbstractStateDecl"), 
Ada_Anonymous_Expr_Decl => To_Unbounded_String ("AnonymousExprDecl"), 
Ada_Component_Decl => To_Unbounded_String ("ComponentDecl"), 
Ada_Discriminant_Spec => To_Unbounded_String ("DiscriminantSpec"), 
Ada_Generic_Formal_Obj_Decl => To_Unbounded_String ("GenericFormalObjDecl"), 
Ada_Generic_Formal_Package => To_Unbounded_String ("GenericFormalPackage"), 
Ada_Generic_Formal_Subp_Decl => To_Unbounded_String ("GenericFormalSubpDecl"), 
Ada_Generic_Formal_Type_Decl => To_Unbounded_String ("GenericFormalTypeDecl"), 
Ada_Param_Spec => To_Unbounded_String ("ParamSpec"), 
Ada_Synthetic_Formal_Param_Decl => To_Unbounded_String ("SyntheticFormalParamDecl"), 
Ada_Generic_Package_Internal => To_Unbounded_String ("GenericPackageInternal"), 
Ada_Package_Decl => To_Unbounded_String ("PackageDecl"), 
Ada_Discrete_Base_Subtype_Decl => To_Unbounded_String ("DiscreteBaseSubtypeDecl"), 
Ada_Subtype_Decl => To_Unbounded_String ("SubtypeDecl"), 
Ada_Classwide_Type_Decl => To_Unbounded_String ("ClasswideTypeDecl"), 
Ada_Incomplete_Type_Decl => To_Unbounded_String ("IncompleteTypeDecl"), 
Ada_Incomplete_Formal_Type_Decl => To_Unbounded_String ("IncompleteFormalTypeDecl"), 
Ada_Incomplete_Tagged_Type_Decl => To_Unbounded_String ("IncompleteTaggedTypeDecl"), 
Ada_Protected_Type_Decl => To_Unbounded_String ("ProtectedTypeDecl"), 
Ada_Task_Type_Decl => To_Unbounded_String ("TaskTypeDecl"), 
Ada_Single_Task_Type_Decl => To_Unbounded_String ("SingleTaskTypeDecl"), 
Ada_Anonymous_Type_Decl => To_Unbounded_String ("AnonymousTypeDecl"), 
Ada_Synth_Anonymous_Type_Decl => To_Unbounded_String ("SynthAnonymousTypeDecl"), 
Ada_Concrete_Type_Decl => To_Unbounded_String ("ConcreteTypeDecl"), 
Ada_Formal_Type_Decl => To_Unbounded_String ("FormalTypeDecl"), 
Ada_Abstract_Subp_Decl => To_Unbounded_String ("AbstractSubpDecl"), 
Ada_Abstract_Formal_Subp_Decl => To_Unbounded_String ("AbstractFormalSubpDecl"), 
Ada_Concrete_Formal_Subp_Decl => To_Unbounded_String ("ConcreteFormalSubpDecl"), 
Ada_Subp_Decl => To_Unbounded_String ("SubpDecl"), 
Ada_Entry_Decl => To_Unbounded_String ("EntryDecl"), 
Ada_Enum_Literal_Decl => To_Unbounded_String ("EnumLiteralDecl"), 
Ada_Synthetic_Char_Enum_Lit => To_Unbounded_String ("SyntheticCharEnumLit"), 
Ada_Generic_Subp_Internal => To_Unbounded_String ("GenericSubpInternal"), 
Ada_Synthetic_Subp_Decl => To_Unbounded_String ("SyntheticSubpDecl"), 
Ada_Expr_Function => To_Unbounded_String ("ExprFunction"), 
Ada_Null_Subp_Decl => To_Unbounded_String ("NullSubpDecl"), 
Ada_Subp_Body => To_Unbounded_String ("SubpBody"), 
Ada_Subp_Renaming_Decl => To_Unbounded_String ("SubpRenamingDecl"), 
Ada_Package_Body_Stub => To_Unbounded_String ("PackageBodyStub"), 
Ada_Protected_Body_Stub => To_Unbounded_String ("ProtectedBodyStub"), 
Ada_Subp_Body_Stub => To_Unbounded_String ("SubpBodyStub"), 
Ada_Task_Body_Stub => To_Unbounded_String ("TaskBodyStub"), 
Ada_Entry_Body => To_Unbounded_String ("EntryBody"), 
Ada_Package_Body => To_Unbounded_String ("PackageBody"), 
Ada_Protected_Body => To_Unbounded_String ("ProtectedBody"), 
Ada_Task_Body => To_Unbounded_String ("TaskBody"), 
Ada_Entry_Index_Spec => To_Unbounded_String ("EntryIndexSpec"), 
Ada_Error_Decl => To_Unbounded_String ("ErrorDecl"), 
Ada_Exception_Decl => To_Unbounded_String ("ExceptionDecl"), 
Ada_Exception_Handler => To_Unbounded_String ("ExceptionHandler"), 
Ada_For_Loop_Var_Decl => To_Unbounded_String ("ForLoopVarDecl"), 
Ada_Generic_Package_Decl => To_Unbounded_String ("GenericPackageDecl"), 
Ada_Generic_Subp_Decl => To_Unbounded_String ("GenericSubpDecl"), 
Ada_Generic_Package_Instantiation => To_Unbounded_String ("GenericPackageInstantiation"), 
Ada_Generic_Subp_Instantiation => To_Unbounded_String ("GenericSubpInstantiation"), 
Ada_Generic_Package_Renaming_Decl => To_Unbounded_String ("GenericPackageRenamingDecl"), 
Ada_Generic_Subp_Renaming_Decl => To_Unbounded_String ("GenericSubpRenamingDecl"), 
Ada_Label_Decl => To_Unbounded_String ("LabelDecl"), 
Ada_Named_Stmt_Decl => To_Unbounded_String ("NamedStmtDecl"), 
Ada_Number_Decl => To_Unbounded_String ("NumberDecl"), 
Ada_Object_Decl => To_Unbounded_String ("ObjectDecl"), 
Ada_Extended_Return_Stmt_Object_Decl => To_Unbounded_String ("ExtendedReturnStmtObjectDecl"), 
Ada_No_Type_Object_Renaming_Decl => To_Unbounded_String ("NoTypeObjectRenamingDecl"), 
Ada_Package_Renaming_Decl => To_Unbounded_String ("PackageRenamingDecl"), 
Ada_Single_Protected_Decl => To_Unbounded_String ("SingleProtectedDecl"), 
Ada_Single_Task_Decl => To_Unbounded_String ("SingleTaskDecl"), 
Ada_Case_Stmt_Alternative => To_Unbounded_String ("CaseStmtAlternative"), 
Ada_Compilation_Unit => To_Unbounded_String ("CompilationUnit"), 
Ada_Component_Clause => To_Unbounded_String ("ComponentClause"), 
Ada_Component_Def => To_Unbounded_String ("ComponentDef"), 
Ada_Constant_Absent => To_Unbounded_String ("ConstantAbsent"), 
Ada_Constant_Present => To_Unbounded_String ("ConstantPresent"), 
Ada_Composite_Constraint => To_Unbounded_String ("CompositeConstraint"), 
Ada_Delta_Constraint => To_Unbounded_String ("DeltaConstraint"), 
Ada_Digits_Constraint => To_Unbounded_String ("DigitsConstraint"), 
Ada_Range_Constraint => To_Unbounded_String ("RangeConstraint"), 
Ada_Declarative_Part => To_Unbounded_String ("DeclarativePart"), 
Ada_Private_Part => To_Unbounded_String ("PrivatePart"), 
Ada_Public_Part => To_Unbounded_String ("PublicPart"), 
Ada_Elsif_Expr_Part => To_Unbounded_String ("ElsifExprPart"), 
Ada_Elsif_Stmt_Part => To_Unbounded_String ("ElsifStmtPart"), 
Ada_Abstract_State_Decl_Expr => To_Unbounded_String ("AbstractStateDeclExpr"), 
Ada_Allocator => To_Unbounded_String ("Allocator"), 
Ada_Aggregate => To_Unbounded_String ("Aggregate"), 
Ada_Bracket_Aggregate => To_Unbounded_String ("BracketAggregate"), 
Ada_Delta_Aggregate => To_Unbounded_String ("DeltaAggregate"), 
Ada_Bracket_Delta_Aggregate => To_Unbounded_String ("BracketDeltaAggregate"), 
Ada_Null_Record_Aggregate => To_Unbounded_String ("NullRecordAggregate"), 
Ada_Bin_Op => To_Unbounded_String ("BinOp"), 
Ada_Relation_Op => To_Unbounded_String ("RelationOp"), 
Ada_Box_Expr => To_Unbounded_String ("BoxExpr"), 
Ada_Case_Expr_Alternative => To_Unbounded_String ("CaseExprAlternative"), 
Ada_Concat_Op => To_Unbounded_String ("ConcatOp"), 
Ada_Concat_Operand => To_Unbounded_String ("ConcatOperand"), 
Ada_Case_Expr => To_Unbounded_String ("CaseExpr"), 
Ada_If_Expr => To_Unbounded_String ("IfExpr"), 
Ada_Contract_Cases => To_Unbounded_String ("ContractCases"), 
Ada_Decl_Expr => To_Unbounded_String ("DeclExpr"), 
Ada_Membership_Expr => To_Unbounded_String ("MembershipExpr"), 
Ada_Attribute_Ref => To_Unbounded_String ("AttributeRef"), 
Ada_Call_Expr => To_Unbounded_String ("CallExpr"), 
Ada_Defining_Name => To_Unbounded_String ("DefiningName"), 
Ada_Synthetic_Defining_Name => To_Unbounded_String ("SyntheticDefiningName"), 
Ada_Discrete_Subtype_Name => To_Unbounded_String ("DiscreteSubtypeName"), 
Ada_Dotted_Name => To_Unbounded_String ("DottedName"), 
Ada_End_Name => To_Unbounded_String ("EndName"), 
Ada_Explicit_Deref => To_Unbounded_String ("ExplicitDeref"), 
Ada_Qual_Expr => To_Unbounded_String ("QualExpr"), 
Ada_Reduce_Attribute_Ref => To_Unbounded_String ("ReduceAttributeRef"), 
Ada_Char_Literal => To_Unbounded_String ("Chr"), 
Ada_Identifier => To_Unbounded_String ("Id"), 
Ada_Op_Abs => To_Unbounded_String ("OpAbs"), 
Ada_Op_And => To_Unbounded_String ("OpAnd"), 
Ada_Op_And_Then => To_Unbounded_String ("OpAndThen"), 
Ada_Op_Concat => To_Unbounded_String ("OpConcat"), 
Ada_Op_Div => To_Unbounded_String ("OpDiv"), 
Ada_Op_Double_Dot => To_Unbounded_String ("OpDoubleDot"), 
Ada_Op_Eq => To_Unbounded_String ("OpEq"), 
Ada_Op_Gt => To_Unbounded_String ("OpGt"), 
Ada_Op_Gte => To_Unbounded_String ("OpGte"), 
Ada_Op_In => To_Unbounded_String ("OpIn"), 
Ada_Op_Lt => To_Unbounded_String ("OpLt"), 
Ada_Op_Lte => To_Unbounded_String ("OpLte"), 
Ada_Op_Minus => To_Unbounded_String ("OpMinus"), 
Ada_Op_Mod => To_Unbounded_String ("OpMod"), 
Ada_Op_Mult => To_Unbounded_String ("OpMult"), 
Ada_Op_Neq => To_Unbounded_String ("OpNeq"), 
Ada_Op_Not => To_Unbounded_String ("OpNot"), 
Ada_Op_Not_In => To_Unbounded_String ("OpNotIn"), 
Ada_Op_Or => To_Unbounded_String ("OpOr"), 
Ada_Op_Or_Else => To_Unbounded_String ("OpOrElse"), 
Ada_Op_Plus => To_Unbounded_String ("OpPlus"), 
Ada_Op_Pow => To_Unbounded_String ("OpPow"), 
Ada_Op_Rem => To_Unbounded_String ("OpRem"), 
Ada_Op_Xor => To_Unbounded_String ("OpXor"), 
Ada_String_Literal => To_Unbounded_String ("Str"), 
Ada_Null_Literal => To_Unbounded_String ("Null"), 
Ada_Int_Literal => To_Unbounded_String ("Int"), 
Ada_Real_Literal => To_Unbounded_String ("Real"), 
Ada_Synthetic_Identifier => To_Unbounded_String ("SyntheticIdentifier"), 
Ada_Target_Name => To_Unbounded_String ("TargetName"), 
Ada_Update_Attribute_Ref => To_Unbounded_String ("UpdateAttributeRef"), 
Ada_Paren_Expr => To_Unbounded_String ("ParenExpr"), 
Ada_Quantified_Expr => To_Unbounded_String ("QuantifiedExpr"), 
Ada_Raise_Expr => To_Unbounded_String ("RaiseExpr"), 
Ada_Un_Op => To_Unbounded_String ("UnOp"), 
Ada_Handled_Stmts => To_Unbounded_String ("HandledStmts"), 
Ada_Interface_Kind_Limited => To_Unbounded_String ("InterfaceKindLimited"), 
Ada_Interface_Kind_Protected => To_Unbounded_String ("InterfaceKindProtected"), 
Ada_Interface_Kind_Synchronized => To_Unbounded_String ("InterfaceKindSynchronized"), 
Ada_Interface_Kind_Task => To_Unbounded_String ("InterfaceKindTask"), 
Ada_Iter_Type_In => To_Unbounded_String ("IterTypeIn"), 
Ada_Iter_Type_Of => To_Unbounded_String ("IterTypeOf"), 
Ada_Library_Item => To_Unbounded_String ("LibraryItem"), 
Ada_Limited_Absent => To_Unbounded_String ("LimitedAbsent"), 
Ada_Limited_Present => To_Unbounded_String ("LimitedPresent"), 
Ada_For_Loop_Spec => To_Unbounded_String ("ForLoopSpec"), 
Ada_While_Loop_Spec => To_Unbounded_String ("WhileLoopSpec"), 
Ada_Mode_Default => To_Unbounded_String ("ModeDefault"), 
Ada_Mode_In => To_Unbounded_String ("ModeIn"), 
Ada_Mode_In_Out => To_Unbounded_String ("ModeInOut"), 
Ada_Mode_Out => To_Unbounded_String ("ModeOut"), 
Ada_Multi_Abstract_State_Decl => To_Unbounded_String ("MultiAbstractStateDecl"), 
Ada_Not_Null_Absent => To_Unbounded_String ("NotNullAbsent"), 
Ada_Not_Null_Present => To_Unbounded_String ("NotNullPresent"), 
Ada_Null_Component_Decl => To_Unbounded_String ("NullComponentDecl"), 
Ada_Others_Designator => To_Unbounded_String ("OthersDesignator"), 
Ada_Overriding_Not_Overriding => To_Unbounded_String ("OverridingNotOverriding"), 
Ada_Overriding_Overriding => To_Unbounded_String ("OverridingOverriding"), 
Ada_Overriding_Unspecified => To_Unbounded_String ("OverridingUnspecified"), 
Ada_Params => To_Unbounded_String ("Params"), 
Ada_Paren_Abstract_State_Decl => To_Unbounded_String ("ParenAbstractStateDecl"), 
Ada_Pp_Else_Directive => To_Unbounded_String ("PpElseDirective"), 
Ada_Pp_Elsif_Directive => To_Unbounded_String ("PpElsifDirective"), 
Ada_Pp_End_If_Directive => To_Unbounded_String ("PpEndIfDirective"), 
Ada_Pp_If_Directive => To_Unbounded_String ("PpIfDirective"), 
Ada_Pp_Then_Kw => To_Unbounded_String ("PpThenKw"), 
Ada_Pragma_Node => To_Unbounded_String ("PragmaNode"), 
Ada_Private_Absent => To_Unbounded_String ("PrivateAbsent"), 
Ada_Private_Present => To_Unbounded_String ("PrivatePresent"), 
Ada_Protected_Def => To_Unbounded_String ("ProtectedDef"), 
Ada_Protected_Absent => To_Unbounded_String ("ProtectedAbsent"), 
Ada_Protected_Present => To_Unbounded_String ("ProtectedPresent"), 
Ada_Quantifier_All => To_Unbounded_String ("QuantifierAll"), 
Ada_Quantifier_Some => To_Unbounded_String ("QuantifierSome"), 
Ada_Range_Spec => To_Unbounded_String ("RangeSpec"), 
Ada_Renaming_Clause => To_Unbounded_String ("RenamingClause"), 
Ada_Synthetic_Renaming_Clause => To_Unbounded_String ("SyntheticRenamingClause"), 
Ada_Reverse_Absent => To_Unbounded_String ("ReverseAbsent"), 
Ada_Reverse_Present => To_Unbounded_String ("ReversePresent"), 
Ada_Select_When_Part => To_Unbounded_String ("SelectWhenPart"), 
Ada_Accept_Stmt => To_Unbounded_String ("AcceptStmt"), 
Ada_Accept_Stmt_With_Stmts => To_Unbounded_String ("AcceptStmtWithStmts"), 
Ada_For_Loop_Stmt => To_Unbounded_String ("ForLoopStmt"), 
Ada_Loop_Stmt => To_Unbounded_String ("LoopStmt"), 
Ada_While_Loop_Stmt => To_Unbounded_String ("WhileLoopStmt"), 
Ada_Begin_Block => To_Unbounded_String ("BeginBlock"), 
Ada_Decl_Block => To_Unbounded_String ("DeclBlock"), 
Ada_Case_Stmt => To_Unbounded_String ("CaseStmt"), 
Ada_Extended_Return_Stmt => To_Unbounded_String ("ExtendedReturnStmt"), 
Ada_If_Stmt => To_Unbounded_String ("IfStmt"), 
Ada_Named_Stmt => To_Unbounded_String ("NamedStmt"), 
Ada_Select_Stmt => To_Unbounded_String ("SelectStmt"), 
Ada_Error_Stmt => To_Unbounded_String ("ErrorStmt"), 
Ada_Abort_Stmt => To_Unbounded_String ("AbortStmt"), 
Ada_Assign_Stmt => To_Unbounded_String ("AssignStmt"), 
Ada_Call_Stmt => To_Unbounded_String ("CallStmt"), 
Ada_Delay_Stmt => To_Unbounded_String ("DelayStmt"), 
Ada_Exit_Stmt => To_Unbounded_String ("ExitStmt"), 
Ada_Goto_Stmt => To_Unbounded_String ("GotoStmt"), 
Ada_Label => To_Unbounded_String ("Label"), 
Ada_Null_Stmt => To_Unbounded_String ("NullStmt"), 
Ada_Raise_Stmt => To_Unbounded_String ("RaiseStmt"), 
Ada_Requeue_Stmt => To_Unbounded_String ("RequeueStmt"), 
Ada_Return_Stmt => To_Unbounded_String ("ReturnStmt"), 
Ada_Terminate_Alternative => To_Unbounded_String ("TerminateAlternative"), 
Ada_Subp_Kind_Function => To_Unbounded_String ("SubpKindFunction"), 
Ada_Subp_Kind_Procedure => To_Unbounded_String ("SubpKindProcedure"), 
Ada_Subunit => To_Unbounded_String ("Subunit"), 
Ada_Synchronized_Absent => To_Unbounded_String ("SynchronizedAbsent"), 
Ada_Synchronized_Present => To_Unbounded_String ("SynchronizedPresent"), 
Ada_Tagged_Absent => To_Unbounded_String ("TaggedAbsent"), 
Ada_Tagged_Present => To_Unbounded_String ("TaggedPresent"), 
Ada_Task_Def => To_Unbounded_String ("TaskDef"), 
Ada_Type_Attributes_Repository => To_Unbounded_String ("TypeAttributesRepository"), 
Ada_Access_To_Subp_Def => To_Unbounded_String ("AccessToSubpDef"), 
Ada_Anonymous_Type_Access_Def => To_Unbounded_String ("AnonymousTypeAccessDef"), 
Ada_Type_Access_Def => To_Unbounded_String ("TypeAccessDef"), 
Ada_Array_Type_Def => To_Unbounded_String ("ArrayTypeDef"), 
Ada_Derived_Type_Def => To_Unbounded_String ("DerivedTypeDef"), 
Ada_Enum_Type_Def => To_Unbounded_String ("EnumTypeDef"), 
Ada_Formal_Discrete_Type_Def => To_Unbounded_String ("FormalDiscreteTypeDef"), 
Ada_Interface_Type_Def => To_Unbounded_String ("InterfaceTypeDef"), 
Ada_Mod_Int_Type_Def => To_Unbounded_String ("ModIntTypeDef"), 
Ada_Private_Type_Def => To_Unbounded_String ("PrivateTypeDef"), 
Ada_Decimal_Fixed_Point_Def => To_Unbounded_String ("DecimalFixedPointDef"), 
Ada_Floating_Point_Def => To_Unbounded_String ("FloatingPointDef"), 
Ada_Ordinary_Fixed_Point_Def => To_Unbounded_String ("OrdinaryFixedPointDef"), 
Ada_Record_Type_Def => To_Unbounded_String ("RecordTypeDef"), 
Ada_Signed_Int_Type_Def => To_Unbounded_String ("SignedIntTypeDef"), 
Ada_Anonymous_Type => To_Unbounded_String ("AnonymousType"), 
Ada_Enum_Lit_Synth_Type_Expr => To_Unbounded_String ("EnumLitSynthTypeExpr"), 
Ada_Subtype_Indication => To_Unbounded_String ("SubtypeIndication"), 
Ada_Constrained_Subtype_Indication => To_Unbounded_String ("ConstrainedSubtypeIndication"), 
Ada_Discrete_Subtype_Indication => To_Unbounded_String ("DiscreteSubtypeIndication"), 
Ada_Synthetic_Type_Expr => To_Unbounded_String ("SyntheticTypeExpr"), 
Ada_Unconstrained_Array_Index => To_Unbounded_String ("UnconstrainedArrayIndex"), 
Ada_Until_Absent => To_Unbounded_String ("UntilAbsent"), 
Ada_Until_Present => To_Unbounded_String ("UntilPresent"), 
Ada_Use_Package_Clause => To_Unbounded_String ("UsePackageClause"), 
Ada_Use_Type_Clause => To_Unbounded_String ("UseTypeClause"), 
Ada_Value_Sequence => To_Unbounded_String ("ValueSequence"), 
Ada_Variant => To_Unbounded_String ("Variant"), 
Ada_Variant_Part => To_Unbounded_String ("VariantPart"), 
Ada_With_Clause => To_Unbounded_String ("WithClause"), 
Ada_With_Private_Absent => To_Unbounded_String ("WithPrivateAbsent"), 
Ada_With_Private_Present => To_Unbounded_String ("WithPrivatePresent"));
   ---------------
   -- Kind_Name --
   ---------------
   function Kind_Name (Node : Bare_Ada_Node) return String is
   begin
      return To_String (Kind_Names (Node.Kind));
   end Kind_Name;
   --------------------
   -- Children_Count --
   --------------------
   function Children_Count (Node : Bare_Ada_Node) return Natural is
      C : Integer := Kind_To_Node_Children_Count (Node.Kind);
   begin
      if C = -1 then
         return Node.Count;
      else
         return C;
      end if;
   end Children_Count;
   ----------------------
   -- Free_User_Fields --
   ----------------------
   procedure Free_User_Fields (Node : Bare_Ada_Node) is
      procedure Reset_Logic_Var (LV : in out Logic_Var_Record);
      --  Reset the LV logic variable, clearing the value it stores
      ---------------------
      -- Reset_Logic_Var --
      ---------------------
      procedure Reset_Logic_Var (LV : in out Logic_Var_Record) is
      begin
         LV.Value := No_Entity;
         Entity_Vars.Reset (LV'Unrestricted_Access);
         Entity_Vars.Destroy (LV);
      end Reset_Logic_Var;
      K : constant Ada_Node_Kind_Type := Node.Kind;
   begin
      case Ada_Ada_Node (K) is
when Ada_Base_Type_Decl =>
declare
N_Bare_Base_Type_Decl : constant Bare_Base_Type_Decl := Node;
begin
Dec_Ref (N_Bare_Base_Type_Decl.Lf_Stg_Dottable_Subps_Env);
case Ada_Base_Type_Decl (K) is
when Ada_Type_Decl =>
declare
N_Bare_Type_Decl : constant Bare_Type_Decl := N_Bare_Base_Type_Decl;
begin
Dec_Ref (N_Bare_Type_Decl.Lf_Stg_Direct_Primitives_Env);
Dec_Ref (N_Bare_Type_Decl.Lf_Stg_Direct_Primitive_Subps);
end;
when others => null;
end case;
end;
when Ada_Generic_Instantiation =>
declare
N_Bare_Generic_Instantiation : constant Bare_Generic_Instantiation := Node;
begin
Dec_Ref (N_Bare_Generic_Instantiation.Lf_Stg_Instantiation_Env);
Dec_Ref (N_Bare_Generic_Instantiation.Lf_Stg_Actual_Expr_Decls);
end;
when Ada_Compilation_Unit_Range =>
declare
N_Bare_Compilation_Unit : constant Bare_Compilation_Unit := Node;
begin
Dec_Ref (N_Bare_Compilation_Unit.Compilation_Unit_No_Env);
end;
when Ada_Attribute_Ref_Range =>
declare
N_Bare_Attribute_Ref : constant Bare_Attribute_Ref := Node;
begin
Reset_Logic_Var (N_Bare_Attribute_Ref.Attribute_Ref_R_Ref_Var);
end;
when Ada_Call_Expr_Range =>
declare
N_Bare_Call_Expr : constant Bare_Call_Expr := Node;
begin
Reset_Logic_Var (N_Bare_Call_Expr.Call_Expr_R_Called_Spec);
end;
when Ada_Explicit_Deref_Range =>
declare
N_Bare_Explicit_Deref : constant Bare_Explicit_Deref := Node;
begin
Reset_Logic_Var (N_Bare_Explicit_Deref.Explicit_Deref_R_Called_Spec);
end;
when Ada_Reduce_Attribute_Ref_Range =>
declare
N_Bare_Reduce_Attribute_Ref : constant Bare_Reduce_Attribute_Ref := Node;
begin
Reset_Logic_Var (N_Bare_Reduce_Attribute_Ref.Reduce_Attribute_Ref_R_Ref_Var);
end;
when Ada_Target_Name_Range =>
declare
N_Bare_Target_Name : constant Bare_Target_Name := Node;
begin
Reset_Logic_Var (N_Bare_Target_Name.Target_Name_R_Ref_Var);
end;
when Ada_Update_Attribute_Ref_Range =>
declare
N_Bare_Update_Attribute_Ref : constant Bare_Update_Attribute_Ref := Node;
begin
Reset_Logic_Var (N_Bare_Update_Attribute_Ref.Update_Attribute_Ref_R_Ref_Var);
end;
when others => null;
end case;
   end Free_User_Fields;
   ----------------
   -- Token_Data --
   ----------------
   function Token_Data (Unit : Internal_Unit) return Token_Data_Handler_Access
   is (Unit.TDH'Access);
   -------------------
   -- Lookup_Symbol --
   -------------------
   function Lookup_Symbol
     (Context : Internal_Context; Symbol : Text_Type) return Symbol_Type
   is
      Canon_Symbol : constant Symbolization_Result :=
            Libadalang.Sources.Canonicalize (Symbol)
      ;
   begin
      if Canon_Symbol.Success then
         return Get_Symbol
           (Context.Symbols, Find (Context.Symbols, Canon_Symbol.Symbol));
      else
         raise Invalid_Symbol_Error with Image (Canon_Symbol.Error_Message);
      end if;
   end Lookup_Symbol;
   -------------------------
   -- Create_Special_Unit --
   -------------------------
   function Create_Special_Unit
     (Context             : Internal_Context;
      Normalized_Filename : Virtual_File;
      Charset             : String;
      Rule                : Grammar_Rule) return Internal_Unit
   is
      Unit : Internal_Unit := new Analysis_Unit_Type'
        (Context                      => Context,
         Is_Internal                  => False,
         Ast_Root                     => null,
         Filename                     => Normalized_Filename,
         Charset                      => To_Unbounded_String (Charset),
         TDH                          => <>,
         Diagnostics                  => <>,
         Is_Env_Populated             => False,
         Rule                         => Rule,
         Ast_Mem_Pool                 => No_Pool,
         Destroyables                 => Destroyable_Vectors.Empty_Vector,
         Referenced_Units             => <>,
         Exiled_Entries               => Exiled_Entry_Vectors.Empty_Vector,
         Foreign_Nodes                =>
            Foreign_Node_Entry_Vectors.Empty_Vector,
         Exiled_Entries_In_NED        =>
            Exiled_Entry_In_NED_Vectors.Empty_Vector,
         Exiled_Envs                  => Exiled_Env_Vectors.Empty_Vector,
         Named_Envs                   => Named_Env_Vectors.Empty_Vector,
         Nodes_With_Foreign_Env       => <>,
         Rebindings                   => Env_Rebindings_Vectors.Empty_Vector,
         Cache_Version                => <>,
         Unit_Version                 => <>,
         Memoization_Map            => <>,
         others => <>
      );
   begin
      Initialize
        (Unit.TDH, Context.Symbols, Unit.all'Address, Context.Tab_Stop);
      return Unit;
   end Create_Special_Unit;
   --------------------
   -- Templates_Unit --
   --------------------
   function Templates_Unit (Context : Internal_Context) return Internal_Unit is
   begin
      if Context.Templates_Unit = No_Analysis_Unit then
         Context.Templates_Unit := Create_Special_Unit
           (Context             => Context,
            Normalized_Filename => No_File,
            Charset             => Default_Charset,
            Rule                => Compilation_Rule);
      end if;
      return Context.Templates_Unit;
   end Templates_Unit;
   --------------
   -- Set_Rule --
   --------------
   procedure Set_Rule (Unit : Internal_Unit; Rule : Grammar_Rule) is
   begin
      Unit.Rule := Rule;
   end Set_Rule;
   ------------------------------
   -- Normalized_Unit_Filename --
   ------------------------------
   function Normalized_Unit_Filename
     (Context : Internal_Context; Filename : String) return Virtual_File
   is
      use Virtual_File_Maps;
      Key : constant Unbounded_String := To_Unbounded_String (Filename);
      Cur : Cursor := Context.Filenames.Find (Key);
   begin
      if Cur = No_Element then
         declare
            F : constant Virtual_File := Create
              (Create_From_Base (+Filename).Full_Name,
               Normalize => True);
         begin
            Context.Filenames.Insert (Key, F);
            return F;
         end;
      else
         return Element (Cur);
      end if;
   end Normalized_Unit_Filename;
   --------------------------
   -- Register_Destroyable --
   --------------------------
   procedure Register_Destroyable_Helper
     (Unit    : Internal_Unit;
      Object  : System.Address;
      Destroy : Destroy_Procedure)
   is
   begin
      Destroyable_Vectors.Append (Unit.Destroyables, (Object, Destroy));
   end Register_Destroyable_Helper;
   --------------------------
   -- Register_Destroyable --
   --------------------------
   procedure Register_Destroyable
     (Unit : Internal_Unit; Node : Bare_Ada_Node)
   is
      procedure Helper is new Register_Destroyable_Gen
        (Root_Node_Record,
         Bare_Ada_Node,
         Destroy_Synthetic_Node);
   begin
      Helper (Unit, Node);
   end Register_Destroyable;
   --------------------------
   -- Register_Destroyable --
   --------------------------
   procedure Register_Destroyable
     (Unit : Internal_Unit; Env : AST_Envs.Lexical_Env_Access)
   is
      procedure Helper is new Register_Destroyable_Gen
        (AST_Envs.Lexical_Env_Record, AST_Envs.Lexical_Env_Access, Destroy);
   begin
      Helper (Unit, Env);
   end Register_Destroyable;
   -----------------------
   -- Invalidate_Caches --
   -----------------------
   procedure Invalidate_Caches
     (Context : Internal_Context; Invalidate_Envs : Boolean) is
   begin
      --  Increase Context's version number. If we are about to overflow, reset
      --  all version numbers from analysis units.
      if Context.Cache_Version = Version_Number'Last then
         Context.Cache_Version := 1;
         for Unit of Context.Units loop
            Unit.Cache_Version := 0;
         end loop;
      else
         Context.Cache_Version := Context.Cache_Version + 1;
      end if;
      if Invalidate_Envs then
         Context.Reparse_Cache_Version := Context.Cache_Version;
      end if;
   end Invalidate_Caches;
   ------------------
   --  Reset_Envs  --
   ------------------
   procedure Reset_Envs (Unit : Internal_Unit) is
      procedure Deactivate_Refd_Envs (Node : Bare_Ada_Node);
      procedure Recompute_Refd_Envs (Node : Bare_Ada_Node);
      --------------------------
      -- Deactivate_Refd_Envs --
      --------------------------
      procedure Deactivate_Refd_Envs (Node : Bare_Ada_Node) is
      begin
         if Node = null then
            return;
         end if;
         Deactivate_Referenced_Envs (Node.Self_Env);
         for I in 1 .. Children_Count (Node) loop
            Deactivate_Refd_Envs (Child (Node, I));
         end loop;
      end Deactivate_Refd_Envs;
      -------------------------
      -- Recompute_Refd_Envs --
      -------------------------
      procedure Recompute_Refd_Envs (Node : Bare_Ada_Node) is
      begin
         if Node = null then
            return;
         end if;
         Recompute_Referenced_Envs (Node.Self_Env);
         for I in 1 .. Children_Count (Node) loop
            Recompute_Refd_Envs (Child (Node, I));
         end loop;
      end Recompute_Refd_Envs;
   begin
      --  First pass will deactivate every referenced envs that Unit possesses
      Deactivate_Refd_Envs (Unit.Ast_Root);
      --  Second pass will recompute the env they are pointing to
      Recompute_Refd_Envs (Unit.Ast_Root);
   end Reset_Envs;
   -------------
   -- Destroy --
   -------------
   procedure Destroy (Reparsed : in out Reparsed_Unit) is
   begin
      Free (Reparsed.TDH);
      Reparsed.Diagnostics := Diagnostics_Vectors.Empty_Vector;
      Free (Reparsed.Ast_Mem_Pool);
      Reparsed.Ast_Root := null;
   end Destroy;
   --------------
   -- Basename --
   --------------
   function Basename (Filename : String) return String is
   begin
      return +Create (+Filename).Base_Name;
   end Basename;
   --------------
   -- Basename --
   --------------
   function Basename (Unit : Internal_Unit) return String is
   begin
      return +Unit.Filename.Base_Name;
   end Basename;
   ------------------
   -- Reset_Caches --
   ------------------
   procedure Reset_Caches (Unit : Internal_Unit) is
      Cache_Version : constant Version_Number := Unit.Cache_Version;
   begin
      if Cache_Version < Unit.Context.Reparse_Cache_Version then
         Unit.Cache_Version := Unit.Context.Reparse_Cache_Version;
         Reset_Envs (Unit);
      end if;
      if Cache_Version < Unit.Context.Cache_Version then
         Unit.Cache_Version := Unit.Context.Cache_Version;
            Destroy (Unit.Memoization_Map);
      end if;
   end Reset_Caches;
   --------------------
   -- Reference_Unit --
   --------------------
   procedure Reference_Unit (From, Referenced : Internal_Unit) is
      Dummy : Boolean;
   begin
      Dummy := Analysis_Unit_Sets.Add (From.Referenced_Units, Referenced);
   end Reference_Unit;
   ------------------------
   -- Is_Referenced_From --
   ------------------------
   function Is_Referenced_From
     (Self, Unit : Internal_Unit) return Boolean is
   begin
      if Unit = null or else Self = null then
         return False;
      elsif Unit = Self then
         return True;
      else
         return Analysis_Unit_Sets.Has (Unit.Referenced_Units, Self);
      end if;
   end Is_Referenced_From;
   ----------------
   -- Do_Parsing --
   ----------------
   procedure Do_Parsing
     (Unit   : Internal_Unit;
      Input  : Internal_Lexer_Input;
      Result : out Reparsed_Unit)
   is
      Context  : constant Internal_Context := Unit.Context;
      Unit_TDH : constant Token_Data_Handler_Access := Token_Data (Unit);
      Saved_TDH : Token_Data_Handler;
      --  Holder to save tokens data in Unit.
      --
      --  By design, parsing is required to bind the nodes it creates to an
      --  analysis unit. However, this procedure is supposed to preserve the
      --  Unit itself and return its parsing result in Result.
      --
      --  In order to implement this, we first move "old" token data in this
      --  variable, then we do parsing. Only then, we can move "new" token data
      --  from the unit to Result, and restore the "old" token data to Unit.
      --  This last step is what Rotate_TDH (see below) is above.
      procedure Rotate_TDH;
      --  Move token data from Unit to Result and restore data in Saved_TDH to
      --  Unit.
      ----------------
      -- Rotate_TDH --
      ----------------
      procedure Rotate_TDH is
      begin
         Move (Result.TDH, Unit_TDH.all);
         Move (Unit_TDH.all, Saved_TDH);
      end Rotate_TDH;
   begin
      GNATCOLL.Traces.Trace (Main_Trace, "Parsing unit " & Basename (Unit));
      Result.Ast_Root := null;
      Move (Saved_TDH, Unit_TDH.all);
      Initialize (Unit_TDH.all,
                  Saved_TDH.Symbols,
                  Unit.all'Address,
                  Unit.Context.Tab_Stop);
      --  This is where lexing occurs, so this is where we get most "setup"
      --  issues: missing input file, bad charset, etc. If we have such an
      --  error, catch it, turn it into diagnostics and abort parsing.
      --
      --  As it is quite common, first check if the file is readable: if not,
      --  don't bother opening it and directly emit a diagnostic. This avoid
      --  pointless exceptions which harm debugging. Note that this
      --  optimization is valid only when there is no file reader, which can
      --  work even when there is no real source file.
      if Context.File_Reader = null
         and then Input.Kind = File
         and then (Input.Filename.Is_Directory
                   or else (not Input.Filename.Is_Readable))
      then
         declare
            Name : constant String := Basename (Unit);
         begin
            GNATCOLL.Traces.Trace
              (Main_Trace, "WARNING: File is not readable: " & Name);
            Append
              (Result.Diagnostics,
               No_Source_Location_Range,
               "Cannot read " & To_Text (Name));
            Rotate_TDH;
            return;
         end;
      end if;
      --  Initialize the parser, which fetches the source buffer and extract
      --  all tokens.
      Init_Parser
        (Input, Context.With_Trivia, Unit, Unit_TDH, Unit.Context.Parser);
      --  If we could run the lexer, run the parser and get the root node
      if Unit_TDH.Source_Buffer /= null then
         Result.Ast_Mem_Pool := Create;
         Unit.Context.Parser.Mem_Pool := Result.Ast_Mem_Pool;
         Result.Ast_Root := Bare_Ada_Node
           (Parse (Unit.Context.Parser, Rule => Unit.Rule));
      end if;
      --  Forward token data and diagnostics to the returned unit
      Rotate_TDH;
      --  TODO we use a for loop rt. than the new ``Append_Vector`` here for
      --  compatibility with old compilers, but someday we'll be able to get
      --  rid of it.
      for Diag of Unit.Context.Parser.Diagnostics loop
         Result.Diagnostics.Append (Diag);
      end loop;
   end Do_Parsing;
   --------------------------
   -- Update_After_Reparse --
   --------------------------
   procedure Update_After_Reparse
     (Unit : Internal_Unit; Reparsed : in out Reparsed_Unit) is
   begin
      --  Remove the `symbol -> AST node` associations for Unit's nodes in
      --  foreign lexical environments.
      Remove_Exiled_Entries (Unit);
      --  Remove the named envs that Unit created
      declare
         Named_Envs_Needing_Update : NED_Maps.Map;
      begin
         Remove_Named_Envs (Unit, Named_Envs_Needing_Update);
         Update_Named_Envs (Unit.Context, Named_Envs_Needing_Update);
      end;
      --  At this point, envs and nodes that don't belong to this unit no
      --  longer reference this unit's envs and nodes. It is thus now safe to
      --  deallocate this unit's obsolete data.
      --  Replace Unit's diagnostics by Reparsed's
      Unit.Diagnostics := Reparsed.Diagnostics;
      Reparsed.Diagnostics.Clear;
      --  As (re-)loading a unit can change how any AST node property in the
      --  whole analysis context behaves, we have to invalidate caches. This
      --  is likely overkill, but kill all caches here as it's easy to do.
      --
      --  As an optimization, invalidate referenced envs cache only if this is
      --  not the first time we parse Unit.
      Invalidate_Caches
        (Unit.Context, Invalidate_Envs => Unit.Ast_Root /= null);
      --  Likewise for token data
      Free (Unit.TDH);
      Move (Unit.TDH, Reparsed.TDH);
      --  Reparsing will invalidate all lexical environments related to this
      --  unit, so destroy all related rebindings as well. This browses AST
      --  nodes, so we have to do this before destroying the old AST nodes
      --  pool.
      Destroy_Rebindings (Unit.Rebindings'Access);
      --  Destroy the old AST node and replace it by the new one
      if Unit.Ast_Root /= null then
         Destroy (Unit.Ast_Root);
      end if;
      Unit.Ast_Root := Reparsed.Ast_Root;
      --  Likewise for memory pools
      Free (Unit.Ast_Mem_Pool);
      Unit.Ast_Mem_Pool := Reparsed.Ast_Mem_Pool;
      Reparsed.Ast_Mem_Pool := No_Pool;
      --  Increment unit version number to invalidate caches and stale node
      --  reference. Also propagate it to the TDH.
      Unit.Unit_Version := Unit.Unit_Version + 1;
      Unit.TDH.Version := Unit.Unit_Version;
      --  If Unit had its lexical environments populated, re-populate them
      if not Unit.Is_Env_Populated then
         return;
      end if;
      declare
         Unit_Name     : constant String := +Unit.Filename.Base_Name;
         Context       : constant Internal_Context := Unit.Context;
         Foreign_Nodes : Bare_Ada_Node_Vectors.Vector :=
            Bare_Ada_Node_Vectors.Empty_Vector;
         Saved_In_Populate_Lexical_Env : constant Boolean :=
            Context.In_Populate_Lexical_Env;
      begin
         GNATCOLL.Traces.Trace
           (Main_Trace, "Updating lexical envs for " & Unit_Name
                        & " after reparse");
         GNATCOLL.Traces.Increase_Indent (Main_Trace);
         Context.In_Populate_Lexical_Env := True;
         --  Collect all nodes that are foreign in this Unit's lexical envs.
         --  Exclude them from the corresponding lists of exiled entries.
         Extract_Foreign_Nodes (Unit, Foreign_Nodes);
         --  Reset the flag so that the call to Populate_Lexical_Env below does
         --  its work.
         Unit.Is_Env_Populated := False;
         --  Now that Unit has been reparsed, we can destroy all its
         --  destroyables, which refer to the old tree (i.e. dangling
         --  pointers).
         Destroy_Unit_Destroyables (Unit);
         for FN of Foreign_Nodes loop
            declare
               Node_Image : constant String := Image (Short_Text_Image (FN));
               Unit_Name  : constant String := +FN.Unit.Filename.Base_Name;
            begin
               GNATCOLL.Traces.Trace
                 (Main_Trace, "Rerooting: " & Node_Image
                              & " (from " & Unit_Name & ")");
            end;
            Reroot_Foreign_Node (FN);
         end loop;
         Foreign_Nodes.Destroy;
         Populate_Lexical_Env (Unit);
         Context.In_Populate_Lexical_Env := Saved_In_Populate_Lexical_Env;
         GNATCOLL.Traces.Decrease_Indent (Main_Trace);
      end;
   end Update_After_Reparse;
   -------------------------------
   -- Destroy_Unit_Destroyables --
   -------------------------------
   procedure Destroy_Unit_Destroyables (Unit : Internal_Unit) is
   begin
      for D of Unit.Destroyables loop
         D.Destroy (D.Object);
      end loop;
      Destroyable_Vectors.Clear (Unit.Destroyables);
   end Destroy_Unit_Destroyables;
   ---------------------------
   -- Remove_Exiled_Entries --
   ---------------------------
   procedure Remove_Exiled_Entries (Unit : Internal_Unit) is
   begin
      for EE of Unit.Exiled_Entries loop
         AST_Envs.Remove (EE.Env, EE.Key, EE.Node);
         --  Also strip foreign nodes information from "outer" units so that it
         --  does not contain stale information (i.e. dangling pointers to
         --  nodes that belong to the units in the queue).
         if EE.Env.Owner /= No_Generic_Unit then
            declare
               Foreign_Nodes : Foreign_Node_Entry_Vectors.Vector renames
                  Convert_Unit (EE.Env.Owner).Foreign_Nodes;
               Current       : Positive := Foreign_Nodes.First_Index;
            begin
               while Current <= Foreign_Nodes.Last_Index loop
                  if Foreign_Nodes.Get (Current).Node = EE.Node then
                     Foreign_Nodes.Pop (Current);
                  else
                     Current := Current + 1;
                  end if;
               end loop;
            end;
         end if;
      end loop;
      Unit.Exiled_Entries.Clear;
   end Remove_Exiled_Entries;
   -----------------------
   -- Remove_Named_Envs --
   -----------------------
   procedure Remove_Named_Envs
     (Unit                      : Internal_Unit;
      Named_Envs_Needing_Update : in out NED_Maps.Map) is
   begin
      --  Remove nodes in this unit from the Named_Env_Descriptor.Foreign_Nodes
      --  components in which they are registered and from the foreign
      --  environments themselves.
      for EE of Unit.Exiled_Entries_In_NED loop
         Remove (EE.Named_Env.Foreign_Nodes, EE.Key, EE.Node);
         Remove (EE.Named_Env.Env_With_Precedence, EE.Key, EE.Node);
      end loop;
      Unit.Exiled_Entries_In_NED.Clear;
      --  Remove nodes in this unit from the
      --  Named_Env_Descriptor.Nodes_With_Foreign_Env components in which they
      --  are registered.
      for Cur in Unit.Nodes_With_Foreign_Env.Iterate loop
         declare
            use Node_To_Named_Env_Maps;
            Node : constant Bare_Ada_Node := Key (Cur);
            NE   : constant Named_Env_Descriptor_Access := Element (Cur);
         begin
            NE.Nodes_With_Foreign_Env.Delete (Node);
         end;
      end loop;
      Unit.Nodes_With_Foreign_Env.Clear;
      --  Remove ends in this unit from the Named_Env_Descriptor.Foreign_Envs
      --  components in which they are registered.
      for EE of Unit.Exiled_Envs loop
         EE.Named_Env.Foreign_Envs.Delete (Env_Node (EE.Env));
      end loop;
      Unit.Exiled_Envs.Clear;
      --  Remove named envs that this unit created
      for NE of Unit.Named_Envs loop
         declare
            NED_Access : constant Named_Env_Descriptor_Access :=
               Unit.Context.Named_Envs.Element (NE.Name);
            NED        : Named_Env_Descriptor renames NED_Access.all;
         begin
            NED.Envs.Delete (Env_Node (NE.Env));
            --  If this named environment had precedence, we must schedule an
            --  update for this name environment entry.
            if NE.Env = NED.Env_With_Precedence then
               Named_Envs_Needing_Update.Include (NE.Name, NED_Access);
               NED.Env_With_Precedence := Empty_Env;
            end if;
         end;
      end loop;
      Unit.Named_Envs.Clear;
   end Remove_Named_Envs;
   ---------------------------
   -- Extract_Foreign_Nodes --
   ---------------------------
   procedure Extract_Foreign_Nodes
     (Unit          : Internal_Unit;
      Foreign_Nodes : in out Bare_Ada_Node_Vectors.Vector) is
   begin
      --  Go through all foreign nodes registered in Unit's lexical
      --  environments.
      for FN of Unit.Foreign_Nodes loop
         --  Collect them
         Foreign_Nodes.Append (FN.Node);
         --  For each foreign node, remove the corresponding exiled entry in
         --  that foreign unit (each foreign node in unit A has a corresponding
         --  exiled entry in unit B).
         declare
            Exiled_Entries : Exiled_Entry_Vectors.Vector renames
               FN.Unit.Exiled_Entries;
            Current        : Positive := Exiled_Entries.First_Index;
         begin
            while Current <= Exiled_Entries.Last_Index loop
               if Exiled_Entries.Get (Current).Node = FN.Node then
                  Exiled_Entries.Pop (Current);
               else
                  Current := Current + 1;
               end if;
            end loop;
         end;
      end loop;
      Unit.Foreign_Nodes.Clear;
   end Extract_Foreign_Nodes;
   --------------------------
   -- Reroot_Foreign_Nodes --
   --------------------------
   procedure Reroot_Foreign_Node (Node : Bare_Ada_Node) is
      Unit : constant Internal_Unit := Node.Unit;
   begin
      --  First, filter the exiled entries in foreign units so that they don't
      --  contain references to this unit's lexical environments.  We need to
      --  do that before running the partial Populate_Lexical_Env pass so that
      --  we don't remove exiled entries that this pass will produce.
      declare
         Exiled_Entries : Exiled_Entry_Vectors.Vector renames
            Unit.Exiled_Entries;
         Current        : Positive := Exiled_Entries.First_Index;
      begin
         while Current <= Exiled_Entries.Last_Index loop
            if Exiled_Entries.Get (Current).Node = Node then
               Exiled_Entries.Pop (Current);
            else
               Current := Current + 1;
            end if;
         end loop;
      end;
      --  Re-do a partial Populate_Lexical_Env pass for each foreign node that
      --  this unit contains so that they are relocated in our new lexical
      --  environments.
      declare
         Unit_State : aliased PLE_Unit_State :=
           (Named_Envs_Needing_Update => <>);
         State      : PLE_Node_State :=
           (Unit_State  => Unit_State'Unchecked_Access,
            Current_Env => Node.Self_Env,
            Current_NED => null);
      begin
         Pre_Env_Actions (Node, State, Add_To_Env_Only => True);
         Post_Env_Actions (Node, State);
      end;
   end Reroot_Foreign_Node;
   ----------
   -- Text --
   ----------
   function Text (Node : Bare_Ada_Node) return String_Type is
   begin
      return Create_String (Text (Node));
   end Text;
   ------------------------
   -- Destroy_Rebindings --
   ------------------------
   procedure Destroy_Rebindings
     (Rebindings : access Env_Rebindings_Vectors.Vector)
   is
      procedure Recurse (R : in out Env_Rebindings);
      --  Destroy R's children and then destroy R. It is up to the caller to
      --  remove R from its parent's Children vector.
      procedure Unregister
        (R          : Env_Rebindings;
         Rebindings : in out Env_Rebindings_Vectors.Vector);
      --  Remove R from Rebindings
      -------------
      -- Recurse --
      -------------
      procedure Recurse (R : in out Env_Rebindings) is
      begin
         for C of R.Children loop
            declare
               C_Var : Env_Rebindings := C;
            begin
               Recurse (C_Var);
            end;
         end loop;
         R.Children.Destroy;
         Unregister (R, Convert_Unit (R.Old_Env.Owner).Rebindings);
         Unregister (R, Convert_Unit (R.New_Env.Owner).Rebindings);
         Release_Rebinding (R);
      end Recurse;
      ----------------
      -- Unregister --
      ----------------
      procedure Unregister
        (R          : Env_Rebindings;
         Rebindings : in out Env_Rebindings_Vectors.Vector) is
      begin
         for I in 1 .. Rebindings.Length loop
            if Rebindings.Get (I) = R then
               Rebindings.Pop (I);
               return;
            end if;
         end loop;
         --  We are always supposed to find R in Rebindings, so this should be
         --  unreachable.
         raise Program_Error;
      end Unregister;
   begin
      while Rebindings.Length > 0 loop
         declare
            R : Env_Rebindings := Rebindings.Get (1);
         begin
            --  Here, we basically undo what has been done in AST_Envs.Append
            --  If this rebinding has no parent, then during its creation we
            --  registered it in its Old_Env. Otherwise, it is registered
            --  in its Parent's Children list.
            if R.Parent = null then
               Unwrap (R.Old_Env).Rebindings_Pool.Delete (R.New_Env);
            else
               Unregister (R, R.Parent.Children);
            end if;
            --  In all cases it's registered in Old_Env's and New_Env's units
            Recurse (R);
         end;
      end loop;
   end Destroy_Rebindings;
   --------------------------
   -- Get_Rewriting_Handle --
   --------------------------
   function Get_Rewriting_Handle
     (Context : Internal_Context) return Rewriting_Handle_Pointer is
   begin
      return Context.Rewriting_Handle;
   end Get_Rewriting_Handle;
   --------------------------
   -- Set_Rewriting_Handle --
   --------------------------
   procedure Set_Rewriting_Handle
     (Context : Internal_Context; Handle : Rewriting_Handle_Pointer) is
   begin
      Context.Rewriting_Handle := Handle;
   end Set_Rewriting_Handle;
   -----------------------
   -- Create_Safety_Net --
   -----------------------
   function Create_Safety_Net
     (Context : Internal_Context) return Iterator_Safety_Net
   is
   begin
      return (Context         => Context,
              Context_Serial  => Context.Serial_Number,
              Context_Version => Context.Cache_Version);
   end Create_Safety_Net;
   ----------------------
   -- Check_Safety_Net --
   ----------------------
   procedure Check_Safety_Net (Self : Iterator_Safety_Net) is
   begin
      if Self.Context = null then
         return;
      end if;
      --  Check that the context is still the same (not released nor reused)
      if Self.Context.Serial_Number /= Self.Context_Serial
         or else Self.Context.Cache_Version /= Self.Context_Version
      then
         raise Stale_Reference_Error;
      end if;
   end Check_Safety_Net;
   ----------------------
   -- String_To_Symbol --
   ----------------------
   function String_To_Symbol
     (Self    : Bare_Ada_Node;
      Context : Internal_Context;
      S       : String_Type) return Symbol_Type is
   begin
      return (if S.Length > 0
              then Lookup_Symbol (Context, S.Content)
              else null);
   exception
      when Exc : Invalid_Symbol_Error =>
         Raise_Property_Exception
           (Self,
            Property_Error'Identity,
            Ada.Exceptions.Exception_Message (Exc));
   end String_To_Symbol;
   -------------
   -- Inc_Ref --
   -------------
   procedure Inc_Ref (Self : String_Type) is
   begin
      if Self.Ref_Count >= 0 then
         Self.Ref_Count := Self.Ref_Count + 1;
      end if;
   end Inc_Ref;
   -------------
   -- Dec_Ref --
   -------------
   procedure Dec_Ref (Self : in out String_Type) is
   begin
      if Self = null or else Self.Ref_Count < 0 then
         return;
      end if;
      if Self.Ref_Count = 1 then
         Free (Self);
      else
         Self.Ref_Count := Self.Ref_Count - 1;
         Self := null;
      end if;
   end Dec_Ref;
   -------------------
   -- Create_String --
   -------------------
   function Create_String (Content : Text_Type) return String_Type is
   begin
      return Result : constant String_Type := new String_Record'
        (Length    => Content'Length,
         Ref_Count => 1,
         Content   => Content);
   end Create_String;
   -------------------
   -- Create_String --
   -------------------
   function Create_String (Content : Unbounded_Text_Type) return String_Type is
      S : Big_Wide_Wide_String_Access;
      L : Natural;
   begin
      Get_Wide_Wide_String (Content, S, L);
      return Create_String (S.all (1 .. L));
   end Create_String;
   -------------------
   -- Concat_String --
   -------------------
   function Concat_String (Left, Right : String_Type) return String_Type is
   begin
      return Result : constant String_Type :=
        new String_Record (Length => Left.Length + Right.Length)
      do
         Result.Ref_Count := 1;
         Result.Content (1 .. Left.Length) := Left.Content;
         Result.Content (Left.Length + 1 .. Result.Length) := Right.Content;
      end return;
   end Concat_String;
   ----------------
   -- Equivalent --
   ----------------
   function Equivalent (Left, Right : String_Type) return Boolean is
   begin
      return Left.Content = Right.Content;
   end Equivalent;
begin
   No_Big_Integer.Value.Set (0);
end Libadalang.Implementation;